/*
 *= CMU (UNIVERSAL RADIO COMMUNICATION TESTER VISA) =========================
 * LabWindows/CVI 5.0 Instrument Driver
 * Original Release : June, 1999
 *
 * By : ROHDE & SCHWARZ FRANCE
 *      CONTACTS :
 *
 *              Franois Ribiere
 *              Telephone : 00 33 1 41 36 10 83
 *              Fax       : 00 33 1 41 36 11 10
 *              e-Mail    : Francois.Ribiere@rsf.rohde-schwarz.com
 *
 *              Rohde & Schwarz France
 *              Parc Tertiaire de Meudon
 *              9-11, rue Jeanne Braconnier
 *              92366 Meudon-la-Foret Cedex
 *
 * Version : V5.00.8, 06/2012
 *
 *  Modification History:
 *    see ChangeLog
 *===========================================================================*/
 
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include <ctype.h>
#include <stdarg.h>
#include <visa.h>
#include "rscmuk2g.h"
#include <rscmu200.h>

/*****************************************************************************/
/*= DEFINES =================================================================*/
/*****************************************************************************/

/*---------------------------------------------------------------------------*/
/* Instrument driver revision:
/*---------------------------------------------------------------------------*/

#define RSCMU_K2G_VERSION      "5.0.8"  // Instrument driver version string
#define RSCMU_K2G_CREATIONDATE "06/2012"  // Instrument driver creation month/year
#define RSCMU_K2G_CVIVERSION   "9.0"      // Used Labwindows/CVI-version

#define RSCMU_K2G_REVISION "Rev " RSCMU_K2G_VERSION", "RSCMU_K2G_CREATIONDATE", CVI "RSCMU_K2G_CVIVERSION // Instrument driver revision

/*****************************************************************************/
/*= INSTRUMENT-DEPENDENT COMMAND ARRAYS======================================*/
/*****************************************************************************/
static ViString mode_On_Off[] = {"OFF","ON",VI_NULL}; // Common for every
static ViString mode_low_upp[] = {":LOW",":UPP",VI_NULL};
static ViString mode_ScopeMeas [] = {"SCAL","ARR",VI_NULL};
static ViString StrRepetition[] = {"CONT","SING",VI_NULL};
static ViString StrStopCondition[] = {"NONE","SON",VI_NULL};
static ViString StrStepMode[] = {"NONE","STEP",VI_NULL};
//static ViString StrMode[] = {"OFF","SRQ","SOPC","SRSQ",VI_NULL};
static ViString StrStatistics[] = {"ALL","ARIT","MIN","MAX","IVAL",VI_NULL};
static ViString StrModulation[] = {"",":GMSK",":EPSK",VI_NULL};
static ViString StrCommand[] = {"CONF","INIT","ABOR","STOP","CONT","READ","FETC","SAMP","CALC",VI_NULL};
static ViString StrObject[] = {":POW",":MOD",":SPEC",":SPOW",":WPOW",":SPEC:MOD",":SPEC:SWIT",":POW:MPR",":POW:SLOT",
                               ":POW:XSL",":POW:FRAM",":POW:PCL",":MOD:XPER",":MOD:OVER",":MOD:EVM",":MOD:PERR",
                               ":MOD:MERR", ":POW:ABUR",":POW:MSL",":NPOW",":NPOW",":SPECtrum:MSWitching",VI_NULL};
static ViString StrStatMode[] = {"CURR","AVER","MAX","MIN",VI_NULL};
static ViString StrEventReporting[] = {"OFF","SRQ","SOPC","SRSQ",VI_NULL};
static ViString recoveryArr[] = {"NON","TSC",VI_NULL};
static ViString offTemplateArr[] = {"RMAX","RSL",VI_NULL};
static ViString subchannelArr[] = {"SC0","SC1",VI_NULL};
static ViString bandArr[] = {"G450","G480","G700","G850","G900PGSM","G900EGSM","G900RGSM","G1800",
                             "G1900","GGT800","UFDD","U384TDD","U128TDD","C2000",VI_NULL};
static ViString repetitionArr[] = {"CONT","SING","MULT",VI_NULL};
static ViString stopConditionArr[] = {"NONE","SON",VI_NULL};
static ViString stepModeArr[] = {"NONE","STEP",VI_NULL};
static ViString measurementStatusArr[] = {"OFF","RUN","STOP","ERR","STEP","RDY",VI_NULL};
static ViString burstTypeArr[] = {"SCH","FCH","S6D","DALL","FS5D",VI_NULL};
static ViString powerLevelArr[] = {"LLIS","RLEV","PLEV1","PLEV2","PLEV3","PLEV4","PLEV5","PLEV6",VI_NULL};
static ViString searchLevelArr[] = {"LLR","MCR",VI_NULL};
static ViString wstrModeArr[] = {"OFF","MAST","SLAV",VI_NULL};
static ViString negPosArr[] = {"NEG","POS", VI_NULL};
static ViString fillingSigTypeArr[] = {"DBUR","PRBS",VI_NULL};
static ViString epcUplinkContArr[] = {"SACCH","EPCCH",VI_NULL};
static ViString driftStepSizeArr[] = {"0","-1","+1",VI_NULL};
static ViString generationArr[] = {"GSM","WCDM",VI_NULL};
static ViString quadrantArr[] = {"RSCP","ECNO",VI_NULL};
static ViString rxqRdsStatusArr[] = {"INV","PASS","FAIL","TLOW","IMP", VI_NULL};
static ViString enaDisaArr[] = {"DISA","ENAB",VI_NULL};
static ViString confProcArr[] = {"CONF","PROC", VI_NULL};
static ViString codecModeList[] = {"","CM1","CM2","CM3","CM4", VI_NULL};
static ViString netwProcModeArr[] = {"FAST","REL", VI_NULL};
static ViString netwSmsContentArr[] = {"INT","FILE", VI_NULL};
static ViString reloadStatusArr[] = {"FAIL","OK", VI_NULL}; 
static ViString netwCMIPhaseArr[] = {"ODD","EVEN", VI_NULL};   
static ViString netwRateReconfigArr[] = {"RATSCCH","CMM", VI_NULL}; 
static ViString netwTrafModeHandArr[] = {"SOURCE","DEST", VI_NULL};    
static ViString aburstDetectTimeoutArr[] = {"20","60","120", VI_NULL};
static ViString repeatedDownlinkSACCHArr[] = {"DISA","ENAB","SRR", VI_NULL}; 
static ViString rxcLevelModeArr[] = {"LLIS","IFL", VI_NULL}; 
static ViString netwSmsMsgClassArr[] = {"NONE","C0","C1","C2","C3", VI_NULL};
static ViString CTMTextTelephonyArr[] = {"NSUP","SUP", "NAN", VI_NULL}; 

// Structure "RSCMU_GSM_Sig_Globals" is initialized for each Session in an 'init' function               
struct  RSCMU_GSM_Sig_Globals
{
  struct    RSCMU_SESSION_Globals RSCMU_tGlobal;
  struct    RSCMU_HandOver        RSCMU_tHandOver;
  ViInt32   RSCMU_SigChannelConf;
};

// Structure "RSCMU_GSM_NSig_Globals" is initialized for each Session in an 'init' function
struct  RSCMU_GSM_NSig_Globals
{
  struct RSCMU_SESSION_Globals RSCMU_tGlobal;
};

/*****************************************************************************/
/*****************************************************************************/
/*========== Local functions ================================================*/
/*****************************************************************************/
/*****************************************************************************/
ViStatus RSCMU_ScanMod (ViChar[100][100], ViInt32, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*);
ViStatus RSCMU_ScanModXper (ViChar[100][100], ViInt32, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*);
ViStatus RSCMU_ScanModOver (ViChar[100][100], ViInt32, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*);
ViStatus RSCMU_ScanModOverV307 (ViChar[100][100], ViInt32, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*);
ViStatus RSCMU_ScanModOverV423 (ViChar[100][100], ViInt32, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*);
ViStatus RSCMU_ScanModEvm  (ViChar[100][100], ViInt32, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*);
ViStatus RSCMU_ScanModEvmV307  (ViChar[100][100], ViInt32, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*);
ViStatus RSCMU_ScanModEvmV423  (ViChar[100][100], ViInt32, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*);
ViStatus RSCMU_EDGE_ScanModPerr (ViChar[100][100], ViInt32, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*);
ViStatus RSCMU_EDGE_ScanModPerrV307 (ViChar[100][100], ViInt32, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*);
ViStatus RSCMU_ScanModMerr (ViChar[100][100], ViInt32, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*);
ViStatus RSCMU_ScanModMerrV307 (ViChar[100][100], ViInt32, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*);
ViStatus RSCMU_ScanModulation (ViChar[100][100], ViInt32, ViInt32, ViReal64*, ViReal64*, ViReal64*);
ViStatus RSCMU_Sig_ScanPow (ViChar[100][100], ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViReal64*, ViInt32*, ViReal64*);
ViStatus RSCMU_NSig_ScanPow (ViChar[100][100], ViReal64*, ViReal64*, ViReal64*, ViInt32*, ViReal64*);
ViStatus RSCMU_Sig_ScanPowMsl (ViChar[100][100], ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViInt32*);
ViStatus RSCMU_Sig_ScanPowMpr (ViChar[100][100], ViInt32, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViReal64*, ViReal64*, ViReal64*);
ViStatus RSCMU_NSig_ScanPowMpr (ViChar[100][100], ViInt32, ViReal64*, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViReal64*, ViReal64*, ViReal64*);
ViStatus RSCMU_SendCommand (ViSession, ViChar _VI_FAR[], const char *, ...);
ViStatus RSCMU_DisplayGrid (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus RSCMU_ConfLimLineDef (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus RSCMU_ConfSubarrays (ViSession, ViInt32, ViInt32, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus RSCMU_MeasScalarPowerBurst (ViSession, ViInt32, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViChar[]);
ViStatus RSCMU_MeasArrayPowerBurst (ViSession instrSession, ViInt32, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus RSCMU_MeasSubarraysPowerBurst (ViSession, ViInt32, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus RSCMU_CalcPowAreaLimMatc (ViSession, ViInt32, ViInt32, ViInt32*, ViInt32*, ViChar[]);
ViStatus RSCMU_CalcArrPowLimMatc (ViSession, ViInt32, ViInt32, ViInt32*, ViChar[]);
ViStatus RSCMU_CalcScalPowLimMatc (ViSession, ViInt32, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);
ViStatus RSCMU_ConfPowTimeBoff (ViSession, ViInt32, ViReal64, ViChar[]);
ViStatus RSCMU_ConfPowLimLineUpp (ViSession, ViInt32, ViInt32, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus RSCMU_ConfPowLimLineLow (ViSession, ViInt32, ViInt32, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus RSCMU_ConfPowLimLineUppDyn (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus RSCMU_ConfPowLimLineLowDyn (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus RSCMU_ConfPowLimUppDynMod (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus RSCMU_ConfPowLimLowDynMod (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus RSCMU_ConfPowContRepStat (ViSession, ViInt32     Modulation, ViInt32, ViInt32, ViInt32, ViChar[]);
//ViStatus RSCMU_ConfContDef (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus RSCMU_MeasScalarPower (ViSession, ViInt32, ViInt32, ViInt32, ViReal64*, ViChar[]);
ViStatus RSCMU_MeasArrayPower (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus RSCMU_MeasSubarraysPower (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus RSCMU_MeasArrayPowerMsl (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus RSCMU_MeasSubarraysPowerMsl (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus RSCMU_ConfModLimMod (ViSession, ViInt32, ViInt32, ViBoolean, ViChar[]);
ViStatus RSCMU_MeasModXper (ViSession, ViInt32, ViInt32, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus RSCMU_MeasArrModXper (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus RSCMU_MeasSubArrModXper (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus RSCMU_ConfModOempLimLineDef (ViSession, ViBoolean, ViChar[]);
ViStatus RSCMU_ConfModOempLimLineUpp (ViSession, ViInt32, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViInt32, ViChar[]);
ViStatus RSCMU_ConfModOempLimLine95 (ViSession, ViReal64, ViReal64, ViReal64, ViChar[]);
ViStatus RSCMU_MeasModOver (ViSession, ViInt32, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus RSCMU_CalcModOverLimMatc (ViSession, ViInt32, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);
ViStatus RSCMU_MeasModEvm (ViSession, ViInt32, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus RSCMU_CalcModEvmLimMatc (ViSession, ViInt32, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);
ViStatus RSCMU_MeasArrModEvm (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus RSCMU_MeasSubArrModEvm (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus RSCMU_EDGE_MeasModPerr (ViSession, ViInt32, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus RSCMU_EDGE_CalcModPerrLimMatc (ViSession, ViInt32, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);
ViStatus RSCMU_EDGE_MeasArrModPerr (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus RSCMU_EDGE_MeasSubArrModPerr (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus RSCMU_MeasModMerr (ViSession, ViInt32, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus RSCMU_CalcModMerrLimMatc (ViSession, ViInt32, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);
ViStatus RSCMU_MeasArrModMerr (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus RSCMU_MeasSubArrModMerr (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus RSCMU_ConfSpecSwitLimLine (ViSession, ViInt32, ViInt32, ViReal64, ViInt32, ViReal64, ViReal64, ViReal64, ViReal64, ViChar[]);
ViStatus RSCMU_ConfSpecSwitLimLineMod (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus RSCMU_ConfSpecSwitContMpo (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus RSCMU_MeasSpecSwit (ViSession, ViInt32, ViInt32, ViReal64*, ViInt32*, ViChar[]);
ViStatus RSCMU_MeasArrSpecSwit (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus RSCMU_MeasSubArrSpecSwit (ViSession, ViInt32, ViInt32, ViReal64[], ViChar[]);
ViStatus RSCMU_ConfSpecModLimLineRefp (ViSession, ViInt32, ViReal64, ViReal64, ViChar[]);
ViStatus RSCMU_ConfSpecModLimLine (ViSession, ViInt32, ViInt32, ViInt32, ViReal64, ViReal64, ViReal64, ViChar[]);
ViStatus RSCMU_ConfSpecModLimLineMod (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus RSCMU_ConfSpecModContMpo (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus RSCMU_MeasSpecMod (ViSession, ViInt32, ViInt32, ViReal64*, ViInt32*, ViChar[]);
ViStatus RSCMU_MeasNpow (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus RSCMU_ConfFilt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus RSCMU_CheckMinFwVersion (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus RSCMU_ScanSensRfer  (ViChar[100][100], ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32);
ViStatus RSCMU_ScanSensBer   (ViChar[100][100], ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32);
ViStatus RSCMU_ScanSensBbb   (ViChar[100][100], ViInt32, ViPReal64, ViPReal64, ViPInt32, ViPInt32);
ViStatus RSCMU_ScanSensDbler (ViChar[100][100], ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32);
ViStatus RSCMU_ScanSensAibf (ViChar[100][100], ViInt32, ViPReal64, ViPReal64, ViPInt32);
ViStatus RSCMU_ConfSpecSwitContStatMod  (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus RSCMU_ConfSpecSwitSlotCount    (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus RSCMU_MeasBler (ViSession, ViInt32,ViReal64*,ViReal64*,ViReal64*,ViReal64[],ViReal64[],ViReal64*,ViReal64[],ViReal64*,ViReal64*,ViChar[]);
ViStatus RSCMU_ConfSpecSwitAddMeaPoints (ViSession,ViInt32,ViInt32,ViReal64,ViInt32,ViReal64,ViChar[]);
ViStatus RSCMU_FetcSpecSwitAddMeaPoints (ViSession,ViInt32,ViReal64*,ViReal64*,ViReal64*,ViReal64*,ViChar[]);
ViStatus RSCMU_MeasSpecModSwitch (ViSession,ViInt32,ViReal64*,ViInt32*,ViReal64*,ViInt32*,ViChar[]);
ViStatus RSCMU_MeasSpecVarMeaPoint (ViSession,ViChar*,ViInt32,ViInt32,ViReal64,ViChar[]);
ViStatus RSCMU_ConfSub (ViSession,ViChar*,ViInt32,ViReal64,ViInt32,ViChar[]);
ViStatus RSCMU_MeasIqanScalarNSig (ViSession,ViChar *,ViReal64  *,ViReal64  *,ViReal64  *,ViReal64  *,ViChar[]);
ViStatus RSCMU_MeasIqanScalarSig (ViSession,ViChar *,ViReal64  *,ViReal64  *,ViReal64  *,ViReal64  *,ViReal64  *,ViChar[]);
ViStatus RSCMU_MeasSclarDemodBit (ViSession,ViChar *,ViInt32 *,ViChar[]);
ViStatus RSCMU_MeasPeakDemodBit (ViSession ,ViChar *,ViInt32 *,ViInt32 *,ViChar[]);
ViStatus RSCMU_MeasSclarDemodBit (ViSession,ViChar *,ViInt32 *,ViChar[]);
ViStatus RSCMU_MeasPeakDemodBit (ViSession,ViChar *,ViInt32 *,ViInt32 *,ViChar[]);

/*****************************************************************************/
/*****************************************************************************/
/*========== Class: GSM_NonSignalling =======================================*/
/*****************************************************************************/
/*****************************************************************************/
/*
 * ----------------------------------------------------------------------------
 * GSM MEASUREMENTS WITHOUT SIGNALLING (NON SIGNALLING):
 * ----------------------------------------------------------------------------
 * In the Non Signalling mode, a GSM-specific RF signal can be
 * generated and an RF signal with GSM characteristics analyzed.
 * No signalling parameters are transferred and measured.
 * ----------------------------------------------------------------------------
 */
/*
 * ----------------------------------------------------------------------------
 * Initialize
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Initialize
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_Init_GSM_NSig (ViSession   BaseSession,
                                                              ViPSession  instrSession,
                                                              ViUInt32    GSMFunctionGpr,
                                                              ViChar      errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViSession   globalSession = 0;
  ViInt32     secondAddr = 0, comp = 1;
  ViChar      FctGrpBuffer[128]= "", resource[25]="";
  ViBoolean   Flag = RSCMU_OFF;

  struct RSCMU_Base_Globals     *p_globalvarBase;
  struct RSCMU_GSM_NSig_Globals  *p_globalvarGSM;

  // Which Fonction Group does the User want?
  switch (GSMFunctionGpr)
  {
    case RSCMU_GSM400:
      strcpy (FctGrpBuffer, "\"GSM400MS_NSig\"");
      break;
    case RSCMU_GSM850:
      strcpy (FctGrpBuffer, "\"GSM850MS_NSig\"");
      break;
    case RSCMU_GSM900:
      strcpy (FctGrpBuffer, "\"GSM900MS_NSig\"");
      break;
    case RSCMU_GSM1800:
      strcpy (FctGrpBuffer, "\"GSM1800MS_NSig\"");
      break;
    case RSCMU_GSM1900:
      strcpy (FctGrpBuffer, "\"GSM1900MS_NSig\"");
      break;
  }

  // Init the Error Message
  strcpy (errorMessage, "No Error");

  // Get the current options (= Function Group Names) in the CMU.
  if ((RSCMU_Status = viGetAttribute (BaseSession, VI_ATTR_USER_DATA,(ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_K2G_errorMessage (BaseSession, RSCMU_Status, errorMessage);

  // Find the Secondary address for GSM_NSig
  while ((comp != 0) && (secondAddr < 30))
  {
    comp = strncmp (p_globalvarBase->RSCMU_tSecAddr[secondAddr].FctGrp, FctGrpBuffer, strlen(FctGrpBuffer));
    secondAddr++;
    if (comp == 0)  Flag = RSCMU_ON;
  }

  if (Flag == RSCMU_OFF)
    return RSCMU_K2G_errorMessage (*instrSession, RSCMU_ERROR_INVALID_FCT_GRP, errorMessage);

  // Hardware Connection
  comp = strncmp ("GPIB",p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection, 4);

  if (comp == 0)
    sprintf(resource, "%s::%d::%d::INSTR",p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection, p_globalvarBase->RSCMU_tGlobal.RSCMU_primary_address, secondAddr-1);
  else sprintf(resource, "%s::INSTR",p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection);

  // Take default instrument session
  globalSession = p_globalvarBase->RSCMU_tGlobal.RSCMU_RmSessionDefault;


  if ((RSCMU_Status = viOpen (globalSession, resource, VI_NULL, VI_NULL, instrSession)) != 0)
    return RSCMU_K2G_errorMessage (globalSession, RSCMU_Status, errorMessage);

  // Allocate space for "struct RSCMU_SESSION_Globals"
  if ((p_globalvarGSM = (struct RSCMU_GSM_NSig_Globals *)malloc(sizeof(struct RSCMU_GSM_NSig_Globals))) == 0)
    return RSCMU_initCleanUp (globalSession, *instrSession, RSCMU_Status);

  if ((RSCMU_Status = viSetAttribute(*instrSession, VI_ATTR_USER_DATA,(ViAttrState)p_globalvarGSM)) < 0)
    return RSCMU_initCleanUp (globalSession, *instrSession, RSCMU_Status);

  // Set initial values of variables for function Group 'GSM_NonSig' .
  strcpy (p_globalvarGSM->RSCMU_tGlobal.FGrp_Name, FctGrpBuffer);
  strcpy (p_globalvarGSM->RSCMU_tGlobal.RSCMU_SCPIConnection, p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection);
  p_globalvarGSM->RSCMU_tGlobal.RSCMU_primary_address = p_globalvarBase->RSCMU_tGlobal.RSCMU_primary_address;
  p_globalvarGSM->RSCMU_tGlobal.RSCMU_secondary_address = secondAddr - 1;
  p_globalvarGSM->RSCMU_tGlobal.RSCMU_TRACE = p_globalvarBase->RSCMU_tGlobal.RSCMU_TRACE;
  p_globalvarGSM->RSCMU_tGlobal.RSCMU_Stb = p_globalvarBase->RSCMU_tGlobal.RSCMU_Stb;
  p_globalvarGSM->RSCMU_tGlobal.RSCMU_SessionNb = *instrSession;

  // Base CMU FW available
  strcpy (p_globalvarGSM->RSCMU_tGlobal.CmuVersion, p_globalvarBase->RSCMU_tGlobal.CmuVersion);
  p_globalvarGSM->RSCMU_tGlobal.RSCMU_FW_Version = p_globalvarBase->RSCMU_tGlobal.RSCMU_FW_Version;

  if (p_globalvarGSM->RSCMU_tGlobal.RSCMU_TRACE == RSCMU_ON)
    p_globalvarGSM->RSCMU_tGlobal.RSCMU_AddrTargetFile = p_globalvarBase->RSCMU_tGlobal.RSCMU_AddrTargetFile;

  // Record the execution of this Init Function.
  p_globalvarBase->RSCMU_tSecAddr[secondAddr - 1].SessionNb = *instrSession;

  // Timeout changed from 10s to 30 seconds
  if ((RSCMU_Status = viSetAttribute (*instrSession, VI_ATTR_TMO_VALUE, RSCMU_TMO_VALUE)) < 0)
    return RSCMU_Status;

  CHECKRET(RSCMU_setCheckStatus(*instrSession, VI_TRUE));

  return RSCMU_Status;
}


/*
 *-----------------------------------------------------------------------------
 * CONNECTION CONTROL
 * ------------------
 * The functions presented in this section determine the signals analyzed and
 * generated by the CMU, the inputs and outputs used to this end as well as the
 * reference frequency. It corresponds to the settings in the popup menu of the
 * softkey Connect. Control, located to the right of the headline of each main
 * menu.
 * ----------------------------------------------------------------------------
 *      Subsystem RFANanlyzer (Analyzed Input Signals)
 *      This subsystem contains the functions to determine the signals
 *      received and analyzed by the CMU. It corresponds to the panel
 *      Analyzer Settings in the index card Signal in the popup menu
 *      Connect. Control.
 * ----------------------------------------------------------------------------
 */

/*
 * ----------------------------------------------------------------------------
 *    Subsystem LEVel (Input Level)
 *    The subsystem LEVel determines the input level for the currently used
 *    input. It corresponds to the index card Input Level in the popup menu
 *    Group Configuration.
 * ----------------------------------------------------------------------------
 */

/*===========================================================================*/
/* Function: Minimum Trigger Gap
/* Purpose : This function defines a gap time (in us) before a trigger event
/*           can be generated. The setting of a numeric value is effective
/*           for Power or External trigger sources.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_TrigMtg (ViSession instrSession,
                                         ViInt32 triggerGap,
                                         ViChar errorMessage[])
{
   ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setViInt32(instrSession, "TRIG:MTG",
                            triggerGap, 0, 1000,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Set Input Level (Manual/Automatic)
/* Purpose : This function defines the mode for setting the maximum
/*           input.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SensLevMode (ViSession instrSession,
                                                                     ViInt32   inputLevelSetting,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    mode_Setting[]= {"MAN","AUT"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, inputLevelSetting, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set the Input level Manual/PCL
  sprintf (wrtBuf, "SENS:LEV:MODE %s", mode_Setting[inputLevelSetting]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Input level - Maximum
/* Purpose : This function sets the maximum input level. The permissible
/*           value range depends on the RF input used and the external
/*           attenuation set.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SensLevMax (ViSession  instrSession,
                                                                    ViReal64   Level,
                                                                    ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Do not check if the function is correctly used because it depends on the
  // RF input used and the external attenuation set.

  sprintf (wrtBuf, "SENS:LEV:MAX %lf", Level);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Input level - attenuation
/* Purpose : This function sets an attenuation or gain factor for the
/*           RF input signal.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SensLevAtt (ViSession  instrSession,
                                                                    ViInt32    Mode,
                                                                    ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  ViString    StrMode[] = {"NORM","LNO","LDIS"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set the input level attenuation
  sprintf (wrtBuf, "SENS:LEV:ATT %s", StrMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*
 *-----------------------------------------------------------------------------
 *    Subsystem TRIGger (Trigger Mode)
 *    The subsystem TRIGger contains the commands for determination
 *    of the trigger mode. It corresponds to the index card Trigger in
 /*   the popup menu Group Configuration.
 * ----------------------------------------------------------------------------
 */


/*===========================================================================*/
/* Function: Trigger Source
/* Purpose : This function defines the trigger condition. The setting POWer
/*           assumes bursted signals.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_TrigSour (ViSession  instrSession,
                                                                  ViInt32    Source,
                                                                  ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  ViString    StrSource[] = {"FRUN","RFP", "IFP","EXT"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Source, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "TRIG:SOUR %s", StrSource[Source]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set Trigger RF Power
/* Purpose : This Function sets the trigger RF power. It is valid for
/*           trigger Source RFPower. Possible values are Low, Medium and High.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_TrigThrRFPow (ViSession instrSession,
                                                 ViInt32 RFPower,
                                                  ViChar errorMessage[])
{

    ViString    list[] = {"LOW","MED", "HIGH", VI_NULL};
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_setEnum(instrSession, "TRIG:THR:RFP",
                         RFPower, list,
                         RSCMU_ERROR_PARAMETER2));

}

/*===========================================================================*/
/* Function: Set Trigger IF Power
/* Purpose : This Function sets the trigger IF power. It is valid for
/*           trigger Source IFPower. Possible values between -47.0 and 0.0 dB.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_TrigThrIFPow (ViSession instrSession,
                                                ViReal64 IFPower,
                                                  ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_setViReal64(instrSession, "TRIG:THR:IFP",
                             IFPower, -47.0,0.0,
                             RSCMU_ERROR_PARAMETER2));

}

/*===========================================================================*/
/* Function: Set Trigger Slope
/* Purpose : This Function sets the trigger slope. It is enabled for
/*           trigger Source RFPower and IFPower only.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_TrigSlop (ViSession instrSession,
                                             ViInt32 slope,
                                              ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_setEnum(instrSession, "TRIG:SLOP",
                         slope, negPosArr,
                         RSCMU_ERROR_PARAMETER2));
}


/*===========================================================================*/
/* Function: Set Trigger External Source
/* Purpose : This Function sets the trigger extrenal source.
/*           Possible values are Pin 6, Pin 7 and Pin 8
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_TrigSourExt (ViSession instrSession,
                                                ViInt32 extSource,
                                                 ViChar errorMessage[])
{
    ViString    list[] = {"PIN6","PIN7", "PIN8", VI_NULL};
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_setEnum(instrSession, "TRIG:SOUR:EXT",
                         extSource, list,
                         RSCMU_ERROR_PARAMETER2));
}


/*===========================================================================*/
/*
/*                  Only for compatibility
/*
/* Function: Trigger Threshold
/* Purpose : This function sets the trigger level, i.e. the signal level at
/*           which the measurement is triggered. The function is enabled for
/*           trigger source RFPower and IFPower only.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_TrigThr (ViSession  instrSession,
                                                                 ViInt32    TriggerThreshold,
                                                                 ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrTriggerThreshold[] = {"LOW","MED","HIGH"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TriggerThreshold, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set the trigger threshold:
  sprintf (wrtBuf, "TRIG:THR %s", StrTriggerThreshold[TriggerThreshold]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}


/*===========================================================================*/
/* Function: RF Channel (Number)
/* Purpose : This function determines the channel number of the RF signal
/*           analyzed. The assignment of channel numbers meets the GSM
/*           specification for the uplink (signal direction from mobile to
/*           CMU).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_RfanChan (ViSession  instrSession,
                                                                  ViInt32    ChannelNumber,
                                                                  ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarSession;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used (depends on the current Fonction Group):
  if (strncmp ("\"GSM400MS_NSig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ChannelNumber, 259, 340, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  if (strncmp ("\"GSM850MS_NSig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ChannelNumber, 128, 251, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM900MS_NSig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    if ((RSCMU_invalidViInt32Range (ChannelNumber, 0, 124)) && (RSCMU_invalidViInt32Range (ChannelNumber, 955, 1023)))
      return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1800MS_NSig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ChannelNumber, 512, 885, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1900MS_NSig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ChannelNumber, 512, 810, RSCMU_ERROR_PARAMETER2, errorMessage);
  }

  // Set the channel number of the RF signal analysed:
  sprintf (wrtBuf, "RFAN:CHAN %d CH", ChannelNumber);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: RF Channel (Frequency)
/* Purpose : This function determines the frequency of the RF signal
/*           analyzed. The assignment of frequencies meets the GSM
/*           specification for the uplink (signal direction from mobile to
/*           CMU).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_RfanFreq (ViSession  instrSession,
                                                                  ViReal64   Frequency,
                                                                  ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, Frequency, 0.2, 2700.0, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set the frequency of the RF signal generated:
  sprintf (wrtBuf, "RFAN:CHAN %lf MHZ", Frequency);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Frequency Offset
/* Purpose : This command sets an offset shifting the channel frequency
/*           set with the previous function. The offset frequency must be
/*           in multiples of 1 Hz.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_RfanFreqOffs (ViSession  instrSession,
                                                                      ViReal64   FreqOffset,
                                                                      ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, FreqOffset, -100.0, +100.0, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf, "RFAN:FREQ:OFFS %lf KHZ", FreqOffset);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;
  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Training Sequence
/* Purpose : This function determines the training sequence of the signal
/*           analyzed by the CMU. If no training sequence is determined
/*           (OFF), the CMU will measure all signals.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_RfanTseq (ViSession  instrSession,
                                                                  ViInt32    TrainingSequence,
                                                                  ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrTrainingSequence[] = {"OFF","GSM0","GSM1","GSM2","GSM3","GSM4","GSM5","GSM6","GSM7", "DUMM", "ANY"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TrainingSequence, 0, 10, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "RFAN:TSEQ %s", StrTrainingSequence[TrainingSequence]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Template PCL
/* Purpose : This function determines the template PCL which is used for
/*           dynamic limit line correction in the POWer measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfRfanTpcl (ViSession  instrSession,
                                                                      ViInt32    TemplatePCL,
                                                                      ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TemplatePCL, 0, 31, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:RFAN:TPCL %d", TemplatePCL);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Modulation
/* Purpose : This function selects one of the supported modulation schemes.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfRfan (ViSession  instrSession,
                                                                  ViInt32    Modulation,
                                                                  ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrRfanMod[] = {"","GMSK","EPSK"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Modulation, 1, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "RFAN:MOD %s", StrRfanMod[Modulation]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Trigger Slot Offset
/* Purpose : This function defines a delay time between the trigger time and
/*           the measured timeslot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfRfanMconTsoff (ViSession instrSession,
                                                                           ViInt32   SlotNr,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, SlotNr, 0, 7, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:RFAN:MCON:TSOF %d", SlotNr);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*
 *-----------------------------------------------------------------------------
 *  GENERAL CONTROL OF RF GENERATOR
 * --------------------------------
 *  This subsystem contains the functions for controlling the
 *  internal RF generator.
 *  It corresponds to the softkey RF Generator in the index card
 *  Signal in the popup menu Connect. Control and the measurement
 *  menu Analyzer/Generator.
 * ----------------------------------------------------------------------------
 *    GENERATOR CONTROL
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start RF generator
/* Purpose : This function starts or stop the RF Generator.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_InitRfg (ViSession  instrSession,
                                                                 ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU_Status = RSCMU_Query (instrSession, "INIT:RFG", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Switch off RF generator
/* Purpose : This function stops the RF Generator.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborRfg (ViSession  instrSession,
                                                                 ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU_Status = RSCMU_Query (instrSession, "ABORT:RFG", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Generator Status
/* Purpose : This function returns the current generator status.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcRfgStat (ViSession instrSession,
                                                                     ViPInt32  RFGeneratorStatus,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";

  // Fetch the generator status:
  if ((RSCMU_Status = RSCMU_Query (instrSession, "FETC:RFG:STAT?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Get the RF generator status value:
  *RFGeneratorStatus = RSCMU_GetGenStatVal (rdBuf);

  if (*RFGeneratorStatus < 0)
    return RSCMU_ERROR_GEN_STAT_UNKNOWN;

  return RSCMU_Status;
}

/*
 * ----------------------------------------------------------------------------
 *    Generator Level - Subsystem RFGenerator:LEVel
 *    This subsystem determines the level of the generated RF signals. It
 *    corresponds to the input field RF Level of the panel RF Generator in the
 *    index card Signal in the popup menu Connect. Control.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Level in the used timeslot
/* Purpose : This function sets the RF generator level in the used
/*           timeslot. The permissible value range depends on the used
/*           RF output of the CMU and the external attenuation set.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgLevUtim (ViSession  instrSession,
                                                                        ViReal64   RFLevelUsed,
                                                                        ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Do not check if the function is correctly used because it depends on the
  // RF input used and the external attenuation set.

  // Set absolute level in used timeslot:
  sprintf (wrtBuf, "SOUR:RFG:LEV:UTIM %lf", RFLevelUsed);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Level in the unused timeslots
/* Purpose : This function sets the RF generator level in the unused
/*           timeslots relative to the level in the used timeslot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgLevUnt (ViSession  instrSession,
                                                                       ViReal64   RFLevelUnused,
                                                                       ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Do not check if the function is correctly used because it depends on the
  // RF input used and the external attenuation set.

  // Set relative level for unused timeslots:
  sprintf (wrtBuf, "SOUR:RFG:LEV:UNT %lf", RFLevelUnused);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*
 *-----------------------------------------------------------------------------
 *    RF CHANNEL
 *    This subsystem contains the functions for determining the
 *    frequency of the generated RF signals.
 *    It corresponds to the softkeys RF Channel and Freq. Offset of
 *    the panel RF Generator in the index card Signal in the popup
 *    menu Connect. Control.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: RF Frequency Offset
/* Purpose : This function specifies the frequency offset for the CMU
/*           signals in the selected RF Channel.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgFmDev (ViSession  instrSession,
                                                                      ViReal64   FrequencyOffSet,
                                                                      ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, FrequencyOffSet, -100.0, +100.0, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf, "SOUR:RFG:FM:DEV %lf KHZ", FrequencyOffSet);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: RF Channel (Number)
/* Purpose : This function determines the channel number of the RF signal
/*           generated. The assignment of channel numbers meets the GSM
/*           specification for the downlink (signal direction from CMU to
/*           mobile).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgFreqChan (ViSession  instrSession,
                                                                         ViInt32    ChannelNumber,
                                                                         ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  struct RSCMU_SESSION_Globals  *p_globalvarSession;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used (depends on the current Fonction Group):
  if (strncmp ("\"GSM400MS_NSig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ChannelNumber, 259, 340, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM850MS_NSig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ChannelNumber, 128, 251, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM900MS_NSig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    if ((RSCMU_invalidViInt32Range (ChannelNumber, 0, 124)) && (RSCMU_invalidViInt32Range (ChannelNumber, 955, 1023)))
      return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1800MS_NSig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ChannelNumber, 512, 885, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1900MS_NSig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ChannelNumber, 512, 810, RSCMU_ERROR_PARAMETER2, errorMessage);
  }

  // Set the channel number of the RF signal generated:
  sprintf (wrtBuf, "SOUR:RFG:FREQ:CHAN %d CH", ChannelNumber);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: RF Channel (Frequency)
/* Purpose : This function determines the frequency of the RF signal
/*           generated. The assignment of frequencies meets the GSM
/*           specification for the downlink (signal direction from CMU to
/*           mobile).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgFreq (ViSession  instrSession,
                                                                     ViReal64   Frequency,
                                                                     ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, Frequency, 0.2, 2700.0, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set the frequency of the RF signal generated:
  sprintf (wrtBuf, "SOUR:RFG:FREQ:CHAN %lf MHZ", Frequency);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*
 *-----------------------------------------------------------------------------
 *    RF GENERATOR MODULATION
 *    -----------------------
 *    This subsystem contains the functions for determination of an
 *    information which is modulated on the RF signal generated by the
 *    CMU and the signal shape.
 *    It corresponds to the panel Generator Modulation in the index
 *    card Signal in the popup menu Connect. Control.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Selection of bit modulation
/* Purpose : This function selects a bit sequence used to modulate the
/*           signal generated by the CMU.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfRfgModBitSel (ViSession  instrSession,
                                                                          ViInt32    Selection,
                                                                          ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  ViString    StrSelection[] = {"OFF","PRBS","DUMM","ALL0","EALL0","EPRBS"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Selection, 0, 5, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:RFG:MOD:BIT:SEL %s", StrSelection[Selection]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Selection of training sequence
/* Purpose : This function selects the training sequence used to modulate
/*           the signal generated by the CMU.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfRfgModTseqSel (ViSession  instrSession,
                                                                           ViInt32    Selection,
                                                                           ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrSelection[] = {"ALL","GSM0","GSM1","GSM2","GSM3","GSM4","GSM5","GSM6","GSM7", "DUMM"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Selection, 0, 9, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:RFG:MOD:TSEQ:SEL %s", StrSelection[Selection]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Signal shape
/* Purpose : This function  determines whether the the CMU generates a
/*           bursted or a contiunuous RF carrier signal.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfRfgModTran (ViSession  instrSession,
                                                                        ViInt32    SignalShape,
                                                                        ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrSignalShape[] = {"BURS","CONT"};

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean)(ViBoolean) SignalShape, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:RFG:MOD:TRAN %s", StrSignalShape[SignalShape]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}


/*===========================================================================*/
/*
/*              Generator AuxTX (CMU-B95 is required!)
/*
/*===========================================================================*/

/*===========================================================================*/
/* Function: Set AuxTx level
/* Purpose : This function sets the AuxTx generator level
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AuxTXGenLevel (ViSession instrSession,
                                                ViReal64 auxTxlevel,
                                                ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  RETMSG(RSCMU_setViReal64(instrSession, "SOURce:RFGenerator:AUXTx:LEVel",
                             auxTxlevel, -122.0, -60.0,
                             RSCMU_ERROR_PARAMETER2));

}

/*===========================================================================*/
/* Function: Set AuxTx Frequency
/* Purpose : This function defines the AuxTx generator output frequency.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AuxTXGenFreq (ViSession instrSession,
                                               ViReal64  auxTxfrequency,
                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  if (   (auxTxfrequency <  350.0)
     || ((auxTxfrequency >  550.0)&&(auxTxfrequency <  700.0))
     || ((auxTxfrequency > 1100.0)&&(auxTxfrequency < 1400.0))
     ||  (auxTxfrequency > 2200.0)
     )
     return RSCMU_Base_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);

  RETMSG(RSCMU_setViReal64(instrSession,"SOURce:RFGenerator:AUXTx:FREQuency",
                                 auxTxfrequency,//*1.0E+6,
                                 350.00/* E+6 */, 2200.00E+6,
                                 RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Start AuxTx Generator
/* Purpose : Starts AuxTx Generator and reserves ressources
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AuxTXGenInit (ViSession instrSession,
                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  RETMSG(RSCMU_sendCmd(instrSession, "INITiate:RFGenerator:AUXTx"));
}

/*===========================================================================*/
/* Function: Switch Off AuxTx Generator
/* Purpose : Switches off AuxTx Generator and releases resources
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AuxTXGenAbort (ViSession instrSession,
                                                ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  RETMSG(RSCMU_sendCmd(instrSession, "ABORt:RFGenerator:AUXTx"));
}

/*===========================================================================*/
/* Function: AuxTx Generator Status
/* Purpose : This function returns the current AuxTx generator status.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AuxTXGenFetchStat (ViSession instrSession,
                                                    ViInt32  *auxTxGenStatus,
                                                    ViChar    errorMessage[])
{
  ViString    list[] = {"OFF","RUN","ERR", VI_NULL};
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  CHECKERR(RSCMU_getEnum(instrSession, "FETCh:RFGenerator:AUXTx:STATus?",
                           auxTxGenStatus, list,
                           RSCMU_ERROR_PARAMETER2));

  if (RSCMU_Status == RSCMU_ERROR_INTERPRETING_RESPONSE)
      RSCMU_Status = RSCMU_ERROR_GEN_STAT_UNKNOWN;

  return RSCMU_Base_errorMessage(instrSession, RSCMU_Status, errorMessage);
}


/*===========================================================================*/
/* Function: Selection of output connector for the generated AuxTx Signal
/* Purpose : This function determines the output connector to be used for the
/*           generated Aux Tx signal. The bidirectional connectors RF 1 and RF 2
/*           can be used both as input and output connectors in the same measurement.
/*           Only one input and one output may be active simultaneously, so the
/*           previous one is automatically deactivated on switch-over.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AuxTXOutp (ViSession  instrSession,
                                            ViInt32    State,
                                            ViChar     errorMessage[])
{
  ViString    StrState[] = {"RF1","RF2", VI_NULL};
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  RETMSG(RSCMU_setEnum(instrSession, "OUTPut:AUXTx:STATe", State, StrState,
                         RSCMU_ERROR_PARAMETER2));
}
/*===========================================================================*/
/* Function: External attenuation at the output for the generated AuxTx Signal
/* Purpose : This command assigns an external attenuation value to the
/*           outputs of the instrument (RF 1, RF 2, RF 3 OUT).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AuxTXCorrOut (ViSession  instrSession,
                                               ViInt32    OutputNr,
                                               ViReal64   Absorption,
                                               ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, OutputNr, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  sprintf(wrtBuf, "SOURce:CORRection:LOSS:OUTPut%d:AUXTx:MAGNitude", OutputNr+1);
  RETMSG(RSCMU_setViReal64(instrSession, wrtBuf,
                           Absorption, -50.0, 50.0,
                           RSCMU_ERROR_PARAMETER3));
}

/*===========================================================================*/
/* AuxTX Overange Level (only CMU-B96)
/* This function defines the Aux Tx overange level at Connector Out3
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgOverLevAuxTx (ViSession instrSession,
                                                      ViInt32 ovrlevel,
                                                      ViBoolean enable,
                                                      ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    // Check if function is correctly used:
    CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) enable, RSCMU_ERROR_PARAMETER3, errorMessage);

    switch (enable)
    {
      case RSCMU_OFF:
        CHECKRETMSG (RSCMU_sendCmd (instrSession, "SOURce:RFGenerator:AUXTx:OLEVel OFF"));
        break;
      case RSCMU_ON:
        CHECKRETMSG(RSCMU_setViInt32(instrSession, "SOURce:RFGenerator:AUXTx:OLEVel",
                                 ovrlevel, -100, 13,
                                 RSCMU_ERROR_PARAMETER2));
        break;
    }

    return RSCMU_Status;

}

/* ----------------------------------------------------------------------------
 *      INPUT AND OUTPUT CONNECTORS
 *      The subsystem IOConnector contains the commands for
 *      configuration of the input and output connectors.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Selection of input connector
/* Purpose : This command determines the connector to be used for incoming
/*           RF signals. The bidirectional connectors RF 1 and RF 2 can be
/*           used both as input and output connectors in the very same
/*           measurement (see OUTPut[:STATe]).
/*           Only one input and one output may be active at a time, which
/*           is why the cur-rently active one is automatically deactivated
/*           on switchover.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_Inp (ViSession  instrSession,
                                                             ViInt32    State,
                                                             ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrState[] = {"RF1","RF2","RF4"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, State, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "INP:STAT %s", StrState[State]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Selection of output connector
/* Purpose : This function determines the connector to be used for
/*           outgoing RF signals. The bidirectional connectors RF 1 and
/*           RF 2 can be used both as input and output connectors in the
/*           very same measurement.
/*           Only one input and one output may be active at a time, which
/*           is why the cur-rently active one is automatically deactivated
/*           on switchover.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_Outp (ViSession  instrSession,
                                                              ViInt32    State,
                                                              ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrState[] = {"RF1","RF2","RF3"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, State, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "OUTP:STAT %s", StrState[State]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: External attenuation at the input
/* Purpose : This command assigns an external attenuation value to the
/*           inputs of the instrument (RF 1, RF 2, RF 4 IN).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SensCorrLossInp (ViSession  instrSession,
                                                                         ViInt32    InputNr,
                                                                         ViReal64   Absorption,
                                                                         ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, InputNr, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);
  if((InputNr == RSCMU_INPUT_RF1) || (InputNr == RSCMU_INPUT_RF2))
  {
    CHECK_VI_REAL64_RANGE(instrSession, Absorption, RSCMU_ATT_MIN, RSCMU_ATT_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  }
  else
  {
    CHECK_VI_REAL64_RANGE(instrSession, Absorption, -90, 90, RSCMU_ERROR_PARAMETER3, errorMessage);
  }

  switch (InputNr)
  {
    case RSCMU_INPUT_RF1:
      sprintf (wrtBuf, "SENS:CORR:LOSS:INP1 %lf", Absorption);
      break;
    case RSCMU_INPUT_RF2:
      sprintf (wrtBuf, "SENS:CORR:LOSS:INP2 %lf", Absorption);
      break;
    case RSCMU_INPUT_RF4:
      sprintf (wrtBuf, "SENS:CORR:LOSS:INP4 %lf", Absorption);
      break;
  }
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Selection of Aux TX Overange Level output connector
/* Purpose : This function determines the connector to be used for
/*           outgoing RF signals. The bidirectional connectors RF 1 and
/*           RF 2 can be used both as input and output connectors in the
/*           very same measurement.
/*           Only one input and one output may be active at a time, which
/*           is why the cur-rently active one is automatically deactivated
/*           on switchover.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AuxTXOvrLv (ViSession  instrSession,
                                            ViInt32    State,
                                            ViChar     errorMessage[])
{
    ViString    list[] = {"RF1","RF2","RF3",VI_NULL};

    RETMSG(RSCMU_setEnum(instrSession, "OUTPut:AUXTx:OLEVel", State, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: External attenuation at the Aux TX Overange Level output connector
/* Purpose : This command assigns an external attenuation value to the
/*           outputs of the instrument (RF 1, RF 2, RF 4 IN).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AuxTXCorrOvrLv (ViSession  instrSession,
                                                 ViInt32    connector,
                                                 ViReal64   Absorption,
                                                 ViChar     errorMessage[])
{
    ViString    list[]={"OUTPut1", "OUTPut2", "OUTPut3", VI_NULL};
    ViStatus    RSCMU_Status;
    GET_WRT_BUF(instrSession);

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, connector, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "SENSe:CORRection:LOSS:%s:AUXTx:OLEVel", list[connector]);

    RETMSG(RSCMU_setViReal64(instrSession, wrtBuf,
                             Absorption, RSCMU_ATT_MIN, RSCMU_ATT_MAX,
                             RSCMU_ERROR_PARAMETER3));
}

/*===========================================================================*/
/* Function: External attenuation at the output
/* Purpose : This command assigns an external attenuation value to the
/*           outputs of the instrument (RF 1, RF 2, RF 3 OUT).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourCorrLossOutp (ViSession  instrSession,
                                                                          ViInt32    OutputNr,
                                                                          ViReal64   Absorption,
                                                                          ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, OutputNr, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);
  if((OutputNr == RSCMU_OUTPUT_RF1) || (OutputNr == RSCMU_OUTPUT_RF2))
  {
    CHECK_VI_REAL64_RANGE(instrSession, Absorption, RSCMU_ATT_MIN, RSCMU_ATT_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  }
  else
  {
    CHECK_VI_REAL64_RANGE(instrSession, Absorption, -90, 90, RSCMU_ERROR_PARAMETER3, errorMessage);
  }

  switch (OutputNr)
  {
    case RSCMU_OUTPUT_RF1:
      sprintf (wrtBuf, "SOUR:CORR:LOSS:OUTP1 %lf", Absorption);
      break;
    case RSCMU_OUTPUT_RF2:
      sprintf (wrtBuf, "SOUR:CORR:LOSS:OUTP2 %lf", Absorption);
      break;
    case RSCMU_OUTPUT_RF3:
      sprintf (wrtBuf, "SOUR:CORR:LOSS:OUTP3 %lf", Absorption);
      break;
  }
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Speech Encoder
/* Purpose : This command determines the input source that feeds the CMU speech
/*           encoder (option CMU-B52).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_RoutSpenInp (ViSession  instrSession,
                                                                     ViInt32    SpeechEncoder,
                                                                     ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrSpen[] = {"GEN","HAND"};

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) SpeechEncoder, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "ROUT:SPEN:INP %s", StrSpen[SpeechEncoder]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Speech Decoder
/* Purpose : This command routes the CMU speech decoder output (option CMU-B52).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_RoutSpdOutp (ViSession instrSession,
                                                                     ViInt32   SpeechDecoder,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrSpd[] = {"ANAL","HAND","ANA2","ABOT"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, SpeechDecoder, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "ROUT:SPD:OUTP %s", StrSpd[SpeechDecoder]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*
 *-----------------------------------------------------------------------------
 * SYNCHRONISATION
 * ------------------
 * Subsystem REFerence (Synchronization)
 * The subsystem REFerence contains the commands for setting a system clock
 * specific to the network. This frquency is set in the index card Synch. in
 * the popup menu Connect. Control.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Switching on/off and setting the system clock
/* Purpose : This commands switches the system clock specific to the
/*           network at the REF OUT 2 connector on or off, and determines
/*           the system clock frequency applied to REF OUT 2.
/*           The frequency entered is internally rounded to one of a
/*           discrete values defined in the operating manual.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourDmCloc (ViSession  instrSession,
                                                                    ViInt32    Mode,
                                                                    ViReal64   Frequency,
                                                                    ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"OFF","ON"};

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) Mode, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, Frequency, RSCMU_REF_FRQ_MIN, RSCMU_REF_FRQ_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  // Setting the system clock
  sprintf (wrtBuf, "SOUR:DM:CLOC:FREQ %lf", Frequency);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Switching the system clock ON or OFF
  sprintf (wrtBuf, "SOUR:DM:CLOC:STAT %s", StrMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT WPOWER
 *    The subsystem WPOWer contains the commands for measuring the
 *    power of the signal transmitted by the mobile phone.
 *    it's corresponds to the softkey Power of the index card Signal
 *    in the menu group Connect Control.
 * ----------------------------------------------------------------------------
/*===========================================================================*/
/* Function: Init Measurements
/* Purpose : This function start the measurement,
/*           setting it to the status beyond.
/*           RUN        Start measurement without waiting
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_InitSpow (ViSession instrSession, ViChar errorMessage[])
{
  return RSCMU_GSM_Sig_InitSpow (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Abort Measurements
/* Purpose : This function abort running signal-power measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborSpow (ViSession instrSession, ViChar errorMessage[])
{
  return RSCMU_GSM_Sig_AborSpow (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Stop Measurements
/* Purpose : This function stop measurement after current statistic cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopSpow (ViSession instrSession, ViChar errorMessage[])
{
  return RSCMU_GSM_Sig_StopSpow (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Run Next Measurement Step
/* Purpose : This function runs next signal-power measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContSpow (ViSession instrSession, ViChar errorMessage[])
{
  return RSCMU_GSM_Sig_ContSpow (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpowErep (ViSession  instrSession,
                                                                      ViInt32    Mode,
                                                                      ViChar errorMessage[])
{
  return RSCMU_GSM_Sig_ConfSpowErep (instrSession, Mode, errorMessage);
}

/*===========================================================================*/
/* Function: Wideband Power Measurement Status
/* Purpose : This function returns the status of the current wideband power
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSpowStat (ViSession  instrSession,
                                                                      ViInt32   *MeasurementStatus,
                                                                      ViInt32   *CountingNo,
                                                                      ViChar     errorMessage[])
{
  return RSCMU_GSM_Sig_FetcSpowStat (instrSession, MeasurementStatus, CountingNo, errorMessage);
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpowContRep (ViSession  instrSession,
                                                                          ViInt32    Repetition,
                                                                          ViInt32    StopCondition,
                                                                          ViInt32    StepMode,
                                                                          ViChar     errorMessage[])
{
  return RSCMU_GSM_Sig_ConfSpowContRep (instrSession, Repetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Meas. Peak Burst Power
/* Purpose : This function starts the measurement of the maximum burst
/*           power of the signals sent by the mobile (peak burst power)
/*           and outputs the result.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSpow (ViSession  instrSession,
                                                                  ViReal64  *MaxBurstPower,
                                                                  ViChar     errorMessage[])
{
  return RSCMU_GSM_Sig_ReadSpow (instrSession, MaxBurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Meas. Peak Burst Power
/* Purpose : This function starts the measurement of the maximum burst
/*           power of the signals sent by the mobile (peak burst power)
/*           and outputs the result.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSpow (ViSession  instrSession,
                                                                  ViReal64  *MaxBurstPower,
                                                                  ViChar     errorMessage[])
{
  return RSCMU_GSM_Sig_FetcSpow (instrSession, MaxBurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Meas. Peak Burst Power
/* Purpose : This function starts the measurement of the maximum burst
/*           power of the signals sent by the mobile (peak burst power)
/*           and outputs the result.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSpow (ViSession  instrSession,
                                                                  ViReal64  *MaxBurstPower,
                                                                  ViChar     errorMessage[])
{
  return RSCMU_GSM_Sig_SampSpow (instrSession, MaxBurstPower, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    STATISTICS
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpowContRepStat (ViSession  instrSession,
                                                                             ViInt32    NbRepetition,
                                                                             ViInt32    StopCondition,
                                                                             ViInt32    StepMode,
                                                                             ViChar     errorMessage[])
{
  return RSCMU_GSM_Sig_ConfSpowContRepStat (instrSession, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT NARROW-BAND POWER
 *
 * The subsystem NPOWer measures the power of the signal transmitted by the
 * mobile phone using the RF analyzer configuration of the POWer measurement.
 * Compared to WPOWer, the NPOWer measurement uses a narrow-band (500 kHz Gauss)
 * filter. The narrow-band NPOWer measurement yields the average, maximum and
 * minimum burst power of the current burst (display mode Current) and of the
 * averaged measurement curve (display mode Average).
 * The entire measurement curves (arrays) are not available, and no limit check
 * is performed. NPOWer is a quick and precise alternative to the WPOWer or
 * POWer measurements if only scalar results are needed.
 * Note: A Free Run trigger (TRIGger[:SEQuence]:SOURce FRUN) should be avoided
 * because it delays the NPOWer measurement.
 * ----------------------------------------------------------------------------
 *      MEASUREMENT CONTROL
 *      This subsystem contains the functions for general control of the
 *      narrow-band power measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start new measurement
/* Purpose : This function starts the narrow-band power measurement, setting it
/*           to the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_InitNpow (ViSession instrSession,
                                                                  ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_NPOW, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Abort running measurement and switch off
/* Purpose : This function stops the narrow-band power measurement, setting it
/*           to the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborNpow (ViSession instrSession,
                                                                  ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_NPOW, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: stop measurement after current statistic cycle
/* Purpose : This function stops the narrow-band power measurement, setting it
/*           to the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopNpow (ViSession instrSession,
                                                                  ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_NPOW, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Next Measurement Step
/* Purpose : This function continues the narrow-band power measurement, setting
/*           it to the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContNpow (ViSession instrSession,
                                                                  ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_NPOW, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the measurement
/*           is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfNpowErep (ViSession  instrSession,
                                                                      ViInt32    Report,
                                                                      ViChar     errorMessage[])
{
  return RSCMU_ConfReporting (instrSession, RSCMU_NPOW, RSCMU_NONE, Report, errorMessage);
}

/*===========================================================================*/
/* Function: Power/t Measurement Status
/* Purpose : This function returns the status of the current narrow-band power
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcNpowStat (ViSession  instrSession,
                                                                      ViInt32   *MeasurementStatus,
                                                                      ViInt32   *CountingNo,
                                                                      ViInt32   *StatisticNo,
                                                                      ViChar     errorMessage[])
{
  return RSCMU_FetcStatus (instrSession, RSCMU_NPOW, RSCMU_GMSK, MeasurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of Measurement
/* Purpose : This function selects the type of measured values and determines
/*           the number of bursts forming one statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfNpowCont (ViSession instrSession,
                                                                      ViInt32   NbBurst,
                                                                      ViInt32   repetition,
                                                                      ViInt32   NbRepetition,
                                                                      ViInt32   StopCondition,
                                                                      ViInt32   StepMode,
                                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version Manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the calling function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, 1, 1000, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, repetition, 0, 2, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, 1, 10000, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) StopCondition, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) StepMode, RSCMU_ERROR_PARAMETER6, errorMessage);

  if (repetition != RSCMU_MULTIPLE)
    sprintf(wrtBuf, "CONF:NPOW:CONT %d,%s,%s,%s", NbBurst
                                                , StrRepetition[repetition]
                                                , StrStopCondition[StopCondition]
                                                , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONF:NPOW:CONT %d,%d,%s,%s", NbBurst
                                                , NbRepetition
                                                , StrStopCondition[StopCondition]
                                                , StrStepMode[StepMode]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfNpowContRep (ViSession  instrSession,
                                                                         ViInt32    Repetition,
                                                                         ViInt32    StopCondition,
                                                                         ViInt32    StepMode,
                                                                         ViChar     errorMessage[])
{
  return RSCMU_ConfControlRep (instrSession, RSCMU_NPOW, RSCMU_NONE, Repetition, StopCondition, StepMode, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Statistic Count
/* Purpose : This function selects the type of measured values and determines
/*           the number of bursts forming one statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfNpowContStat (ViSession instrSession,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version Manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the calling function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, 1, 1000, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf, "CONF:NPOW:CONT:STAT %d", NbBurst);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfNpowContRepStat (ViSession instrSession,
                                                                             ViInt32   NbRepetition,
                                                                             ViInt32   StopCondition,
                                                                             ViInt32   StepMode,
                                                                             ViChar    errorMessage[])
{
  return RSCMU_ConfContRepStat (instrSession, RSCMU_NPOW, RSCMU_NONE, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      RESULTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Read Scalar
/* Purpose : This function starts the NPOWer measurement and returns the
/*           results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadNpow (ViSession  instrSession,
                                                                  ViReal64  *AvgPowCurr,
                                                                  ViReal64  *MinPowCurr,
                                                                  ViReal64  *MaxPowCurr,
                                                                  ViReal64  *AvgPowAvg,
                                                                  ViReal64  *MinPowAvg,
                                                                  ViReal64  *MaxPowAvg,
                                                                  ViChar     errorMessage[])
{
  return RSCMU_MeasNpow (instrSession, RSCMU_COMMAND_READ, AvgPowCurr, MinPowCurr, MaxPowCurr,
    AvgPowAvg, MinPowAvg, MaxPowAvg, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Scalar
/* Purpose : This function reads out measurements (unsynchronized) and returns
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcNpow (ViSession  instrSession,
                                                                  ViReal64  *AvgPowCurr,
                                                                  ViReal64  *MinPowCurr,
                                                                  ViReal64  *MaxPowCurr,
                                                                  ViReal64  *AvgPowAvg,
                                                                  ViReal64  *MinPowAvg,
                                                                  ViReal64  *MaxPowAvg,
                                                                  ViChar     errorMessage[])
{
  return RSCMU_MeasNpow (instrSession, RSCMU_COMMAND_FETC, AvgPowCurr, MinPowCurr, MaxPowCurr,
    AvgPowAvg, MinPowAvg, MaxPowAvg, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Scalar
/* Purpose : This function reads out measurements (synchronized) and returns
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampNpow (ViSession  instrSession,
                                                                  ViReal64  *AvgPowCurr,
                                                                  ViReal64  *MinPowCurr,
                                                                  ViReal64  *MaxPowCurr,
                                                                  ViReal64  *AvgPowAvg,
                                                                  ViReal64  *MinPowAvg,
                                                                  ViReal64  *MaxPowAvg,
                                                                  ViChar     errorMessage[])
{
  return RSCMU_MeasNpow (instrSession, RSCMU_COMMAND_SAMP, AvgPowCurr, MinPowCurr, MaxPowCurr,
    AvgPowAvg, MinPowAvg, MaxPowAvg, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT POWER/T
 *    The subsystem POWer contains the commands for measuring the
 *    signal power.
 *    This subsystem corresponds to the measurement menu Power vs.
 *    Time and the associated popup menu Power vs Time Configuration.
 * ----------------------------------------------------------------------------
 *      MEASUREMENT CONTROL
 *      This subsystem contains the functions for general control of the
 *      power measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start new measurement
/* Purpose : This function starts the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_InitPow (ViSession  instrSession,
                                                                 ViChar     errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_POW, RSCMU_GMSK, errorMessage);
}

/*===========================================================================*/
/* Function: Abort running measurement and switch off
/* Purpose : This function stops the power measurement, setting it to
/*           the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborPow (ViSession  instrSession,
                                                                 ViChar     errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_POW, RSCMU_GMSK, errorMessage);
}

/*===========================================================================*/
/* Function: stop measurement after current statistic cycle
/* Purpose : This function stops the power measurement, setting it to
/*           the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopPow (ViSession  instrSession,
                                                                 ViChar     errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_POW, RSCMU_GMSK, errorMessage);
}

/*===========================================================================*/
/* Function: Next Measurement Step
/* Purpose : This function continue the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContPow (ViSession  instrSession,
                                                                 ViChar     errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_POW, RSCMU_GMSK, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowErep (ViSession  instrSession,
                                                                     ViInt32    Report,
                                                                     ViChar     errorMessage[])
{
  return RSCMU_ConfReporting (instrSession, RSCMU_POW, RSCMU_GMSK, Report, errorMessage);
}

/*===========================================================================*/
/* Function: Power/t Measurement Status
/* Purpose : This function returns the status of the current Power/t
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPowStat (ViSession  instrSession,
                                                                     ViInt32   *MeasurementStatus,
                                                                     ViInt32   *CountingNo,
                                                                     ViInt32   *StatisticNo,
                                                                     ViChar     errorMessage[])
{
  return RSCMU_FetcStatus (instrSession, RSCMU_POW, RSCMU_GMSK, MeasurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of Measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowCont (ViSession instrSession,
                                                                     ViInt32   MeasuredValuesType,
                                                                     ViInt32   NbBurst,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_ConfControl (instrSession, RSCMU_POW, RSCMU_GMSK, MeasuredValuesType, NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set offset time
/* Purpose : This function defines an offset time by which the burst is shifted
/*           relative to the time axis and the tolerance template
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowTimeBoff (ViSession instrSession,
                                                                         ViReal64  Offset,
                                                                         ViChar    errorMessage[])
{
  return RSCMU_ConfPowTimeBoff(instrSession, RSCMU_GMSK, Offset, errorMessage);
}

/*===========================================================================*/
/* Function: Filter
/* Purpose : This function selects the measurement filter for the P/t
/*           measurement. The default filter setting differs for the two
/*           modulation schemes.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowFilt (ViSession instrSession,
                                                                     ViInt32   Filter,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_ConfFilt(instrSession, RSCMU_POW, RSCMU_GMSK, Filter, errorMessage);
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowContRep (ViSession  instrSession,
                                                                        ViInt32    Repetition,
                                                                        ViInt32    StopCondition,
                                                                        ViInt32    StepMode,
                                                                        ViChar     errorMessage[])
{
  return RSCMU_ConfControlRep (instrSession, RSCMU_POW, RSCMU_GMSK, Repetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Set Grid (ON/OFF)
/* Purpose : This function switches the grid lines in the test diagrams
/*           on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_DispPowContGrid (ViSession instrSession,
                                                                         ViInt32   gridLines,
                                                                         ViChar    errorMessage[])
{
  return RSCMU_DisplayGrid (instrSession, RSCMU_POW, RSCMU_GMSK, gridLines, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowContRepStat (ViSession  instrSession,
                                                                            ViInt32    NbRepetition,
                                                                            ViInt32    StopCondition,
                                                                            ViInt32    StepMode,
                                                                            ViChar     errorMessage[])
{
  return RSCMU_ConfPowContRepStat(instrSession, RSCMU_GMSK, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      TEST CONFIGURATION
 *      The functions of this subsystem determine the parameters of the
 *      signal power measurement. GSM signals are transferred in the
 *      form of bursts, which divided up into various tolerance ranges
 *      defined in the GSM standard.
 * -----------------------------------------------------------------------------
 *        LIMITS LINES
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Default limit Lines (ON/OFF)
/* Purpose : This function switches the default limit lines on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowLimLineDef (ViSession  instrSession,
                                                                           ViInt32    DefaultLimitLines,
                                                                           ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU_Status = RSCMU_Query (instrSession, "CONF:POW:LIM:LINE:DEF ON", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Upper limit Line
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowLimLineUpp (ViSession instrSession,
                                                                           ViInt32   Area,
                                                                           ViInt32   StartTimeOnOff,
                                                                           ViReal64  StartTime,
                                                                           ViInt32   EndTimeOnOff,
                                                                           ViReal64  EndTime,
                                                                           ViInt32   StartRelLevOnOff,
                                                                           ViReal64  StartRelLev,
                                                                           ViInt32   EndRelLevOnOff,
                                                                           ViReal64  EndRelLev,
                                                                           ViInt32   StartAbsLevOnOff,
                                                                           ViReal64  StartAbsLev,
                                                                           ViInt32   EndAbsLevOnOff,
                                                                           ViReal64  EndAbsLev,
                                                                           ViInt32   Visibility,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      StringStartTime [20];
  ViChar      StringEndTime [20];
  ViChar      StringStartRelLev [20];
  ViChar      StringEndRelLev  [20];
  ViChar      StringStartAbsLev  [20];
  ViChar      StringEndAbsLev  [20];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Area, 1, 16, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Version Manager
  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V2_10)
  {
   if (StartTimeOnOff == RSCMU_ON)
    sprintf (StringStartTime, "%lf", StartTime);
   else
    sprintf (StringStartTime, "%s", mode_On_Off [StartTimeOnOff]);

   if (EndTimeOnOff == RSCMU_ON)
    sprintf (StringEndTime, "%lf", EndTime);
   else
    sprintf (StringEndTime, "%s", mode_On_Off [EndTimeOnOff]);

   if (StartRelLevOnOff == RSCMU_ON)
    sprintf (StringStartRelLev , "%lf", StartRelLev);
   else
    sprintf (StringStartRelLev, "%s", mode_On_Off [StartRelLevOnOff]);

   if (EndRelLevOnOff == RSCMU_ON)
    sprintf (StringEndRelLev , "%lf", EndRelLev);
   else
    sprintf (StringEndRelLev, "%s", mode_On_Off [EndRelLevOnOff]);

   if (StartAbsLevOnOff == RSCMU_ON)
    sprintf (StringStartAbsLev, "%lf", StartAbsLev);
   else
    sprintf (StringStartAbsLev, "%s", mode_On_Off [StartAbsLevOnOff]);

   if (EndAbsLevOnOff == RSCMU_ON)
    sprintf (StringEndAbsLev , "%lf", EndAbsLev);
   else
    sprintf (StringEndAbsLev, "%s", mode_On_Off [EndAbsLevOnOff]);

    sprintf ( wrtBuf, "CONF:POW:LIM:LINE:UPP%d %s,%s,%s,%s,%s,%s,%s",
              Area,
              StringStartTime,
              StringEndTime,
              StringStartRelLev,
              StringEndRelLev,
              StringStartAbsLev,
              StringEndAbsLev,
              mode_On_Off [Visibility]);
   }
   else
   {
     sprintf (wrtBuf, "CONF:POW:LIM:LINE:UPP%d %lf,%lf,%lf,%lf,%lf,%lf,%s",
             Area,
             (StartTimeOnOff == RSCMU_ON) ? StartTime : 0.0,
             (EndTimeOnOff == RSCMU_ON) ? EndTime : 0.0,
             (StartRelLevOnOff == RSCMU_ON) ? StartRelLev : 0.0,
             (EndRelLevOnOff == RSCMU_ON) ? EndRelLev : 0.0,
             (StartAbsLevOnOff == RSCMU_ON) ? StartAbsLev : 0.0,
             (EndAbsLevOnOff == RSCMU_ON) ? EndAbsLev : 0.0,
             Visibility);

    }
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Query Lower limit Line
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_QueryConfPowLimLineLow (ViSession instrSession,
                                                                                ViInt32   Area,
                                                                                ViInt32   *StartTimeOnOff,
                                                                                ViReal64  *StartTime,
                                                                                ViInt32   *EndTimeOnOff,
                                                                                ViReal64  *EndTime,
                                                                                ViInt32   *StartRelLevOnOff,
                                                                                ViReal64  *StartRelLev,
                                                                                ViInt32   *EndRelLevOnOff,
                                                                                ViReal64  *EndRelLev,
                                                                                ViInt32   *StartAbsLevOnOff,
                                                                                ViReal64  *StartAbsLev,
                                                                                ViInt32   *EndAbsLevOnOff,
                                                                                ViReal64  *EndAbsLev,
                                                                                ViInt32   *Visibility,
                                                                                ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab [100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Area, 1, 16, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf (wrtBuf, "CONF:POW:LIM:LINE:LOW%d?", Area);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Version Manager
  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V2_10)
  {
      // Get the Start time of the area
      if (strcmp (tab[0], "OFF") != 0)
      {
        sscanf (tab[0], "%lf", StartTime);
        *StartTimeOnOff = RSCMU_ON;
      }
      else
      {
        StartTimeOnOff = RSCMU_OFF;
        *StartTime = RSCMU_NAN;
      }

      // Get the End time of the area
      if (strcmp (tab[1], "OFF") != 0)
      {
        sscanf (tab[1], "%lf", EndTime);
        *EndTimeOnOff = RSCMU_ON;
      }
      else
      {
        EndTimeOnOff = RSCMU_OFF;
        *EndTime = RSCMU_NAN;
      }

      // Get the Start Relative Level of the area
      if (strcmp (tab[2], "OFF") != 0)
      {
        sscanf (tab[2], "%lf", StartRelLev);
        *StartRelLevOnOff = RSCMU_ON;
      }
      else
      {
        StartRelLevOnOff = RSCMU_OFF;
        *StartRelLev = RSCMU_NAN;
      }

      // Get the End Relative Level of the area
      if (strcmp (tab[3], "OFF") != 0)
      {
        sscanf (tab[3], "%lf", EndRelLev);
        *EndRelLevOnOff = RSCMU_ON;
      }
      else
      {
        EndRelLevOnOff = RSCMU_OFF;
        *EndRelLev = RSCMU_NAN;
      }

      // Get the Start Absolute Level of the area
      if (strcmp (tab[4], "OFF") != 0)
      {
        sscanf (tab[4], "%lf", StartAbsLev);
        *StartAbsLevOnOff = RSCMU_ON;
      }
      else
      {
        *StartAbsLevOnOff = RSCMU_OFF;
        *StartAbsLev = RSCMU_NAN;
      }

      // Get the End Absolute Level of the area
      if (strcmp (tab[5], "OFF") != 0)
      {
        sscanf (tab[5], "%lf", EndAbsLev);
        *EndAbsLevOnOff = RSCMU_ON;
      }
      else
      {
        EndAbsLevOnOff = RSCMU_OFF;
        *EndAbsLev = RSCMU_NAN;
      }

      // Get the Visibility state of the area
      if (strcmp (tab[6], "OFF") != 0)
        *Visibility = RSCMU_ON;
      else
        *Visibility = RSCMU_OFF;
    }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Upper limit Line
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_QueryConfPowLimLineUpp (ViSession instrSession,
                                                                                ViInt32   Area,
                                                                                ViInt32   *StartTimeOnOff,
                                                                                ViReal64  *StartTime,
                                                                                ViInt32   *EndTimeOnOff,
                                                                                ViReal64  *EndTime,
                                                                                ViInt32   *StartRelLevOnOff,
                                                                                ViReal64  *StartRelLev,
                                                                                ViInt32   *EndRelLevOnOff,
                                                                                ViReal64  *EndRelLev,
                                                                                ViInt32   *StartAbsLevOnOff,
                                                                                ViReal64  *StartAbsLev,
                                                                                ViInt32   *EndAbsLevOnOff,
                                                                                ViReal64  *EndAbsLev,
                                                                                ViInt32   *Visibility,
                                                                                ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab [100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Area, 1, 16, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf (wrtBuf, "CONF:POW:LIM:LINE:UPP%d?", Area);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Version Manager
  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V2_10)
  {
      // Get the Start time of the area
      if (strcmp (tab[0], "OFF") != 0)
      {
        sscanf (tab[0], "%lf", StartTime);
        *StartTimeOnOff = RSCMU_ON;
      }
      else
      {
        StartTimeOnOff = RSCMU_OFF;
        *StartTime = RSCMU_NAN;
      }

      // Get the End time of the area
      if (strcmp (tab[1], "OFF") != 0)
      {
        sscanf (tab[1], "%lf", EndTime);
        *EndTimeOnOff = RSCMU_ON;
      }
      else
      {
        EndTimeOnOff = RSCMU_OFF;
        *EndTime = RSCMU_NAN;
      }

      // Get the Start Relative Level of the area
      if (strcmp (tab[2], "OFF") != 0)
      {
        sscanf (tab[2], "%lf", StartRelLev);
        *StartRelLevOnOff = RSCMU_ON;
      }
      else
      {
        StartRelLevOnOff = RSCMU_OFF;
        *StartRelLev = RSCMU_NAN;
      }

      // Get the End Relative Level of the area
      if (strcmp (tab[3], "OFF") != 0)
      {
        sscanf (tab[3], "%lf", EndRelLev);
        *EndRelLevOnOff = RSCMU_ON;
      }
      else
      {
        EndRelLevOnOff = RSCMU_OFF;
        *EndRelLev = RSCMU_NAN;
      }

      // Get the Start Absolute Level of the area
      if (strcmp (tab[4], "OFF") != 0)
      {
        sscanf (tab[4], "%lf", StartAbsLev);
        *StartAbsLevOnOff = RSCMU_ON;
      }
      else
      {
        *StartAbsLevOnOff = RSCMU_OFF;
        *StartAbsLev = RSCMU_NAN;
      }

      // Get the End Absolute Level of the area
      if (strcmp (tab[5], "OFF") != 0)
      {
        sscanf (tab[5], "%lf", EndAbsLev);
        *EndAbsLevOnOff = RSCMU_ON;
      }
      else
      {
        *EndAbsLevOnOff = RSCMU_OFF;
        *EndAbsLev = RSCMU_NAN;
      }

      // Get the Visibility state of the area
      if (strcmp (tab[6], "OFF") != 0)
        *Visibility = RSCMU_ON;
      else
        *Visibility = RSCMU_OFF;
    }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Lower limit Line
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowLimLineLow (ViSession instrSession,
                                                                           ViInt32   area,
                                                                           ViInt32   StartTimeOnOff,
                                                                           ViReal64  StartTime,
                                                                           ViInt32   EndTimeOnOff,
                                                                           ViReal64  EndTime,
                                                                           ViInt32   StartRelLevOnOff,
                                                                           ViReal64  StartRelLev,
                                                                           ViInt32   EndRelLevOnOff,
                                                                           ViReal64  EndRelLev,
                                                                           ViInt32   StartAbsLevOnOff,
                                                                           ViReal64  StartAbsLev,
                                                                           ViInt32   EndAbsLevOnOff,
                                                                           ViReal64  EndAbsLev,
                                                                           ViInt32   Visibility,
                                                                           ViChar    errorMessage[])
{
   return RSCMU_ConfPowLimLineLow (instrSession, RSCMU_GMSK, area, StartTimeOnOff, StartTime, EndTimeOnOff, EndTime,
     StartRelLevOnOff, StartRelLev, EndRelLevOnOff, EndRelLev, StartAbsLevOnOff, StartAbsLev, EndAbsLevOnOff, EndAbsLev, Visibility, errorMessage);
}

/*===========================================================================*/
/* Function: Dynamic Correction of Upper limit Line
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowLimLineUppDyn (ViSession instrSession,
                                                                              ViInt32   Area,
                                                                              ViInt32   TPCLRange,
                                                                              ViInt32   FromTPCLOnOff,
                                                                              ViInt32   FromTPCL,
                                                                              ViInt32   ToTPCLOnOff,
                                                                              ViInt32   ToTPCL,
                                                                              ViInt32   CorrectionOnOff,
                                                                              ViReal64  Correction,
                                                                              ViInt32   Enable,
                                                                              ViChar    errorMessage[])
{
    return RSCMU_ConfPowLimLineUppDyn (instrSession, RSCMU_GMSK, Area, TPCLRange, FromTPCLOnOff, FromTPCL, ToTPCLOnOff,
                                       ToTPCL, CorrectionOnOff, Correction, Enable, errorMessage);
}

/*===========================================================================*/
/* Function: Dynamic Correction of Lower limit Line
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowLimLineLowDyn (ViSession instrSession,
                                                                              ViInt32   Area,
                                                                              ViInt32   TPCLRange,
                                                                              ViInt32   FromTPCLOnOff,
                                                                              ViInt32   FromTPCL,
                                                                              ViInt32   ToTPCLOnOff,
                                                                              ViInt32   ToTPCL,
                                                                              ViInt32   CorrectionOnOff,
                                                                              ViReal64  Correction,
                                                                              ViInt32   Enable,
                                                                              ViChar    errorMessage[])
{
    return RSCMU_ConfPowLimLineLowDyn (instrSession, RSCMU_GMSK, Area, TPCLRange, FromTPCLOnOff, FromTPCL, ToTPCLOnOff,
                                       ToTPCL, CorrectionOnOff, Correction, Enable, errorMessage);
}

/*===========================================================================*/
/* Function: Dynamic Correction of Upper limit Line On/Off
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowLimUppDynMod (ViSession instrSession,
                                                                             ViInt32   area,
                                                                             ViInt32   enable,
                                                                             ViChar    errorMessage[])
{
    return RSCMU_ConfPowLimUppDynMod (instrSession, RSCMU_GMSK, area, enable, errorMessage);
}

/*===========================================================================*/
/* Function: Dynamic Correction of Lower limit Line On/Off
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowLimLowDynMod (ViSession instrSession,
                                                                             ViInt32   area,
                                                                             ViInt32   enable,
                                                                             ViChar    errorMessage[])
{
    return RSCMU_ConfPowLimLowDynMod (instrSession, RSCMU_GMSK, area, enable, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *        AVERAGED BURST POWER LIMIT VALUES
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Average Burst Power limit lines
/* Purpose : This Function determine the tolerances for ranges of power
/*           control levels (PCLs).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowLimAbp (ViSession instrSession,
                                                                       ViInt32   group,
                                                                       ViInt32   enable,
                                                                       ViInt32   StartPCL_ON_OFF,
                                                                       ViInt32   StartPCL,
                                                                       ViInt32   EndPCL_ON_OFF,
                                                                       ViInt32   EndPCL,
                                                                       ViInt32   LowerLimit_ON_OFF,
                                                                       ViReal64  LowerLimit,
                                                                       ViInt32   UpperLimit_ON_OFF,
                                                                       ViReal64  UpperLimit,
                                                                       ViChar    errorMessage[])
{
  return RSCMU_GSM_Sig_ConfPowLimAbp (instrSession, group, enable, StartPCL_ON_OFF, StartPCL,
                                      EndPCL_ON_OFF, EndPCL, LowerLimit_ON_OFF, LowerLimit,
                                      UpperLimit_ON_OFF, UpperLimit, errorMessage);
}

/*
 * -----------------------------------------------------------------------------
 *        POSITIONNING BURST IN TIME
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Positionning Burst in Time (not used anymore in 3.05)
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowTimeMode (ViSession instrSession,
                                                                         ViInt32   TimeMode,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) TimeMode, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (TimeMode == RSCMU_GSM)
    sprintf (wrtBuf, "CONF:POW:TIME:MODE GSM");
  else  sprintf (wrtBuf, "CONF:POW:TIME:MODE OFFS");

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*
 * ----------------------------------------------------------------------------
 *      MEASURED VALUES
 *      The functions of this subsystem determine and output the results
 *      of the signal power measurement.
 * ----------------------------------------------------------------------------
 *        MEASUREMENT AND BURST POWER
 *        (Subsystem POWer[:RESult])
 *        It contains the functions for measurement and output of the
 *        burst power and its comparison with tolerance values.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start Combined Power/Modulation Measurements
/* Purpose : This function start the Combined Power/Modulation measurement,
/*           setting it to the status beyond.
/*           RUN        Start measurement without waiting
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_InitPowMpr (ViSession instrSession, ViChar errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_POWMPR, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Abort Combined Power/Modulation Measurements
/* Purpose : This function abort the running power/modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborPowMpr (ViSession instrSession, ViChar errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_POWMPR, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Stop Combined Power/Modulation Measurements
/* Purpose : This function stop the running power/modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopPowMpr (ViSession instrSession, ViChar errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_POWMPR, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Run next measurement step
/* Purpose : This function runs next modulation measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContPowMpr (ViSession instrSession, ViChar errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_POWMPR, RSCMU_NONE, errorMessage);
}



/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function starts a single shot measurement and output all
/*           scalar measurement results. These are:
/*             Average power of current burst
/*             Peak power of current burst
/*             Bursts out of tolerance
/*             Burst template matching
/*             Average power of averaged trace
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadPow (ViSession   instrSession,
                                                                 ViReal64   *AvgBurstPwCurr,
                                                                 ViReal64   *PeakBurstPwCurr,
                                                                 ViReal64   *BurstsOutOfTol,
                                                                 ViInt32    *BurstMatching,
                                                                 ViReal64   *AvgBurstPwAvg,
                                                                 ViChar      errorMessage[])
{
  return RSCMU_MeasScalarPowerBurst (instrSession, RSCMU_COMMAND_READ, RSCMU_GMSK, AvgBurstPwCurr, PeakBurstPwCurr, BurstsOutOfTol, BurstMatching, AvgBurstPwAvg, errorMessage);
}

/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function reads out measurement and output all scalar
/*             measurement results (unsynchronized). These are:
/*             Average power of current burst
/*             Peak power of current burst
/*             Burst out of tolerance
/*             Burst template matching
/*             Average power of averaged trace
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPow (ViSession   instrSession,
                                                                 ViReal64   *AvgBurstPwCurr,
                                                                 ViReal64   *PeakBurstPwCurr,
                                                                 ViReal64   *BurstsOutOfTol,
                                                                 ViInt32    *BurstMatching,
                                                                 ViReal64   *AvgBurstPwAvg,
                                                                 ViChar      errorMessage[])
{
  return RSCMU_MeasScalarPowerBurst (instrSession, RSCMU_COMMAND_FETC, RSCMU_GMSK, AvgBurstPwCurr, PeakBurstPwCurr, BurstsOutOfTol, BurstMatching, AvgBurstPwAvg, errorMessage);
}

/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function reads out measurement and output all scalar
/*             measurement results (synchronized). These are:
/*             Average power of current burst
/*             Peak power of current burst
/*             Burst out of tolerance
/*             Burst template matching
/*             Average power of averaged trace
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampPow (ViSession   instrSession,
                                                                 ViReal64   *AvgBurstPwCurr,
                                                                 ViReal64   *PeakBurstPwCurr,
                                                                 ViReal64   *BurstsOutOfTol,
                                                                 ViInt32    *BurstMatching,
                                                                 ViReal64   *AvgBurstPwAvg,
                                                                 ViChar      errorMessage[])
{
  return RSCMU_MeasScalarPowerBurst (instrSession, RSCMU_COMMAND_SAMP, RSCMU_GMSK, AvgBurstPwCurr, PeakBurstPwCurr, BurstsOutOfTol, BurstMatching, AvgBurstPwAvg, errorMessage);
}

/*===========================================================================*/
/* Function: Power/t Limit Check
/* Purpose : This function indicates whether and in which way the per-
/*           missible tolerances for the scalar measured values  have
/*           been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcPowLimMatc (ViSession  instrSession,
                                                                        ViInt32   *AvgBurstPwCurr,
                                                                        ViInt32   *PeakBurstPwCurr,
                                                                        ViInt32   *BurstMatching,
                                                                        ViInt32   *AvgBurstPwAvg,
                                                                        ViChar     errorMessage[])
{
  return RSCMU_CalcScalPowLimMatc(instrSession, RSCMU_GMSK, AvgBurstPwCurr, PeakBurstPwCurr, BurstMatching, AvgBurstPwAvg, errorMessage);
}

/*===========================================================================*/
/* Function: Set power subranges
/* Purpose : This function configures the read, fetch and sample commands.
/*           It restricts the measurement to up to 32 subranges where either
/*           all measurement results or a single statistical value is returned
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubPowRang (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  StartTime,
                                                                        ViInt32   NbOfSamples,
                                                                        ViChar    errorMessage[])
{
  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, StartTime, -10.0, 156.75, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbOfSamples, 0, 668, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSubarrays (instrSession, RSCMU_POW, RSCMU_GMSK, Mode, StartTime, NbOfSamples, errorMessage);
}

/*===========================================================================*/
/* Function: Burst power measured values
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrPowBurs (ViSession  instrSession,
                                                                        ViInt32    Mode,
                                                                        ViReal64   BurstPower[],
                                                                        ViChar     errorMessage[])
{
  return RSCMU_MeasArrayPowerBurst (instrSession, RSCMU_COMMAND_READ, RSCMU_GMSK, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetc Burst Power...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrPowBurs (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  BurstPower[],
                                                                        ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPowerBurst (instrSession, RSCMU_COMMAND_FETC, RSCMU_GMSK, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Burst Power...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrPowBurs (ViSession  instrSession,
                                                                        ViInt32    Mode,
                                                                        ViReal64   BurstPower[],
                                                                        ViChar     errorMessage[])
{
  return RSCMU_MeasArrayPowerBurst (instrSession, RSCMU_COMMAND_SAMP, RSCMU_GMSK, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Burst power measured values (SubArray)
/* Purpose : This function outputs the burst power versus time in a fixed
/*           -bit pattern and in subranges defined ny means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrPowBurs (ViSession  instrSession,
                                                                           ViInt32    Mode,
                                                                           ViReal64   BurstPower[],
                                                                           ViChar     errorMessage[])
{
  return RSCMU_MeasSubarraysPowerBurst (instrSession, RSCMU_COMMAND_READ, RSCMU_GMSK, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetc Burst Power (SubArray)...
/* Purpose : This function outputs the burst power versus time in a fixed
/*           -bit pattern and in subranges defined ny means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrPowBurs (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViReal64  BurstPower[],
                                                                           ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPowerBurst (instrSession, RSCMU_COMMAND_FETC, RSCMU_GMSK, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Burst Power (SubArray)...
/* Purpose : This function outputs the burst power versus time in a fixed
/*           -bit pattern and in subranges defined ny means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrPowBurs (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViReal64  BurstPower[],
                                                                           ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPowerBurst (instrSession, RSCMU_COMMAND_SAMP, RSCMU_GMSK, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Read MPR
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrPowMprBurs (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViReal64  BurstPower[],
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];
  ViString    StrMode[] = {"CURR", "AVER", "MAX", "MIN"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:ARR:POW:MPR:BURS:%s?", StrMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, BurstPower);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Fetch MPR
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrPowMprBurs (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViReal64  BurstPower[],
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];
  ViString    StrMode[] = {"CURR", "AVER", "MAX", "MIN"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:ARR:POW:MPR:BURS:%s?", StrMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, BurstPower);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Sample MPR
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrPowMprBurs (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViReal64  BurstPower[],
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];
  ViString    StrMode[] = {"CURR", "AVER", "MAX", "MIN"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:ARR:POW:MPR:BURS:%s?", StrMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, BurstPower);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Read MPR
/* Purpose : This function outputs the burst power versus time in a fixed
/*           -bit pattern and in subranges defined ny means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrPowMprBurs (ViSession instrSession,
                                                                              ViInt32   Mode,
                                                                              ViReal64  BurstPower[],
                                                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];
  ViString    StrMode[] = {"CURR", "AVER", "MAX", "MIN"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:SUB:POW:MPR:BURS:%s?", StrMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, BurstPower);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Fetch MPR
/* Purpose : This function outputs the burst power versus time in a fixed
/*           -bit pattern and in subranges defined ny means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrPowMprBurs (ViSession instrSession,
                                                                              ViInt32   Mode,
                                                                              ViReal64  BurstPower[],
                                                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];
  ViString    StrMode[] = {"CURR", "AVER", "MAX", "MIN"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:SUB:POW:MPR:BURS:%s?", StrMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, BurstPower);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Sample MPR
/* Purpose : This function outputs the burst power versus time in a fixed
/*           -bit pattern and in subranges defined ny means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrPowMprBurs (ViSession instrSession,
                                                                              ViInt32   statMode,
                                                                              ViReal64  BurstPower[],
                                                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, statMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:SUB:POW:MPR:BURS:%s?", StrStatMode[statMode]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, BurstPower);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Power/t Limit Check
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcPowBursLimMatc (ViSession  instrSession,
                                                                            ViInt32    StatisticsMode,
                                                                            ViInt32   *ToleranceError,
                                                                            ViChar     errorMessage[])
{
  return RSCMU_CalcArrPowLimMatc(instrSession, RSCMU_GMSK, StatisticsMode, ToleranceError, errorMessage);
}

/*===========================================================================*/
/* Function: Range Violation
/* Purpose : This command is always query. ANy set bit of the two returned
/*           fiels indicates the violation of the corresponding section
/*           of the limit times
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcPowResAreaLimMatc (ViSession  instrSession,
                                                                               ViInt32    StatisticsMode,
                                                                               ViInt32   *UpperLimit,
                                                                               ViInt32   *LowerLimit,
                                                                               ViChar     errorMessage[])
{
  return RSCMU_CalcPowAreaLimMatc(instrSession, RSCMU_GMSK, StatisticsMode, UpperLimit, LowerLimit, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT POWER/T MULTISLOT
 *
 * The subsystem POWer:MSLot measures the MS output carrier power versus time
 * in up to 4 consecutive timeslots. The subsystem corresponds to the
 * measurement menu Power, application P/t Multislot, and the associated popup
 * menu Power Configuration.
 * Note: The POWer:MSLot measurement can not be carried out with a Free Run
 * trigger (TRIG-ger[:SEQuence]:SOURce FRUN).
 * ----------------------------------------------------------------------------
 *      CONTROL OF POWER MEASUREMENT
 *      This subsystem contains the functions for general control of the
 *      power measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start Measurements
/* Purpose : This function starts measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_InitPowMsl (ViSession instrSession,
                                                                    ViChar errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_POWMSL, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Abort Measurements
/* Purpose : This function abort measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborPowMsl (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_POWMSL, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Stop Measurements
/* Purpose : This function stops measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopPowMsl (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_POWMSL, RSCMU_NONE, errorMessage);
}
/*===========================================================================*/
/* Function: Continue Measurements
/* Purpose : This function continues measurement after stop,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContPowMsl (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_POWMSL, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Measurement Status
/* Purpose : This function returns the status of the current Power/t multislot
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPowMslStat (ViSession  instrSession,
                                                                        ViInt32    *MeasurementStatus,
                                                                        ViInt32    *CountingNo,
                                                                        ViInt32    *StatisticNo,
                                                                        ViChar     errorMessage[])
{
  return RSCMU_FetcStatus (instrSession, RSCMU_POWMSL, RSCMU_NONE, MeasurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMslErep (ViSession  instrSession,
                                                                        ViInt32    Report,
                                                                        ViChar     errorMessage[])
{
  return RSCMU_ConfReporting (instrSession, RSCMU_POWMSL, RSCMU_NONE, Report, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      CONFIGURATION CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMslContRep (ViSession  instrSession,
                                                                           ViInt32    Repetition,
                                                                           ViInt32    StopCondition,
                                                                           ViInt32    StepMode,
                                                                           ViChar     errorMessage[])
{
  return RSCMU_ConfControlRep (instrSession, RSCMU_POWMSL, RSCMU_NONE, Repetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Filter
/* Purpose : This function selects the measurement filter for the P/t
/*           measurement. The default filter setting differs for the two
/*           modulation schemes.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMslFilt (ViSession instrSession,
                                                 ViInt32 filter,
                                                 ViChar errorMessage[])
{
    return RSCMU_ConfFilt (instrSession, RSCMU_POWMSL, 0, filter, errorMessage);
}

/*===========================================================================*/
/* Function: Set Grid (ON/OFF)
/* Purpose : This function switches the grid lines in the test diagrams
/*           on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_DispPowMslContGrid (ViSession instrSession,
                                                                            ViInt32   gridLines,
                                                                            ViChar    errorMessage[])
{
  return RSCMU_GSM_Sig_DispPowMslContGrid (instrSession, gridLines, errorMessage);
}

/*===========================================================================*/
/* Function: Off Template
/* Purpose : This function defines the reference for the upper limit line
/*           in inactive slots.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMslLimLineOtem (ViSession instrSession,
                                                        ViBoolean off_template,
                                                        ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    RETMSG(RSCMU_setEnum(instrSession, "CONF:POW:MSL:LIM:LINE:OTEM",
                            off_template,
                            offTemplateArr,
                            RSCMU_ERROR_PARAMETER2));
}

/*
 *-----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of Measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMslCont (ViSession instrSession,
                                                                        ViInt32   MeasuredValuesType,
                                                                        ViInt32   NbBurst,
                                                                        ViChar    errorMessage[])
{
  return RSCMU_ConfControl (instrSession, RSCMU_POWMSL, RSCMU_NONE, MeasuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistics Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMslContRepStat (ViSession  instrSession,
                                                                               ViInt32    NbRepetition,
                                                                               ViInt32    StopCondition,
                                                                               ViInt32    StepMode,
                                                                               ViChar     errorMessage[])
{
  return RSCMU_GSM_Sig_ConfPowMslContRepStat (instrSession, NbRepetition,
    StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: TSA Level
/* Purpose : This function defines defines a signal level relative to the Max.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMslTsal (ViSession instrSession,
                                                 ViReal64 level,
                                                 ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    CHECK_VI_REAL64_RANGE(instrSession, level, -60.0, 10.0, RSCMU_ERROR_PARAMETER2, errorMessage);

    RETMSG(RSCMU_setViReal64(instrSession, "CONF:POW:MSL:TSAL",
                            level,
                            -60.0, 10.0,
                            RSCMU_ERROR_PARAMETER2));
}

/*
 *-----------------------------------------------------------------------------
 *      TEST CONFIGURATION
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Modulation view
/* Purpose : This function defines the modulation schemes and power/time
/*           templates for the Meas. Timeslot -1, Meas. Timeslot and the two
/*           following timeslots. Values for timeslots that are currently
/*           switched off (see function RSCMU_GSM_NSig_ConfPowMslSco) are not
/*           taken into consideration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMslMvi (ViSession instrSession,
                                                                       ViInt32   timeslot_m1,
                                                                       ViInt32   timeslot,
                                                                       ViInt32   timeslot_p1,
                                                                       ViInt32   timeslot_p2,
                                                                       ViChar    errorMessage[])
{
  return RSCMU_GSM_Sig_ConfPowMslMvi (instrSession, timeslot_m1, timeslot,
    timeslot_p1, timeslot_p2, errorMessage);
}

/*===========================================================================*/
/* Function: Slot count
/* Purpose : This function defines the number of timeslots measured and
/*           determines the length of the measurement arrays.
/*           (see READ:ARRay:POWer:MSLot[:RESult]... commands).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMslSco (ViSession instrSession,
                                                                       ViInt32   nbr_of_timeslots,
                                                                       ViChar    errorMessage[])
{
  return RSCMU_GSM_Sig_ConfPowMslSco (instrSession, nbr_of_timeslots, errorMessage);
}

/*===========================================================================*/
/* Function: timing offset
/* Purpose : This function defines an offset time by which the burst is
/*           shifted relative to the time axis and the tolerance template.
/*           The values entered are rounded to  symbol steps.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMslToff (ViSession instrSession,
                                                                        ViReal64  offset,
                                                                        ViChar    errorMessage[])
{
  return RSCMU_GSM_Sig_ConfPowMslToff (instrSession, offset, errorMessage);
}

/*===========================================================================*/
/* Function: multislot guard
/* Purpose : This function defines the raising of the upper limit line in the
/*           guard period between two consecutive bursts.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMslLimGlev (ViSession instrSession,
                                                                           ViReal64  level,
                                                                           ViChar    errorMessage[])

{
  return RSCMU_GSM_Sig_ConfPowMslLimGlev (instrSession, level, errorMessage);
}

/*===========================================================================*/
/* Function: configure subarrays
/* Purpose : This function configures the read, fetch and sample subarray
/*           functions. It restricts the measurement to up to 32 subranges
/*           where either all measurement results (the number of which is
/*           given by the second numerical parameter) or a single statistical
/*           value is returned. The subranges are defined by the start time
/*           and the number of test points which are located on a fixed,
/*           equidistant grid with a step width of  symbols. If <Start> does
/*           not coincide with a test point then the range will start at the
/*           next test point that is larger than <Start>.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubPowMslRang (ViSession instrSession,
                                                                           ViInt32   Statistics,
                                                                           ViInt32   startTime,
                                                                           ViInt32   Nbofsamples,
                                                                           ViChar    errorMessage[])
{
  return RSCMU_GSM_Sig_ConfSubPowMslRang (instrSession, Statistics, startTime,
    Nbofsamples, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      MEASURED VALUES
 *      The functions of the following subsystems determine and output
 *      the results of the signal power measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function starts a single shot measurement and returns the
/*           results. For more details refer to the description of measurement
/*           control in chapter 5 of the CMU200 operating manual.
/*
/*           These are:
/*           Burst out of tolerance
/*           Average burst power (current burst)
/*           Average burst power of average trace
/*           Peak burst power (current burst)
/*           Timing advance error
/*           Burst template matching
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadPowMsl (ViSession  instrSession,
                                                                    ViReal64  *BurstOutOfTol,
                                                                    ViReal64  *AvgBurstPwCurr,
                                                                    ViReal64  *AvgBurstPwAvg,
                                                                    ViReal64  *PeakBurstPwCurr,
                                                                    ViReal64  *TimingAdvError,
                                                                    ViInt32   *BurstMatching,
                                                                    ViChar     errorMessage[])
{
  return RSCMU_GSM_Sig_ReadPowMsl (instrSession, BurstOutOfTol, AvgBurstPwCurr,
    AvgBurstPwAvg, PeakBurstPwCurr, TimingAdvError, BurstMatching, errorMessage);
}

/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function returns the results. For more details refer to the
/*           description of measurement control in chapter 5 of the CMU200
/*           operating manual.
/*
/*           These are:
/*           Burst out of tolerance
/*           Average burst power (current burst)
/*           Average burst power of average trace
/*           Peak burst power (current burst)
/*           Timing advance error
/*           Burst template matching
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPowMsl (ViSession  instrSession,
                                                                    ViReal64  *BurstOutOfTol,
                                                                    ViReal64  *AvgBurstPwCurr,
                                                                    ViReal64  *AvgBurstPwAvg,
                                                                    ViReal64  *PeakBurstPwCurr,
                                                                    ViReal64  *TimingAdvError,
                                                                    ViInt32   *BurstMatching,
                                                                    ViChar     errorMessage[])
{
  return RSCMU_GSM_Sig_FetcPowMsl (instrSession, BurstOutOfTol, AvgBurstPwCurr,
    AvgBurstPwAvg, PeakBurstPwCurr, TimingAdvError, BurstMatching, errorMessage);
}

/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function waits until the results are valid (depending on
/*           the statistic count) and then returns the results. For more
/*           details refer to the description of measurement control in
/*           chapter 5 of the CMU200 operating manual.
/*
/*           These are:
/*           Burst out of tolerance
/*           Average burst power (current burst)
/*           Average burst power of average trace
/*           Peak burst power (current burst)
/*           Timing advance error
/*           Burst template matching
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampPowMsl (ViSession  instrSession,
                                                                    ViReal64  *BurstOutOfTol,
                                                                    ViReal64  *AvgBurstPwCurr,
                                                                    ViReal64  *AvgBurstPwAvg,
                                                                    ViReal64  *PeakBurstPwCurr,
                                                                    ViReal64  *TimingAdvError,
                                                                    ViInt32   *BurstMatching,
                                                                    ViChar     errorMessage[])
{
  return RSCMU_GSM_Sig_SampPowMsl (instrSession, BurstOutOfTol, AvgBurstPwCurr,
    AvgBurstPwAvg, PeakBurstPwCurr, TimingAdvError, BurstMatching, errorMessage);
}

/*===========================================================================*/
/* Function: Request Tolerance On Values
/* Purpose : This function indicates whether and in which way the per-
/*           missible tolerances for the scalar measured values have
/*           been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcPowMslLimMatc (ViSession  instrSession,
                                                                           ViInt32   *AvgBurstPowCurr,
                                                                           ViInt32   *AvgBurstPowAvg,
                                                                           ViInt32   *PeakBurstPowCurr,
                                                                           ViInt32   *TimingAdvanceErr,
                                                                           ViInt32   *BurstMatching,
                                                                           ViChar     errorMessage[])
{
  return RSCMU_GSM_Sig_CalcPowMslLimMatc (instrSession, AvgBurstPowCurr, AvgBurstPowAvg,
    PeakBurstPowCurr, TimingAdvanceErr, BurstMatching, errorMessage);
}

/*===========================================================================*/
/* Function: Read Power/t multislot array
/* Purpose : This function starts a single shot measurement and returns the
/*           burst power relative to the average burst power in the measurement
/*           slot at n equidistant measurement points with a fixed  symbol
/*           spacing. The time range measured corresponds to 1 to 4 entire
/*           timeslots plus 18  symbol periods before the beginning (symbol 0)
/*           of the first slot and 10 symbol periods after the end of the last
/*           slot. The resulting array lengths n are listed below.
/*
/*           Number of timeslots (according to     1      2      3      4
/*           RSCMU_GSM_NSig_ConfPowMslSco)
/*           n                                   738   1363   1988   2613
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrPowMsl (ViSession instrSession,
                                                                       ViInt32   Mode,
                                                                       ViReal64  BurstPower[],
                                                                       ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPowerMsl (instrSession, RSCMU_COMMAND_READ, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Power/t multislot array
/* Purpose : This function returns the burst power relative to the average
/*           burst power in the measurement slot at n equidistant measurement
/*           points with a fixed  symbol spacing. The time range measured
/*           corresponds to 1 to 4 entire timeslots plus 18  symbol periods
/*           before the beginning (symbol 0) of the first slot and 10 symbol
/*           periods after the end of the last slot. The resulting array
/*           lengths n are listed below.
/*
/*           Number of timeslots (according to     1      2      3      4
/*           RSCMU_GSM_NSig_ConfPowMslSco)
/*           n                                   738   1363   1988   2613
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrPowMsl (ViSession instrSession,
                                                                       ViInt32   Mode,
                                                                       ViReal64  BurstPower[],
                                                                       ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPowerMsl (instrSession, RSCMU_COMMAND_FETC, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Power/t multislot array
/* Purpose : This function waits until the results are valid (depending on
/*           the statistic count) and then returns the burst power relative
/*           to the average burst power in the measurement slot at n
/*           equidistant measurement points with a fixed  symbol spacing.
/*           The time range measured corresponds to 1 to 4 entire timeslots
/*           plus 18  symbol periods before the beginning (symbol 0) of the
/*           first slot and 10 symbol periods after the end of the last slot.
/*           The resulting array lengths n are listed below.
/*
/*           Number of timeslots (according to     1      2      3      4
/*           RSCMU_GSM_NSig_ConfPowMslSco)
/*           n                                   738   1363   1988   2613
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrPowMsl (ViSession instrSession,
                                                                       ViInt32   Mode,
                                                                       ViReal64  BurstPower[],
                                                                       ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPowerMsl (instrSession, RSCMU_COMMAND_SAMP, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Global burst matching
/* Purpose : This function indicates whether and in which way the per-
/*           missible tolerances for the scalar measured values have
/*           been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcArrPowMslLimMatc (ViSession  instrSession,
                                                                              ViInt32    Mode,
                                                                              ViInt32   *ToleranceError,
                                                                              ViChar     errorMessage[])
{
  return RSCMU_GSM_Sig_CalcArrPowMslLimMatc (instrSession, Mode, ToleranceError, errorMessage);
}

/*===========================================================================*/
/* Function: area limit matching
/* Purpose : A bit in the two output values is set if the corresponding
/*           section of the limit lines is exceeded. n is the total number of
/*           areas in the limit lines, depending on the number of bursts
/*           measured (according to RSCMU_GSM_NSig_ConfPowMslSco).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcPowMslAreaLimMatc (ViSession  instrSession,
                                                                               ViInt32    StatisticsMode,
                                                                               ViInt32   *UpperLimit,
                                                                               ViInt32   *LowerLimit,
                                                                               ViChar     errorMessage[])
{
  return RSCMU_GSM_Sig_CalcPowMslAreaLimMatc (instrSession, StatisticsMode, UpperLimit, LowerLimit, errorMessage);
}

/*===========================================================================*/
/* Function: Read subarrays
/* Purpose : This function outputs the burst power versus time multislot in a
/*           fixed -bit pattern and in subranges defined ny means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrPowMsl (ViSession  instrSession,
                                                                          ViInt32    Mode,
                                                                          ViReal64   BurstPower[],
                                                                          ViChar     errorMessage[])
{
  return RSCMU_MeasSubarraysPowerMsl (instrSession, RSCMU_COMMAND_READ, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch subarrays
/* Purpose : This function outputs the burst power versus time multislot in a
/*           fixed -bit pattern and in subranges defined ny means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrPowMsl (ViSession  instrSession,
                                                                          ViInt32    Mode,
                                                                          ViReal64   BurstPower[],
                                                                          ViChar     errorMessage[])
{
  return RSCMU_MeasSubarraysPowerMsl (instrSession, RSCMU_COMMAND_FETC, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample subarrays
/* Purpose : This function outputs the burst power versus time multislot in a
/*           fixed -bit pattern and in subranges defined ny means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrPowMsl (ViSession  instrSession,
                                                                          ViInt32    Mode,
                                                                          ViReal64   BurstPower[],
                                                                          ViChar     errorMessage[])
{
  return RSCMU_MeasSubarraysPowerMsl (instrSession, RSCMU_COMMAND_SAMP, Mode, BurstPower, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT Combined POWER/MODULATION
 *    The subsystem MODulation contains the commands for the
 *    measurement of the modulation parameters, ie the frequency and
 *    measured bursts phase error.
 * ----------------------------------------------------------------------------
 *      CONTROL OF MODULATION MEAS
 *      It contains the functions for general control of the modulation
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMprErep (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  ViString    StrMode[] = {"OFF","SRQ","SOPC","SRSQ"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:POW:MPR:EREP %s", StrMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Combined Power & Modulation Measurement Status
/* Purpose : This function returns the status of the current combined Power
/*           & Modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPowMprStat (ViSession  instrSession,
                                                                        ViInt32    *MeasurementStatus,
                                                                        ViInt32    *CountingNo,
                                                                        ViInt32    *StatisticNo,
                                                                        ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  // Fetch the status of the combined Power & Modulation measurement:
  if ((RSCMU_Status = RSCMU_Query (instrSession, "FETC:POW:MPR:STAT?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Get the status of the measurement:
  if ((RSCMU_Status = RSCMU_GetMeasStatVal (MeasurementStatus, TableOfDataValues, 0)) < 0)
    return RSCMU_Status;

  // Get the current value of the statistics counter (the number of the current statistics cycle):
  if ((RSCMU_Status = RSCMU_GetCountingNo (CountingNo, TableOfDataValues, 1)) < 0)
    return RSCMU_Status;

  // Get the current evaluation period within a statistics cycle:
  if ((RSCMU_Status = RSCMU_GetStatisticNo (StatisticNo, TableOfDataValues, 2)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set Scope of measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMprCont (ViSession instrSession,
                                                                        ViInt32   MeasuredValuesType,
                                                                        ViInt32   NbBurst,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) MeasuredValuesType, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, RSCMU_NBBURST_MIN, RSCMU_NBBURST_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:POW:MPR:CONT %s,%d", mode_ScopeMeas[MeasuredValuesType], NbBurst);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Invalid Result detect timeout
/* This function defines the Invalid Result Detected Timeout.
/* It is valid for the Power/Time Measurements.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_PowerTimeMeasTimeout (ViSession instrSession,
                                                       ViInt32   invalidResultDetectedTimeout,
                                                       ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[]= {"NORMal", "MEDium", "SHORt", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    RETMSG(RSCMU_setEnum(instrSession, "CONFigure:POWer:PVT:IRDTimeout",
                         invalidResultDetectedTimeout, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMprContRep (ViSession  instrSession,
                                                                           ViInt32    Repetition,
                                                                           ViInt32    StopCondition,
                                                                           ViInt32    StepMode,
                                                                           ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) Repetition, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:POW:MPR:CONT:REP %s,%s,%s", StrRepetition[Repetition], StrStopCondition[StopCondition], StrStepMode[StepMode]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}


/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMprContRepStat (ViSession  instrSession,
                                                                               ViInt32    NbRepetition,
                                                                               ViInt32    StopCondition,
                                                                               ViInt32    StepMode,
                                                                               ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU_MULT_MEAS_MIN, RSCMU_MULT_MEAS_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:POW:MPR:CONT:REP %d,%s,%s", NbRepetition, StrStopCondition[StopCondition], StrStepMode[StepMode]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}



/*===========================================================================*/
/* Function: Set power subranges
/* Purpose : This function configures the read, fetch and sample commands.
/*           It restricts the measurement to up to 32 subranges where either
/*           all measurement results or a single statistical value is returned
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMprSubRang (ViSession instrSession,
                                                                           ViInt32   Statistics,
                                                                           ViReal64  StartTime,
                                                                           ViInt32   Samples,
                                                                           ViChar    errorMessage[])
{
  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, StartTime, -10.0, 156.75, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Samples, 0, 668, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSubarrays (instrSession, RSCMU_POW, RSCMU_GMSK, Statistics, StartTime, Samples, errorMessage);
}



/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function starts a single shot combined power vs. time and
/*           modulation measurement and output all scalar measurement
/*           results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadPowMpr (ViSession   instrSession,
                                                                    ViInt32     StatisticsMode,
                                                                    ViReal64    *AvgBurstPwCurr,
                                                                    ViReal64    *PeakBurstPwCurr,
                                                                    ViReal64    *BurstOutOfTol,
                                                                    ViInt32     *BurstMatching,
                                                                    ViReal64    *PhErrPeak,
                                                                    ViReal64    *PhErrRMS,
                                                                    ViReal64    *FreqErr,
                                                                    ViReal64    *AvgBurstPwAvg,
                                                                    ViChar       errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU_Status = RSCMU_Query (instrSession, "READ:POW:MPR?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Scan the results of combined power & modulation:
  RSCMU_NSig_ScanPowMpr (TableOfDataValues,
                         StatisticsMode,
                         AvgBurstPwCurr,
                         PeakBurstPwCurr,
                         BurstOutOfTol,
                         BurstMatching,
                         PhErrPeak,
                         PhErrRMS,
                         FreqErr,
                         AvgBurstPwAvg);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function starts a combined power vs. time and modulation
/*           measurement and output all scalar measurement results
/*           (unsynchronized).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPowMpr (ViSession   instrSession,
                                                                    ViInt32     StatisticsMode,
                                                                    ViReal64    *AvgBurstPwCurr,
                                                                    ViReal64    *PeakBurstPwCurr,
                                                                    ViReal64    *BurstOutOfTol,
                                                                    ViInt32     *BurstMatching,
                                                                    ViReal64    *PhErrPeak,
                                                                    ViReal64    *PhErrRMS,
                                                                    ViReal64    *FreqErr,
                                                                    ViReal64    *AvgBurstPwAvg,
                                                                    ViChar       errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU_Status = RSCMU_Query (instrSession, "FETC:POW:MPR?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Scan the results of combined power & modulation:
  RSCMU_NSig_ScanPowMpr (TableOfDataValues,
                         StatisticsMode,
                         AvgBurstPwCurr,
                         PeakBurstPwCurr,
                         BurstOutOfTol,
                         BurstMatching,
                         PhErrPeak,
                         PhErrRMS,
                         FreqErr,
                         AvgBurstPwAvg);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function starts a combined power vs. time and modulation
/*           measurement and output all scalar measurement results
/*           (synchronized).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampPowMpr (ViSession   instrSession,
                                                                    ViInt32     StatisticsMode,
                                                                    ViReal64    *AvgBurstPwCurr,
                                                                    ViReal64    *PeakBurstPwCurr,
                                                                    ViReal64    *BurstOutOfTol,
                                                                    ViInt32     *BurstMatching,
                                                                    ViReal64    *PhErrPeak,
                                                                    ViReal64    *PhErrRMS,
                                                                    ViReal64    *FreqErr,
                                                                    ViReal64    *AvgBurstPwAvg,
                                                                    ViChar       errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU_Status = RSCMU_Query (instrSession, "SAMP:POW:MPR?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Scan the results of combined power & modulation:
  RSCMU_NSig_ScanPowMpr (TableOfDataValues,
                         StatisticsMode,
                         AvgBurstPwCurr,
                         PeakBurstPwCurr,
                         BurstOutOfTol,
                         BurstMatching,
                         PhErrPeak,
                         PhErrRMS,
                         FreqErr,
                         AvgBurstPwAvg);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcPowMprLimMatc (ViSession  instrSession,
                                                                           ViInt32    StatisticsMode,
                                                                           ViInt32    *AverBurstPow,
                                                                           ViInt32    *PeakBurstPow,
                                                                           ViInt32    *BurstMatching,
                                                                           ViInt32    *phErrPeak,
                                                                           ViInt32    *phErrRMS,
                                                                           ViInt32    *freqErr,
                                                                           ViInt32    *avgBurstPowerAvg,
                                                                           ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  if ((RSCMU_Status = RSCMU_Query (instrSession, "CALC:POW:MPR:LIM:MATC?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Max phase error with single-value measurement
  RSCMU_Status = RSCMU_GetMatchingValue (AverBurstPow,TableOfDataValues,0);
  // RMS phase error with single-value measurement
  RSCMU_Status = RSCMU_GetMatchingValue (PeakBurstPow,TableOfDataValues,1);
  // Frequency error with single-value measurement
  RSCMU_Status = RSCMU_GetMatchingValue (BurstMatching,TableOfDataValues,2);

  switch (StatisticsMode)
  {
    case RSCMU_CURRENT:
      // Max phase error with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrPeak,TableOfDataValues,3);
      // RMS phase error with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrRMS,TableOfDataValues,6);
      // Frequency error with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (freqErr,TableOfDataValues,9);
    break;
    case RSCMU_AVERAGE:
      // Max phase error with average measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrPeak, TableOfDataValues, 4);
      // RMS phase error with average measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrRMS, TableOfDataValues, 7);
      // Frequency error with average measurement
      RSCMU_Status = RSCMU_GetMatchingValue (freqErr, TableOfDataValues, 10);
    break;
    case RSCMU_MAXMIN:
      // Max phase error with extreme-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrPeak,TableOfDataValues, 5);
      // RMS phase error with extreme-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrRMS,TableOfDataValues, 8);
      // Frequency error with extreme-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (freqErr,TableOfDataValues, 11);
    break;
  }
  // Average burst power with single-value measurement
  RSCMU_Status = RSCMU_GetMatchingValue (avgBurstPowerAvg, TableOfDataValues, 12);

  return RSCMU_Status;
}


/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT POWER/SLOT
 * ----------------------------------------------------------------------------
*/
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowSlotContDef (ViSession instrSession,
                                                                            ViInt32   DefaultValues,
                                                                            ViChar    errorMessage[])
{
  return RSCMU_ConfContDef(instrSession, RSCMU_POWSLOT, RSCMU_NONE, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowSlotContRep (ViSession instrSession,
                                                                            ViInt32   repetition,
                                                                            ViInt32   stopCondition,
                                                                            ViInt32   stepMode,
                                                                            ViChar    errorMessage[])
{
  return RSCMU_ConfControlRep(instrSession, RSCMU_POWSLOT, RSCMU_NONE, repetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowSlotContRepStat (ViSession instrSession,
                                                                                ViInt32   NbRepetition,
                                                                                ViInt32   stopCondition,
                                                                                ViInt32   stepMode,
                                                                                ViChar    errorMessage[])
{
   return RSCMU_ConfContRepStat(instrSession, RSCMU_POWSLOT, RSCMU_NONE, NbRepetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Set power subranges
/* Purpose : This function configures the read, fetch and sample commands.
/*           It restricts the measurement to up to 32 subranges where either
/*           all measurement results or a single statistical value is returned
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubPowSlot (ViSession instrSession,
                                                                        ViInt32   mode,
                                                                        ViInt32   startTime,
                                                                        ViInt32   numberOfsamples,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, startTime, 0, 7, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, numberOfsamples, 1, 8, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:POW:SLOT %s,%d,%d", StrStatistics[mode], startTime, numberOfsamples);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Start new measurement
/* Purpose : This function starts the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_InitPowSlot (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_POWSLOT, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Abort running measurement and switch off
/* Purpose : This function stopss the power measurement, setting it to
/*           the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborPowSlot (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_POWSLOT, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: stop measurement after current statistic cycle
/* Purpose : This function stops the power measurement, setting it to
/*           the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopPowSlot (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_POWSLOT, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Next Measurement Step
/* Purpose : This function continue the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContPowSlot (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_POWSLOT, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Combined Power & Modulation Measurement Status
/* Purpose : This function returns the status of the current Power versus
/*           slot measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPowSlotStat (ViSession instrSession,
                                                                         ViInt32  *measStatus,
                                                                         ViInt32  *CurrCycleCounter,
                                                                         ViChar    errorMessage[])
{
  ViInt32 EvalPeriodCounter; //only needed to allow  call of RSCMU_FetcStatus()

  return RSCMU_FetcStatus(instrSession, RSCMU_POWSLOT, RSCMU_NONE, measStatus, CurrCycleCounter, &EvalPeriodCounter, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowSlotErep (ViSession instrSession,
                                                                         ViInt32   Report,
                                                                         ViChar    errorMessage[])
{
   return RSCMU_ConfReporting(instrSession, RSCMU_POWSLOT, RSCMU_NONE, Report, errorMessage);
}

/*===========================================================================*/
/* Function: Read average power in selected slot
/* Purpose : This function outputs the average power value of the
/*           selected timeslot (from 0 to 7)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadPowSlotSpow (ViSession  instrSession,
                                                                         ViInt32    timeslot,
                                                                         ViReal64  *avgPower,
                                                                         ViChar     errorMessage[])
{
  return RSCMU_MeasScalarPower(instrSession, RSCMU_COMMAND_READ, RSCMU_POWSLOT, timeslot, avgPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch average power in selected slot
/* Purpose : This function outputs the average power value of the
/*           selected timeslot (from 0 to 7)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPowSlotSpow (ViSession  instrSession,
                                                                         ViInt32    timeslot,
                                                                         ViReal64  *avgPower,
                                                                         ViChar     errorMessage[])
{
  return RSCMU_MeasScalarPower(instrSession, RSCMU_COMMAND_FETC, RSCMU_POWSLOT, timeslot, avgPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample average power in selected slot
/* Purpose : This function outputs the average power value of the
/*           selected timeslot (from 0 to 7)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampPowSlotSpow (ViSession  instrSession,
                                                                         ViInt32    timeslot,
                                                                         ViReal64  *avgPower,
                                                                         ViChar     errorMessage[])
{
  return RSCMU_MeasScalarPower(instrSession, RSCMU_COMMAND_SAMP, RSCMU_POWSLOT, timeslot, avgPower, errorMessage);
}

/*===========================================================================*/
/* Function: Read power in all timeslots
/* Purpose : This function outputs the average all power values of the
/*           selected timeslot (from 0 to 7)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrPowSlot (ViSession instrSession,
                                                                        ViReal64  slotPowerValues[],
                                                                        ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPower(instrSession, RSCMU_COMMAND_READ, RSCMU_POWSLOT, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch power in all timeslots
/* Purpose : This function outputs the average all power values of the
/*           selected timeslot (from 0 to 7)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrPowSlot (ViSession instrSession,
                                                                        ViReal64  slotPowerValues[],
                                                                        ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPower(instrSession, RSCMU_COMMAND_FETC, RSCMU_POWSLOT, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Sample power in all timeslots
/* Purpose : This function outputs the average all power values of the
/*           selected timeslot (from 0 to 7)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrPowSlot (ViSession instrSession,
                                                                        ViReal64  slotPowerValues[],
                                                                        ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPower(instrSession, RSCMU_COMMAND_SAMP, RSCMU_POWSLOT, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Read all power in all slots
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrPowSlot (ViSession instrSession,
                                                                           ViReal64  slotPowerValues[],
                                                                           ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPower(instrSession, RSCMU_COMMAND_READ, RSCMU_POWSLOT, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch all power in all slots
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrPowSlot (ViSession instrSession,
                                                                           ViReal64  slotPowerValues[],
                                                                           ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPower(instrSession, RSCMU_COMMAND_FETC, RSCMU_POWSLOT, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Sample all power in all slots
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrPowSlot (ViSession instrSession,
                                                                           ViReal64  slotPowerValues[],
                                                                           ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPower(instrSession, RSCMU_COMMAND_SAMP, RSCMU_POWSLOT, slotPowerValues, errorMessage);
}



/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT POWER VERSUS SLOT TABLE MEASUREMENT
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowXslContDef (ViSession instrSession,
                                                                           ViInt32   DefaultValues,
                                                                           ViChar    errorMessage[])
{
  return RSCMU_ConfContDef(instrSession, RSCMU_POWXSL, RSCMU_NONE, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowXslContRep (ViSession instrSession,
                                                                           ViInt32   repetition,
                                                                           ViInt32   stopCondition,
                                                                           ViInt32   stepMode,
                                                                           ViChar    errorMessage[])
{
  return RSCMU_ConfControlRep(instrSession, RSCMU_POWXSL, RSCMU_NONE, repetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowXslContRepStat (ViSession instrSession,
                                                                               ViInt32   NbRepetition,
                                                                               ViInt32   stopCondition,
                                                                               ViInt32   stepMode,
                                                                               ViChar    errorMessage[])
{
  return RSCMU_ConfContRepStat(instrSession, RSCMU_POWXSL, RSCMU_NONE, NbRepetition, stopCondition, stepMode, errorMessage);
}


/*===========================================================================*/
/* Function: Set power subranges
/* Purpose : This function configures the read, fetch and sample commands.
/*           It restricts the measurement to up to 32 subranges where either
/*           all measurement results or a single statistical value is returned
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubPowXsl (ViSession instrSession,
                                                                       ViInt32   statMode,
                                                                       ViInt32   startTime,
                                                                       ViInt32   numberOfsamples,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, statMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, startTime, 0, 127, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, numberOfsamples, 1, 128, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:POW:XSL %s,%d,%d", StrStatistics[statMode], startTime, numberOfsamples);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Slot Count
/* Purpose : This function defines the total number of slots measured.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowXslSco (ViSession instrSession,
                                                                       ViInt32   slotCount,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrSlotCount[]={"S128","S256","S384","S512"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, slotCount, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Configure  slot count
  sprintf (wrtBuf, "CONF:POW:XSL:SCO %s", StrSlotCount[slotCount]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Slot Count for FW >= 3.05
/* Purpose : This function defines the total number of slots measured.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowXslSco305 (ViSession instrSession,
                                                                          ViInt32   Group,
                                                                          ViInt32   SlotCount,
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrGroup[]={"S128","S256","S384","S512"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Group, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, SlotCount, 1, 512, RSCMU_ERROR_PARAMETER3, errorMessage);

  // Configure  slot count
  sprintf (wrtBuf, "CONF:POW:XSL:SCO %s,d", StrGroup[Group], SlotCount);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Start new measurement
/* Purpose : This function starts the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_InitPowXsl (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_POWXSL, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Abort running measurement and switch off
/* Purpose : This function stopss the power measurement, setting it to
/*           the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborPowXsl (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_POWXSL, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: stop measurement after current statistic cycle
/* Purpose : This function stops the power measurement, setting it to
/*           the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopPowXsl (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_POWXSL, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Next Measurement Step
/* Purpose : This function continue the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContPowXsl (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_POWXSL, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Combined Power & Modulation Measurement Status
/* Purpose : This function returns the status of the current Power versus
/*           slot measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPowXslStat (ViSession instrSession,
                                                                        ViInt32  *measStatus,
                                                                        ViInt32  *CurrCycleCounter,
                                                                        ViChar    errorMessage[])
{
  ViInt32 EvalPeriodCounter; //only needed to allow  call of RSCMU_FetcStatus()

  return RSCMU_FetcStatus(instrSession, RSCMU_POWXSL, RSCMU_NONE, measStatus, CurrCycleCounter, &EvalPeriodCounter, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowXslErep (ViSession instrSession,
                                                                        ViInt32   Report,
                                                                        ViChar    errorMessage[])
{
   return RSCMU_ConfReporting(instrSession, RSCMU_POWXSL, RSCMU_NONE, Report, errorMessage);
}

/*===========================================================================*/
/* Function: Read average power in selected slot
/* Purpose : This function outputs the average power value of the
/*           selected timeslot (from 0 to 127)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadPowXslSpow (ViSession instrSession,
                                                                        ViInt32   timeslot,
                                                                        ViReal64 *avgPower,
                                                                        ViChar    errorMessage[])
{
  return RSCMU_MeasScalarPower(instrSession, RSCMU_COMMAND_READ, RSCMU_POWXSL, timeslot, avgPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetches average power in selected slot
/* Purpose : This function outputs the average power value of the
/*           selected timeslot (from 0 to 127)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPowXslSpow (ViSession instrSession,
                                                                        ViInt32   timeslot,
                                                                        ViReal64 *avgPower,
                                                                        ViChar    errorMessage[])
{
   return RSCMU_MeasScalarPower(instrSession, RSCMU_COMMAND_FETC, RSCMU_POWXSL, timeslot, avgPower, errorMessage);
}

/*===========================================================================*/
/* Function: Samples average power in selected slot
/* Purpose : This function outputs the average power value of the
/*           selected timeslot (from 0 to 127)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampPowXslSpow (ViSession instrSession,
                                                                        ViInt32   timeslot,
                                                                        ViReal64 *avgPower,
                                                                        ViChar    errorMessage[])
{
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, timeslot, 0, 127, RSCMU_ERROR_PARAMETER2, errorMessage);

  return RSCMU_MeasScalarPower(instrSession, RSCMU_COMMAND_SAMP, RSCMU_POWXSL, timeslot, avgPower, errorMessage);
}

/*===========================================================================*/
/* Function: Read average power in all slots
/* Purpose : This function outputs the average power value of all
/*           timeslots (from 0 to 127)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrPowXsl (ViSession instrSession,
                                                                       ViReal64  slotPowerValues[],
                                                                       ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPower(instrSession, RSCMU_COMMAND_READ, RSCMU_POWXSL, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetches average power in all slots
/* Purpose : This function outputs the average power value of all
/*           timeslots (from 0 to 127)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrPowXsl (ViSession instrSession,
                                                                       ViReal64  slotPowerValues[],
                                                                       ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPower(instrSession, RSCMU_COMMAND_FETC, RSCMU_POWXSL, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Samples average power in all slots
/* Purpose : This function outputs the average power value of all
/*           timeslots (from 0 to 127)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrPowXsl (ViSession instrSession,
                                                                       ViReal64  slotPowerValues[],
                                                                       ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPower(instrSession, RSCMU_COMMAND_SAMP, RSCMU_POWXSL, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Reads all power in all slots
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrPowXsl (ViSession instrSession,
                                                                          ViReal64  slotPowerValues[],
                                                                          ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPower(instrSession, RSCMU_COMMAND_READ, RSCMU_POWXSL, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetches all power in all slots
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrPowXsl (ViSession instrSession,
                                                                          ViReal64  slotPowerValues[],
                                                                          ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPower(instrSession, RSCMU_COMMAND_FETC, RSCMU_POWXSL, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Samples all power in all slots
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrPowXsl (ViSession instrSession,
                                                                          ViReal64  slotPowerValues[],
                                                                          ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPower(instrSession, RSCMU_COMMAND_SAMP, RSCMU_POWXSL, slotPowerValues, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT POWER VERSUS FRAME MEASUREMENT
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowFramContDef (ViSession instrSession,
                                                                            ViInt32   defaultValues,
                                                                            ViChar    errorMessage[])
{
  return RSCMU_ConfContDef(instrSession, RSCMU_POWFRAM, RSCMU_NONE, defaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowFramContRep (ViSession instrSession,
                                                                            ViInt32   repetition,
                                                                            ViInt32   stopCondition,
                                                                            ViInt32   stepMode,
                                                                            ViChar    errorMessage[])
{
  return RSCMU_ConfControlRep(instrSession, RSCMU_POWFRAM, RSCMU_NONE, repetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowFramContRepStat (ViSession instrSession,
                                                                                ViInt32   NbRepetition,
                                                                                ViInt32   stopCondition,
                                                                                ViInt32   stepMode,
                                                                                ViChar    errorMessage[])
{
  return RSCMU_ConfContRepStat(instrSession, RSCMU_POWFRAM, RSCMU_NONE, NbRepetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Set power subranges
/* Purpose : This function configures the read, fetch and sample commands.
/*           It restricts the measurement to up to 32 subranges where either
/*           all measurement results or a single statistical value is returned
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubPowFram (ViSession instrSession,
                                                                        ViInt32   statMode,
                                                                        ViInt32   startTime,
                                                                        ViInt32   numberOfsamples,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, statMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, startTime, 0, 127, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, numberOfsamples, 1, 128, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:POW:FRAM %s,%d,%d", StrStatistics[statMode], startTime, numberOfsamples);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Start new measurement
/* Purpose : This function starts the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_InitPowFram (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_POWFRAM, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Abort running measurement and switch off
/* Purpose : This function stopss the power measurement, setting it to
/*           the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborPowFram (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_POWFRAM, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Stop measurement after current statistic cycle
/* Purpose : This function stops the power measurement, setting it to
/*           the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopPowFram (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_POWFRAM, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Next Measurement Step
/* Purpose : This function continue the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContPowFram (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_POWFRAM, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Power vs Frame Measurement Status
/* Purpose : This function returns the status of the current Power versus
/*           Frame measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPowFramStat (ViSession instrSession,
                                                                         ViInt32  *measStatus,
                                                                         ViInt32  *CurrCycleCounter,
                                                                         ViChar    errorMessage[])
{
  ViInt32 EvalPeriodCounter; //only needed to allow  call of RSCMU_FetcStatus()

  return RSCMU_FetcStatus(instrSession, RSCMU_POWFRAM, RSCMU_NONE, measStatus, CurrCycleCounter, &EvalPeriodCounter, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowFramErep (ViSession instrSession,
                                                                         ViInt32   Report,
                                                                         ViChar    errorMessage[])
{
  return RSCMU_ConfReporting(instrSession, RSCMU_POWFRAM, RSCMU_NONE, Report, errorMessage);
}

/*===========================================================================*/
/* Function: Reads average power in selected slot
/* Purpose : This function outputs the average power value of the
/*           selected frame (from 1 to 128)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadPowFramFpow (ViSession instrSession,
                                                                         ViInt32   timeslot,
                                                                         ViReal64 *avgPower,
                                                                         ViChar    errorMessage[])
{
  return RSCMU_MeasScalarPower(instrSession, RSCMU_COMMAND_READ, RSCMU_POWFRAM, timeslot, avgPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetches average power in selected slot
/* Purpose : This function outputs the average power value of the
/*           selected frame (from 1 to 128)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPowFramFpow (ViSession instrSession,
                                                                         ViInt32   timeslot,
                                                                         ViReal64 *avgPower,
                                                                         ViChar    errorMessage[])
{
  return RSCMU_MeasScalarPower(instrSession, RSCMU_COMMAND_FETC, RSCMU_POWFRAM, timeslot, avgPower, errorMessage);
}

/*===========================================================================*/
/* Function: Samples average power in selected slot
/* Purpose : This function outputs the average power value of the
/*           selected frame (from 1 to 128)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampPowFramFpow (ViSession instrSession,
                                                                         ViInt32   timeslot,
                                                                         ViReal64 *avgPower,
                                                                         ViChar    errorMessage[])
{
  return RSCMU_MeasScalarPower(instrSession, RSCMU_COMMAND_SAMP, RSCMU_POWFRAM, timeslot, avgPower, errorMessage);
}

/*===========================================================================*/
/* Function: Reads average power in selected slot
/* Purpose : This function outputs the average burst power value in the 128
/*           consecutive timeslots (from 1 to 128)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrPowFram (ViSession instrSession,
                                                                        ViReal64  slotPowerValues[],
                                                                        ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPower(instrSession, RSCMU_COMMAND_READ, RSCMU_POWFRAM, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetches average power in selected slot
/* Purpose : This function outputs the average burst power value in the 128
/*           consecutive timeslots (from 1 to 128)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrPowFram (ViSession instrSession,
                                                                        ViReal64  slotPowerValues[],
                                                                        ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPower(instrSession, RSCMU_COMMAND_FETC, RSCMU_POWFRAM, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Samples average power in selected slot
/* Purpose : This function outputs the average burst power value in the 128
/*           consecutive timeslots (from 1 to 128)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrPowFram (ViSession instrSession,
                                                                        ViReal64  slotPowerValues[],
                                                                        ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPower(instrSession, RSCMU_COMMAND_SAMP, RSCMU_POWFRAM, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Reads all power in all slots
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrPowFram (ViSession instrSession,
                                                                           ViReal64  slotPowerValues[],
                                                                           ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPower(instrSession, RSCMU_COMMAND_READ, RSCMU_POWFRAM, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Reads all power in all slots
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrPowFram (ViSession instrSession,
                                                                           ViReal64  slotPowerValues[],
                                                                           ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPower(instrSession, RSCMU_COMMAND_FETC, RSCMU_POWFRAM, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Reads all power in all slots
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrPowFram (ViSession instrSession,
                                                                           ViReal64  slotPowerValues[],
                                                                           ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPower(instrSession, RSCMU_COMMAND_SAMP, RSCMU_POWFRAM, slotPowerValues, errorMessage);
}


/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT MODULATION
 *    The Test Object MODulation contains the commands for the
 *    measurement of the modulation parameters, ie the frequency and
 *    measured bursts phase error in the GMSK modulation.
 * ----------------------------------------------------------------------------
 *      CONTROL OF MODULATION MEAS
 *      It contains the functions for general control of the modulation
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start Modulation Measurements
/* Purpose : This function start the modulation measurement,
/*           setting it to the status beyond.
/*           RUN        Start measurement without waiting
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_InitMod (ViSession instrSession, ViChar errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_MOD, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Abort Modulation Measurements
/* Purpose : This function abort the running modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborMod (ViSession instrSession, ViChar errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_MOD, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Stop Modulation Measurements
/* Purpose : This function stop measurement after current statistic cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopMod (ViSession instrSession, ViChar errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_MOD, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Run next measurement step
/* Purpose : This function runs next modulation measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContMod (ViSession instrSession, ViChar errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_MOD, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModErep (ViSession  instrSession,
                                                                     ViInt32    Report,
                                                                     ViChar     errorMessage[])
{
  return RSCMU_ConfReporting(instrSession, RSCMU_MOD, RSCMU_NONE, Report, errorMessage);
}

/*===========================================================================*/
/* Function: Modulation Measurement Status
/* Purpose : This function returns the status of the current Modulation
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcModStat (ViSession instrSession,
                                                                     ViInt32   *measStatus,
                                                                     ViInt32   *CountingNo,
                                                                     ViInt32   *StatisticNo,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_FetcStatus(instrSession, RSCMU_MOD, RSCMU_NONE, measStatus, CountingNo, StatisticNo, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      CONFIGURATION
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModCont (ViSession instrSession,
                                                                     ViInt32   MeasuredValuesType,
                                                                     ViInt32   NbBurst,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_ConfControl (instrSession, RSCMU_MOD, RSCMU_NONE, MeasuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModContRep (ViSession  instrSession,
                                                                        ViInt32    repetition,
                                                                        ViInt32    stopCondition,
                                                                        ViInt32    stepMode,
                                                                        ViChar     errorMessage[])
{
  return RSCMU_ConfControlRep(instrSession, RSCMU_MOD, RSCMU_NONE, repetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModContRepStat (ViSession  instrSession,
                                                                            ViInt32    NbRepetition,
                                                                            ViInt32    stopCondition,
                                                                            ViInt32    stepMode,
                                                                            ViChar     errorMessage[])
{
  return RSCMU_ConfContRepStat(instrSession, RSCMU_MOD, RSCMU_NONE, NbRepetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModContDef (ViSession instrSession,
                                                                        ViInt32   defaultValues,
                                                                        ViChar    errorMessage[])
{
  return RSCMU_ConfContDef(instrSession, RSCMU_MOD, RSCMU_NONE, defaultValues, errorMessage);
}

/* ----------------------------------------------------------------------------
 *      LIMITS
 *      The subsystem MODulation:LIMit contains the commands for
 *      definition of tolerance values for the modulation measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Upper ErrorLimits
/* Purpose : This function defines the upper limits for the peak and rms
/*           phase error as well as for the frequency error in the
/*           current burst.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModLimUpp (ViSession instrSession,
                                                                       ViInt32   KindOfBurst,
                                                                       ViReal64  MaxPhaseErrorLimit,
                                                                       ViReal64  RMSPhaseErrorLimit,
                                                                       ViReal64  FrequencyErrorLimit,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) KindOfBurst, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, MaxPhaseErrorLimit, 0, RSCMU_PHASE_ERROR_LIM_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, RMSPhaseErrorLimit, 0, RSCMU_PHASE_ERROR_LIM_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, FrequencyErrorLimit, 0, RSCMU_FREQ_ERROR_LIM_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);

  switch (KindOfBurst)
  {
    case RSCMU_CURRENT:
      sprintf (wrtBuf, "CONF:MOD:LIM:UPP %lf,%lf,%lf", MaxPhaseErrorLimit, RMSPhaseErrorLimit, FrequencyErrorLimit);
      break;
    case RSCMU_AVERAGE:
      sprintf (wrtBuf, "CONF:MOD:LIM:UPP:AVER %lf,%lf,%lf", MaxPhaseErrorLimit, RMSPhaseErrorLimit, FrequencyErrorLimit);
      break;
  }
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Limit Upper Mode
/* Purpose : This function switches the upper limit checking
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModLimUppMod (ViSession instrSession,
                                                                          ViBoolean upperlimitcheck,
                                                                          ViChar    errorMessage[])
{
  return RSCMU_ConfModLimMod(instrSession, RSCMU_UPP, RSCMU_MOD, upperlimitcheck, errorMessage);
}

/*===========================================================================*/
/* Function: Lower ErrorLimits
/* Purpose : This function defines the upper limits for the peak and RMS
/*           phase error as well as for the frequency error in the
/*           current burst.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModLimLow (ViSession instrSession,
                                                                       ViInt32   KindOfBurst,
                                                                       ViReal64  MaxPhaseErrorLimit,
                                                                       ViReal64  FrequencyErrorLimit,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) KindOfBurst, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, MaxPhaseErrorLimit, RSCMU_PHASE_ERROR_LIM_MIN, 0.0, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, FrequencyErrorLimit, RSCMU_FREQ_ERROR_LIM_MIN, 0.0, RSCMU_ERROR_PARAMETER5, errorMessage);

  switch (KindOfBurst)
  {
    case RSCMU_CURRENT:
      sprintf (wrtBuf, "CONF:MOD:LIM:LOW %lf,%lf", MaxPhaseErrorLimit, FrequencyErrorLimit);
      break;
    case RSCMU_AVERAGE:
      sprintf (wrtBuf, "CONF:MOD:LIM:LOW:AVER %lf,%lf", MaxPhaseErrorLimit, FrequencyErrorLimit);
      break;
  }
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Limit Lower Mode
/* Purpose : This function switches the lower limit checking
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModLimLowMod (ViSession instrSession,
                                                                          ViBoolean lowerlimitcheck,
                                                                          ViChar    errorMessage[])
{
  return RSCMU_ConfModLimMod(instrSession, RSCMU_LOW, RSCMU_MOD, lowerlimitcheck, errorMessage);
}

/*===========================================================================*/
/* Function: Type of decoding
/* Purpose : This function selects the type of decoding applied for the
/*           determination of phase and frequency errors.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModTimeDec (ViSession instrSession,
                                                                        ViBoolean typeOfDecoding,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) typeOfDecoding, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (typeOfDecoding)
  {
    case RSCMU_STAN:
      strcpy (wrtBuf, "CONF:MOD:TIME:DEC STAN");
      break;
    case RSCMU_GTB:
      strcpy (wrtBuf, "CONF:MOD:TIME:DEC GTB");
      break;
  }
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Configure Subranges...
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubModRang (ViSession instrSession,
                                                                        ViInt32   statistics,
                                                                        ViReal64  startTime,
                                                                        ViInt32   samples,
                                                                        ViChar    errorMessage[])

{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, statistics, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:MOD %s,%lf,%d", StrStatistics[statistics],startTime*1E-6,samples);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      RESULTS: FREQUENCY AND PHASE ERROR
 *      The subsystem MODulation[:RESULT] contains the commands for
 *      measurement and output of the frequency and phase error and
 *      their comparison with the tolerance values.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function start a measurement and output all scalar,
/*           numeric measurement results.
/*      These are:
/*  Maximum phase error with single-value measurement
/*             => phase error peak current
/*  Maximum phase error with average measurement
/*             => phase error peak average
/*  Maximum phase error with extreme-value measurement
/*             => phase error peak max./min.
/*  Rms phase error with single-value measurement
/*             => phase error RMS current
/*  Rms phase error with average measurement
/*             => phase error RMS average
/*  Rms phase error with extreme-value measurement
/*             => phase error RMS max./min.
/*  Frequency error with single-value measurement
/*             => frequency error current
/*  Frequency error with average measurement
/*             => frequency error average
/*  Frequency error with extreme-value measurement
/*             => frequency error max./min.
/*  Average burst power with single-value measurement
/*             => avg. burst power current
/*  Relative portion of faulty burst
/*             => bursts out of tolerance
/*
/*      Average measurement means that the results of the single-value
/*      measurement are averaged over several bursts. Extreme-value
/*      measurement means that the extreme value is determined from the
/*      results of the single-value measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadMod (ViSession instrSession,
                                                                 ViInt32   StatisticsMode,
                                                                 ViReal64 *phErrPeak,
                                                                 ViReal64 *phErrRMS,
                                                                 ViReal64 *freqErr,
                                                                 ViReal64 *avgBurstPowerCurr,
                                                                 ViReal64 *burstOutOfTol,
                                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU_Status = RSCMU_Query (instrSession, "READ:MOD?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  RSCMU_Status = RSCMU_ScanMod (tab , 0, StatisticsMode, phErrPeak, phErrRMS, freqErr, avgBurstPowerCurr, burstOutOfTol);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function start a measurement and output all scalar,
/*           numeric measurement results.
/*      These are:
/*  Maximum phase error with single-value measurement
/*             => phase error peak current
/*  Maximum phase error with average measurement
/*             => phase error peak average
/*  Maximum phase error with extreme-value measurement
/*             => phase error peak max./min.
/*  Rms phase error with single-value measurement
/*             => phase error RMS current
/*  Rms phase error with average measurement
/*             => phase error RMS average
/*  Rms phase error with extreme-value measurement
/*             => phase error RMS max./min.
/*  Frequency error with single-value measurement
/*             => frequency error current
/*  Frequency error with average measurement
/*             => frequency error average
/*  Frequency error with extreme-value measurement
/*             => frequency error max./min.
/*  Average burst power with single-value measurement
/*             => avg. burst power current
/*  Relative portion of faulty burst
/*             => bursts out of tolerance
/*
/*      Average measurement means that the results of the single-value
/*      measurement are averaged over several bursts. Extreme-value
/*      measurement means that the extreme value is determined from the
/*      results of the single-value measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcMod (ViSession instrSession,
                                                                 ViInt32   StatisticsMode,
                                                                 ViReal64  *phErrPeak,
                                                                 ViReal64  *phErrRMS,
                                                                 ViReal64  *freqErr,
                                                                 ViReal64  *avgBurstPowerCurr,
                                                                 ViReal64  *burstOutOfTol,
                                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU_Status = RSCMU_Query (instrSession, "FETC:MOD?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Scan the results of Modulation
  RSCMU_ScanMod (tab, 0, StatisticsMode, phErrPeak, phErrRMS, freqErr, avgBurstPowerCurr, burstOutOfTol);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampMod (ViSession instrSession,
                                                                 ViInt32   StatisticsMode,
                                                                 ViReal64  *phErrPeak,
                                                                 ViReal64  *phErrRMS,
                                                                 ViReal64  *freqErr,
                                                                 ViReal64  *avgBurstPowerCurr,
                                                                 ViReal64  *burstOutOfTol,
                                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU_Status = RSCMU_Query (instrSession, "SAMP:MOD?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Scan the results of Modulation
  RSCMU_ScanMod (tab, 0, StatisticsMode, phErrPeak, phErrRMS, freqErr, avgBurstPowerCurr, burstOutOfTol);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcModLimMatc (ViSession  instrSession,
                                                                        ViInt32    StatisticsMode,
                                                                        ViInt32    *phErrPeak,
                                                                        ViInt32    *phErrRMS,
                                                                        ViInt32    *freqErr,
                                                                        ViInt32    *avgBurstPowerCurr,
                                                                        ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  if ((RSCMU_Status = RSCMU_Query (instrSession, "CALC:MOD:LIM:MATC?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  switch (StatisticsMode)
  {
    case RSCMU_CURRENT:
      // Max phase error with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrPeak,TableOfDataValues,0);
      // RMS phase error with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrRMS,TableOfDataValues,3);
      // Frequency error with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (freqErr,TableOfDataValues,6);
    break;
    case RSCMU_AVERAGE:
      // Max phase error with average measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrPeak, TableOfDataValues, 1);
      // RMS phase error with average measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrRMS, TableOfDataValues, 4);
      // Frequency error with average measurement
      RSCMU_Status = RSCMU_GetMatchingValue (freqErr, TableOfDataValues, 7);
    break;
    case RSCMU_MAXMIN:
      // Max phase error with extreme-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrPeak,TableOfDataValues, 2);
      // RMS phase error with extreme-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrRMS,TableOfDataValues, 5);
      // Frequency error with extreme-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (freqErr,TableOfDataValues, 8);
    break;
  }
  // Average burst power with single-value measurement
  RSCMU_Status = RSCMU_GetMatchingValue (avgBurstPowerCurr, TableOfDataValues, 9);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Read Phase Error in Burst...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrModBurs (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  PhaseErrorValues[],
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViInt32     NbOfMeasValues = 0;
  ViChar      PhaseErrorTmp[669][20];
  ViChar*     hugeBuf = VI_NULL;
  ViChar*     p2buf;
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:ARR:MOD:%s?", StrMode[Mode]);
  CHECKRETMSG(RSCMU_viWrite(instrSession, wrtBuf, strlen(wrtBuf)));

  RSCMU_Status = RSCMU_ReadDataUnknownLength (instrSession, &hugeBuf, VI_NULL);

  if (!RSCMU_Status)
  {
    p2buf = hugeBuf;
    // Find all burst power values by breaking the read buffer:
    NbOfMeasValues = RSCMU_scanStringBurst (p2buf, PhaseErrorTmp);
  }

  if (hugeBuf) free ( hugeBuf );

  CHECKRETMSG(RSCMU_Status);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, PhaseErrorTmp, PhaseErrorValues);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Fetch Phase Error in Burst...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrModBurs (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  PhaseErrorValues[],
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      PhaseErrorTmp[669][20];

  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:ARR:MOD:%s?", StrMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, PhaseErrorTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, PhaseErrorTmp, PhaseErrorValues);

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Sample Phase Error in Burst...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrModBurs (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  PhaseErrorValues[],
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      PhaseErrorTmp[669][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:ARR:MOD:%s?", StrMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, PhaseErrorTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, PhaseErrorTmp, PhaseErrorValues);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Read Phase Error in Burst (SubArray)...
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrModBurs (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViReal64  PhaseErrorValues[],
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      PhaseErrorTmp[669][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:SUB:MOD:%s?", StrMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, PhaseErrorTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, PhaseErrorTmp, PhaseErrorValues);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Fetch Phase Error in Burst (SubArray)...
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrModBurs (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViReal64  PhaseErrorValues[],
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      PhaseErrorTmp[669][20];

  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:SUB:MOD:%s?", StrMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, PhaseErrorTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, PhaseErrorTmp, PhaseErrorValues);

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Sample Phase Error in Burst (SubArray)...
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrModBurs (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViReal64  PhaseErrorValues[],
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      PhaseErrorTmp[669][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:SUB:MOD:%s?", StrMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, PhaseErrorTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, PhaseErrorTmp, PhaseErrorValues);

  return RSCMU_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT MODULATION XPERror
 *    The subsystem MODulation:XPERror measures the modulation parameters (frequency
 *    and errors) in GMSK modulation including the I/Q Imbalance and the Origin
 *    Offset in the I/Q constellation diagram. The subsystem corresponds to the
 *    measurement menu Modulation, application Ext. Phase Err. GMSK, and the
 *    associated popup menu Modulation Configuration.
 * ----------------------------------------------------------------------------
 *      CONTROL OF MODULATION MEAS
 *      It contains the functions for general control of the modulation
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start Modulation Measurements
/* Purpose : This function start the modulation measurement,
/*           setting it to the status beyond.
/*           RUN        Start measurement without waiting
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_InitModXper (ViSession instrSession, ViChar errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_MODXPER, RSCMU_GMSK, errorMessage);
}

/*===========================================================================*/
/* Function: Abort Modulation Measurements
/* Purpose : This function abort the running modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborModXper (ViSession instrSession, ViChar errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_MODXPER, RSCMU_GMSK, errorMessage);
}

/*===========================================================================*/
/* Function: Stop Modulation Measurements
/* Purpose : This function stop measurement after current statistic cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopModXper (ViSession instrSession, ViChar errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_MODXPER, RSCMU_GMSK, errorMessage);
}

/*===========================================================================*/
/* Function: Run next measurement step
/* Purpose : This function runs next modulation measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContModXper (ViSession instrSession, ViChar errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_MODXPER, RSCMU_GMSK, errorMessage);
}

/*===========================================================================*/
/* Function: Modulation Measurement Status
/* Purpose : This function returns the status of the current Modulation
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcModXperStat (ViSession  instrSession,
                                                                         ViInt32   *measStatus,
                                                                         ViInt32   *CountingNo,
                                                                         ViInt32   *StatisticNo,
                                                                         ViChar     errorMessage[])
{
  return RSCMU_FetcStatus(instrSession, RSCMU_MODXPER, RSCMU_GMSK, measStatus, CountingNo, StatisticNo, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModXperErep (ViSession instrSession,
                                                                         ViInt32   Report,
                                                                         ViChar    errorMessage[])
{
  return RSCMU_ConfReporting(instrSession, RSCMU_MODXPER, RSCMU_NONE, Report, errorMessage);
}



/*
 * ----------------------------------------------------------------------------
 *      CONFIGURATION
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModXperCont (ViSession instrSession,
                                                                         ViInt32   measuredValuesType,
                                                                         ViInt32   NbBurst,
                                                                         ViChar    errorMessage[])
{
  return RSCMU_ConfControl (instrSession, RSCMU_MODXPER, RSCMU_GMSK, measuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModXperContRepStat (ViSession instrSession,
                                                                                ViInt32   NbRepetition,
                                                                                ViInt32   stopCondition,
                                                                                ViInt32   stepMode,
                                                                                ViChar    errorMessage[])
{
  return RSCMU_ConfContRepStat(instrSession, RSCMU_MODXPER, RSCMU_GMSK, NbRepetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModXperContRep (ViSession instrSession,
                                                                            ViInt32   repetition,
                                                                            ViInt32   stopCondition,
                                                                            ViInt32   stepMode,
                                                                            ViChar    errorMessage[])
{
  return RSCMU_ConfControlRep(instrSession, RSCMU_MODXPER, RSCMU_GMSK, repetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModXperContDef (ViSession instrSession,
                                                                            ViInt32   defaultValues,
                                                                            ViChar    errorMessage[])
{
  return RSCMU_ConfContDef(instrSession, RSCMU_MODXPER, RSCMU_GMSK, defaultValues, errorMessage);
}

/* ----------------------------------------------------------------------------
 *      LIMITS
 *      The subsystem MODulation:LIMit contains the commands for
 *      definition of tolerance values for the modulation measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Upper ErrorLimits
/* Purpose : This function defines the upper limits for the peak and rms
/*           phase error as well as for the frequency error in the
/*           current burst.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModXperLim (ViSession instrSession,
                                                                        ViBoolean kindOfBurst,
                                                                        ViReal64  phaseErrorPeakLimit,
                                                                        ViReal64  phaseErrorRMSLimit,
                                                                        ViReal64  originOffsetLimit,
                                                                        ViReal64  IQImbalanceLimit,
                                                                        ViReal64  frequencyErrorLowerLimit,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) kindOfBurst, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, phaseErrorPeakLimit, 0.0, RSCMU_PHASE_ERROR_LIM_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, phaseErrorRMSLimit, 0.0, RSCMU_PHASE_ERROR_LIM_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, originOffsetLimit, RSCMU_ORIGIN_OFFSET_LIM_MIN, RSCMU_ORIGIN_OFFSET_LIM_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, IQImbalanceLimit, RSCMU_ORIGIN_OFFSET_LIM_MIN, RSCMU_ORIGIN_OFFSET_LIM_MAX, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, frequencyErrorLowerLimit, 0.0, RSCMU_FREQ_ERROR_LIM_MAX, RSCMU_ERROR_PARAMETER7, errorMessage);

  switch (kindOfBurst)
  {
    case RSCMU_CURRENT:
      sprintf (wrtBuf, "CONF:MOD:XPER:LIM %lf,%lf,%lf,%lf,%lf", phaseErrorPeakLimit, phaseErrorRMSLimit, originOffsetLimit, IQImbalanceLimit, frequencyErrorLowerLimit);
      break;
    case RSCMU_AVERAGE:
      sprintf (wrtBuf, "CONF:MOD:XPER:LIM:AVER %lf,%lf,%lf,%lf,%lf", phaseErrorPeakLimit, phaseErrorRMSLimit, originOffsetLimit, IQImbalanceLimit, frequencyErrorLowerLimit);
      break;
  }
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Limit Upper Mode
/* Purpose : This function switches the upper limit checking
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModXperLimUppMod (ViSession instrSession,
                                                                              ViBoolean upperlimitcheck,
                                                                              ViChar    errorMessage[])
{
  return RSCMU_ConfModLimMod(instrSession, RSCMU_UPP, RSCMU_MODXPER, upperlimitcheck, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lower Mode
/* Purpose : This function switches the lower limit checking
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModXperLimLowMod (ViSession instrSession,
                                                                              ViBoolean upperlimitcheck,
                                                                              ViChar    errorMessage[])
{
  return RSCMU_ConfModLimMod(instrSession, RSCMU_LOW, RSCMU_MODXPER, upperlimitcheck, errorMessage);
}

/*===========================================================================*/
/* Function: Type of decoding
/* Purpose : This function selects the type of decoding applied for the
/*           determination of phase and frequency errors.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModXperTimeDec (ViSession instrSession,
                                                                            ViBoolean typeOfDecoding,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) typeOfDecoding, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (typeOfDecoding)
  {
    case RSCMU_STAN:
      strcpy (wrtBuf, "CONF:MOD:XPER:TIME:DEC STAN");
      break;
    case RSCMU_GTB:
      strcpy (wrtBuf, "CONF:MOD:XPER:TIME:DEC GTB");
      break;
  }
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Raw Symbol Timing Recovery
/* Purpose : This function specifies how the R&S CMU determines the raw symbol
/*           timing in order to demodulate the signal and calculate the
/*           modulation results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModXperRstr (ViSession instrSession,
                                                  ViBoolean raw_symbol_timing_recovery,
                                                  ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    RETMSG(RSCMU_setEnum(instrSession, "CONF:MOD:XPER:RSTR",
                            raw_symbol_timing_recovery,
                            recoveryArr,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Filter
/* Purpose : This function selects the measurement filter for the Modulation
/*           XPER measurement. The default filter setting differs for the two
/*           modulation schemes.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModXperFilt (ViSession instrSession,
                                                                         ViInt32   Filter,
                                                                         ViChar    errorMessage[])
{
  return RSCMU_ConfFilt(instrSession, RSCMU_MODXPER, RSCMU_GMSK, Filter, errorMessage);
}

/*===========================================================================*/
/* Function: Configure Subranges...
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubModXper (ViSession instrSession,
                                                                        ViInt32   statistics,
                                                                        ViReal64  startTime,
                                                                        ViInt32   samples,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, statistics, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:MOD:XPER %s,%lf,%d", StrStatistics[statistics],startTime*1E-6,samples);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      RESULTS: FREQUENCY AND PHASE ERROR
 *      The subsystem MODulation[:RESULT] contains the commands for
 *      measurement and output of the frequency and phase error and
 *      their comparison with the tolerance values.
 *-----------------------------------------------------------------------------
 *        SCALAR for FW 2.15
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function start a measurement and output all scalar,
/*           numeric measurement results.
/*      These are:
/*  Phase error Peak with single-value measurement
/*             => phase error peak current
/*  Phase error Peak with average measurement
/*             => phase error peak average
/*  Phase error Peak with extreme-value measurement
/*             => phase error peak max./min.
/*  Phase error RMS with single-value measurement
/*             => phase error RMS current
/*  Phase error RMS with average measurement
/*             => phase error RMS average
/*  Phase error RMS with extreme-value measurement
/*             => phase error RMS max./min.
/*  Origin Offset with single-value measurement
/*             => Origin offset current
/*  Origin Offset with average measurement
/*             => Origin offset average
/*  Origin Offset with extreme-value measurement
/*             => Origin offset max./min.
/*  I/Q Imbalanced with single-value measurement
/*             => I/Q Imbalanced current
/*  I/Q Imbalanced with average measurement
/*             => I/Q Imbalanced average
/*  I/Q Imbalanced with extreme-value measurement
/*             => I/Q Imbalanced max./min.
/*  Frequency error with single-value measurement
/*             => frequency error current
/*  Frequency error with average measurement
/*             => frequency error average
/*  Frequency error with extreme-value measurement
/*             => frequency error max./min.
/*  Average burst power with single-value measurement
/*             => avg. burst power current
/*  Relative portion of faulty burst
/*             => bursts out of tolerance
/*
/*      Average measurement means that the results of the single-value
/*      measurement are averaged over several bursts. Extreme-value
/*      measurement means that the extreme value is determined from the
/*      results of the single-value measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadModXper (ViSession instrSession,
                                                                     ViInt32   statistics,
                                                                     ViReal64 *phErrPeak,
                                                                     ViReal64 *phErrRMS,
                                                                     ViReal64 *originOffset,
                                                                     ViReal64 *IQImbalance,
                                                                     ViReal64 *freqErr,
                                                                     ViReal64 *avgBurstPowerCurr,
                                                                     ViReal64 *burstOutOfTol_,
                                                                     ViChar    errorMessage[])
{
  ViStatus RSCMU_Status = VI_SUCCESS;
  ViReal64 PhaseOfOriginOffsetVector;
  struct   RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  return RSCMU_MeasModXper(instrSession, RSCMU_MODXPER, RSCMU_COMMAND_READ, statistics, phErrPeak, phErrRMS, originOffset, IQImbalance, freqErr, avgBurstPowerCurr, burstOutOfTol_, &PhaseOfOriginOffsetVector, errorMessage);
}


/*===========================================================================*/
/* Function: All Measured Values
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcModXper (ViSession instrSession,
                                                                     ViInt32   statistics,
                                                                     ViReal64 *phErrPeak,
                                                                     ViReal64 *phErrRMS,
                                                                     ViReal64 *originOffset,
                                                                     ViReal64 *IQImbalance,
                                                                     ViReal64 *freqErr,
                                                                     ViReal64 *avgBurstPowerCurr,
                                                                     ViReal64 *burstOutOfTol,
                                                                     ViChar    errorMessage[])
{
  ViStatus RSCMU_Status = VI_SUCCESS;
  ViReal64 PhaseOfOriginOffsetVector;
  struct   RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  return RSCMU_MeasModXper(instrSession, RSCMU_MODXPER, RSCMU_COMMAND_FETC, statistics, phErrPeak, phErrRMS, originOffset, IQImbalance, freqErr, avgBurstPowerCurr, burstOutOfTol, &PhaseOfOriginOffsetVector, errorMessage);
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampModXper (ViSession instrSession,
                                                                     ViInt32   statistics,
                                                                     ViReal64 *phErrPeak,
                                                                     ViReal64 *phErrRMS,
                                                                     ViReal64 *originOffset,
                                                                     ViReal64 *IQImbalance,
                                                                     ViReal64 *freqErr,
                                                                     ViReal64 *avgBurstPowerCurr,
                                                                     ViReal64 *burstOutOfTol,
                                                                     ViChar    errorMessage[])
{
  ViStatus RSCMU_Status = VI_SUCCESS;
  ViReal64 PhaseOfOriginOffsetVector;
  struct   RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  return RSCMU_MeasModXper(instrSession, RSCMU_MODXPER, RSCMU_COMMAND_SAMP, statistics, phErrPeak, phErrRMS, originOffset, IQImbalance, freqErr, avgBurstPowerCurr, burstOutOfTol, &PhaseOfOriginOffsetVector, errorMessage);
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcModXperLimMatc (ViSession instrSession,
                                                                            ViInt32   statistics,
                                                                            ViInt32  *phErrPeak,
                                                                            ViInt32  *phErrRMS,
                                                                            ViInt32  *originOffset,
                                                                            ViInt32  *IQImbalance,
                                                                            ViInt32  *freqErr,
                                                                            ViInt32  *avgBurstPowerCurr,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, statistics, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  if ((RSCMU_Status = RSCMU_Query (instrSession, "CALC:MOD:XPER:LIM:MATC?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  switch (statistics)
  {
    case RSCMU_CURRENT:
      // Max phase error with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrPeak,TableOfDataValues,0);
      // RMS phase error with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrRMS,TableOfDataValues,3);
      // Origin Offset with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (originOffset,TableOfDataValues,6);
      // I/Q Imbalance with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (IQImbalance,TableOfDataValues,9);
      // Frequency error with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (freqErr,TableOfDataValues,12);
    break;
    case RSCMU_AVERAGE:
      // Max phase error with average measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrPeak, TableOfDataValues, 1);
      // RMS phase error with average measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrRMS, TableOfDataValues, 4);
      // Origin Offset with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (originOffset,TableOfDataValues,7);
      // I/Q Imbalance with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (IQImbalance,TableOfDataValues,10);
      // Frequency error with average measurement
      RSCMU_Status = RSCMU_GetMatchingValue (freqErr, TableOfDataValues, 13);
    break;
    case RSCMU_MAXMIN:
      // Max phase error with extreme-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrPeak,TableOfDataValues, 2);
      // RMS phase error with extreme-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrRMS,TableOfDataValues, 5);
      // Origin Offset with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (originOffset,TableOfDataValues,8);
      // I/Q Imbalance with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (IQImbalance,TableOfDataValues,11);
      // Frequency error with extreme-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (freqErr,TableOfDataValues, 14);
    break;
  }
  // Average burst power with single-value measurement
  RSCMU_Status = RSCMU_GetMatchingValue (avgBurstPowerCurr, TableOfDataValues, 15);

  return RSCMU_Status;
}

/*
 *-----------------------------------------------------------------------------
 *        SCALAR for FW >= 2.16
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function start a measurement and output all scalar,
/*           numeric measurement results.
/*      These are:
/*  Phase error Peak with single-value measurement
/*             => phase error peak current
/*  Phase error Peak with average measurement
/*             => phase error peak average
/*  Phase error Peak with extreme-value measurement
/*             => phase error peak max./min.
/*  Phase error RMS with single-value measurement
/*             => phase error RMS current
/*  Phase error RMS with average measurement
/*             => phase error RMS average
/*  Phase error RMS with extreme-value measurement
/*             => phase error RMS max./min.
/*  Origin Offset with single-value measurement
/*             => Origin offset current
/*  Origin Offset with average measurement
/*             => Origin offset average
/*  Origin Offset with extreme-value measurement
/*             => Origin offset max./min.
/*  I/Q Imbalanced with single-value measurement
/*             => I/Q Imbalanced current
/*  I/Q Imbalanced with average measurement
/*             => I/Q Imbalanced average
/*  I/Q Imbalanced with extreme-value measurement
/*             => I/Q Imbalanced max./min.
/*  Frequency error with single-value measurement
/*             => frequency error current
/*  Frequency error with average measurement
/*             => frequency error average
/*  Frequency error with extreme-value measurement
/*             => frequency error max./min.
/*  Average burst power with single-value measurement
/*             => avg. burst power current
/*  Relative portion of faulty burst
/*             => bursts out of tolerance
/*  Phase Of Origin Offset Vector
/*
/*      Average measurement means that the results of the single-value
/*      measurement are averaged over several bursts. Extreme-value
/*      measurement means that the extreme value is determined from the
/*      results of the single-value measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadModXperPoov (ViSession instrSession,
                                                                         ViInt32   statistics,
                                                                         ViReal64 *phErrPeak,
                                                                         ViReal64 *phErrRMS,
                                                                         ViReal64 *originOffset,
                                                                         ViReal64 *IQImbalance,
                                                                         ViReal64 *freqErr,
                                                                         ViReal64 *avgBurstPowerCurr,
                                                                         ViReal64 *burstOutOfTol_,
                                                                         ViReal64 *PhaseOfOriginOffsetVector,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_16)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_16, errorMessage);

  return RSCMU_MeasModXper(instrSession, RSCMU_MODXPER, RSCMU_COMMAND_READ, statistics, phErrPeak, phErrRMS, originOffset, IQImbalance, freqErr, avgBurstPowerCurr, burstOutOfTol_, PhaseOfOriginOffsetVector, errorMessage);
}


/*===========================================================================*/
/* Function: All Measured Values
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcModXperPoov (ViSession instrSession,
                                                                         ViInt32   statistics,
                                                                         ViReal64 *phErrPeak,
                                                                         ViReal64 *phErrRMS,
                                                                         ViReal64 *originOffset,
                                                                         ViReal64 *IQImbalance,
                                                                         ViReal64 *freqErr,
                                                                         ViReal64 *avgBurstPowerCurr,
                                                                         ViReal64 *burstOutOfTol,
                                                                         ViReal64 *PhaseOfOriginOffsetVector,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_16)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_16, errorMessage);

  return RSCMU_MeasModXper(instrSession, RSCMU_MODXPER, RSCMU_COMMAND_FETC, statistics, phErrPeak, phErrRMS, originOffset, IQImbalance, freqErr, avgBurstPowerCurr, burstOutOfTol, PhaseOfOriginOffsetVector, errorMessage);
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampModXperPoov (ViSession instrSession,
                                                                         ViInt32   statistics,
                                                                         ViReal64 *phErrPeak,
                                                                         ViReal64 *phErrRMS,
                                                                         ViReal64 *originOffset,
                                                                         ViReal64 *IQImbalance,
                                                                         ViReal64 *freqErr,
                                                                         ViReal64 *avgBurstPowerCurr,
                                                                         ViReal64 *burstOutOfTol,
                                                                         ViReal64 *PhaseOfOriginOffsetVector,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_16)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_16, errorMessage);

  return RSCMU_MeasModXper(instrSession, RSCMU_MODXPER, RSCMU_COMMAND_SAMP, statistics, phErrPeak, phErrRMS, originOffset, IQImbalance, freqErr, avgBurstPowerCurr, burstOutOfTol, PhaseOfOriginOffsetVector, errorMessage);
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcModXperPoovLimMatc (ViSession instrSession,
                                                                                ViInt32   statistics,
                                                                                ViInt32  *phErrPeak,
                                                                                ViInt32  *phErrRMS,
                                                                                ViInt32  *originOffset,
                                                                                ViInt32  *IQImbalance,
                                                                                ViInt32  *freqErr,
                                                                                ViInt32  *avgBurstPowerCurr,
                                                                                ViInt32  *PhaseOfOriginOffsetVector,
                                                                                ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_16)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_16, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, statistics, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  if ((RSCMU_Status = RSCMU_Query (instrSession, "CALC:MOD:XPER:LIM:MATC?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  switch (statistics)
  {
    case RSCMU_CURRENT:
      // Max phase error with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrPeak,TableOfDataValues,0);
      // RMS phase error with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrRMS,TableOfDataValues,3);
      // Origin Offset with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (originOffset,TableOfDataValues,6);
      // I/Q Imbalance with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (IQImbalance,TableOfDataValues,9);
      // Frequency error with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (freqErr,TableOfDataValues,12);
    break;
    case RSCMU_AVERAGE:
      // Max phase error with average measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrPeak, TableOfDataValues, 1);
      // RMS phase error with average measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrRMS, TableOfDataValues, 4);
      // Origin Offset with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (originOffset,TableOfDataValues,7);
      // I/Q Imbalance with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (IQImbalance,TableOfDataValues,10);
      // Frequency error with average measurement
      RSCMU_Status = RSCMU_GetMatchingValue (freqErr, TableOfDataValues, 13);
    break;
    case RSCMU_MAXMIN:
      // Max phase error with extreme-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrPeak,TableOfDataValues, 2);
      // RMS phase error with extreme-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrRMS,TableOfDataValues, 5);
      // Origin Offset with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (originOffset,TableOfDataValues,8);
      // I/Q Imbalance with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (IQImbalance,TableOfDataValues,11);
      // Frequency error with extreme-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (freqErr,TableOfDataValues, 14);
    break;
  }
  // Average burst power with single-value measurement
  RSCMU_Status = RSCMU_GetMatchingValue (avgBurstPowerCurr, TableOfDataValues, 15);

  // Phase of the origin offset vector
  RSCMU_Status = RSCMU_GetMatchingValue (PhaseOfOriginOffsetVector, TableOfDataValues, 16);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Reads Phase Error in Burst...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 588 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrModXper (ViSession instrSession,
                                                                        ViInt32   statistics,
                                                                        ViReal64  phaseError_inBurstValues[],
                                                                        ViChar    errorMessage[])
{
  return RSCMU_MeasArrModXper(instrSession, RSCMU_COMMAND_READ, statistics, phaseError_inBurstValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetches Phase Error in Burst...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 588 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrModXper (ViSession instrSession,
                                                                        ViInt32   statistics,
                                                                        ViReal64  phaseError_inBurstValues[],
                                                                        ViChar    errorMessage[])
{
  return RSCMU_MeasArrModXper(instrSession, RSCMU_COMMAND_FETC, statistics, phaseError_inBurstValues, errorMessage);
}

/*===========================================================================*/
/* Function: Samples Phase Error in Burst...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 588 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrModXper (ViSession instrSession,
                                                                        ViInt32   statistics,
                                                                        ViReal64  phaseError_inBurstValues[],
                                                                        ViChar    errorMessage[])
{
  return RSCMU_MeasArrModXper(instrSession, RSCMU_COMMAND_SAMP, statistics, phaseError_inBurstValues, errorMessage);
}

/*===========================================================================*/
/* Function: Read Phase Error in Burst (SubArray)...
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrModXper (ViSession instrSession,
                                                                           ViInt32   statistics,
                                                                           ViReal64  phaseError_inBurstValues[],
                                                                           ViChar    errorMessage[])
{
  return RSCMU_MeasSubArrModXper(instrSession, RSCMU_COMMAND_READ, statistics, phaseError_inBurstValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetches Phase Error in Burst (SubArray)...
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrModXper (ViSession instrSession,
                                                                           ViInt32   statistics,
                                                                           ViReal64  phaseError_inBurstValues[],
                                                                           ViChar    errorMessage[])
{
  return RSCMU_MeasSubArrModXper(instrSession, RSCMU_COMMAND_FETC, statistics, phaseError_inBurstValues, errorMessage);
}

/*===========================================================================*/
/* Function: Samples Phase Error in Burst (SubArray)...
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrModXper (ViSession instrSession,
                                                                           ViInt32   statistics,
                                                                           ViReal64  phaseError_inBurstValues[],
                                                                           ViChar    errorMessage[])
{
  return RSCMU_MeasSubArrModXper(instrSession, RSCMU_COMMAND_SAMP, statistics, phaseError_inBurstValues, errorMessage);
}



/*********************************************************************************
** Dmod Bits
*********************************************************************************/


/*===========================================================================*/
/* Configure Demod Bits
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModDemodBits (ViSession instrSession,
                                                    ViInt32   edgeModMeasurement,
                                                    ViInt32   demodBits,
                                                    ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "CONFigure:MODulation:%s:EPSK:DBITs", list[edgeModMeasurement]);

    RETMSG(RSCMU_setViString(instrSession, wrtBuf,
                             mode_On_Off[demodBits],
                             RSCMU_ERROR_PARAMETER2));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModDemodBits (ViSession instrSession,
                                                    ViInt32   edgeModMeasurement,
                                                    ViInt32   demodBits,
                                                    ViChar    errorMessage[])
{
    return RSCMU_EDGE_NSig_ConfModDemodBits (instrSession,
                                             edgeModMeasurement,
                                             demodBits,
                                             errorMessage);
}


/*===========================================================================*/
/* Read Array Demod Bits
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadArrModDemodBits (ViSession instrSession,
                                                       ViInt32   edgeModMeasurement,
                                                       ViInt32   demodBits[],
                                                       ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "READ:ARRay:MODulation:%s:EPSK:DBITs", list[edgeModMeasurement]);

    RETMSG(RSCMU_MeasArrayInt( instrSession, wrtBuf
                               ,demodBits, errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadArrModDemodBits (ViSession instrSession,
                                                       ViInt32   edgeModMeasurement,
                                                       ViInt32   demodBits[],
                                                       ViChar    errorMessage[])
{
        return RSCMU_EDGE_NSig_ReadArrModDemodBits (instrSession,
                                                    edgeModMeasurement,
                                                    demodBits,
                                                    errorMessage);
}

/*===========================================================================*/
/* Fetch Array Demod Bits
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcArrModDemodBits (ViSession instrSession,
                                                       ViInt32   edgeModMeasurement,
                                                       ViInt32   demodBits[],
                                                       ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "FETCh:ARRay:MODulation:%s:EPSK:DBITs", list[edgeModMeasurement]);

    RETMSG(RSCMU_MeasArrayInt( instrSession, wrtBuf
                               ,demodBits, errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcArrModDemodBits (ViSession instrSession,
                                                       ViInt32   edgeModMeasurement,
                                                       ViInt32   demodBits[],
                                                       ViChar    errorMessage[])
{
        return RSCMU_EDGE_NSig_FetcArrModDemodBits (instrSession,
                                                    edgeModMeasurement,
                                                    demodBits,
                                                    errorMessage);
}

/*===========================================================================*/
/* Sample Array Demod Bits
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampArrModDemodBits (ViSession instrSession,
                                                       ViInt32   edgeModMeasurement,
                                                       ViInt32   demodBits[],
                                                       ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "SAMPle:ARRay:MODulation:%s:EPSK:DBITs", list[edgeModMeasurement]);

    RETMSG(RSCMU_MeasArrayInt( instrSession, wrtBuf
                               ,demodBits, errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampArrModDemodBits (ViSession instrSession,
                                                       ViInt32   edgeModMeasurement,
                                                       ViInt32   demodBits[],
                                                       ViChar    errorMessage[])
{
        return RSCMU_EDGE_NSig_SampArrModDemodBits (instrSession,
                                                    edgeModMeasurement,
                                                    demodBits,
                                                    errorMessage);
}

/*===========================================================================*/
/* Read Scalar Demod Bits
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadScalModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "READ:SCALar:MODulation:%s:EPSK:DBITs? %d", list[edgeModMeasurement],measPointSym);

    RETMSG(RSCMU_MeasSclarDemodBit( instrSession, wrtBuf
                                    ,demodulation, errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadScalModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
        return RSCMU_EDGE_NSig_ReadScalModDemodBits (instrSession,
                                                     edgeModMeasurement,
                                                     measPointSym,
                                                     demodulation,
                                                     errorMessage);
}

/*===========================================================================*/
/* Fetch Scalar Demod Bits
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcScalModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "FETCh:SCALar:MODulation:%s:EPSK:DBITs? %d", list[edgeModMeasurement],measPointSym);

    RETMSG(RSCMU_MeasSclarDemodBit( instrSession, wrtBuf
                                    ,demodulation, errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcScalModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
        return RSCMU_EDGE_NSig_FetcScalModDemodBits (instrSession,
                                                     edgeModMeasurement,
                                                     measPointSym,
                                                     demodulation,
                                                     errorMessage);
}


/*===========================================================================*/
/* Sample Scalar Demod Bits
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampScalModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "SAMPle:SCALar:MODulation:%s:EPSK:DBITs? %d", list[edgeModMeasurement],measPointSym);

    RETMSG(RSCMU_MeasSclarDemodBit( instrSession, wrtBuf
                                    ,demodulation, errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampScalModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
        return RSCMU_EDGE_NSig_SampScalModDemodBits (instrSession,
                                                     edgeModMeasurement,
                                                     measPointSym,
                                                     demodulation,
                                                     errorMessage);
}




/*===========================================================================*/
/* Read Peak Demod Bits
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadPeakModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   *measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "READ:SCALar:MODulation:%s:EPSK:DBITs:PEAK?", list[edgeModMeasurement]);

    RETMSG(RSCMU_MeasPeakDemodBit( instrSession, wrtBuf
                                  ,measPointSym,demodulation,errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadPeakModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   *measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
        return RSCMU_EDGE_NSig_ReadPeakModDemodBits (instrSession,
                                                     edgeModMeasurement,
                                                     measPointSym,
                                                     demodulation,
                                                     errorMessage);
}

/*===========================================================================*/
/* Fetch Peak Demod Bits
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcPeakModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   *measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "FETCh:SCALar:MODulation:%s:EPSK:DBITs:PEAK?", list[edgeModMeasurement]);

    RETMSG(RSCMU_MeasPeakDemodBit( instrSession, wrtBuf
                                  ,measPointSym,demodulation,errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcPeakModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   *measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
        return RSCMU_EDGE_NSig_FetcPeakModDemodBits (instrSession,
                                                     edgeModMeasurement,
                                                     measPointSym,
                                                     demodulation,
                                                     errorMessage);
}

/*===========================================================================*/
/* Sample Peak Demod Bits
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampPeakModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   *measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[]= {"PERRor", "EVMagnitude", "MERRor", VI_NULL};
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, edgeModMeasurement, RSCMU_MOD_PERR, RSCMU_MOD_MERR, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrtBuf, "SAMPle:SCALar:MODulation:%s:EPSK:DBITs:PEAK?", list[edgeModMeasurement]);

    RETMSG(RSCMU_MeasPeakDemodBit( instrSession, wrtBuf
                                  ,measPointSym,demodulation,errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampPeakModDemodBits (ViSession instrSession,
                                                        ViInt32   edgeModMeasurement,
                                                        ViInt32   *measPointSym,
                                                        ViInt32   *demodulation,
                                                        ViChar    errorMessage[])
{
        return RSCMU_EDGE_NSig_SampPeakModDemodBits (instrSession,
                                                     edgeModMeasurement,
                                                     measPointSym,
                                                     demodulation,
                                                     errorMessage);
}



/*-----------------------------------------------------------------------------
 * Modulation IQAN (IQAnalyzer)
 *
 * The subsystem MODulation:IQANalyzer analyzes the I/Q modulation signals as
 * well as measures general scalar modulation parameters. The subsystem corresponds
 * to the measurement menu Modulation, application IQAnalyzer 8PSK, and the
 * sections in the popup menu Modulation Configuration that are related to the
 * IQAnalyzer... applications.
 * ----------------------------------------------------------------------------
 * CONFIGURATION:
 * The commands of the following subsystems configure the Modulation measurement.
 * They correspond to the sections in the Modulation Configuration menu that
 * are related to the IQAnalyzer applications.
 * ----------------------------------------------------------------------------
 * CONTROL:
 * The subsystem MODulation:IQANalyzer...:CONTrol configures the scope of the
 * modulation measurement. It corresponds to the Control tab in the popup menu
 * Modulation Configuration.
 * ----------------------------------------------------------------------------
 */


/*===========================================================================*/
/* Function: Result Mode
/* Purpose : This function restricts the type of measured values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfIqanContRmod (ViSession  instrSession,
                                                    ViInt32    ValuesType,
                                                    ViChar     errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    RETMSG(RSCMU_setEnum(instrSession, "CONFigure:MODulation:IQANalyzer:EPSK:CONTrol:RMODe",
                         ValuesType, mode_ScopeMeas,
                         RSCMU_ERROR_PARAMETER2));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfIqanContRmod (ViSession  instrSession,
                                                   ViInt32    ValuesType,
                                                   ViChar     errorMessage[])
{
  return RSCMU_EDGE_NSig_ConfIqanContRmod (instrSession,
                                           ValuesType,
                                           errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function sets the number of statistics cycles, the stop
/*           condition and the stepping mode for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfIqanContRep (ViSession  instrSession,
                                                   ViInt32    Repetition,
                                                   ViInt32    NbRepetition,
                                                   ViInt32    StepMode,
                                                   ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Repetition, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, 1, 10000, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) StepMode, RSCMU_ERROR_PARAMETER4,errorMessage);

  if(Repetition != RSCMU_MULTIPLE)
    sprintf(wrtBuf, "CONFigure:MODulation:IQANalyzer:EPSK:CONTrol:REPetition %s,NONE,%s", StrRepetition[Repetition]
                                                                                   , StrStepMode[StepMode]);
  else
    sprintf(wrtBuf, "CONFigure:MODulation:IQANalyzer:EPSK:CONTrol:REPetition %d,NONE,%s", NbRepetition
                                                                                   , StrStepMode[StepMode]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfIqanContRep (ViSession  instrSession,
                                                  ViInt32    Repetition,
                                                  ViInt32    NbRepetition,
                                                  ViInt32    StepMode,
                                                  ViChar     errorMessage[])
{
    return RSCMU_EDGE_NSig_ConfIqanContRep (instrSession,
                                             Repetition,
                                             NbRepetition,
                                             StepMode,
                                             errorMessage);
}

/*===========================================================================*/
/* Function: IQ Filter
/* Purpose : This function selects ....
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfIqanIQFilter (ViSession  instrSession,
                                                    ViInt32    IQFilter,
                                                    ViChar     errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[]= {"ISIRemoved", "UNFiltered", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    RETMSG(RSCMU_setEnum(instrSession, "CONFigure:MODulation:IQANalyzer:EPSK:IQFilter",
                         IQFilter, list,
                         RSCMU_ERROR_PARAMETER2));

}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfIqanIQFilter (ViSession  instrSession,
                                                   ViInt32    IQFilter,
                                                   ViChar     errorMessage[])
{
    return RSCMU_EDGE_NSig_ConfIqanIQFilter (instrSession,
                                             IQFilter,
                                             errorMessage);
}


/*===========================================================================*/
/* Function: Rotation
/* Purpose : This function selects ....
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfIqanRotation (ViSession instrSession,
                                                    ViInt32   rotation,
                                                    ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[]= {"P38", "P38Removed", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    RETMSG(RSCMU_setEnum(instrSession, "CONFigure:MODulation:IQANalyzer:EPSK:ROTation",
                         rotation, list,
                         RSCMU_ERROR_PARAMETER2));

}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfIqanRotation (ViSession instrSession,
                                                   ViInt32   rotation,
                                                   ViChar    errorMessage[])
{
    return RSCMU_EDGE_NSig_ConfIqanRotation (instrSession,
                                             rotation,
                                             errorMessage);
}


/* ----------------------------------------------------------------------------
 * CONTROL:
 * The subsystem MODulation:EVMagnitude controls the modulation measurement.
 * It corresponds to the softkey EVM 8PSK in the measurement menu Modulation.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Starts Modulation IQAN Measurements
/* Purpose : This function starts a new modulation IQAN measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_InitIqan (ViSession  instrSession,
                                            ViChar     errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    RETMSG(RSCMU_sendCmd(instrSession, "INITiate:MODulation:IQANalyzer:EPSK"));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_InitIqan (ViSession  instrSession,
                                            ViChar     errorMessage[])
{
    return RSCMU_EDGE_NSig_InitIqan (instrSession,
                                     errorMessage);
}

/*===========================================================================*/
/* Function: Aborts Modulation IQAN Measurements
/* Purpose : This function aborts running Modulation IQAN measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_AborIqan (ViSession  instrSession,
                                            ViChar     errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    RETMSG(RSCMU_sendCmd(instrSession, "ABORt:MODulation:IQANalyzer:EPSK"));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_AborIqan (ViSession  instrSession,
                                           ViChar     errorMessage[])
{
    return RSCMU_EDGE_NSig_AborIqan (instrSession,
                                     errorMessage);
}

/*===========================================================================*/
/* Function: Stops Modulation IQAN Measurements
/* Purpose : This function stops measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_StopIqan (ViSession  instrSession,
                                            ViChar     errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    RETMSG(RSCMU_sendCmd(instrSession, "STOP:MODulation:IQANalyzer:EPSK"));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_StopIqan (ViSession  instrSession,
                                           ViChar     errorMessage[])
{
    return RSCMU_EDGE_NSig_StopIqan (instrSession,
                                     errorMessage);
}

/*===========================================================================*/
/* Function: Continues Modulation IQAN Measurements
/* Purpose : This function runs next Modulation IQAN measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ContIqan (ViSession  instrSession,
                                            ViChar     errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    RETMSG(RSCMU_sendCmd(instrSession, "CONTinue:MODulation:IQANalyzer:EPSK"));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ContIqan (ViSession  instrSession,
                                           ViChar     errorMessage[])
{
    return RSCMU_EDGE_NSig_ContIqan (instrSession,
                                     errorMessage);
}

/*===========================================================================*/
/* Function: Modulation IQAN Measurement Status
/* Purpose : This function returns the status of measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcIqanStat (ViSession  instrSession,
                                                ViInt32   *MeasurementStatus,
                                                ViInt32   *CountingNo,
                                                ViInt32   *StatisticNo,
                                                ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      Tab[100][100];

  if ((RSCMU_Status = RSCMU_Query (instrSession, "FETCh:MODulation:IQANalyzer:EPSK:STATus?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", Tab);

  // Gets the status of the measurement:
  if ((RSCMU_Status = RSCMU_GetMeasStatVal (MeasurementStatus, Tab, 0)) < 0)
    return RSCMU_Status;

  // Gets the current value of the statistics counter (the number of the current statistics cycle):
  if ((RSCMU_Status = RSCMU_GetCountingNo (CountingNo, Tab, 1)) < 0)
    return RSCMU_Status;

  // Gets the current evaluation period within a statistics cycle:
  if ((RSCMU_Status = RSCMU_GetStatisticNo (StatisticNo, Tab, 2)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcIqanStat (ViSession  instrSession,
                                               ViInt32   *MeasurementStatus,
                                               ViInt32   *CountingNo,
                                               ViInt32   *StatisticNo,
                                               ViChar     errorMessage[])
{
  return RSCMU_EDGE_NSig_FetcIqanStat (instrSession,
                                       MeasurementStatus,
                                       CountingNo,
                                       StatisticNo,
                                       errorMessage);
}

/*===========================================================================*/
/* Function: Event Report
/* Purpose : This function defines the events generated when the measurement
/*           is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfIqanErep (ViSession  instrSession,
                                                ViInt32    EventReport,
                                                ViChar     errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    StrMode[] = {"OFF","SRQ","SOPC","SRSQ", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    RETMSG(RSCMU_setEnum(instrSession, "CONFigure:MODulation:IQANalyzer:EPSK:EREPorting",
                         EventReport, StrMode, RSCMU_ERROR_PARAMETER2));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfIqanErep (ViSession  instrSession,
                                               ViInt32    EventReport,
                                               ViChar     errorMessage[])
{
    return RSCMU_EDGE_NSig_ConfIqanErep (instrSession,
                                         EventReport,
                                         errorMessage);
}

/* ----------------------------------------------------------------------------
 * RESULTS:
 * The subsystem MODulation:IQANalyzer:...? measures and returns the modulation
 * parameters and compares them with the tolerance values. The subsystem
 * corresponds to the various output elements in the measurement menu MODulation,
 * application IQAN .
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Read Scalar
/* Purpose : This function starts a single shot measurement and returns
/*           results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadIqan (ViSession  instrSession,
                                            ViReal64  *EvmRMS,
                                            ViReal64  *MerrRMS,
                                            ViReal64  *PerrRMS,
                                            ViReal64  *AvgBurstPow,
                                            ViChar     errorMessage[])
{
    RETMSG(RSCMU_MeasIqanScalarNSig( instrSession, "READ:SCALar:MODulation:IQANalyzer:EPSK",
                                 EvmRMS, MerrRMS, PerrRMS, AvgBurstPow, errorMessage));
}
/* ----------------------------
   ... for Signalling Mode
   ----------------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadIqan (ViSession  instrSession,
                                            ViReal64  *EvmRMS,
                                            ViReal64  *MerrRMS,
                                            ViReal64  *PerrRMS,
                                            ViReal64  *TimeErr,
                                            ViReal64  *AvgBurstPow,
                                            ViChar     errorMessage[])
{
    RETMSG(RSCMU_MeasIqanScalarSig( instrSession, "READ:SCALar:MODulation:IQANalyzer:EPSK",
                                 EvmRMS, MerrRMS, PerrRMS, TimeErr, AvgBurstPow, errorMessage));
}

/*===========================================================================*/
/* Function: Fetch Scalar
/* Purpose : This function reads out measurement results (unsynchronized).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcIqan (ViSession  instrSession,
                                            ViReal64  *EvmRMS,
                                            ViReal64  *MerrRMS,
                                            ViReal64  *PerrRMS,
                                            ViReal64  *AvgBurstPow,
                                            ViChar     errorMessage[])
{
    RETMSG(RSCMU_MeasIqanScalarNSig( instrSession, "FETCh:SCALar:MODulation:IQANalyzer:EPSK",
                                 EvmRMS, MerrRMS, PerrRMS, AvgBurstPow, errorMessage));
}
/* ----------------------------
   ... for Signalling Mode
   ----------------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcIqan (ViSession  instrSession,
                                            ViReal64  *EvmRMS,
                                            ViReal64  *MerrRMS,
                                            ViReal64  *PerrRMS,
                                            ViReal64  *TimeErr,
                                            ViReal64  *AvgBurstPow,
                                            ViChar     errorMessage[])
{
    RETMSG(RSCMU_MeasIqanScalarSig( instrSession, "FETCh:SCALar:MODulation:IQANalyzer:EPSK",
                                 EvmRMS, MerrRMS, PerrRMS, TimeErr, AvgBurstPow, errorMessage));
}

/*===========================================================================*/
/* Function: Sample Scalar
/* Purpose : This function reads out measurement results (synchronized).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampIqan (ViSession  instrSession,
                                            ViReal64  *EvmRMS,
                                            ViReal64  *MerrRMS,
                                            ViReal64  *PerrRMS,
                                            ViReal64  *AvgBurstPow,
                                            ViChar     errorMessage[])
{
    RETMSG(RSCMU_MeasIqanScalarNSig( instrSession, "SAMPle:SCALar:MODulation:IQANalyzer:EPSK",
                                 EvmRMS, MerrRMS, PerrRMS, AvgBurstPow, errorMessage));
}
/* ----------------------------
   ... for Signalling Mode
   ----------------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampIqan (ViSession  instrSession,
                                            ViReal64  *EvmRMS,
                                            ViReal64  *MerrRMS,
                                            ViReal64  *PerrRMS,
                                            ViReal64  *TimeErr,
                                            ViReal64  *AvgBurstPow,
                                            ViChar     errorMessage[])
{
    RETMSG(RSCMU_MeasIqanScalarSig( instrSession, "SAMPle:SCALar:MODulation:IQANalyzer:EPSK",
                                 EvmRMS, MerrRMS, PerrRMS, TimeErr, AvgBurstPow, errorMessage));
}

/*===========================================================================*/
/* Function: Read Array
/* Purpose : This function starts a single shot measurement and returns the
/*           I-signal values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadArrIqanIPh (ViSession  instrSession,
                                                  ViReal64   IqanValues[],
                                                  ViChar     errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    RETMSG(RSCMU_MeasArray( instrSession, "READ:ARRay:MODulation:IQANalyzer:EPSK:IPHase"
                           ,IqanValues, errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadArrIqanIPh (ViSession  instrSession,
                                                  ViReal64   IqanValues[],
                                                  ViChar     errorMessage[])
{
    return RSCMU_EDGE_NSig_ReadArrIqanIPh (instrSession,
                                           IqanValues,
                                           errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Array
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcArrIqanIPh (ViSession  instrSession,
                                                  ViReal64   IqanValues[],
                                                  ViChar     errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    RETMSG(RSCMU_MeasArray( instrSession, "FETCh:ARRay:MODulation:IQANalyzer:EPSK:IPHase"
                           ,IqanValues, errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcArrIqanIPh (ViSession  instrSession,
                                                 ViReal64   IqanValues[],
                                                 ViChar     errorMessage[])
{
    return RSCMU_EDGE_NSig_FetcArrIqanIPh (instrSession,
                                           IqanValues,
                                           errorMessage);
}

/*===========================================================================*/
/* Function: Sample Array
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampArrIqanIPh (ViSession  instrSession,
                                                  ViReal64   IqanValues[],
                                                  ViChar     errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    RETMSG(RSCMU_MeasArray( instrSession, "SAMPle:ARRay:MODulation:IQANalyzer:EPSK:IPHase"
                           ,IqanValues, errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampArrIqanIPh (ViSession  instrSession,
                                                 ViReal64   IqanValues[],
                                                 ViChar     errorMessage[])
{
    return RSCMU_EDGE_NSig_SampArrIqanIPh (instrSession,
                                           IqanValues,
                                           errorMessage);
}


/*===========================================================================*/
/* Function: Read Array
/* Purpose : This function starts a single shot measurement and returns the
/*           Q-signal values.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadArrIqanQPh (ViSession  instrSession,
                                                  ViReal64   IqanValues[],
                                                  ViChar     errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    RETMSG(RSCMU_MeasArray( instrSession, "READ:ARRay:MODulation:IQANalyzer:EPSK:QPHase"
                           ,IqanValues, errorMessage));
}


/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadArrIqanQPh (ViSession  instrSession,
                                                 ViReal64   IqanValues[],
                                                 ViChar     errorMessage[])
{
    return RSCMU_EDGE_NSig_ReadArrIqanQPh (instrSession,
                                           IqanValues,
                                           errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Array
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcArrIqanQPh (ViSession  instrSession,
                                                  ViReal64   IqanValues[],
                                                  ViChar     errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    RETMSG(RSCMU_MeasArray( instrSession, "FETCh:ARRay:MODulation:IQANalyzer:EPSK:QPHase"
                           ,IqanValues, errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcArrIqanQPh (ViSession  instrSession,
                                                 ViReal64   IqanValues[],
                                                 ViChar     errorMessage[])
{
    return RSCMU_EDGE_NSig_FetcArrIqanQPh (instrSession,
                                           IqanValues,
                                           errorMessage);
}

/*===========================================================================*/
/* Function: Sample Array
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampArrIqanQPh (ViSession  instrSession,
                                                  ViReal64   IqanValues[],
                                                  ViChar     errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    RETMSG(RSCMU_MeasArray( instrSession, "SAMPle:ARRay:MODulation:IQANalyzer:EPSK:QPHase"
                           ,IqanValues, errorMessage));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampArrIqanQPh (ViSession  instrSession,
                                                 ViReal64   IqanValues[],
                                                 ViChar     errorMessage[])
{
    return RSCMU_EDGE_NSig_SampArrIqanQPh (instrSession,
                                           IqanValues,
                                           errorMessage);
}



/*===========================================================================*/
/* Invalid Result detect timeout
/* This function defines the Invalid Result Detected Timeout.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ModulationMeasTimeout (ViSession instrSession,
                                                       ViInt32   invalidResultDetectedTimeout,
                                                       ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[]= {"NORMal", "MEDium", "SHORt", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    RETMSG(RSCMU_setEnum(instrSession, "CONFigure:MODulation:IRDTimeout",
                         invalidResultDetectedTimeout, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT SPECTRUM/SWITCHING
 *-----------------------------------------------------------------------------
 */


/*===========================================================================*/
/* Function: Select Limit Line Template
/* Purpose : These function selects the limit line to be applied.
/*           The current template can be queried using
/*           [SENSe:]SPECtrum:<Application>:LIMit:LINE:USED?.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecLimLineSel (ViSession instrSession,
                                                     ViInt32   select,
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViString    list[] = {"GMSK","EPSK","AUTO", VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  RETMSG(RSCMU_setEnum(instrSession, "CONFigure:SPECtrum:LIMit:LINE:SELect", select, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Invalid Result detect timeout
/* This function defines the Invalid Result Detected Timeout.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SpectrumMeasTimeout (ViSession instrSession,
                                                       ViInt32   invalidResultDetectedTimeout,
                                                       ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[]= {"NORMal", "MEDium", "SHORt", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V5_00,RSCMU_ERROR_FW_VERSION_5_00));

    RETMSG(RSCMU_setEnum(instrSession, "CONFigure:SPECtrum:IRDTimeout",
                         invalidResultDetectedTimeout, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitContDef (ViSession instrSession,
                                                                             ViInt32   DefaultValues,
                                                                             ViChar    errorMessage[])
{
  return RSCMU_ConfContDef(instrSession, RSCMU_SPECSWIT, RSCMU_NONE, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitContRep (ViSession  instrSession,
                                                                             ViInt32    Repetition,
                                                                             ViInt32    StopCondition,
                                                                             ViInt32    StepMode,
                                                                             ViChar     errorMessage[])
{
  return RSCMU_ConfControlRep(instrSession, RSCMU_SPECSWIT, RSCMU_NONE, Repetition, StopCondition, StepMode, errorMessage);
}


/*===========================================================================*/
/* Function: continuous statistical mode
/* Purpose : This function defines the continuous statistical mode for the
/*           Spectrum due to Switching measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SpecSwitContStatMod (ViSession instrSession,
                                                      ViInt32   continuousStatisticalMode,
                                                      ViChar    errorMessage[])
{
    return RSCMU_ConfSpecSwitContStatMod (instrSession, RSCMU_GMSK, continuousStatisticalMode, errorMessage);
}


/*===========================================================================*/
/* Function: Nr. of Slots
/* Purpose : This function sets the Number of slots per TDMA frame measured
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SpecSwitNoOfSlot (ViSession instrSession,
                                                   ViInt32   nr_ofSlots,
                                                   ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  RETMSG(RSCMU_setViInt32(instrSession,
                          "CONFigure:SPECtrum:SWITching:NOSLots",
                          nr_ofSlots,
                          1, 8,
                          RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Slot Count
/* Purpose : Don' use this function - only for compatibility
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SpecSwitSlotCount (ViSession instrSession,
                                                    ViInt32   slotCount,
                                                    ViChar    errorMessage[])
{
    return RSCMU_ConfSpecSwitSlotCount (instrSession, RSCMU_GMSK, slotCount, errorMessage);
}


/*===========================================================================*/
/* Function: Frequency Select f. Time Domain
/* Purpose : These function selects the measurement frequency for the time
/*           domain (power vs. time) measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitFSelFTimeD (ViSession instrSession,
                                                         ViInt32   select,
                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViString    list[] = {"OFF","N180","N160","N140","N120","N100","N080","N060","N040","N025","N020","N010",
                        "REF","P010","P020","P025","P040","P060","P080","P100","P120","P140","P160","P180",
                        "NV4","NV3","NV2","NV1","PV1","PV2","PV3","PV4", VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  RETMSG(RSCMU_setEnum(instrSession, "CONFigure:SPECtrum:SWITching:TDFSelect", select, list,
                                      RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Grid On/Off
/* Purpose : This function switches the grid lines in the test diagrams on or
/*           off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_DispSpecSwitContGrid (ViSession instrSession,
                                                                              ViInt32   gridLines,
                                                                              ViChar    errorMessage[])
{
  return RSCMU_DisplayGrid (instrSession, RSCMU_SPECSWIT, RSCMU_NONE, gridLines, errorMessage);
}

/*===========================================================================*/
/* Function: Default Limit Lines
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitLimLineDef (ViSession instrSession,
                                                                                ViInt32   DefaultValues,
                                                                                ViChar    errorMessage[])
{
  return RSCMU_ConfLimLineDef (instrSession, RSCMU_SPECSWIT, RSCMU_NONE, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines
/* Purpose : These commands activate and define limit lines for the spectrum
/*           due to switching measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitLimLine (ViSession instrSession,
                                                                             ViInt32   PowerLevel,
                                                                             ViReal64  power,
                                                                             ViInt32   enable,
                                                                             ViReal64  value1,
                                                                             ViReal64  value2,
                                                                             ViReal64  value3,
                                                                             ViReal64  value4,
                                                                             ViChar    errorMessage[])
{
  return RSCMU_ConfSpecSwitLimLine (instrSession, RSCMU_NONE, PowerLevel, power, enable, value1, value2, value3, value4, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines On/Off
/* Purpose : This function switches the limit checking for all measurepoints.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitLimLineMod (ViSession instrSession,
                                                                                ViInt32   limitLines,
                                                                                ViChar    errorMessage[])
{
  return RSCMU_ConfSpecSwitLimLineMod(instrSession, RSCMU_NONE, limitLines, errorMessage);
}

/*===========================================================================*/
/* Function: Statistic Count
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitCont (ViSession instrSession,
                                                                          ViInt32   MeasuredValuesType,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    errorMessage[])
{
  return RSCMU_ConfControl (instrSession, RSCMU_SPECSWIT, RSCMU_NONE, MeasuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitContRepSta (ViSession  instrSession,
                                                                                ViInt32    NbRepetition,
                                                                                ViInt32    StopCondition,
                                                                                ViInt32    StepMode,
                                                                                ViChar     errorMessage[])
{
  return RSCMU_ConfContRepStat(instrSession, RSCMU_SPECSWIT, RSCMU_NONE, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Measure Points
/* Purpose : This function permits to select which frequencies a spectrum
/*           switching measurement is performed. A reduction of the
/*           measurement points enhances the measurement speed.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitContMpo (ViSession  instrSession,
                                                                             ViInt32    MeasurePoint,
                                                                             ViInt32    Enable,
                                                                             ViChar     errorMessage[])
{
  return RSCMU_ConfSpecSwitContMpo (instrSession, RSCMU_NONE, MeasurePoint, Enable, errorMessage);
}

/*===========================================================================*/
/* Function: Variable Measure Points
/* Purpose : This function sets and enables additional pairs of
/*           measurement points at up to 4 variable offset frequencies
/*           (numbered by the numeric suffix <nr> = 1 to 4).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitVarMpo (ViSession instrSession,
                                                     ViInt32   nr,
                                                     ViInt32   enable,
                                                     ViReal64  frequencyMHz,
                                                     ViChar    errorMessage[])
{
  return RSCMU_MeasSpecVarMeaPoint(instrSession, "CONFigure:SPECtrum:SWITching:CONTrol:VMPOint", nr, enable, frequencyMHz, errorMessage);
}

/*===========================================================================*/
/* Function: Burst Power SubRanges
/* Purpose : This function configurates the READ..., FETCh... and
/*           SAMPle:SUBarray:SPECtrum:SWITching commands.
/*           If the requested number of results exceeds the measurement
/*           range, the count parameter will be corrected by the system.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubSpecSwit (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  FirstMeasurementFreq,
                                                                         ViInt32   MeasureResultsNumber,
                                                                         ViChar    errorMessage[])
{
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, FirstMeasurementFreq, -1.8, 1.8, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, MeasureResultsNumber, 1, 9, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSubarrays (instrSession, RSCMU_SPECSWIT, 0, Mode, FirstMeasurementFreq, MeasureResultsNumber, errorMessage);
}

/*===========================================================================*/
/* Function: Configure TimeDomain SubRanges
/* Purpose : This function configurates the READ..., FETCh... and
/*           SAMPle:SSUBarrays:SPECtrum:<Application>:TDOMain commands.
/*           If the requested number of results exceeds the measurement
/*           range, the count parameter will be corrected by the system.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubSpecSwitTime (ViSession instrSession,
                                                      ViInt32   mode,
                                                      ViReal64  startTime,
                                                      ViInt32   numberOfSamples,
                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, mode, 0, 4, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, startTime, -186, 1111, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, numberOfSamples, 1, 3894, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSub (instrSession, "SPECtrum:SWITching:TDOMain", mode, startTime, numberOfSamples, errorMessage);
}

/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_InitSpecSwit (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_SPECSWIT, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : Abort measurement and switch off => OFF
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborSpecSwit (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_SPECSWIT, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : Stop measurement => STOP
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopSpecSwit (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_SPECSWIT, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : Next measurement step (only counting mode) => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContSpecSwit (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_SPECSWIT, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Spectrum Switching Measurement Status
/* Purpose : This function returns the status of the current Spectrum Switching
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSpecSwitStat (ViSession  instrSession,
                                                                          ViInt32   *MeasurementStatus,
                                                                          ViInt32   *CountingNo,
                                                                          ViInt32   *StatisticNo,
                                                                          ViChar     errorMessage[])
{
  return RSCMU_FetcStatus (instrSession, RSCMU_SPECSWIT, RSCMU_NONE, MeasurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*===========================================================================*/
/* Function: Event Reporting Mode
/* Purpose : This function defines the events to be reported during the
/*           measurement (event reporting, see chapter 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitErep (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViChar    errorMessage[])
{
  return RSCMU_ConfReporting (instrSession, RSCMU_SPECSWIT, RSCMU_NONE, Mode, errorMessage);
}

/*===========================================================================*/
/* Function: Read
/* Purpose : This function starts the measurement and outputs some results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSpecSwit (ViSession  instrSession,
                                                                      ViReal64  *referencePower,
                                                                      ViInt32   *matching,
                                                                      ViChar     errorMessage[])
{
  return RSCMU_MeasSpecSwit (instrSession, RSCMU_COMMAND_READ, RSCMU_NONE, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This function only outputs the results without any care of the
/*           measurement state.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSpecSwit (ViSession  instrSession,
                                                                      ViReal64  *referencePower,
                                                                      ViInt32   *matching,
                                                                      ViChar     errorMessage[])
{
  return RSCMU_MeasSpecSwit (instrSession, RSCMU_COMMAND_FETC, RSCMU_NONE, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This function waits until the results are valid for the first
/*           time (depending on the chosen statistic count) and then outputs
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSpecSwit (ViSession  instrSession,
                                                                      ViReal64  *referencePower,
                                                                      ViInt32   *matching,
                                                                      ViChar     errorMessage[])
{
  return RSCMU_MeasSpecSwit (instrSession, RSCMU_COMMAND_SAMP, RSCMU_NONE, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Read
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrSpecSwit (ViSession instrSession,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    errorMessage[])
{
  return RSCMU_MeasArrSpecSwit (instrSession, RSCMU_COMMAND_READ, RSCMU_NONE, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrSpecSwit (ViSession instrSession,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    errorMessage[])
{
  return RSCMU_MeasArrSpecSwit (instrSession, RSCMU_COMMAND_FETC, RSCMU_NONE, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrSpecSwit (ViSession instrSession,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    errorMessage[])
{
  return RSCMU_MeasArrSpecSwit (instrSession, RSCMU_COMMAND_SAMP, RSCMU_NONE, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: area limit matching
/* Purpose : A bit in the output values is set if the corresponding fixed
/*           measurement point exceeds the limit.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcSpecSwiAreaLimMatc (ViSession instrSession,
                                                         ViInt32  *limitMatching,
                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  CHECKRETMSG(RSCMU_getViString(instrSession,"CALCulate:ARRay:SPECtrum:SWITching:AREA:LIMit:MATChing?",rdBuf,RD_BUFFER_SIZE,0));

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf,"%d", limitMatching);
  else *limitMatching = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Read Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrVarSpecSwit (ViSession instrSession,
                                                     ViReal64  burstPower[],
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "READ:ARRay:SPECtrum:SWitching:VMPoint", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrVarSpecSwit (ViSession instrSession,
                                                     ViReal64  burstPower[],
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:SWitching:VMPoint", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrVarSpecSwit (ViSession instrSession,
                                                     ViReal64  burstPower[],
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:SWitching:VMPoint", burstPower, errorMessage);
}


/*===========================================================================*/
/* Function: Read Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrSpecSwitTime (ViSession instrSession,
                                                      ViReal64  burstPower[],
                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "READ:ARRay:SPECtrum:SWITching:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrSpecSwitTime (ViSession instrSession,
                                                      ViReal64  burstPower[],
                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:SWITching:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrSpecSwitTime (ViSession instrSession,
                                                      ViReal64  burstPower[],
                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:SWITching:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Read (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrSpecSwit (ViSession instrSession,
                                                                            ViReal64  BurstPower[],
                                                                            ViChar    errorMessage[])
{
  return RSCMU_MeasSubArrSpecSwit (instrSession, RSCMU_COMMAND_READ, RSCMU_NONE, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrSpecSwit (ViSession instrSession,
                                                                            ViReal64  BurstPower[],
                                                                            ViChar    errorMessage[])
{
  return RSCMU_MeasSubArrSpecSwit (instrSession, RSCMU_COMMAND_FETC, RSCMU_NONE, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrSpecSwit (ViSession instrSession,
                                                                            ViReal64  BurstPower[],
                                                                            ViChar    errorMessage[])
{
  return RSCMU_MeasSubArrSpecSwit (instrSession, RSCMU_COMMAND_SAMP, RSCMU_NONE, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Read SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrSpecSwitTime (ViSession instrSession,
                                                         ViReal64  burstPower[],
                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "READ:SUBarrays:SPECtrum:SWITching:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrSpecSwitTime (ViSession instrSession,
                                                         ViReal64  burstPower[],
                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "FETCh:SUBarrays:SPECtrum:SWITching:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrSpecSwitTime (ViSession instrSession,
                                                         ViReal64  burstPower[],
                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "SAMPle:SUBarrays:SPECtrum:SWITching:TDOMain", burstPower, errorMessage);
}


/*===========================================================================*/
/* Function: Current Limit Line Template
/* Purpose : These function is always a query and returns the
/*           current limit line template.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SensSpecSwiLimLineUsed (ViSession instrSession,
                                                         ViInt32  *currLimLine,
                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  CHECKRETMSG(RSCMU_getViString(instrSession,"SENSe:SPECtrum:SWitching:LIMit:LINE:USED?",rdBuf,RD_BUFFER_SIZE,0));

  // Extract the CMU response:
  if (strncmp ("GMSK", rdBuf, 4) == 0)
    *currLimLine = RSCMU_GMSK;
  else if (strncmp ("EPSK", rdBuf, 4) == 0)
    *currLimLine = RSCMU_EPSK;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Configure Additional Measurepoints
/* Purpose : This function permits to configure the frequencies for two
/*           additional Measurepoints for spectrum switching measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitConfAMP (ViSession instrSession,
                                                      ViInt32   enableMP1,
                                                      ViReal64  frequencyMP1,
                                                      ViInt32   enableMP2,
                                                      ViReal64  frequencyMP2,
                                                      ViChar    errorMessage[])
{
  return RSCMU_ConfSpecSwitAddMeaPoints (instrSession, RSCMU_GMSK, enableMP1, frequencyMP1, enableMP2, frequencyMP2, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch scalar results for Additional Measurepoints
/* Purpose : This function output the off-carrier power due to switching
/*           in the additional Measurepoints.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSpecSwitAMP (ViSession instrSession,
                                                  ViReal64  *valueMP1Neg,
                                                  ViReal64  *valueMP1Pos,
                                                  ViReal64  *valueMP2Neg,
                                                  ViReal64  *valueMP2Pos,
                                                  ViChar    errorMessage[])
{
  return RSCMU_FetcSpecSwitAddMeaPoints (instrSession, RSCMU_GMSK, valueMP1Neg, valueMP1Pos, valueMP2Neg, valueMP2Pos, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT SPECTRUM/MODULATION
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModContDef (ViSession instrSession,
                                                                            ViInt32   DefaultValues,
                                                                            ViChar    errorMessage[])
{
  return RSCMU_ConfContDef(instrSession, RSCMU_SPECMOD, RSCMU_NONE, DefaultValues, errorMessage);
}


/*===========================================================================*/
/* Function: Averaging Areas
/* Purpose : These function selects one or two 40-bit sections of the burst which
/*           are measured and averaged in order to calculate the Modulation results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SpecModAvgAreas (ViSession instrSession,
                                                  ViInt32   averaging_area,
                                                  ViChar    errorMessage[])
{
    ViString    list[] = {"A","B","AB", VI_NULL};
    ViStatus    RSCMU_Status = VI_SUCCESS;

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_50, RSCMU_ERROR_FW_VERSION_3_50));

    RETMSG(RSCMU_setEnum(instrSession, "CONFigure:SPECtrum:MODulation:AVGareas",
                         averaging_area, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModContRep (ViSession  instrSession,
                                                                            ViInt32    Repetition,
                                                                            ViInt32    StopCondition,
                                                                            ViInt32    StepMode,
                                                                            ViChar     errorMessage[])
{
  return RSCMU_ConfControlRep(instrSession, RSCMU_SPECMOD, RSCMU_NONE, Repetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Frequency Select f. Time Domain
/* Purpose : These function selects the measurement frequency for the time
/*           domain (power vs. time) measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModFSelFTimeD (ViSession instrSession,
                                                        ViInt32   select,
                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViString    list[] = {"OFF","N180","N160","N140","N120","N100","N080","N060","N040","N025","N020","N010",
                        "REF","P010","P020","P025","P040","P060","P080","P100","P120","P140","P160","P180",
                        "NV4","NV3","NV2","NV1","PV1","PV2","PV3","PV4", VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  RETMSG(RSCMU_setEnum(instrSession, "CONFigure:SPECtrum:MODulation:TDFSelect", select, list,
                                      RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Grid On/Off
/* Purpose : This function switches the grid lines in the test diagrams on or
/*           off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_DispSpecModContGrid (ViSession instrSession,
                                                                             ViInt32   gridLines,
                                                                             ViChar    errorMessage[])
{
  return RSCMU_DisplayGrid (instrSession, RSCMU_SPECMOD, RSCMU_NONE, gridLines, errorMessage);
}

/*===========================================================================*/
/* Function: Default limit Lines
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModLimLineDef (ViSession instrSession,
                                                                               ViInt32   DefaultValues,
                                                                               ViChar    errorMessage[])
{
  return RSCMU_ConfLimLineDef (instrSession, RSCMU_SPECMOD, RSCMU_NONE, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Reference Power
/* Purpose : This function defines the MS carrier output power domain where
/*           the limit lines are to be determined by linear interpolation
/*           (see Table 1). Below Min. Power, the lower limit line applies,
/*           above Max. Power, the upper limit line applies.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModLimLineRefp (ViSession instrSession,
                                                                                ViReal64  minPower,
                                                                                ViReal64  maxPower,
                                                                                ViChar    errorMessage[])
{
  return RSCMU_ConfSpecModLimLineRefp (instrSession, RSCMU_NONE, minPower, maxPower, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines
/* Purpose : These commands activate and define limit lines for the spectrum
/*           due to modulation measurement.
/*           The limit lines for the spectrum due to modulation as specified
/*           in standard GSM 05.05 depend on the GSM band, the frequency, and
/*           (for frequencies that differ from the carrier frequency by more
/*           than 400 kHz) on the output power of the mobile station.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModLimLine (ViSession instrSession,
                                                                            ViInt32   measurePoint,
                                                                            ViInt32   enable,
                                                                            ViReal64  minPower,
                                                                            ViReal64  maxPower,
                                                                            ViReal64  AbsLevel,
                                                                            ViChar    errorMessage[])
{
  return RSCMU_ConfSpecModLimLine (instrSession, RSCMU_NONE, measurePoint, enable, minPower, maxPower, AbsLevel, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines On/Off
/* Purpose : This function switches the limit checking for all measurepoints.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModLimLineMod (ViSession instrSession,
                                                                               ViInt32   limitLines,
                                                                               ViChar    errorMessage[])
{
  return RSCMU_ConfSpecModLimLineMod (instrSession, RSCMU_NONE, limitLines, errorMessage);
}

/*===========================================================================*/
/* Function: Statistic Count
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModCont (ViSession instrSession,
                                                                         ViInt32   MeasuredValuesType,
                                                                         ViInt32   NbBurst,
                                                                         ViChar    errorMessage[])
{
  return RSCMU_ConfControl (instrSession, RSCMU_SPECMOD, RSCMU_NONE, MeasuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModContRepStat (ViSession  instrSession,
                                                                               ViInt32    NbRepetition,
                                                                               ViInt32    StopCondition,
                                                                               ViInt32    StepMode,
                                                                               ViChar     errorMessage[])
{
  return RSCMU_ConfContRepStat(instrSession, RSCMU_SPECMOD, RSCMU_NONE, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Measure Points
/* Purpose : This function permits to select which frequencies a spectrum
/*           modulation measurement is performed. A reduction of the
/*           measurement points enhances the measurement speed.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModContMpo (ViSession  instrSession,
                                                                            ViInt32    MeasurePoint,
                                                                            ViInt32    Enable,
                                                                            ViChar     errorMessage[])
{
  return RSCMU_ConfSpecModContMpo (instrSession, RSCMU_NONE, MeasurePoint, Enable, errorMessage);
}

/*===========================================================================*/
/* Function: Variable Measure Points
/* Purpose : This function sets and enables additional pairs of
/*           measurement points at up to 4 variable offset frequencies
/*           (numbered by the numeric suffix <nr> = 1 to 4).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModVarMpo (ViSession instrSession,
                                                    ViInt32   nr,
                                                    ViInt32   enable,
                                                    ViReal64  frequencyMHz,
                                                    ViChar    errorMessage[])
{
  return RSCMU_MeasSpecVarMeaPoint(instrSession, "CONFigure:SPECtrum:MODulation:CONTrol:VMPOint", nr, enable, frequencyMHz, errorMessage);
}


/*===========================================================================*/
/* Function: Burst Power SubRanges
/* Purpose : This function configurates the READ..., FETCh... and
/*           SAMPle:SUBArrays:MODulation:SWITching commands.
/*           If the requested number of results exceeds the measurement
/*           range, the count parameter will be corrected by the system.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubSpecMod (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  FirstMeasurementFreq,
                                                                        ViInt32   MeasureResultsNumber,
                                                                        ViChar    errorMessage[])
{
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, FirstMeasurementFreq, -1.8, 1.8, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, MeasureResultsNumber, 1, 23, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSubarrays (instrSession, RSCMU_SPECMOD, RSCMU_NONE, Mode, FirstMeasurementFreq, MeasureResultsNumber, errorMessage);
}

/*===========================================================================*/
/* Function: Configure TimeDomain SubRanges
/* Purpose : This function configurates the READ..., FETCh... and
/*           SAMPle:SSUBarrays:SPECtrum:<Application>:TDOMain commands.
/*           If the requested number of results exceeds the measurement
/*           range, the count parameter will be corrected by the system.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubSpecModTime (ViSession instrSession,
                                                     ViInt32   mode,
                                                     ViReal64  startTime,
                                                     ViInt32   numberOfSamples,
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, mode, 0, 4, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, startTime, -30, 175, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, numberOfSamples, 1, 618, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSub (instrSession, "SPECtrum:MODulation:TDOMain", mode, startTime, numberOfSamples, errorMessage);
}

/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_InitSpecMod (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_SPECMOD, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : Abort measurement and switch off => OFF
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborSpecMod (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_SPECMOD, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : Stop measurement => STOP
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopSpecMod (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_SPECMOD, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : Next measurement step (only counting mode) => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContSpecMod (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_SPECMOD, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Spectrum Modulation Measurement Status
/* Purpose : This function returns the status of the current Spectrum
/*           Modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSpecModStat (ViSession  instrSession,
                                                                         ViInt32   *MeasurementStatus,
                                                                         ViInt32   *CountingNo,
                                                                         ViInt32   *StatisticNo,
                                                                         ViChar     errorMessage[])
{
  return RSCMU_FetcStatus (instrSession, RSCMU_SPECMOD, RSCMU_NONE, MeasurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*===========================================================================*/
/* Function: Event Reporting Mode
/* Purpose : This function defines the events to be reported during the
/*           measurement (event reporting, see chapter 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModErep (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViChar    errorMessage[])
{
  return RSCMU_ConfReporting (instrSession, RSCMU_SPECMOD, RSCMU_NONE, Mode, errorMessage);
}

/*===========================================================================*/
/* Function: Start single shot measurement and return results
/* Purpose : This function starts a single shot measurement and returns the
/*           results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSpecMod (ViSession  instrSession,
                                                                     ViReal64  *ReferencePower,
                                                                     ViInt32   *Matching,
                                                                     ViChar     errorMessage[])
{
  return RSCMU_MeasSpecMod (instrSession, RSCMU_COMMAND_READ, RSCMU_NONE, ReferencePower, Matching, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This function only outputs the results without any care of the
/*           measurement state.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSpecMod (ViSession  instrSession,
                                                                     ViReal64  *ReferencePower,
                                                                     ViInt32   *Matching,
                                                                     ViChar     errorMessage[])
{
  return RSCMU_MeasSpecMod (instrSession, RSCMU_COMMAND_FETC, RSCMU_NONE, ReferencePower, Matching, errorMessage);
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This function waits until the results are valid for the first
/*           time (depending on the chosen statistic count) and then outputs
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSpecMod (ViSession  instrSession,
                                                                     ViReal64  *ReferencePower,
                                                                     ViInt32   *Matching,
                                                                     ViChar     errorMessage[])
{
  return RSCMU_MeasSpecMod (instrSession, RSCMU_COMMAND_SAMP, RSCMU_NONE, ReferencePower, Matching, errorMessage);
}

/*===========================================================================*/
/* Function: Read
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrSpecMod (ViSession instrSession,
                                                                       ViReal64  BurstPower[],
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, "READ:ARR:SPEC:MOD?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, BurstPower);

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Fetch
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrSpecMod (ViSession  instrSession,
                                                                       ViReal64   BurstPower[],
                                                                       ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, "FETC:ARR:SPEC:MOD?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, BurstPower);

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Sample
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrSpecMod (ViSession instrSession,
                                                                       ViReal64  BurstPower[],
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, "SAMP:ARR:SPEC:MOD?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, BurstPower);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: area limit matching
/* Purpose : A bit in the output values is set if the corresponding fixed
/*           measurement point exceeds the limit.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcSpecModAreaLimMatc (ViSession instrSession,
                                                         ViInt32  *limitMatching,
                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  CHECKRETMSG(RSCMU_getViString(instrSession,"CALCulate:ARRay:SPECtrum:MODulation:AREA:LIMit:MATChing?",rdBuf,RD_BUFFER_SIZE,0));

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf,"%d", limitMatching);
  else *limitMatching = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Read Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrVarSpecMod (ViSession instrSession,
                                                    ViReal64  burstPower[],
                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "READ:ARRay:SPECtrum:MODulation:VMPoint", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrVarSpecMod (ViSession instrSession,
                                                    ViReal64  burstPower[],
                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:MODulation:VMPoint", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrVarSpecMod (ViSession instrSession,
                                                    ViReal64  burstPower[],
                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:MODulation:VMPoint", burstPower, errorMessage);
}


/*===========================================================================*/
/* Function: Read Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrSpecModTime (ViSession instrSession,
                                                     ViReal64  burstPower[],
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "READ:ARRay:SPECtrum:MODulation:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrSpecModTime (ViSession instrSession,
                                                     ViReal64  burstPower[],
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:MODulation:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrSpecModTime (ViSession instrSession,
                                                     ViReal64  burstPower[],
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:MODulation:TDOMain", burstPower, errorMessage);
}


/*===========================================================================*/
/* Function: Read (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrSpecMod (ViSession instrSession,
                                                                           ViReal64  BurstPower[],
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, "READ:SUB:SPEC:MOD?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, BurstPower);

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Fetch (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrSpecMod (ViSession  instrSession,
                                                                           ViReal64   BurstPower[],
                                                                           ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, "FETC:SUB:SPEC:MOD?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, BurstPower);

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Sample (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrSpecMod (ViSession instrSession,
                                                                           ViReal64  BurstPower[],
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, "SAMP:SUB:SPEC:MOD?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, BurstPower);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Read SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrSpecModTime (ViSession instrSession,
                                                        ViReal64  burstPower[],
                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "READ:SUBarrays:SPECtrum:MODulation:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrSpecModTime (ViSession instrSession,
                                                        ViReal64  burstPower[],
                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "FETCh:SUBarrays:SPECtrum:MODulation:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrSpecModTime (ViSession instrSession,
                                                        ViReal64  burstPower[],
                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "SAMPle:SUBarrays:SPECtrum:MODulation:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Current Limit Line Template
/* Purpose : These function is always a query and returns the
/*           current limit line template.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SensSpecModLimLineUsed (ViSession instrSession,
                                                         ViInt32  *currLimLine,
                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  CHECKRETMSG(RSCMU_getViString(instrSession,"SENSe:SPECtrum:MODulation:LIMit:LINE:USED?",rdBuf,RD_BUFFER_SIZE,0));

  // Extract the CMU response:
  if (strncmp ("GMSK", rdBuf, 4) == 0)
    *currLimLine = RSCMU_GMSK;
  else if (strncmp ("EPSK", rdBuf, 4) == 0)
    *currLimLine = RSCMU_EPSK;

  return RSCMU_Status;
}





/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT SPECTRUM/Modulation&Switching
 * ----------------------------------------------------------------------------
 */

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecMSwContRep (ViSession instrSession,
                                                     ViInt32   repetition,
                                                     ViInt32   stopCondition,
                                                     ViInt32   stepMode,
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  return RSCMU_ConfControlRep(instrSession, RSCMU_SPECMSW, RSCMU_NONE, repetition, stopCondition, stepMode, errorMessage);
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecMSwContRep (ViSession instrSession,
                                                     ViInt32   repetition,
                                                     ViInt32   stopCondition,
                                                     ViInt32   stepMode,
                                                     ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_ConfSpecMSwContRep (instrSession,
                                           repetition,
                                           stopCondition,
                                           stepMode,
                                           errorMessage);
}

/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_InitSpecMSw (ViSession instrSession,
                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  RETMSG(RSCMU_sendCmd(instrSession, "INITiate:SPECtrum:MSWitching"));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_InitSpecMSw (ViSession instrSession,
                                             ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_InitSpecMSw (instrSession,
                                     errorMessage);
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : Abort measurement and switch off => OFF
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborSpecMSw (ViSession instrSession,
                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  RETMSG(RSCMU_sendCmd(instrSession, "ABORt:SPECtrum:MSWitching"));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborSpecMSw (ViSession instrSession,
                                             ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_AborSpecMSw (instrSession,
                                     errorMessage);
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : Stop measurement => STOP
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopSpecMSw (ViSession instrSession,
                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  RETMSG(RSCMU_sendCmd(instrSession, "STOP:SPECtrum:MSWitching"));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopSpecMSw (ViSession instrSession,
                                             ViChar    errorMessage[])
{
 return RSCMU_GSM_NSig_StopSpecMSw (instrSession,
                                    errorMessage);
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : Next measurement step (only counting mode) => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContSpecMSw (ViSession instrSession,
                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  RETMSG(RSCMU_sendCmd(instrSession, "CONTinue:SPECtrum:MSWitching"));
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContSpecMSw (ViSession instrSession,
                                             ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_ContSpecMSw (instrSession,
                                     errorMessage);
}

/*===========================================================================*/
/* Function: Spectrum Modulation Measurement Status
/* Purpose : This function returns the status of the current Spectrum
/*           Modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSpecMSwStat (ViSession instrSession,
                                                  ViInt32  *MeasurementStatus,
                                                  ViInt32  *CountingNo,
                                                  ViInt32  *StatisticNo,
                                                  ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  return RSCMU_FetcStatus (instrSession, RSCMU_SPECMSW, RSCMU_NONE, MeasurementStatus, CountingNo, StatisticNo, errorMessage);
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSpecMSwStat (ViSession instrSession,
                                                 ViInt32  *MeasurementStatus,
                                                 ViInt32  *CountingNo,
                                                 ViInt32  *StatisticNo,
                                                 ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_FetcSpecMSwStat (instrSession,
                                         MeasurementStatus,
                                         CountingNo,
                                         StatisticNo,
                                         errorMessage);
}

/*===========================================================================*/
/* Function: Event Reporting Mode
/* Purpose : This function defines the events to be reported during the
/*           measurement (event reporting, see chapter 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecMSwErep (ViSession instrSession,
                                                  ViInt32   Mode,
                                                  ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  return RSCMU_ConfReporting (instrSession, RSCMU_SPECMSW, RSCMU_NONE, Mode, errorMessage);
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecMSwErep (ViSession instrSession,
                                                 ViInt32   Mode,
                                                 ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_ConfSpecMSwErep (instrSession,
                                         Mode,
                                         errorMessage);
}


/*===========================================================================*/
/* Function: Start single shot measurement and return results
/* Purpose : This function starts a single shot measurement and returns the
/*           results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSpecMSw (ViSession instrSession,
                                              ViReal64 *refPowMod,
                                              ViInt32  *matchingMod,
                                              ViReal64 *refPowSwitch,
                                              ViInt32  *matchingSwitch,
                                              ViChar    errorMessage[])
{
  return RSCMU_MeasSpecModSwitch (instrSession, RSCMU_COMMAND_READ, refPowMod, matchingMod, refPowSwitch, matchingSwitch, errorMessage);
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSpecMSw (ViSession instrSession,
                                             ViReal64 *refPowMod,
                                             ViInt32  *matchingMod,
                                             ViReal64 *refPowSwitch,
                                             ViInt32  *matchingSwitch,
                                             ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_ReadSpecMSw (instrSession,
                                     refPowMod,
                                     matchingMod,
                                     refPowSwitch,
                                     matchingSwitch,
                                     errorMessage);
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This function only outputs the results without any care of the
/*           measurement state.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSpecMSw (ViSession instrSession,
                                              ViReal64 *refPowMod,
                                              ViInt32  *matchingMod,
                                              ViReal64 *refPowSwitch,
                                              ViInt32  *matchingSwitch,
                                              ViChar    errorMessage[])
{
  return RSCMU_MeasSpecModSwitch (instrSession, RSCMU_COMMAND_FETC, refPowMod, matchingMod, refPowSwitch, matchingSwitch, errorMessage);
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSpecMSw (ViSession instrSession,
                                             ViReal64 *refPowMod,
                                             ViInt32  *matchingMod,
                                             ViReal64 *refPowSwitch,
                                             ViInt32  *matchingSwitch,
                                             ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_FetcSpecMSw (instrSession,
                                     refPowMod,
                                     matchingMod,
                                     refPowSwitch,
                                     matchingSwitch,
                                     errorMessage);
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This function waits until the results are valid for the first
/*           time (depending on the chosen statistic count) and then outputs
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSpecMSw (ViSession instrSession,
                                              ViReal64 *refPowMod,
                                              ViInt32  *matchingMod,
                                              ViReal64 *refPowSwitch,
                                              ViInt32  *matchingSwitch,
                                              ViChar    errorMessage[])
{
  return RSCMU_MeasSpecModSwitch (instrSession, RSCMU_COMMAND_SAMP, refPowMod, matchingMod, refPowSwitch, matchingSwitch, errorMessage);
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSpecMSw (ViSession instrSession,
                                             ViReal64 *refPowMod,
                                             ViInt32  *matchingMod,
                                             ViReal64 *refPowSwitch,
                                             ViInt32  *matchingSwitch,
                                             ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_SampSpecMSw (instrSession,
                                     refPowMod,
                                     matchingMod,
                                     refPowSwitch,
                                     matchingSwitch,
                                     errorMessage);
}


/*===========================================================================*/
/* Function: Read
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrSpecMSw (ViSession instrSession,
                                                 ViReal64  burstPower[],
                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  return RSCMU_MeasArray(instrSession, "READ:ARRay:SPECtrum:MSWitching", burstPower, errorMessage);
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrSpecMSw (ViSession instrSession,
                                                ViReal64  burstPower[],
                                                ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_ReadArrSpecMSw (instrSession,
                                        burstPower,
                                        errorMessage);
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrSpecMSw (ViSession instrSession,
                                                 ViReal64  burstPower[],
                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  return RSCMU_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:MSWitching", burstPower, errorMessage);
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrSpecMSw (ViSession instrSession,
                                                ViReal64  burstPower[],
                                                ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_FetcArrSpecMSw (instrSession,
                                        burstPower,
                                        errorMessage);
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrSpecMSw (ViSession instrSession,
                                                 ViReal64  burstPower[],
                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  return RSCMU_MeasArray(instrSession, "SAMPLe:ARRay:SPECtrum:MSWitching", burstPower, errorMessage);
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrSpecMSw (ViSession instrSession,
                                                ViReal64  burstPower[],
                                                ViChar    errorMessage[])
{
return RSCMU_GSM_NSig_SampArrSpecMSw (instrSession,
                                      burstPower,
                                      errorMessage);
}

/*===========================================================================*/
/* Function: area limit matching
/* Purpose : A bit in the output values is set if the corresponding fixed
/*           measurement point exceeds the limit.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcSpecMSwAreaLimMatc (ViSession  instrSession,
                                                         ViInt32   *modLimit,
                                                         ViInt32   *switLimit,
                                                         ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      tab[100][100];
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  CHECKRETMSG(RSCMU_getViString(instrSession,"CALCulate:ARRay:SPECtrum:MSWitching:AREA:LIMit:MATChing?",rdBuf,RD_BUFFER_SIZE,0));

  //sscanf(rdBuf,"%ld,%ld", modLimit, switLimit);

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%d", modLimit);
  else *modLimit = RSCMU_NAN_VI_INT32;

  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%d", switLimit);
  else *switLimit = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcSpecMSwAreaLimMatc (ViSession  instrSession,
                                                        ViInt32   *modLimit,
                                                        ViInt32   *switLimit,
                                                        ViChar     errorMessage[])
{
  return RSCMU_GSM_NSig_CalcSpecMSwAreaLimMatc (instrSession,
                                                modLimit,
                                                switLimit,
                                                errorMessage);
}

/*===========================================================================*/
/* Function: Read Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrVarSpecMSw (ViSession instrSession,
                                                    ViReal64  burstPower[],
                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  return RSCMU_MeasArray(instrSession, "READ:ARRay:SPECtrum:MSWitching:VMPoint", burstPower, errorMessage);
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrVarSpecMSw (ViSession instrSession,
                                                   ViReal64  burstPower[],
                                                   ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_ReadArrVarSpecMSw (instrSession,
                                           burstPower,
                                           errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrVarSpecMSw (ViSession instrSession,
                                                    ViReal64 burstPower[],
                                                    ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  return RSCMU_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:MSWitching:VMPoint", burstPower, errorMessage);
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrVarSpecMSw (ViSession instrSession,
                                                   ViReal64 burstPower[],
                                                   ViChar errorMessage[])
{
  return RSCMU_GSM_NSig_FetcArrVarSpecMSw (instrSession,
                                           burstPower,
                                           errorMessage);
}

/*===========================================================================*/
/* Function: Sample Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrVarSpecMSw (ViSession instrSession,
                                                    ViReal64 burstPower[],
                                                    ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  return RSCMU_MeasArray(instrSession, "SAMPLe:ARRay:SPECtrum:MSWitching:VMPoint", burstPower, errorMessage);
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrVarSpecMSw (ViSession instrSession,
                                                   ViReal64 burstPower[],
                                                   ViChar errorMessage[])
{
  return RSCMU_GSM_NSig_SampArrVarSpecMSw (instrSession,
                                           burstPower,
                                           errorMessage);
}

/*===========================================================================*/
/* Function: Current Limit Line Template
/* Purpose : These function is always a query and returns the
/*           current limit line template.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SensSpecMswLimLineUsed (ViSession instrSession,
                                                         ViInt32  *currLimLine,
                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  CHECKRETMSG(RSCMU_getViString(instrSession,"SENSe:SPECtrum:MSWitching:LIMit:LINE:USED?",rdBuf,RD_BUFFER_SIZE,0));

  // Extract the CMU response:
  if (strncmp ("GMSK", rdBuf, 4) == 0)
    *currLimLine = RSCMU_GMSK;
  else if (strncmp ("EPSK", rdBuf, 4) == 0)
    *currLimLine = RSCMU_EPSK;

  return RSCMU_Status;
}
/* -----------------------
   ... for Signalling Mode
   -----------------------*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensSpecMswLimLineUsed (ViSession instrSession,
                                                        ViInt32  *currLimLine,
                                                        ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_SensSpecMswLimLineUsed (instrSession,
                                                currLimLine,
                                                errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 * Symbolic Status Event Register Evaluation
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Event Reporting Enable
/* Purpose : This function enables event reporting for the current GSMxxx-MS
/*           Non Signalling function group, i.e. it sets the corresponding
/*           bits in the STATus:OPERation:CMU:SUM<nr>:CMU<nr_event>:ENABle
/*           register (<nr>=1 | 2, <nr_event> denotes the current function
/*           group) and in all sum registers up to the status byte. The
/*           events and the corresponding symbols for the function group are
/*           listed in Chapter 5 (see section Status Registers).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_StatOperSymbEnab (ViSession instrSession,
                                                                          ViInt32   Rfns,
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) Rfns, RSCMU_ERROR_PARAMETER2, errorMessage);

  if(Rfns)
    sprintf(wrtBuf, "STAT:OPER:SYMB:ENAB RFNS");
  else
    sprintf(wrtBuf, "STAT:OPER:SYMB:ENAB NONE");

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: List Of Reported Events
/* Purpose : This function lists the events reported in the current GSMxxx-MS
/*           Non Signalling function group and deletes these events in the
/*           STATus:OPERation:CMU:SUM<nr>:CMU<nr_event>:EVENt register as
/*           well as in all sum registers.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_StatOperSymb (ViSession instrSession,
                                                                      ViInt32   events[],
                                                                      ViChar    errorMessage[])
{
  return RSCMU_GSM_Sig_StatOperSymb(instrSession, events, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 * Close
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Close
/* Purpose : This function close the Basic Unit session and release the
/*           resources
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_Close_GSM_NSig (ViSession instrSession, ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  struct RSCMU_GSM_NSig_Globals *p_globalvarGSM;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarGSM)) < 0)
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  // Deallocate all system resources allocated to the GSMNSig Session:
  if ((RSCMU_Status = viClose (instrSession)) < 0)
    return RSCMU_Status;

  // Deallocate the space pointed by p_globalvarGSM:
  if (p_globalvarGSM)
    free (p_globalvarGSM);

  return RSCMU_Status;
}

/*****************************************************************************/
/*****************************************************************************/
/*========== Class: GSM_Signalling =========================================*/
/*****************************************************************************/
/*****************************************************************************/

/*
 * ----------------------------------------------------------------------------
 * Initialize
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Initialize
/* Purpose : This function can be called only after the initialization
/*           of the "Basic Unit".It opens the instrument, queries the
/*           instrument for its ID, and initializes the instrument
/*           to a known state.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_Init_GSM_Sig (ViSession   BaseSession,
                                                            ViPSession  instrSession,
                                                            ViUInt32    GSMFunctionGpr,
                                                            ViChar      errorMessage[])
{

  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViSession   globalSession = 0;
  ViInt32     secondAddr = 0, comp = 1;
  ViReal64    Flag = RSCMU_OFF;
  ViChar      FctGrpBuffer[128]= "";
  ViChar      resource[25]="";
  struct RSCMU_Base_Globals     *p_globalvarBase;
  struct RSCMU_GSM_Sig_Globals  *p_globalvarGSM;

  // Which Fonction Group does the User want?
  switch (GSMFunctionGpr)
  {
    case RSCMU_GSM400:
      strcpy (FctGrpBuffer, "\"GSM400MS_Sig\"");
      break;
    case RSCMU_GSM850:
      strcpy (FctGrpBuffer, "\"GSM850MS_Sig\"");
      break;
    case RSCMU_GSM900:
      strcpy (FctGrpBuffer, "\"GSM900MS_Sig\"");
      break;
    case RSCMU_GSM1800:
      strcpy (FctGrpBuffer, "\"GSM1800MS_Sig\"");
      break;
    case RSCMU_GSM1900:
      strcpy (FctGrpBuffer, "\"GSM1900MS_Sig\"");
      break;
  }

  // Init the Error Message
  strcpy (errorMessage, "No Error");

  // Get the current options (= Function Group Names) in the CMU.
  if ((RSCMU_Status = viGetAttribute (BaseSession, VI_ATTR_USER_DATA,(ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_K2G_errorMessage (BaseSession, RSCMU_Status, errorMessage);

  // Find the Secondary address for GSM_Sig
  while ((comp != 0) && (secondAddr < 30))
  {
    comp = strncmp (p_globalvarBase->RSCMU_tSecAddr[secondAddr].FctGrp, FctGrpBuffer, strlen(FctGrpBuffer));
    secondAddr++;
    if (comp == 0)  Flag = RSCMU_ON;
  }

  if (Flag == RSCMU_OFF)
    return RSCMU_K2G_errorMessage (*instrSession, RSCMU_ERROR_INVALID_FCT_GRP, errorMessage);

  // Hardware Connection
  comp = strncmp ("GPIB",p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection, 4);

  if (comp == 0)
    sprintf(resource, "%s::%d::%d::INSTR",p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection, p_globalvarBase->RSCMU_tGlobal.RSCMU_primary_address, secondAddr-1);
  else
    sprintf(resource, "%s::INSTR",p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection);

  // Take default instrument session
  globalSession = p_globalvarBase->RSCMU_tGlobal.RSCMU_RmSessionDefault;

  if ((RSCMU_Status = viOpen (globalSession, resource, VI_NULL, VI_NULL, instrSession)) != 0)
    return RSCMU_K2G_errorMessage (globalSession, RSCMU_Status, errorMessage);

  // Allocate space for "struct RSCMU_SESSION_Globals"
  if ((p_globalvarGSM = (struct RSCMU_GSM_Sig_Globals *) malloc (sizeof (struct RSCMU_GSM_Sig_Globals))) == 0)
    return RSCMU_initCleanUp (globalSession, *instrSession, RSCMU_Status);

  if ((RSCMU_Status = viSetAttribute(*instrSession, VI_ATTR_USER_DATA,(ViAttrState)p_globalvarGSM)) < 0)
    return RSCMU_initCleanUp (globalSession, *instrSession, RSCMU_Status);

  // Set initial values of variables for function Group 'GSM_Sig'.
  strcpy (p_globalvarGSM->RSCMU_tGlobal.FGrp_Name, FctGrpBuffer);
  strcpy (p_globalvarGSM->RSCMU_tGlobal.RSCMU_SCPIConnection, p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection);
  p_globalvarGSM->RSCMU_tGlobal.RSCMU_primary_address = p_globalvarBase->RSCMU_tGlobal.RSCMU_primary_address;
  p_globalvarGSM->RSCMU_tGlobal.RSCMU_secondary_address = secondAddr - 1;
  p_globalvarGSM->RSCMU_tGlobal.RSCMU_TRACE = p_globalvarBase->RSCMU_tGlobal.RSCMU_TRACE;
  p_globalvarGSM->RSCMU_tGlobal.RSCMU_Stb = p_globalvarBase->RSCMU_tGlobal.RSCMU_Stb;
  p_globalvarGSM->RSCMU_tGlobal.RSCMU_SessionNb = *instrSession;

  // Base CMU FW available
  strcpy (p_globalvarGSM->RSCMU_tGlobal.CmuVersion, p_globalvarBase->RSCMU_tGlobal.CmuVersion);
  p_globalvarGSM->RSCMU_tGlobal.RSCMU_FW_Version = p_globalvarBase->RSCMU_tGlobal.RSCMU_FW_Version;

  if (p_globalvarGSM->RSCMU_tGlobal.RSCMU_TRACE == RSCMU_ON)
    p_globalvarGSM->RSCMU_tGlobal.RSCMU_AddrTargetFile = p_globalvarBase->RSCMU_tGlobal.RSCMU_AddrTargetFile;

  // Record the execution of this Init Function.
  p_globalvarBase->RSCMU_tSecAddr[secondAddr - 1].SessionNb = *instrSession;

  // Record the "HandOverName" for the actual Session.
  switch (GSMFunctionGpr)
  {
    case RSCMU_GSM400:
      strcpy (p_globalvarGSM->RSCMU_tHandOver.HandOverSessionName, "\"GSM400MsDualBand\"");
      break;
    case RSCMU_GSM850:
      strcpy (p_globalvarGSM->RSCMU_tHandOver.HandOverSessionName, "\"GSM850MsDualBand\"");
      break;
    case RSCMU_GSM900:
      strcpy (p_globalvarGSM->RSCMU_tHandOver.HandOverSessionName, "\"GSM900MsDualBand\"");
      break;
    case RSCMU_GSM1800:
      strcpy (p_globalvarGSM->RSCMU_tHandOver.HandOverSessionName, "\"GSM1800MsDualBand\"");
      break;
    case RSCMU_GSM1900:
      strcpy (p_globalvarGSM->RSCMU_tHandOver.HandOverSessionName, "\"GSM1900MsDualBand\"");
      break;
  }

  // Timeout changed from 10s to 30 seconds
  if ((RSCMU_Status = viSetAttribute (*instrSession, VI_ATTR_TMO_VALUE, RSCMU_TMO_VALUE)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// Class: GSM Signalling
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


/*===========================================================================*/
/* Function: Wired Sync Trigger Mode
/* Purpose : This function qualifies the role of the current CMU in a wired 
/*           synchronization setup.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_WstrMode (ViSession instrSession,
                                          ViInt32 triggerMode,
                                          ViChar errorMessage[])
{
   ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setEnum(instrSession, "WSTR:MODE",
                         triggerMode, wstrModeArr,
                         RSCMU_ERROR_PARAMETER2));
    
}

/*===========================================================================*/
/* Function: Frame Number
/* Purpose : This function qualifies the TDMA frame number in which the
/*           master or slave CMU fires the wired synchronization trigger
/*           signal.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_WstrFnum (ViSession instrSession,
                                          ViInt32 masterSlave,
                                          ViInt32 frameNumber,
                                          ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));
    CHECK_VI_INT32_RANGE (instrSession,masterSlave,1,2,RSCMU_ERROR_PARAMETER2,errorMessage);

    sprintf (wrtBuf, "WSTR:%s:FNUM", wstrModeArr [masterSlave]);
    RETMSG(RSCMU_setViInt32(instrSession, wrtBuf,
                            frameNumber, 0, 2715647,
                            RSCMU_ERROR_PARAMETER3));
}

/*===========================================================================*/
/* Function: Master Routing
/* Purpose : This function assigns the output synchronization trigger signal
/*           to pins 2 to 5 of the AUX 3 connector.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_WstrMasterRout (ViSession instrSession,
                                                ViInt32 PINNumber,
                                                ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));
    CHECK_VI_INT32_RANGE (instrSession,PINNumber,2,5,RSCMU_ERROR_PARAMETER2,errorMessage);

    sprintf (wrtBuf, "WSTR:MAST:ROUT PIN%ld", PINNumber);
    RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Slave Slot
/* Purpose : This function qualifies the initial slot number the slave CMU 
/*           starts with (in the frame defined by WSTRigger:SLAVe:FNUMber) 
/*           after receiving the wired synchronization trigger signal from 
/*           the master CMU.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_WstrSlaveSlot (ViSession instrSession,
                                               ViInt32 slaveSlot,
                                               ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setViInt32(instrSession, "WSTR:SLAV:SLOT",
                            slaveSlot, 0, 7,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Slave Quarter Symbol Offset
/* Purpose : This function sets the quarter symbol offset. The quarter symbol
/*           offset defines the timing delay of the shifted TDMA slave frame
/*           in quarter symbols (a quarter symbol is 0.923 us long).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_WstrSlaveQsof (ViSession instrSession,
                                               ViInt32 quarterSymbolOffset,
                                               ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setViInt32(instrSession, "WSTR:SLAV:QSOF",
                            quarterSymbolOffset, 0, 624,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Slave Slope
/* Purpose : This function qualifies whether the synchronization trigger
/*           event from the master CMU is processed on the Rising Edge or on
/*           the Falling Edge of the trigger signal.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_WstrSlaveSlop (ViSession instrSession,
                                               ViInt32 triggerSlope,
                                               ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setEnum(instrSession, "WSTR:SLAV:SLOP",
                            triggerSlope, negPosArr,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Slave Routing
/* Purpose : This function assigns the input of the synchronization trigger
/*           signal to pins 6 to 8 of the AUX 3 connector of the slave CMU.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_WstrSlaveRout (ViSession instrSession,
                                               ViInt32 PINNumber,
                                               ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));
    CHECK_VI_INT32_RANGE (instrSession,PINNumber,6,8,RSCMU_ERROR_PARAMETER2,errorMessage);

    sprintf (wrtBuf, "WSTR:SLAV:ROUT PIN%ld", PINNumber);
    RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*
 *-----------------------------------------------------------------------------
 * GROUP CONFIGURATION
 * ------------------
 * The functions in this section are used to configure the
 * measurements in the menu group GSM400/GSM900/1800/1900-MS Signalling
 * globally. They correspond to the settings in the popup menu of
 * the softkey Group Config. Located to the left of the headline of
 * each main menu.
 *
 *-----------------------------------------------------------------------------
 *    INPUT LEVEL
 *    This subsystem contains the functions for determination or
 *    modification of the input level for the currently used input.
 *    It corresponds to the index card Input Level in the popup menu
 *    Group Configuration.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Input Level (Manual/PCL)
/* Purpose : This function defines the mode for setting the maximum
/*           input.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensLevMode (ViSession instrSession,
                                                                   ViInt32   ModeOfSetting,
                                                                   ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    mode_Setting_PCL[]= {"MAN","AUT","PCL"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, ModeOfSetting, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set the Input level Manual/PCL
  sprintf (wrtBuf, "SENS:LEV:MODE %s", mode_Setting_PCL[ModeOfSetting]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Set Input Lev - Maximum
/* Purpose : This Function sets the maximum input level. The permissible
/*           value range depends on the RF input used and the external
/*           attenuation set.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensLevMax (ViSession instrSession,
                                                                  ViReal64  LevMax,
                                                                  ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_SensLevMax (instrSession, LevMax, errorMessage);
}
/*===========================================================================*/
/* Function: Input level - Attenuation
/* Purpose : This function sets the attenuation or gain factor for the
/*           RF input signal.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensLevAtt (ViSession  instrSession,
                                                                  ViInt32    Mode,
                                                                  ViChar     errorMessage[])
{
  return RSCMU_GSM_NSig_SensLevAtt (instrSession, Mode, errorMessage);
}
/*
 *-----------------------------------------------------------------------------
 *    TRIGGER MODE
 *    The subsystem TRIGger contains the functions for determination
 *    of the trigger mode.
 *    It corresponds to the index card Trigger in the popup menu Group
 *    Configuration.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Trigger Mode
/* Purpose : This function defines the trigger mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_TrigSour (ViSession instrSession,
                                                                 ViInt32   TriggerMode,
                                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    mode_Trigger_mode[] = {"FRUN","RFP","IFP","SIGN"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TriggerMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Define the Trigger mode
  sprintf (wrtBuf, "TRIG:SOUR %s", mode_Trigger_mode[TriggerMode]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}


/*===========================================================================*/
/* Function: Set Trigger RF Power
/* Purpose : This Function sets the trigger RF power. It is valid for
/*           trigger Source RFPower. Possible values are Low, Medium and High.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_TrigThrRFPow (ViSession instrSession,
                                              ViInt32 RFPower,
                                              ViChar errorMessage[])
{
  return RSCMU_GSM_NSig_TrigThrRFPow (instrSession, RFPower, errorMessage);
}

/*===========================================================================*/
/* Function: Set Trigger IF Power
/* Purpose : This Function sets the trigger IF power. It is valid for
/*           trigger Source IFPower. Possible values between -47.0 and 0.0 dB.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_TrigThrIFPow (ViSession instrSession,
                                              ViReal64 IFPower,
                                              ViChar errorMessage[])
{
  return RSCMU_GSM_NSig_TrigThrIFPow (instrSession, IFPower, errorMessage);
}

/*===========================================================================*/
/* Function: Set Trigger Slope
/* Purpose : This Function sets the trigger slope. It is enabled for
/*           trigger Source RFPower and IFPower only.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_TrigSlop (ViSession instrSession,
                                          ViInt32 slope,
                                          ViChar errorMessage[])
{
  return RSCMU_GSM_NSig_TrigSlop (instrSession, slope, errorMessage);

}

/*===========================================================================*/
/* Function: Set Trigger Signal
/* Purpose : This function assigns the trigger signal (or no signal)
/*           to pins 2 to 5 of the AUX 3/4 connector.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ExtTrigOutSignal (ViSession instrSession,
                                                  ViInt32 routing,
                                                  ViInt32 triggerSignal,
                                                  ViChar errorMessage[])
{
    ViString    lsRouting[] = {"PIN2","PIN3", "PIN4", "PIN5", VI_NULL};
    ViString    lsSignal[] = {"NONE","FCL", VI_NULL};
    ViStatus    RSCMU_Status = VI_SUCCESS;
    GET_WRT_BUF(instrSession);

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

    CHECK_VI_INT32_RANGE(instrSession, routing, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, triggerSignal, 0, 1, RSCMU_ERROR_PARAMETER3, errorMessage);

    sprintf (wrtBuf, "TRIG:OUTP:%s:SIGN %s" , routing[lsRouting], triggerSignal[lsSignal]);

    RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));

}

/*===========================================================================*/
/* Function: Trigger Delay Enable
/* Purpose : This function qualifies whether the trigger signal at pins 2 to 5
/*           of the AUX 3 connector is delayed by the specified delay time
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ExtTrigOutDelayEnable (ViSession instrSession,
                                                       ViInt32 routing,
                                                       ViInt32 delayEnable,
                                                       ViChar  errorMessage[])
{
    ViString    lsRouting[] = {"PIN2","PIN3", "PIN4", "PIN5", VI_NULL};
    ViStatus    RSCMU_Status = VI_SUCCESS;
    GET_WRT_BUF(instrSession);

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

    CHECK_VI_INT32_RANGE(instrSession, routing, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) delayEnable, RSCMU_ERROR_PARAMETER3, errorMessage);

    sprintf (wrtBuf, "TRIG:OUTP:%s:DEL:ENAB %s" , routing[lsRouting], mode_On_Off[delayEnable]);

    RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));


}

/*===========================================================================*/
/* Function: Trigger Delay Time
/* Purpose : This function sets a delay time
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ExtTrigOutDelayValue (ViSession instrSession,
                                                      ViInt32 delayValue,
                                                      ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_setViInt32(instrSession, "TRIG:OUTP:DEL:VAL",
                            delayValue, 0, 7,
                            RSCMU_ERROR_PARAMETER2));
}





/*===========================================================================*/
/* Function: Set Threshold
/* Purpose : This function sets the threshold at which the trigger signal
/*           triggers the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_TrigThr (ViSession  instrSession,
                                                                ViInt32    TriggerThreshold,
                                                                ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrTriggerThreshold[] = {"LOW","MED","HIGH"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TriggerThreshold, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set the trigger threshold:
  sprintf (wrtBuf, "TRIG:THR %s", StrTriggerThreshold[TriggerThreshold]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*
 *-----------------------------------------------------------------------------
 * CONNECTION CONTROL
 * ------------------
 *-----------------------------------------------------------------------------
 *    CALL SETUP AND CLEARDOWN
 *    The subsystem SIGNalling controls the call setup and cleardown
 *    from the CMU to the mobile and determines the signalling
 *    parameters.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Controlling the Signalling
/* Purpose : This function changes between the different signalling states
/*           ofthe CMU.
/*           Available values:
/*           SOFF          |Switch off BCCH signal (signal off)
/*           SON           |Switch on BCCH signal (signal on)
/*           MTC           |Mobile terminating call
/*           SMS           |Short message service
/*           CREL          |Call release
/*           HAND          |Handover
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignAct (ViSession  instrSession,
                                             ViInt32    signallingState,
                                             ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViInt32     prevState;

  CHECK_VI_INT32_RANGE(instrSession, signallingState, 0, 5, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (signallingState)
  {
    case RSCMU_SON:
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensSignStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU_Status;
      // Be sured that CMU is in SOFF
      if (prevState != RSCMU_STATE_SOFF)
      {
        // neant
      }
      else
      {
        if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:ACT SON", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
          return RSCMU_Status;
      }
    break;

    case RSCMU_SOFF:
      if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:ACT SOFF", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;
    break;

    case RSCMU_MTC:
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensSignStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU_Status;
      // Be sured that CMU is in SON or in SYNC.
      if ((prevState != RSCMU_STATE_SON) && (prevState != RSCMU_STATE_SYNC))
        return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
      // Call to mobile
      if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:ACT MTC", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;
    break;

    case RSCMU_SMS:
      // Send short message
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensSignStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU_Status;
      // Be sured that CMU is in SYNC
      if (prevState != RSCMU_STATE_SYNC)
        return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
      if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:ACT SMS", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;
    break;

    case RSCMU_CREL:
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensSignStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU_Status;
      // Be sured that CMU is in CEST | CED | ALER | CPEN.
      if ((prevState != RSCMU_STATE_CEST) && (prevState != RSCMU_STATE_CED) && (prevState != RSCMU_STATE_ALER) && (prevState != RSCMU_STATE_CPEN))
        return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
      // Release the call
      if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:ACT CREL", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;
    break;

    case RSCMU_HAND:
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensSignStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU_Status;
      // Be sured that CMU is in CEST.
      if ((prevState != RSCMU_STATE_CEST) && (prevState != RSCMU_STATE_CED))
        return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
      // Release the call
      if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:ACT HAND", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;
    break;

  }
  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Sense Signalling State
/* Purpose : This function reads out the current signalling state of the
/*           CMU.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensSignStat (ViSession  instrSession,
                                                                     ViInt32   *SignallingState,
                                                                     ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";

  // Sense the current signalling state of the CMU
  if ((RSCMU_Status = RSCMU_Query (instrSession, "SENS:SIGN:STAT?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Extract the CMU response:
  if (strncmp ("SOFF", rdBuf, 4) == 0)
    *SignallingState = RSCMU_STATE_SOFF;
  else if (strncmp ("SON", rdBuf, 3) == 0)
    *SignallingState = RSCMU_STATE_SON;
  else if (strncmp ("SYNC", rdBuf, 4) == 0)
    *SignallingState = RSCMU_STATE_SYNC;
  else if (strncmp ("CEST", rdBuf, 4) == 0)
    *SignallingState = RSCMU_STATE_CEST;
  else if (strncmp ("CPEN", rdBuf, 4) == 0)
    *SignallingState = RSCMU_STATE_CPEN;
  else if (strncmp ("CED", rdBuf, 3) == 0)
    *SignallingState = RSCMU_STATE_CED;
  else if (strncmp ("ALER", rdBuf, 4) == 0)
    *SignallingState = RSCMU_STATE_ALER;
  else
  {
    *SignallingState = RSCMU_UNKNOWN_STATE;
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
  }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Sense Signalling SMS
/* Purpose : This command reads the short message received.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensSignSMS (ViSession instrSession,
                                                                    ViChar    String[],
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar    rdBuf[RD_BUFFER_SIZE_ARRAY]= "";

  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, "SENS:SIGN:SMS?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Extract the CMU_response
  if (strcmp (rdBuf, "") != 0)
    sscanf (rdBuf, "%[^\r\n]", String);
  else
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_NAN, errorMessage);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Configure Signalling SMS
/* Purpose : This command defines a short message in the form of any
/*           alphanumeric sting with a maximum of 160 characters.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSignSMS (ViSession instrSession,
                                                                    ViChar    String[],
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY]= "";

  sprintf (wrtBuf, "CONF:SIGN:SMS \"%s\"", String);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*-----------------------------------------------------------------------------
 * Configuration
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Combined Channel
/* Purpose : This function controls the combined channel change, the
/*           number of the traffic channel for signals of the CMU, the
/*           timeslot for this channel and the mobile power level being
/*           changed at the same time.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignChcc (ViSession instrSession,
                                                                     ViInt32   TrafficChannelNb,
                                                                     ViInt32   TimeSlot,
                                                                     ViInt32   MobilePhonePCL,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar    wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct RSCMU_SESSION_Globals  *p_globalvarSession;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TimeSlot, RSCMU_TIMESLOT_MIN, RSCMU_TIMESLOT_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  // Which Current Fonction Group?
  if (strncmp ("\"GSM400MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, TrafficChannelNb, 259, 340, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 19, RSCMU_ERROR_PARAMETER4, errorMessage);
  }
  else if (strncmp ("\"GSM850MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, TrafficChannelNb, 128, 251, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 19, RSCMU_ERROR_PARAMETER4, errorMessage);
  }
  else if (strncmp ("\"GSM900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    if ((RSCMU_invalidViInt32Range (TrafficChannelNb, 0, 124)) && (RSCMU_invalidViInt32Range (TrafficChannelNb, 955, 1023)))
      return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 31, RSCMU_ERROR_PARAMETER4, errorMessage);
  }
  else if (strncmp ("\"GSM1800MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, TrafficChannelNb, 512, 885, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 32, RSCMU_ERROR_PARAMETER4, errorMessage);
  }
  else if (strncmp ("\"GSM1900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, TrafficChannelNb, 512, 810, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 32, RSCMU_ERROR_PARAMETER4, errorMessage);
  }

  // Change combined channel
  sprintf (wrtBuf, "PROC:SIGN:CHCC %d,%d,%d",TrafficChannelNb, TimeSlot, MobilePhonePCL);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Set PCL Value
/* Purpose : This command defines the PCL value to be set at the mobile.
/*           The range depends on the GSM phase of the mobile.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignMsPcl (ViSession instrSession,
                                                                     ViInt32   MobilePhonePCL,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar    wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct RSCMU_SESSION_Globals  *p_globalvarSession;

  // Get the Session's Globals
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  // Which Current Fonction Group?
  if (strncmp ("\"GSM400MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 19, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM850MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 19, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 19, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1800MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 31, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 31, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  sprintf (wrtBuf, "PROC:SIGN:MS:PCL %d", MobilePhonePCL);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Set Number of Traffic Channel
/* Purpose : After the call has been set up, this function determines the
/*           number (and thus the frequency) of the traffic channel for
/*           signals of the CMU.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignTchChan (ViSession instrSession,
                                                                        ViInt32   TrafficChannelNb,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct RSCMU_SESSION_Globals  *p_globalvarSession;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;


  // Check if the function is correctly used:
  // Which Current Fonction Group?
  if (strncmp ("\"GSM400MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, TrafficChannelNb, 259, 340, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM850MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, TrafficChannelNb, 128, 251, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    if ((RSCMU_invalidViInt32Range (TrafficChannelNb, 0, 124)) && (RSCMU_invalidViInt32Range (TrafficChannelNb, 955, 1023)))
      return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1800MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, TrafficChannelNb, 512, 885, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, TrafficChannelNb, 512, 810, RSCMU_ERROR_PARAMETER2, errorMessage);
  }

  sprintf (wrtBuf, "PROC:SIGN:TCH:CHAN %d", TrafficChannelNb);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Set Hopping Sequence
/* Purpose : This function selects one out of the four possible hopping
/*           sequences for the traffic channel or switches frequency
/*           hopping off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignTchFhopSeq (ViSession instrSession,
                                                                           ViInt32   hoppingSequence,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString hoping_Seq[] = {"OFF","A","B","C","D"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, hoppingSequence, RSCMU_HOPPING_SEQ_OFF, RSCMU_HOPPING_SEQ_D, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Change the Hopping Session
  sprintf(wrtBuf, "PROC:SIGN:FHOP:SEQ %s",hoping_Seq[hoppingSequence]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Set Timeslot
/* Purpose : After the call has been set up, this function selects the
/*           timeslot of the traffic channel for signals of the CMU.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignTchTim (ViSession instrSession,
                                                                       ViInt32   TimeSlot,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar    wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TimeSlot, RSCMU_TIMESLOT_MIN, RSCMU_TIMESLOT_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "PROC:SIGN:TIM %d", TimeSlot);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: DAI acoustic device
/* Purpose : This function determines the routing of the speech data and which
/*           device is being tested.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignDAI (ViSession instrSession,
                                                                    ViInt32   speechData,
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;
  ViString    stringDAI[] = {"NORM", "DEC", "ENC", "ADEV"};

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, speechData, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "PROC:SIGN:DAI %s", stringDAI[speechData]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Timing Advance
/* Purpose : This function changes the mobile's timing while a connection is
/*           established.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignTadv (ViSession instrSession,
                                                                     ViInt32   tadv,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, tadv, 0, 219, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf,"PROC:SIGN:TADV %d", tadv);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Main Timeslot
/* Purpose : This function changes the timeslot that the MS and the BS/CMU
/*           use for signalling (current value).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignMslMtim (ViSession instrSession,
                                                                        ViInt32   MainTimeSlot,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, MainTimeSlot, 0, 7, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "PROC:SIGN:MSL:MTIM %d", MainTimeSlot);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}







/*===========================================================================*/
/* Function: Slot Mode
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSlotMode (ViSession instrSession,
                                              ViInt32 slotMode,
                                              ViChar errorMessage[])
{
    ViString    list[] = {"SSL","MSL", VI_NULL};
    ViStatus    RSCMU_Status = VI_SUCCESS;

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_10, RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:SIGN:CSW:SMOD",
                         slotMode, list,
                         RSCMU_ERROR_PARAMETER2));

}



/*===========================================================================*/
/* Function: Loop Type Single Slot
/* Purpose : This function sets the single loop type RXQuality tests..
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignSslLoop (ViSession instrSession,
                                                    ViInt32 loop,
                                                     ViChar errorMessage[])
{
    ViString    list[] = {"OFF","A", "B","C","D","E","F","G","H","I",VI_NULL};
    ViStatus    RSCMU_Status = VI_SUCCESS;

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_10, RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_setEnum(instrSession, "PROC:SIGN:SSL:LOOP",
                         loop, list,
                         RSCMU_ERROR_PARAMETER2));
/*    RETMSG(RSCMU_setEnum(instrSession, "PROC:MSS:SSLot:LOOP",
                         loop, list,
                         RSCMU_ERROR_PARAMETER2));
*/}


/*===========================================================================*/
/* Function: CSwitched Slot Configuration
/* Purpose : This function changes the slot configuration and the RF levels
/*           that the CMU uses in test mode (current parameters).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignCswMslSconf (ViSession instrSession, ViInt32   MainTS,
                                                      ViInt32   DL0Enable,ViInt32   DL1Enable,ViInt32   DL2Enable,ViInt32   DL3Enable,ViInt32   DL4Enable,ViInt32   DL5Enable,ViInt32   DL6Enable,ViInt32   DL7Enable,
                                                      ViReal64  DL0Level,ViReal64  DL1Level,ViReal64  DL2Level,ViReal64  DL3Level,ViReal64  DL4Level,ViReal64  DL5Level,ViReal64  DL6Level,ViReal64  DL7Level,
                                                      ViInt32   UL0Enable,ViInt32   UL1Enable,ViInt32   UL2Enable,ViInt32   UL3Enable,ViInt32   UL4Enable,ViInt32   UL5Enable,ViInt32   UL6Enable,ViInt32   UL7Enable,
                                                      ViInt32   UL0pcl,ViInt32   UL1pcl,ViInt32   UL2pcl,ViInt32   UL3pcl,ViInt32   UL4pcl,ViInt32   UL5pcl,ViInt32   UL6pcl,ViInt32   UL7pcl,
                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  struct      RSCMU_SESSION_Globals  *p_globalvarSession;


  CHECKRET(viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession));

   // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE (instrSession, MainTS, 0, 7, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) DL0Enable, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) DL1Enable, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) DL2Enable, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) DL3Enable, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) DL4Enable, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) DL5Enable, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) DL6Enable, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) DL7Enable, RSCMU_ERROR_PARAMETER10, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL0Level, -127, 127, RSCMU_ERROR_PARAMETER11, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL1Level, -127, 127, RSCMU_ERROR_PARAMETER12, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL2Level, -127, 127, RSCMU_ERROR_PARAMETER13, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL3Level, -127, 127, RSCMU_ERROR_PARAMETER14, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL4Level, -127, 127, RSCMU_ERROR_PARAMETER15, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL5Level, -127, 127, RSCMU_ERROR_PARAMETER16, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL6Level, -127, 127, RSCMU_ERROR_PARAMETER17, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL7Level, -127, 127, RSCMU_ERROR_PARAMETER18, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) UL0Enable, RSCMU_ERROR_PARAMETER19, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) UL1Enable, RSCMU_ERROR_PARAMETER20, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) UL2Enable, RSCMU_ERROR_PARAMETER21, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) UL3Enable, RSCMU_ERROR_PARAMETER22, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) UL4Enable, RSCMU_ERROR_PARAMETER23, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) UL5Enable, RSCMU_ERROR_PARAMETER24, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) UL6Enable, RSCMU_ERROR_PARAMETER25, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) UL7Enable, RSCMU_ERROR_PARAMETER26, errorMessage);
  // Check if the function is correctly used:
  // Which Current Fonction Group?
  if (strncmp ("\"GSM400MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
  CHECK_VI_INT32_RANGE (instrSession, UL0pcl, 0, 19, RSCMU_ERROR_PARAMETER27, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL1pcl, 0, 19, RSCMU_ERROR_PARAMETER28, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL2pcl, 0, 19, RSCMU_ERROR_PARAMETER29, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL3pcl, 0, 19, RSCMU_ERROR_PARAMETER30, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL4pcl, 0, 19, RSCMU_ERROR_PARAMETER31, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL5pcl, 0, 19, RSCMU_ERROR_PARAMETER32, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL6pcl, 0, 19, RSCMU_ERROR_PARAMETER33, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL7pcl, 0, 19, RSCMU_ERROR_PARAMETER34, errorMessage);
  }
  else if (strncmp ("\"GSM850MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
  CHECK_VI_INT32_RANGE (instrSession, UL0pcl, 0, 19, RSCMU_ERROR_PARAMETER27, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL1pcl, 0, 19, RSCMU_ERROR_PARAMETER28, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL2pcl, 0, 19, RSCMU_ERROR_PARAMETER29, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL3pcl, 0, 19, RSCMU_ERROR_PARAMETER30, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL4pcl, 0, 19, RSCMU_ERROR_PARAMETER31, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL5pcl, 0, 19, RSCMU_ERROR_PARAMETER32, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL6pcl, 0, 19, RSCMU_ERROR_PARAMETER33, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL7pcl, 0, 19, RSCMU_ERROR_PARAMETER34, errorMessage);
  }
  else if (strncmp ("\"GSM900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
  CHECK_VI_INT32_RANGE (instrSession, UL0pcl, 0, 19, RSCMU_ERROR_PARAMETER27, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL1pcl, 0, 19, RSCMU_ERROR_PARAMETER28, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL2pcl, 0, 19, RSCMU_ERROR_PARAMETER29, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL3pcl, 0, 19, RSCMU_ERROR_PARAMETER30, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL4pcl, 0, 19, RSCMU_ERROR_PARAMETER31, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL5pcl, 0, 19, RSCMU_ERROR_PARAMETER32, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL6pcl, 0, 19, RSCMU_ERROR_PARAMETER33, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL7pcl, 0, 19, RSCMU_ERROR_PARAMETER34, errorMessage);
  }
  else if (strncmp ("\"GSM1800MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
  CHECK_VI_INT32_RANGE (instrSession, UL0pcl, 0, 31, RSCMU_ERROR_PARAMETER27, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL1pcl, 0, 31, RSCMU_ERROR_PARAMETER28, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL2pcl, 0, 31, RSCMU_ERROR_PARAMETER29, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL3pcl, 0, 31, RSCMU_ERROR_PARAMETER30, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL4pcl, 0, 31, RSCMU_ERROR_PARAMETER31, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL5pcl, 0, 31, RSCMU_ERROR_PARAMETER32, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL6pcl, 0, 31, RSCMU_ERROR_PARAMETER33, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL7pcl, 0, 31, RSCMU_ERROR_PARAMETER34, errorMessage);
  }
  else if (strncmp ("\"GSM1900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
  CHECK_VI_INT32_RANGE (instrSession, UL0pcl, 0, 31, RSCMU_ERROR_PARAMETER27, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL1pcl, 0, 31, RSCMU_ERROR_PARAMETER28, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL2pcl, 0, 31, RSCMU_ERROR_PARAMETER29, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL3pcl, 0, 31, RSCMU_ERROR_PARAMETER30, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL4pcl, 0, 31, RSCMU_ERROR_PARAMETER31, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL5pcl, 0, 31, RSCMU_ERROR_PARAMETER32, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL6pcl, 0, 31, RSCMU_ERROR_PARAMETER33, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL7pcl, 0, 31, RSCMU_ERROR_PARAMETER34, errorMessage);
  }

  sprintf (wrtBuf, "PROC:SIGN:CSW:MSL:SCON %d,%s,%s,%s,%s,%s,%s,%s,%s,%lf,%lf,%lf,%lf,%lf,%lf,%lf,%lf,%s,%s,%s,%s,%s,%s,%s,%s,%d,%d,%d,%d,%d,%d,%d,%d"
       ,MainTS
       ,mode_On_Off[DL0Enable], mode_On_Off[DL1Enable], mode_On_Off[DL2Enable], mode_On_Off[DL3Enable], mode_On_Off[DL4Enable], mode_On_Off[DL5Enable], mode_On_Off[DL6Enable], mode_On_Off[DL7Enable]
       ,DL0Level, DL1Level, DL2Level, DL3Level, DL4Level, DL5Level, DL6Level, DL7Level
       ,mode_On_Off[UL0Enable], mode_On_Off[UL1Enable], mode_On_Off[UL2Enable], mode_On_Off[UL3Enable], mode_On_Off[UL4Enable], mode_On_Off[UL5Enable], mode_On_Off[UL6Enable], mode_On_Off[UL7Enable]
       ,UL0pcl, UL1pcl, UL2pcl, UL3pcl, UL4pcl, UL5pcl, UL6pcl, UL7pcl);


  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}



/*===========================================================================*/
/* !Only for compatibility!
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignMslBsSconfInd (ViSession instrSession,
                                                                              ViInt32   TS0Enable,
                                                                              ViReal64  TS0Level,
                                                                              ViInt32   TS1Enable,
                                                                              ViReal64  TS1Level,
                                                                              ViInt32   TS2Enable,
                                                                              ViReal64  TS2Level,
                                                                              ViInt32   TS3Enable,
                                                                              ViReal64  TS3Level,
                                                                              ViInt32   TS4Enable,
                                                                              ViReal64  TS4Level,
                                                                              ViInt32   TS5Enable,
                                                                              ViReal64  TS5Level,
                                                                              ViInt32   TS6Enable,
                                                                              ViReal64  TS6Level,
                                                                              ViInt32   TS7Enable,
                                                                              ViReal64  TS7Level,
                                                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_10, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) TS0Enable, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS0Level, -127, 127, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) TS1Enable, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS1Level, -127, 127, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) TS2Enable, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS2Level, -127, 127, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) TS3Enable, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS3Level, -127, 127, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) TS4Enable, RSCMU_ERROR_PARAMETER10, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS4Level, -127, 127, RSCMU_ERROR_PARAMETER11, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) TS5Enable, RSCMU_ERROR_PARAMETER12, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS5Level, -127, 127, RSCMU_ERROR_PARAMETER13, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) TS6Enable, RSCMU_ERROR_PARAMETER14, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS6Level, -127, 127, RSCMU_ERROR_PARAMETER15, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) TS7Enable, RSCMU_ERROR_PARAMETER16, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS7Level, -127, 127, RSCMU_ERROR_PARAMETER17, errorMessage);

  sprintf (wrtBuf, "PROC:SIGN:MSL:BS:SCON:IND %s,%s,%s,%s,%s,%s,%s,%s,%lf,%lf,%lf,%lf,%lf,%lf,%lf,%lf", mode_On_Off[TS0Enable]
                                                                                                      , mode_On_Off[TS1Enable]
                                                                                                      , mode_On_Off[TS2Enable]
                                                                                                      , mode_On_Off[TS3Enable]
                                                                                                      , mode_On_Off[TS4Enable]
                                                                                                      , mode_On_Off[TS5Enable]
                                                                                                      , mode_On_Off[TS6Enable]
                                                                                                      , mode_On_Off[TS7Enable]
                                                                                                      , TS0Level
                                                                                                      , TS1Level
                                                                                                      , TS2Level
                                                                                                      , TS3Level
                                                                                                      , TS4Level
                                                                                                      , TS5Level
                                                                                                      , TS6Level
                                                                                                      , TS7Level);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Loop Type Multi Slot
/* Purpose : This function sets the multislot loop type RXQuality tests..
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignMslLoop (ViSession instrSession,
                                                   ViInt32 loop,
                                                    ViChar errorMessage[])
{
    ViString    list[] = {"OFF","A", "B","C","D","E","F","G","H",VI_NULL};
    ViStatus    RSCMU_Status = VI_SUCCESS;

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_10, RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_setEnum(instrSession, "PROC:SIGN:MSLot:LOOP",
                         loop, list,
                         RSCMU_ERROR_PARAMETER2));
/*    RETMSG(RSCMU_setEnum(instrSession, "PROC:MSS:MSLot:LOOP",
                         loop, list,
                         RSCMU_ERROR_PARAMETER2));*/
}

/*
 *-----------------------------------------------------------------------------
 *    HANDOVER
 *    The subsystem HANDover sets the target for a forced handover of the mobile
 *    phone. The corresponding softkeys are located in the tab Handover in the
 *    popup menu Connect. Control.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Destination list
/* Purpose : This function is always a query and returns a list of all networks
/*           that are available for a handover. The list depends on the current
/*           network.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_HandTargListStat (ViSession instrSession,
                                                                         ViChar    targetList[],
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY]= "";

  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, "STAT:HAND:TARG:LIST?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Extract the CMU_response
  if (strcmp (rdBuf, "") != 0)
    sscanf (rdBuf, "%s", targetList);
  else
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_NAN, errorMessage);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Destination selection
/* Purpose : This function selects a handover target. The targets available
/*           depend on the current network. The handover itself is started
/*           via the PROCedure:SIGNalling:ACTion HANDover command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfHandTarg (ViSession instrSession,
                                                                     ViInt32   selection,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY]= "";
  // JMG 030309 struct      RSCMU_SESSION_Globals  *p_globalvarBase;
  struct      RSCMU_GSM_Sig_Globals *p_globalvarBase;
  ViString    StringTarget[] = {"NONE", "\"GSM1800MsDualBand\"", "\"GSM1900MsDualBand\"", "\"GSM900MsDualBand\"",
                                "\"GSM850MsDualBand\"", "\"GSM400MsDualBand\"", "\"WCDMA1900UEFDDINTERCELL\""};

  // Check if the function is correctly used:
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // JMG 030309if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_01)
  if (p_globalvarBase->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_01)
  {
    CHECK_VI_INT32_RANGE(instrSession, selection, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else
  {
    CHECK_VI_INT32_RANGE(instrSession, selection, 0, 6, RSCMU_ERROR_PARAMETER2, errorMessage);
  }


    // JMG 030309 sprintf (wrtBuf, "CONF:HAND:TARG %s", StringTarget);
  sprintf (wrtBuf, "CONF:HAND:TARG %s", StringTarget[selection]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}


/*===========================================================================*/
/* Function: Alerting
/* Purpose : This function qualifies whether or not alerting is initiated at the
/*           mobile so that it starts ringing before the GSM connection is established.
/*           It is generally used in a GSM prepare session before a handover from
/*           WCDMA to GSM. The setting has no effect for GSM measurements.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfHandAlert (ViSession instrSession,
                                               ViInt32   alerting,
                                               ViChar    errorMessage[])
{
  ViString    StrAlerting[] = {"NONE","WGSM", VI_NULL};
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  RETMSG(RSCMU_setEnum(instrSession, "CONFigure:HANDover:ALERting", alerting, StrAlerting,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Cell Synchronization
/* Purpose : This function selects the procedure for physical channel establishment
/*           in a WCDMA to GSM handover. It is generally used in a GSM prepare
/*           session before the handover from WCDMA to GSM is initiated.
/*           The setting has no effect for GSM measurements.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfHandCSync (ViSession instrSession,
                                               ViInt32   cellSynchronization,
                                               ViChar    errorMessage[])
{
  ViString    StrCSync[] = {"NSYN","FSYN", VI_NULL};
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  RETMSG(RSCMU_setEnum(instrSession, "CONFigure:HANDover:CSYNc", cellSynchronization, StrCSync,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: GSM Sig Enable
/* Purpose : This function loads the GSM function group and activates the
/*           Call Pending state from where a handover to GSM can be initiated
/*           (PROCedure:SIGNalling:ACTion HANDover).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignHandTargPrep (ViSession instrSession,
                                                      ViBoolean GSMSignal,
                                                      ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_00,RSCMU_ERROR_FW_VERSION_4_00));

    RETMSG(RSCMU_setEnum(instrSession, "PROC:SIGN:HAND:TARG:PREP",
                         GSMSignal,
                         mode_On_Off, 
                         RSCMU_ERROR_PARAMETER2));
}

/*-----------------------------------------------------------------------------
 *    MS SIGNAL
 *
 *    The subsystem MSSignal configures the operating mode and the RF traffic
 *    channel signal of the MS under test. It corresponds to the tab MS Signal
 *    in the popup menu Connect. Control.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Measurement Slot
/* Purpose : This function defines the measured timeslot of the MS signal.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfMssMconMesl (ViSession instrSession,
                                                                        ViInt32   Timeslot,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Timeslot, 0, 7, RSCMU_ERROR_PARAMETER2, errorMessage);


  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_10)
    sprintf (wrtBuf, "CONF:MSS:MCON:MESL %d", Timeslot);

  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V3_10)
    sprintf (wrtBuf, "CONF:MCON:MSL:MESL %d", Timeslot);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: PCL Level/PMAX
/* Purpose : This function defines the power control level that the MS shall
/*           use in circuit-switched mode and the power control parameter
/*           PMAX that holds for packet-data mode. Both parameters are always
/*           equal. An overview of power control levels (PCL) in GSM is given
/*           in chapter 4 (see table or index).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfMssCchPcl (ViSession instrSession,
                                                                      ViInt32   MobilePhonePCL,
                                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarSession;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  if (p_globalvarSession->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Get the Session's Globals
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  // Which Current Fonction Group?
  if (strncmp ("\"GSM400MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 19, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM850MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 19, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 19, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1800MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 31, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 31, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  sprintf (wrtBuf, "CONF:MSS:CCH:PMAX %d", MobilePhonePCL);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: DTX
/* Purpose : This function permits the mobile to make use of the DTX mode
/*           (discontinuous transmission mode). The status assumed by the
/*           mobile is to be determined using the command [SENSe:]RREPorts:
/*           DTX?. Only useful data are transferred in DTX mode; if nothing
/*           is spoken, the mobile will transmit nothing in the traffic frames.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfMssDtx (ViSession instrSession,
                                                                   ViInt32   DTXMode,
                                                                   ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) DTXMode, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MSS:DTX %s", mode_On_Off[DTXMode]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Timing Advance
/* Purpose : This function sets the default value for the mobile's timing.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfMssTadv (ViSession instrSession,
                                                                    ViInt32   tadv,
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, tadv, 0, 219, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf,"CONF:MSS:TADV %d", tadv);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}


/*===========================================================================*/
/* Function: PCL Value
/* Purpose : This function  defines the mobile power level upon registration
/*           in the network.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfMssMsPcl (ViSession instrSession,
                                              ViInt32 MobilePhonePCL,
                                              ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar    wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct RSCMU_SESSION_Globals  *p_globalvarSession;

  // Get the Session's Globals
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  // Which Current Fonction Group?
  if (strncmp ("\"GSM400MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 19, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM850MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 19, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 19, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1800MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 31, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 31, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  sprintf (wrtBuf, "CONF:MSS:MS:PCL %d", MobilePhonePCL);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Loop Type Single Slot
/* Purpose : This function sets the singleslot loop type RXQuality tests..
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfMssSslLoop (ViSession instrSession,
                                                        ViInt32 loop,
                                                         ViChar errorMessage[])
{
    ViString    list[] = {"OFF","A", "B","C","D","E","F",VI_NULL};
    ViStatus    RSCMU_Status = VI_SUCCESS;

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_10, RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:MSS:SSL:LOOP",
                         loop, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Slot Configuration: Uplink
/* Purpose : This function defines the active timeslots slots of the MS
/*           signal and the transmitter output power that the MS will use in
/*           all active slots (default values). In the default setting, only
/*           slot 3 is enabled. Slot no. 5 is also the main timeslot;
/*           see CONFigure:BSSignal[:CSWitched][:TCH]:MSLot:MTIMeslot
/*           command on p. 6.173.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfMssMslSconf (ViSession instrSession,
                                                                        ViInt32   TS0Enable,
                                                                        ViInt32   TS0Pcl,
                                                                        ViInt32   TS1Enable,
                                                                        ViInt32   TS1Pcl,
                                                                        ViInt32   TS2Enable,
                                                                        ViInt32   TS2Pcl,
                                                                        ViInt32   TS3Enable,
                                                                        ViInt32   TS3Pcl,
                                                                        ViInt32   TS4Enable,
                                                                        ViInt32   TS4Pcl,
                                                                        ViInt32   TS5Enable,
                                                                        ViInt32   TS5Pcl,
                                                                        ViInt32   TS6Enable,
                                                                        ViInt32   TS6Pcl,
                                                                        ViInt32   TS7Enable,
                                                                        ViInt32   TS7Pcl,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) TS0Enable, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS0Pcl, 0, 31, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) TS1Enable, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS1Pcl, 0, 31, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) TS2Enable, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS2Pcl, 0, 31, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) TS3Enable, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS3Pcl, 0, 31, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) TS4Enable, RSCMU_ERROR_PARAMETER10, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS4Pcl, 0, 31, RSCMU_ERROR_PARAMETER11, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) TS5Enable, RSCMU_ERROR_PARAMETER12, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS5Pcl, 0, 31, RSCMU_ERROR_PARAMETER13, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) TS6Enable, RSCMU_ERROR_PARAMETER14, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS6Pcl, 0, 31, RSCMU_ERROR_PARAMETER15, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) TS7Enable, RSCMU_ERROR_PARAMETER16, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS7Pcl, 0, 31, RSCMU_ERROR_PARAMETER17, errorMessage);

  sprintf (wrtBuf, "CONF:MSS:MSL:SCON %s,%s,%s,%s,%s,%s,%s,%s,%d,%d,%d,%d,%d,%d,%d,%d", mode_On_Off[TS0Enable]
                                                                                      , mode_On_Off[TS1Enable]
                                                                                      , mode_On_Off[TS2Enable]
                                                                                      , mode_On_Off[TS3Enable]
                                                                                      , mode_On_Off[TS4Enable]
                                                                                      , mode_On_Off[TS5Enable]
                                                                                      , mode_On_Off[TS6Enable]
                                                                                      , mode_On_Off[TS7Enable]
                                                                                      , TS0Pcl
                                                                                      , TS1Pcl
                                                                                      , TS2Pcl
                                                                                      , TS3Pcl
                                                                                      , TS4Pcl
                                                                                      , TS5Pcl
                                                                                      , TS6Pcl
                                                                                      , TS7Pcl);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Loop Type Multi Slot
/* Purpose : This function sets the multislot loop type RXQuality tests..
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfMssMslLoop (ViSession instrSession,
                                                        ViInt32 loop,
                                                         ViChar errorMessage[])
{
    ViString    list[] = {"OFF","A", "B","C","D","E","F","G","H",VI_NULL};
    ViStatus    RSCMU_Status = VI_SUCCESS;

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_10, RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:MSS:MSLot:LOOP",
                         loop, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*-----------------------------------------------------------------------------
 *    BS SIGNAL
 *    The subsystem BSSignal configures the control and traffic channels
 *    for the signals sent by the CMU to the mobile phone.
 * ----------------------------------------------------------------------------
 *      SPEECH MODE (BIT STREAM)
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Conf. Speech Mode (Conf. Bit Stream for FW 2.10)
/* Purpose : This function determines the type of data transmitted in
/*           the traffic channel. For BER measurements, one of the
/*           pseudo random sequences (PSR) must be used.
/*           It is available in the signalling states SOFF, SON and SYNC
/*           It configures the traffic channel before it is switched on.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssSpe (ViSession instrSession,
                                                                   ViInt32   Mode,
                                                                   ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    mode_Modul_TCH[] = {"ECHO","LOOP","PR9","PR11","PR15","PR16","HAND","CCAL","ECAL","HLOW","DCAL"};
  struct      RSCMU_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
  {
    CHECK_VI_INT32_RANGE(instrSession, Mode, RSCMU_SPEECH_ECHO, RSCMU_SPEECH_ECAL, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else CHECK_VI_INT32_RANGE(instrSession, Mode, RSCMU_SPEECH_ECHO, RSCMU_SPEECH_DCAL, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Change de Hopping Session
  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_10)
    sprintf(wrtBuf, "CONF:BSS:SPE %s",mode_Modul_TCH[Mode]);
  else sprintf(wrtBuf, "CONF:BSS:BITS %s",mode_Modul_TCH[Mode]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Proc. Speech Mode (Proc. Bit Stream for FW 2.10)
/* Purpose : This function determines the type of data transmitted in
/*           the traffic channel. For BER measurements, one of the
/*           pseudo random sequences (PSR) must be used.
/*           It is available in the signalling state CEST. With an
/*           established call it changes the speech mode, resets the
/*           device hardware to the new speech mode and continues
/*           the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcBssSpe (ViSession instrSession,
                                                                   ViInt32   Mode,
                                                                   ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    mode_Modul_TCH[] = {"ECHO","LOOP","PR9","PR11","PR15","PR16","HAND","CCAL","ECAL","HLOW","DCAL"};
  struct      RSCMU_SESSION_Globals    *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
  {
    CHECK_VI_INT32_RANGE(instrSession, Mode, RSCMU_SPEECH_ECHO, RSCMU_SPEECH_ECAL, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else CHECK_VI_INT32_RANGE(instrSession, Mode, RSCMU_SPEECH_ECHO, RSCMU_SPEECH_DCAL, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Change de Hopping Session
  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_10)
    sprintf(wrtBuf, "PROC:BSS:SPE %s",mode_Modul_TCH[Mode]);
  else sprintf(wrtBuf, "PROC:BSS:BITS %s",mode_Modul_TCH[Mode]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*
 * ----------------------------------------------------------------------------
 *        FREQUENCY OFFSET
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Frequency Offset
/* Purpose : This function specifies the frequency offset for the CMU
/*           signals (CCH and TCH).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssFmDev (ViSession instrSession,
                                                                     ViReal64  FreqOffSet,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, FreqOffSet, RSCMU_GSM_SIG_FREQNEG, RSCMU_GSM_SIG_FREQPOS, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf, "CONF:BSS:FM:DEV %lf", FreqOffSet);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set Frequency Offset
/* Purpose : This function specifies the frequency offset for the CMU
/*           signals (CCH and TCH).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcBssFmDev (ViSession instrSession,
                                                                     ViReal64  FreqOffSet,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

  RETMSG(RSCMU_setViReal64(instrSession, "PROC:BSS:FM:DEV", FreqOffSet,
                             RSCMU_GSM_SIG_FREQNEG, RSCMU_GSM_SIG_FREQPOS,
                             RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Set Random Frequency Offset
/* Purpose : This function switches the random frequency on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcBssRandFmDev (ViSession instrSession,
                                                  ViInt32   enable,
                                                  ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_40, RSCMU_ERROR_FW_VERSION_3_40));

  RETMSG(RSCMU_setEnum(instrSession, "PROCedure:BSSignal:FM:DEViation:RANDom:ENABle",
                       enable, mode_On_Off,
                       RSCMU_ERROR_PARAMETER2));

}

/*
 * ----------------------------------------------------------------------------
 *        CONTROL CHANNEL
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: BCCH Mode
/* Purpose : This function determines the BS signal configuration in the CEST
/*           state. In the BOTH setting the BCCH is switched off as soon as
/*           CEST is reached so that all 8 timeslots are available for the
/*           traffic channel (see command CONFigure:BSSignal[:CSWitched]
/*           [:TCH][:SSLot]:TIMeslot on p 6.171).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssCchMode (ViSession instrSession,
                                                                       ViInt32   Mode,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrBcchMode[] = {"BATC","BOTC"};

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:BSS:CCH:MODE %s", StrBcchMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set Nb Control Channel BCCH
/* Purpose : This command determines the control channel for the CMU signals
/*           (BCCH).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssCchChan (ViSession instrSession,
                                                                       ViInt32   ControlChannelBCCH,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct RSCMU_SESSION_Globals  *p_globalvarSession;

  // Get the Globals.
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  // Which Current Fonction Group?
  if (strncmp ("\"GSM400MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ControlChannelBCCH, 259, 340, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM850MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ControlChannelBCCH, 128, 251, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    if ((RSCMU_invalidViInt32Range (ControlChannelBCCH, 0, 124)) && (RSCMU_invalidViInt32Range (ControlChannelBCCH, 955, 1023)))
      return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1800MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ControlChannelBCCH, 512, 885, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ControlChannelBCCH, 512, 810, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSMGT800MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, ControlChannelBCCH, 350, 425, RSCMU_ERROR_PARAMETER2, errorMessage);
  }


  sprintf (wrtBuf, "CONF:BSS:CCH:CHAN %d",ControlChannelBCCH);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Set Abs. Level of Ctrl Channel
/* Purpose : This function sets the level of the control channel in
/*           absolute units.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssCchLevAbs (ViSession instrSession,
                                                                        ViReal64  AbsLevel,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, AbsLevel, RSCMU_ABSLEVEL_MIN, RSCMU_ABSLEVEL_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:BSS:CCH:LEV %lf",AbsLevel);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*
 * ----------------------------------------------------------------------------
 *        Cell Broadcast
 * ----------------------------------------------------------------------------
 */

/*===========================================================================*/
/* Function: Cell Broadcast State
/* Purpose : This function enables or disables the transmission of cell
/*           broadcast messages on the C0 carrier.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssCchCbr (ViSession instrSession,
                                                                     ViBoolean  state,
                                                                     ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:BSS:CCH:CBR", state, mode_On_Off,
                       RSCMU_ERROR_PARAMETER2));
}


/*===========================================================================*/
/* Function: Repetition Interval
/* Purpose : This function defines the repetition interval for cell broadcast
/*           messages.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssCchCbrRep (ViSession instrSession,
                                                  ViInt32 selectInterval,
                                                  ViReal64 repetitionInterval,
                                                  ViChar _VI_FAR errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, selectInterval, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

    switch (selectInterval)
    {
      case RSCMU_BSS_CBROADCAST_OFF:
        CHECKRETMSG (RSCMU_sendCmd (instrSession, "CONF:BSS:CCH:CBR:REP OFF"));
        break;
      case RSCMU_BSS_CBROADCAST_VAL:
        CHECKRETMSG (RSCMU_setViReal64(instrSession, "CONF:BSS:CCH:CBR:REP",
                             repetitionInterval, 10.0, 60.0,
                             RSCMU_ERROR_PARAMETER3));
        break;
    }

    return RSCMU_Status;
}


/* ----------------------------------------------------------------------------
 *        CONTROL CHANNEL @ Aux-TX (CMU-B95 is required)
 * --------------------------------------------------------------------------*/

/*===========================================================================*/
/* Function: AuxTX Channel Type
/* Purpose : This function select the Channel type which is running on the additional
/*           RF generator or switches the Aux TX signal off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssAuxTxCchType (ViSession instrSession,
                                                     ViInt32   type,
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViString    list[] = {"OFF","BCCH", VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_40, RSCMU_ERROR_FW_VERSION_3_40));

  RETMSG(RSCMU_setEnum(instrSession, "CONFigure:BSSignal:CCH:AUXTx:CHTYpe", type, list,
                                     RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: AuxTX Channel Number
/* Purpose : This command determines the AuxTX channel number for the CMU signals.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssAuxTxCchChan (ViSession instrSession,
                                                     ViInt32   controlChannel,
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  struct RSCMU_SESSION_Globals  *p_globalvarSession;
  GET_WRT_BUF(instrSession);

  // Get the Globals.
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  // Version manager
  if (p_globalvarSession->RSCMU_FW_Version < RSCMU200_V3_40)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_40, errorMessage);

  // Check if the function is correctly used:
  // Which Current Fonction Group?
  if (strncmp ("\"GSM400MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, controlChannel, 259, 340, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM850MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, controlChannel, 128, 251, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    if ((RSCMU_invalidViInt32Range (controlChannel, 0, 124)) && (RSCMU_invalidViInt32Range (controlChannel, 955, 1023)))
      return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1800MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, controlChannel, 512, 885, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, controlChannel, 512, 810, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSMGT800MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, controlChannel, 350, 425, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  sprintf (wrtBuf, "CONFigure:BSSignal:CCH:AUXTx:CHANnel %d",controlChannel);
  RETMSG(RSCMU_sendCmd (instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: AuxTX Abs. Level
/* Purpose : This function sets the AuxTX level of the control channel in
/*           absolute units.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssAuxTxCchLevAbs (ViSession instrSession,
                                                       ViReal64  absLevel,
                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_40, RSCMU_ERROR_FW_VERSION_3_40));

  RETMSG(RSCMU_setViReal64(instrSession, "CONFigure:BSSignal:CCH:AUXTx:LEVel:ABSolute",
                         absLevel, -122.00, 9.00,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Conflict Check
/* Purpose : This function enables or disables the channel conflict check.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfCchBssAuxTxCcch (ViSession instrSession,
                                                     ViBoolean channelConflictCheck,
                                                     ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    RETMSG(RSCMU_setEnum (instrSession,
                          "CONF:BSS:CCH:AUXT:CCCH",
                          channelConflictCheck,
                          mode_On_Off,
                          RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: RF1,2 High Level Mode
/* Purpose : This function enables or disables the RF1/RF2 high level mode.
/*           It is effective with option R&S CMU-B96 only.
/*           The high level mode extends the output level ranges for the
/*           connectors RF1 and RF2.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssCchAuxTxHlm (ViSession instrSession,
                                                    ViBoolean state,
                                                    ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_10,RSCMU_ERROR_FW_VERSION_4_10));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:BSS:CCH:AUXT:HLM",
                         state, mode_On_Off,
                         RSCMU_ERROR_PARAMETER2));
}

/*
 * ----------------------------------------------------------------------------
 *        TRAFFIC CHANNEL
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Number of Traffic Channel
/* Purpose : After the call has been set up, this function sets the
/*           number (and thus the frequency) of the traffic channel for
/*           signals of the CMU.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssTchChan (ViSession instrSession,
                                                                      ViInt32   TrafficChannelNb,
                                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct RSCMU_SESSION_Globals  *p_globalvarSession;

  // Get the Globals
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  // Which Current Fonction Group?
  if (strncmp ("\"GSM400MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, TrafficChannelNb, 259, 340, RSCMU_ERROR_PARAMETER4, errorMessage);
  }
  else if (strncmp ("\"GSM850MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, TrafficChannelNb, 128, 251, RSCMU_ERROR_PARAMETER4, errorMessage);
  }
  else if (strncmp ("\"GSM900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    if ((RSCMU_invalidViInt32Range (TrafficChannelNb, 0, 124)) && (RSCMU_invalidViInt32Range (TrafficChannelNb, 955, 1023)))
      return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1800MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, TrafficChannelNb, 512, 885, RSCMU_ERROR_PARAMETER4, errorMessage);
  }
  else if (strncmp ("\"GSM1900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, TrafficChannelNb, 512, 810, RSCMU_ERROR_PARAMETER4, errorMessage);
  }

  sprintf (wrtBuf, "CONF:BSS:CHAN %d",TrafficChannelNb);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Set TimeslotNb in Traffic Chan
/* Purpose : This command determines the timeslot for the BS traffic channel.
/*           All GSM timeslots are available if the control channel mode is
/*           set to BOTC (see command CONFigure:BSSignal:CCH:MODE on p.
/*           6.170).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssTchTim (ViSession instrSession,
                                                                      ViInt32   TimeSlot,
                                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar    wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, TimeSlot, 0, 7, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:BSS:TCH:TIM %d", TimeSlot);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Level in the used timeslot
/* Purpose : This function sets the absolute level in the used
/*           timeslot. The permissible value range depends on the used
/*           RF output of the CMU and the external attenuation set.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssTchLevUtim (ViSession  instrSession,
                                                                         ViReal64   AbsLevelInUsedTS,
                                                                         ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used
//  CHECK_VI_REAL64_RANGE(instrSession, AbsLevelInUsedTS, RSCMU_USEDSLOTMIN, RSCMU_USEDSLOTMAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set absolute level in used timeslot
  sprintf (wrtBuf, "CONF:BSS:TCH:LEV:UTIM %lf", AbsLevelInUsedTS);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Level in the unused timeslots
/* Purpose : This function sets the relative level in the unused
/*           timeslots relative to the level in the used timeslot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssTchLevUnt (ViSession  instrSession,
                                                                        ViReal64   RelLevelInUnusedTS,
                                                                        ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
//  CHECK_VI_REAL64_RANGE(instrSession, RelLevelInUnusedTS, RSCMU_GSM_SIG_UNUSEDSLOTMIN, RSCMU_GSM_SIG_UNUSEDSLOTMAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set absolute level for Unused Slots
  sprintf (wrtBuf, "CONF:BSS:TCH:LEV:UNT %lf", RelLevelInUnusedTS);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Level in the used timeslot
/* Purpose : This function sets the absolute level in the used timeslot.
/*           The permissible value range depends on the used
/*           RF output of the CMU and the external attenuation set.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcBssTchLevUtim (ViSession  instrSession,
                                                                         ViReal64   AbsLevelInUsedTS,
                                                                         ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used
//  CHECK_VI_REAL64_RANGE(instrSession, AbsLevelInUsedTS, RSCMU_USEDSLOTMIN, RSCMU_USEDSLOTMAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set absolute level in used timeslot
  sprintf (wrtBuf, "PROC:BSS:TCH:LEV:UTIM %lf", AbsLevelInUsedTS);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Level in the unused timeslots
/* Purpose : This function sets the relative level in the unused
/*           timeslots relative to the level in the used timeslot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcBssTchLevUnt (ViSession  instrSession,
                                                                         ViReal64   RelLevelInUnusedTS,
                                                                         ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
//  CHECK_VI_REAL64_RANGE(instrSession, RelLevelInUnusedTS, RSCMU_GSM_SIG_UNUSEDSLOTMIN, RSCMU_GSM_SIG_UNUSEDSLOTMAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set absolute level for Unused Slots
  sprintf (wrtBuf, "PROC:BSS:TCH:LEV:UNT %lf", RelLevelInUnusedTS);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*
 * ----------------------------------------------------------------------------
 *        HOPPING SEQUENCE
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Hopping Sequence
/* Purpose : This function selects a Hopping Sequence for the CMU
/*           signals or switches off frequency hopping.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcBssTchFhopSeq (ViSession instrSession,
                                                                          ViInt32   hoppingSequence,
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    hoping_Seq[] = {"OFF","A","B","C","D"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, hoppingSequence, RSCMU_HOPPING_SEQ_OFF, RSCMU_HOPPING_SEQ_D, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Change the Hopping Session
  sprintf(wrtBuf, "PROC:BSS:FHOP:SEQ %s",hoping_Seq[hoppingSequence]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Edit Hopping Sequence
/* Purpose : This function defines hopping sequences that supersede the four
/*           GSM standard hopping sequences A to D
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssTchFhopChan (ViSession instrSession,
                                                                           ViInt32   hoppingSequence,
                                                                           ViChar    channels[],
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      *StrChan;
  ViChar      *DataValue;
  ViInt32     iChannel;
  ViUInt32     i;
  ViString    hoping_Seq[] = {"","A","B","C","D"};
  struct      RSCMU_SESSION_Globals  *p_globalvarSession;

  // Get the Globals
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, hoppingSequence, RSCMU_HOPPING_SEQ_A, RSCMU_HOPPING_SEQ_D, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Translates characters to uppercase:
  for (i=0; i<strlen (channels); i++)
    channels[i] = toupper(channels[i]);

//27.03.03 BL StrChan = (char *) malloc(sizeof(channels));
  StrChan = (char *) malloc(sizeof(char)*strlen(channels)+1);
  strcpy(StrChan, channels);
  DataValue = strtok (channels, ",");

  if (strncmp ("\"GSM400MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    while (DataValue)
    {
      //Compares each channel with the GSM400 channel range
      if(!strstr((DataValue), "OFF"))
      {
        iChannel = atoi(DataValue);
        if((iChannel < 259) || (iChannel > 340))
        {
          free(StrChan);
          return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_CHANNEL_NUMBER, errorMessage);
        }
      }
      DataValue = strtok (NULL, ",");
    }
  }
  else if (strncmp ("\"GSM850MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    while (DataValue)
    {
      //Compares each channel with the GSM850 channel range
      if(!strstr((DataValue), "OFF"))
      {
        iChannel = atoi(DataValue);
        if((iChannel < 128) || (iChannel > 251))
        {
          free(StrChan);
          return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_CHANNEL_NUMBER, errorMessage);
        }
      }
      DataValue = strtok (NULL, ",");
    }
  }
  // Which Current Fonction Group?
  else if (strncmp ("\"GSM900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    while (DataValue)
    {
      //Compares each channel with the GSM900 channel range
      if(!strstr((DataValue), "OFF"))
      {
        iChannel = atoi(DataValue);
        if(((iChannel > 124) && (iChannel < 955)) || (iChannel > 1024))
        {
          free (StrChan);
          return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_CHANNEL_NUMBER, errorMessage);
        }
      }
      DataValue = strtok (NULL, ",");
    }
  }

  else if (strncmp ("\"GSM1800MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    while (DataValue)
    {
      //Compares each channel with the GSM1800 channel range
      if(!strstr((DataValue), "OFF"))
      {
        iChannel = atoi(DataValue);
        if((iChannel < 512) || (iChannel > 885))
        {
          free(StrChan);
          return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_CHANNEL_NUMBER, errorMessage);
        }
      }
      DataValue = strtok (NULL, ",");
    }
  }

  else if (strncmp ("\"GSM1900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    while (DataValue)
    {
      //Compares each channel with the GSM1900 channel range
      if(!strstr((DataValue), "OFF"))
      {
        iChannel = atoi(DataValue);
        if((iChannel < 512) || (iChannel > 810))
        {
          free(StrChan);
          return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_CHANNEL_NUMBER, errorMessage);
        }
      }
      DataValue = strtok (NULL, ",");
    }
  }

  // Configue the Hopping Sequence
  sprintf(wrtBuf, "CONF:BSS:FHOP:%s %s",hoping_Seq[hoppingSequence], StrChan);
  free(StrChan);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/* ----------------------------------------------------------------------------
 *        TIMING ADVANCE
 * ----------------------------------------------------------------------------
 */

/*===========================================================================*/
/* Function: Handset DTX Enable
/* Purpose : This function enables or disables the DTX mode, e.g. for BFI
/*           measurements. DTX is enabled automatically while a BFI test is
/*           active
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssDtx (ViSession instrSession,
                                            ViBoolean DTXEnable,
                                            ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:BSS:DTX",
                         DTXEnable, mode_On_Off,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Signal Type
/* Purpose : This function controls the type of filling signal to be used in
/*           SID frames of BFI/DTX measurements.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssFstype (ViSession instrSession,
                                               ViInt32 fillingSignalType,
                                               ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:BSS:FSTY",
                         fillingSignalType, fillingSigTypeArr,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Signal Level
/* Purpose : This function sets the level of the filling signal (SID frames)
/ *          in DTX and BFI measurements relative to the traffic channel
/*           unused timeslot level defined for the receiver quality BER and
/*           BER Average measurements
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssFsl (ViSession instrSession,
                                            ViReal64 fillingSignalLevel,
                                            ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setViReal64(instrSession, "CONF:BSS:FSL",
                            fillingSignalLevel, -20.0, 0.0,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Configure Timing Advance
/* Purpose : This function configures the traffic channel before
             it is switched on.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssTimAdv (ViSession instrSession,
                                                                      ViInt32   Bit,
                                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct RSCMU_SESSION_Globals  *p_globalvarSession;

  // Get the Globals
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  // Which Current Fonction Group?
  if (strncmp ("\"GSM400MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, Bit, 0, 219, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else CHECK_VI_INT32_RANGE(instrSession, Bit, 0, 63, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf, "CONF:BSS:TIM:ADV %d", Bit);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Procedure Timing Advance
/* Purpose : This function changes the timing advance setting of
             the current call.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcBssTimAdv (ViSession instrSession,
                                                                      ViInt32   Bit,
                                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Bit, 0, 63, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf, "PROC:BSS:TIM:ADV %d",Bit);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*
 * ----------------------------------------------------------------------------
 *  MULTISLOT
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Conf. Reference Level
/* Purpose : This function defines the reference value for the individual
/*           downlink (BS) signal levels. See command PROCedure:SIGNalling
/*           [:CSWitched][:TCH]:MSLot:BS:SCONfig:INDividual on p. 6.167. See
/*           also note on Current vs. default values on p. 6.161.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssMslRlev (ViSession instrSession,
                                                                       ViReal64  RefLevel,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, RefLevel, -137, 13, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf,"CONF:BSS:MSL:RLEV %lf", RefLevel);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Proc. Reference Level
/* Purpose : This function defines the reference value for the individual
/*           downlink (BS) signal levels. See command PROCedure:SIGNalling
/*           [:CSWitched][:TCH]:MSLot:BS:SCONfig:INDividual on p. 6.167. See
/*           also note on Current vs. default values on p. 6.161.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcBssMslRlev (ViSession instrSession,
                                                                       ViReal64  RefLevel,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, RefLevel, -137, 13, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf,"PROC:BSS:MSL:RLEV %lf", RefLevel);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Main Timeslot
/* Purpose : This function defines the timeslot that the MS and the BS/CMU
.*           use for signalling (default value).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssMslMtim (ViSession instrSession,
                                                                       ViInt32   MainTimeSlot,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, MainTimeSlot, 0, 7, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:BSS:MSL:MTIM %d", MainTimeSlot);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*
 * ----------------------------------------------------------------------------
 *    RADIO NETWORK
 *    The subsystem NETWork determines the parameters of the radio
 *    network and the existing radio link.
 * ----------------------------------------------------------------------------
 *      BA LIST
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set BA List
/* Purpose : This function generates the list of used channels in the
/*           adjacent cells (BA list,BCCH allocation list).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwBal (ViSession instrSession,
                                                                    ViChar    ChannelNbs[],
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      Buffer[100] = "", wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  strcpy (Buffer,ChannelNbs);
  sprintf(wrtBuf, "CONF:NETW:BAL %s",Buffer);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Set BA List
/* Purpose : This function switches on or off data for advice of charge and gets
/*           values 1 to 7 for calculating the charges.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwAOC  (ViSession instrSession,
                                                                     ViInt32   Enable,
                                                                     ViInt32   Value1,
                                                                     ViInt32   Value2,
                                                                     ViInt32   Value3,
                                                                     ViInt32   Value4,
                                                                     ViInt32   Value5,
                                                                     ViInt32   Value6,
                                                                     ViInt32   Value7,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) Enable, RSCMU_ERROR_PARAMETER2, errorMessage);

  //sprintf (wrtBuf, "CONF:NETW:AOC:ENAB %s", StrEnable[Enable]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, "CONF:NETW:AOC:ENAB ON", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  switch (Enable)
    {
    case RSCMU_ON:
  sprintf (wrtBuf, "CONF:NETW:AOC %lf,%lf,%lf,%lf,%lf,%lf,%lf", Value1,Value2,Value3,Value4,Value5,Value6,Value7);
    break;

    case RSCMU_OFF:
    break;
    }
    if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;
  return RSCMU_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      MOBILE DATA REQUESTS
 *      This subsystem determines the signalling parameters of the
 *      mobile to be requested. It corresponds to the table field
 *      'Requested Mobile Data' in the Popup menu 'network'.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set IMSI Request
/* Purpose : This Function sets whether the international mobile
/*           subscriber identity of the connected mobile phone is
/*           requested.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwReqImsi (ViSession instrSession,
                                                                        ViInt32   IMSIRequest,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) IMSIRequest, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:REQ:IMSI %s", mode_On_Off[IMSIRequest]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Set IMEI Request
/* Purpose : This Function sets whether the international mobile station
/*           equipment (IMEI) of the connected mobile phone is requested
/*
/*
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwReqImei (ViSession instrSession,
                                                                        ViInt32   IMEIRequest,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar    wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) IMEIRequest, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:REQ:IMEI %s", mode_On_Off[IMEIRequest]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Set Authentification Request
/* Purpose : This function determines whether an authentication request
/*           of the connected mobile is made.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwReqAuth (ViSession instrSession,
                                                                        ViInt32   authentificationRequest,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) authentificationRequest, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:REQ:AUTH %s", mode_On_Off[authentificationRequest]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Set HandOver Request
/* Purpose : This function determines whether the capability to perform
/*           handover is requested on the connected mobile.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwReqHand (ViSession instrSession,
                                                                        ViInt32   handOverRequest,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) handOverRequest, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:REQ:HAND %s", mode_On_Off[handOverRequest]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*
 * ----------------------------------------------------------------------------
 *      MOBILE SETTINGS
 *      This subsystem defines the mobile parameters.It corresponds to
 *      the table field 'Mobile Settings' in the popup menu 'Network'.
 * ----------------------------------------------------------------------------
 */


/*===========================================================================*/
/* Function: Classmark 3 request
/* Purpose : This function determines whether the classmark 3 element is
/*           requested during location update, call to mobile, call from mobile,
/*           or SMS transfer.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwReqCthree (ViSession instrSession,
                                                   ViBoolean classmark3Request,
                                                   ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    RETMSG(RSCMU_setViString(instrSession, "CONF:NETW:REQ:CTHR",
                            mode_On_Off[classmark3Request],
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Set DTX Request
/* Purpose : This Function permits the mobile to switch on or off DTX
/*           mode (discontinuous transmission mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwDtx (ViSession  instrSession,
                                                                    ViInt32    DTXMode,
                                                                    ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) DTXMode, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:DTX %s", mode_On_Off[DTXMode]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Set Mobile Power level
/* Purpose : This function defines the mobile power level upon
/*           registration in the network.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPow (ViSession instrSession,
                                                                    ViInt32   MobilePhonePCL,
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar    wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct RSCMU_SESSION_Globals  *p_globalvarSession;

  // Get the Session's Globals
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  // Which Current Fonction Group?
  if (strncmp ("\"GSM400MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 19, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM850MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 19, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 19, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1800MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 31, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobilePhonePCL, 0, 31, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  sprintf (wrtBuf, "CONF:NETW:MS:POW %d", MobilePhonePCL);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*
 * ----------------------------------------------------------------------------
 *      SIGNALLING MODES
 *      This subsystem defines the signalling parameters refering to the
 *      functionof the mobile.It corresponds to the table field
 *      'Signalling Modes' in the popup menu 'Network'.
 * ----------------------------------------------------------------------------
 */

/*===========================================================================*/
/* Function: Set Network Identity (IMSI)
/* Purpose : This function defines an international mobile subscriber
/*           identity (IMSI) which serves as the default setting for a
/*           call to the mobile. It consists of the mobile country code
/*           (MCC), mobile network code (MNC) and the mobile
/*           subscriber identification no. (MSIN).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodImsi (ViSession  instrSession,
                                                                         ViInt32    MobileCountryCode,
                                                                         ViInt32    MobileNetworkCode,
                                                                         ViChar     MobileSubscriberIdNumber[],
                                                                         ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  struct RSCMU_SESSION_Globals  *p_globalvarSession;

  // Get the Globals
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, MobileCountryCode, 0, 999, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Which Current Fonction Group?
  if (strncmp ("\"GSM400MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobileNetworkCode, 0, 99, RSCMU_ERROR_PARAMETER3, errorMessage);
  }
  else if (strncmp ("\"GSM850MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobileNetworkCode, 0, 999, RSCMU_ERROR_PARAMETER3, errorMessage);
  }
  else if (strncmp ("\"GSM900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobileNetworkCode, 0, 99, RSCMU_ERROR_PARAMETER3, errorMessage);
  }
  else if (strncmp ("\"GSM1800MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobileNetworkCode, 0, 99, RSCMU_ERROR_PARAMETER3, errorMessage);
  }
  else if (strncmp ("\"GSM1900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, MobileNetworkCode, 0, 999, RSCMU_ERROR_PARAMETER3, errorMessage);
  }

  if (strlen (MobileSubscriberIdNumber) > strlen (RSCMU_MSIN_MAX))
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure IMSI
  sprintf (wrtBuf, "CONF:NETW:SMOD:IMSI:MCC %d", MobileCountryCode);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  sprintf (wrtBuf, "CONF:NETW:SMOD:IMSI:MNC %d", MobileNetworkCode);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  sprintf (wrtBuf, "CONF:NETW:SMOD:IMSI:MSIN \"%s\"", MobileSubscriberIdNumber);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Caller ID
/* Purpose : This function sets a 1 to 20-digit caller ID, to be displayed at
/*           the mobile under test.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodCid (ViSession instrSession,
                                                 ViChar CID[],
                                                 ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      buffer [WR_BUFFER_SIZE]="";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_10,RSCMU_ERROR_FW_VERSION_4_10));

    sprintf (buffer,"'%s'",CID);
    RETMSG(RSCMU_setViString(instrSession, "CONF:NETW:SMOD:CID",
                             buffer, 
                             RSCMU_ERROR_PARAMETER2));

}

/*===========================================================================*/
/* Function: Set Speed of Power Change
/* Purpose : This function determines the speed of power control on the
/*           mobile phone.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodPch (ViSession instrSession,
                                                                        ViInt32   SpeedPowerChange,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    mode_ChgPui[] = {"SLOW","FAST","EPC"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, SpeedPowerChange, 0,2,RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:SMOD:PCH %s", mode_ChgPui[SpeedPowerChange]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: EPC Uplink Power Control
/* Purpose : This function determines the uplink power control channel to be
/*           used.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodEupc (ViSession instrSession,
                                                  ViInt32 EPCUplinkPowerControl,
                                                  ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:NETW:SMOD:EUPC",
                         EPCUplinkPowerControl, epcUplinkContArr,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Set the Signalling Channel
/* Purpose : This function determines the signalling channel.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodSch (ViSession instrSession,
                                                                        ViInt32   signallingChannel,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    signCh[] = {"NONE","SDCCH","FACCH"};
  struct            RSCMU_GSM_Sig_Globals *p_globalvarGSM;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarGSM)) < 0)
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, signallingChannel, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:SMOD:SCH %s", signCh[signallingChannel]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  p_globalvarGSM->RSCMU_SigChannelConf = signallingChannel;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set SpeechCoding in TrafChannel
/* Purpose : This function determines the speech coding and voice transmission
/*           in the traffic channels (full-rate channel, half-rate channel,
/*           packet data channel etc.).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcNetwSmodTraf (ViSession instrSession,
                                                  ViInt32 speechCoding,
                                                  ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViString    mode_Traffic[] = {"FRV1", "FRV2", "HRV1", "FD24", "FD48", "FD96", "HD24", "HD48", "FD14",
                                "C1TM", "C2TM", "C3TM", "C4TM",
                                "MC1T", "MC2T", "MC3T", "MC4T", "MC5T", "MC6T", "MC7T", "MC8T", "MC9T",
                                "AMRF", "AMRH", "ANH8", "AWFG","AWF8","AWH8", VI_NULL};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  // Version Manager
  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15)
  {
    CHECK_VI_INT32_RANGE(instrSession, speechCoding, 0, 7, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if ( (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V2_15) &&
            (p_globalvarBase->RSCMU_FW_Version <= RSCMU200_V2_16))
  {
    CHECK_VI_INT32_RANGE(instrSession, speechCoding, 0, 9, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if ((p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V2_17) &&
           (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_20))
  {
    CHECK_VI_INT32_RANGE(instrSession, speechCoding, 0, 21, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if ((p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V3_20) &&
           (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V4_00))
  {
    CHECK_VI_INT32_RANGE(instrSession, speechCoding, 0, 23, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if ((p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V4_20) &&
           (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V4_23))
  {
    CHECK_VI_INT32_RANGE(instrSession, speechCoding, 0, 24, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else
  {
    CHECK_VI_INT32_RANGE(instrSession, speechCoding, 0, 27, RSCMU_ERROR_PARAMETER2, errorMessage);
  }

  RETMSG(RSCMU_setEnum(instrSession, "PROC:NETW:SMOD:TRAF",
                            speechCoding,
                            mode_Traffic,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Half Rate Subchannel
/* Purpose : This function selects the subchannel to be used if half rate
/*           speech coding is used.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcNetwSmodTrafHrs (ViSession instrSession,
                                                     ViInt32 halfRateSubchannel,
                                                     ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    RETMSG(RSCMU_setEnum(instrSession, "PROC:NETW:SMOD:TRAF:HRS",
                            halfRateSubchannel,
                            subchannelArr,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Set SpeechCoding in TrafChannel
/* Purpose : This function determines the speech coding and voice
/*           transmission in the traffic channels (full-rate channel,
/*           half-rate channel, full-rate channel with variable
/*           transmission rate).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodTraf (ViSession instrSession,
                                                  ViInt32   speechCoding,
                                                  ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE];
  ViString    mode_Traffic[] = {"FRV1", "FRV2", "HRV1", "FD24", "FD48", "FD96", "HD24", "HD48", "FD14",
                                "C1TM", "C2TM", "C3TM", "C4TM",
                                "MC1T", "MC2T", "MC3T", "MC4T", "MC5T", "MC6T", "MC7T", "MC8T", "MC9T",
                                "AMRF", "AMRH", "ANH8", "AWFG", "AWF8", "AWH8", VI_NULL};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  // Version Manager
  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15)
  {
    CHECK_VI_INT32_RANGE(instrSession, speechCoding, 0, 7, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if ( (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V2_15) &&
            (p_globalvarBase->RSCMU_FW_Version <= RSCMU200_V2_16))
  {
    CHECK_VI_INT32_RANGE(instrSession, speechCoding, 0, 9, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if ((p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V2_17) &&
           (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_20))
  {
    CHECK_VI_INT32_RANGE(instrSession, speechCoding, 0, 21, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if ((p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V3_20) &&
           (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V4_20))
  {
    CHECK_VI_INT32_RANGE(instrSession, speechCoding, 0, 23, RSCMU_ERROR_PARAMETER2, errorMessage);
  }

  else if ((p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V4_20) &&
           (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V4_23))
  {
    CHECK_VI_INT32_RANGE(instrSession, speechCoding, 0, 24, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else
  {
    CHECK_VI_INT32_RANGE(instrSession, speechCoding, 0, 27, RSCMU_ERROR_PARAMETER2, errorMessage);
  }

  sprintf (wrtBuf, "CONFigure:NETWork:SMODe:TRAFfic %s", mode_Traffic[speechCoding]);
  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));

}

/*===========================================================================*/
/* Function: Half Rate Subchannel
/* Purpose : This function selects the subchannel to be used if half rate
/*           speech coding is used.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodTrafHrs (ViSession instrSession,
                                                     ViInt32 halfRateSubchannel,
                                                     ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    RETMSG(RSCMU_setEnum(instrSession, "CONF:NETW:SMOD:TRAF:HRS",
                            halfRateSubchannel,
                            subchannelArr,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Conf. Bit Stream
/* Purpose : This function determines the type of data transmitted in the
/*           traffic channel. For BER measurements, one of the pseudo random
/*           sequences (PSR) must be used. See note on Current vs. default
/*           values on p. 6.161.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodBits (ViSession instrSession,
                                                                         ViInt32   bitStream,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrBitStream[] = {"ECHO","LOOP","PR9","PR11","PR15","PR16","HAND","HLOW","CCAL","ECAL",
                                "DCAL","FA0","FA1","FA01","LC9","LC11","LC15","LC16"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  CHECK_VI_INT32_RANGE(instrSession, bitStream, 0, 17, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:SMOD:BITS %s", StrBitStream[bitStream]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Proc. Bit Stream
/* Purpose : This function determines the type of data transmitted in the
/*           traffic channel. For BER measurements, one of the pseudo random
/*           sequences (PSR) must be used. See note on Current vs. default
/*           values on p. 6.161.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcNetwSmodBits (ViSession instrSession,
                                                                         ViInt32   bitStream,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrBitStream[] = {"ECHO","LOOP","PR9","PR11","PR15","PR16","HAND","HLOW","CCAL","ECAL",
                                "DCAL","FA0","FA1","FA01","LC9","LC11","LC15","LC16"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  CHECK_VI_INT32_RANGE(instrSession, bitStream, 0, 17, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "PROC:NETW:SMOD:BITS %s", StrBitStream[bitStream]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Proc. Repeated UL SACCH
/* Purpose : This function requests the repeated sending of the last UL SACCH
/*           block.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcRusAct (ViSession instrSession,
                                            ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_sendCmd(instrSession, "PROC:RUS:ACT"));
}

/*===========================================================================*/
/* Function: BLER Permanent Polling
/* Purpose : This function switches permanent polling during a BLER
/*           measurement on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatBpp (ViSession instrSession,
                                                 ViBoolean state,
                                                 ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_10,RSCMU_ERROR_FW_VERSION_4_10));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:NETW:PDAT:BPP",
                         state, mode_On_Off,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Set LoopCommand
/* Purpose : This function determines in which cases the open/close loop
/*           command is sent to the mobile. Closing of the loop causes
/*           the mobile to send back the bits received.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodLcom (ViSession instrSession,
                                                                         ViInt32   loopCommand,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    loopCMU[] = {"BER", "ENAB", "DIS"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, loopCommand, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:SMOD:LCOM %s", loopCMU[loopCommand]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Set Starting Time
/* Purpose : The starting time is used with channel, timeslot and fast
/*           power change. The value 0 means that no start time is used.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodStim (ViSession  instrSession,
                                                                        ViInt32    StartingTime,
                                                                        ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StartingTime, 0, 600, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Configure the starting time (frames transferred)
  sprintf (wrtBuf, "CONF:NETW:SMOD:STIM %d", StartingTime);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: TBF Starting Time
/* Purpose : This function defines the TBF Starting Time for the channel
/*           change.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwTstime (ViSession instrSession,
                                                ViInt32 startingTime,
                                                ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setViInt32(instrSession, "CONF:NETW:PDAT:TST",
                            startingTime, 0, 8191,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Band Indicator on PBCCH
/* Purpose : This function enables the sending of a PBCCH system information
/*           message to the mobile on the PACCH channel, although a PBCCH is
/*           not active. This happens when the parameter is set to ON,
/*           and the band indicator setting is changed during a packet data
/*           connection.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatBpib (ViSession instrSession,
                                                  ViBoolean state,
                                                  ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_50,RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:NETW:PDAT:BIPB",
                         state, mode_On_Off,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Procedure Mode
/* Purpose : This function defines the Procedure Mode, that is if changes are 
/*           invoked in reliable (slower mode) or fast mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatPmode (ViSession instrSession,
                                                   ViInt32 procedureMode,
                                                   ViChar _VI_FAR errorMessage[])

{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:NETW:PDAT:PMOD", procedureMode,
                    netwProcModeArr, RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Traffic Mode After Handover
/* Purpose : This function defines which Traffic Mode is used after GSM dual
/*           band handover, either from the source network or the destination
/*           network.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodTrafHand
             (ViSession instrSession, ViInt32 trafficModeHandover,
              ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_50,RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:NETW:SMOD:TRAF:HAND",
                         trafficModeHandover, netwTrafModeHandArr,
                         RSCMU_ERROR_PARAMETER2));
}
 
/*===========================================================================*/
/* Function: Set Location Update
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodLoc (ViSession  instrSession,
                                                                        ViInt32    locationUpdate,
                                                                        ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    Str[] = {"ALW","AUTO"};

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) locationUpdate, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:SMOD:LOC %s", Str[locationUpdate]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Level Mode
/* Purpose : This function determines whether the CMU uses the used/unused
/*           timeslot level scheme (two different levels) or individual
/*           levels in all timeslots.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssMslLmod (ViSession instrSession,
                                                                       ViInt32   mode,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrLevelMode[] = {"UUN","IND"};

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, mode, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:BSS:MSL:LMOD %s", StrLevelMode[mode]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Slot Configuration: Used/Unused
/* Purpose : This function determines whether the CMU uses the used/unused
/*           timeslot level scheme (two different levels) or individual
/*           levels in all timeslots.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssMslSconfUun (ViSession instrSession,
                                                                           ViInt32   TS0Enable,
                                                                           ViInt32   TS1Enable,
                                                                           ViInt32   TS2Enable,
                                                                           ViInt32   TS3Enable,
                                                                           ViInt32   TS4Enable,
                                                                           ViInt32   TS5Enable,
                                                                           ViInt32   TS6Enable,
                                                                           ViInt32   TS7Enable,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS0Enable, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS1Enable, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS2Enable, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS3Enable, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS4Enable, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS5Enable, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS6Enable, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS7Enable, RSCMU_ERROR_PARAMETER9, errorMessage);

  sprintf (wrtBuf, "CONF:BSS:MSL:SCON:UUN %s,%s,%s,%s,%s,%s,%s,%s", mode_On_Off[TS0Enable]
                                                                  , mode_On_Off[TS1Enable]
                                                                  , mode_On_Off[TS2Enable]
                                                                  , mode_On_Off[TS3Enable]
                                                                  , mode_On_Off[TS4Enable]
                                                                  , mode_On_Off[TS5Enable]
                                                                  , mode_On_Off[TS6Enable]
                                                                  , mode_On_Off[TS7Enable]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Slot Configuration : Individual
/* Purpose : This function defines the active timeslots slots of the BS
/*           signal (default values) and the levels for the Individual level
/*           mode (see command CONFigure:BSSignal[:CSWitched][:TCH]:MSLot:
/*           LMODe on p. 6.173). All 8 timeslots can be enabled and their
/*           levels can be set individually. They are defined relative to the
/*           Reference Level set via CONFigure:BSSignal[:CSWitched][:TCH]:
/*           MSLot:RLEVel (see p. 6.173). The level range quoted above is
/*           restricted by the condition that the absolute level (calculated
/*           from the reference level and the relative individual levels)
/*           must not exceed the level ranges of the RF connectors.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssMslSconfInd (ViSession instrSession,
                                                                           ViInt32   TS0Enable,
                                                                           ViReal64  TS0Level,
                                                                           ViInt32   TS1Enable,
                                                                           ViReal64  TS1Level,
                                                                           ViInt32   TS2Enable,
                                                                           ViReal64  TS2Level,
                                                                           ViInt32   TS3Enable,
                                                                           ViReal64  TS3Level,
                                                                           ViInt32   TS4Enable,
                                                                           ViReal64  TS4Level,
                                                                           ViInt32   TS5Enable,
                                                                           ViReal64  TS5Level,
                                                                           ViInt32   TS6Enable,
                                                                           ViReal64  TS6Level,
                                                                           ViInt32   TS7Enable,
                                                                           ViReal64  TS7Level,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS0Enable, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS0Level, -127, 127, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS1Enable, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS1Level, -127, 127, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS2Enable, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS2Level, -127, 127, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS3Enable, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS3Level, -127, 127, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS4Enable, RSCMU_ERROR_PARAMETER10, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS4Level, -127, 127, RSCMU_ERROR_PARAMETER11, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS5Enable, RSCMU_ERROR_PARAMETER12, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS5Level, -127, 127, RSCMU_ERROR_PARAMETER13, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS6Enable, RSCMU_ERROR_PARAMETER14, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS6Level, -127, 127, RSCMU_ERROR_PARAMETER15, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS7Enable, RSCMU_ERROR_PARAMETER16, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS7Level, -127, 127, RSCMU_ERROR_PARAMETER17, errorMessage);

  sprintf (wrtBuf, "CONF:BSS:MSL:SCON:IND %s,%s,%s,%s,%s,%s,%s,%s,%lf,%lf,%lf,%lf,%lf,%lf,%lf,%lf", mode_On_Off[TS0Enable]
                                                                                                  , mode_On_Off[TS1Enable]
                                                                                                  , mode_On_Off[TS2Enable]
                                                                                                  , mode_On_Off[TS3Enable]
                                                                                                  , mode_On_Off[TS4Enable]
                                                                                                  , mode_On_Off[TS5Enable]
                                                                                                  , mode_On_Off[TS6Enable]
                                                                                                  , mode_On_Off[TS7Enable]
                                                                                                  , TS0Level
                                                                                                  , TS1Level
                                                                                                  , TS2Level
                                                                                                  , TS3Level
                                                                                                  , TS4Level
                                                                                                  , TS5Level
                                                                                                  , TS6Level
                                                                                                  , TS7Level);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Timing Drift Period
/* Purpose : This function defines the timing drift period, which specifies
/*           after how many frames the timing drift is repeatedly inserted.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssDrifPer (ViSession instrSession,
                                                ViInt32 timingDriftPeriod,
                                                ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setViInt32(instrSession, "CONF:BSS:DRIF:PER",
                            timingDriftPeriod, 1, 2715647,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Step Size
/* Purpose : This function controls the direction of the timing drift by
/*           defining whether a quarter symbol is added (+) or removed ()
/*           during the guard periods of unused time slots after every drift
/*           period.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssDrifSsiz (ViSession instrSession,
                                                 ViInt32 step_size,
                                                 ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:BSS:DTX",
                         step_size, driftStepSizeArr,
                         RSCMU_ERROR_PARAMETER2));
}

/*
 * ----------------------------------------------------------------------------
 *      MOBILE IDENTITY
 *      This subsystem defines the identity for the mobile radio
 *      network.It corresponds to the table field 'Network identity' in
 *      the popup menu 'Network'.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Network Color Code (NCC)
/* Purpose : This function defines the color code of the network
/*           (NCC = network color) for the signals of the measuring
/*           instrument.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwIdenNcc (ViSession  instrSession,
                                                                       ViInt32    NetworkColorCode,
                                                                       ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NetworkColorCode, RSCMU_NCC_MIN, RSCMU_NCC_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:IDEN:NCC %d", NetworkColorCode);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Set Mobile Country Code (MCC)
/* Purpose : This function defines the mobile country code.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwIdenMcc (ViSession  instrSession,
                                                                       ViInt32    MobileCountryCode,
                                                                       ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, MobileCountryCode, RSCMU_MCC_MIN, RSCMU_MCC_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:IDEN:MCC %d", MobileCountryCode);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Set Mobile Network Code (MNC)
/* Purpose : This function defines the mobile network code for the signals
/*           of the measuring instrument.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwIdenMnc (ViSession  instrSession,
                                                                       ViInt32    MobileNetworkCode,
                                                                       ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, MobileNetworkCode, RSCMU_MNC_MIN, RSCMU_MNC_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:IDEN:MNC %d", MobileNetworkCode);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set Mobile Network Code (MNC)
/* Purpose : This function defines the digits of the Mobile Network Code.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwIdenMncDig (ViSession instrSession,
                                                    ViInt32 mobileNetworkCode_MNC_Digit,
                                                    ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;
    ViString    mobDigArr[] = {"TWO", "THREE", VI_NULL};

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    CHECK_VI_INT32_RANGE(instrSession, mobileNetworkCode_MNC_Digit, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

    RETMSG(RSCMU_setViString(instrSession, "CONF:NETW:IDEN:MNC:DIG",
                            mobDigArr[mobileNetworkCode_MNC_Digit],
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Set BTS Color Code (BCC)
/* Purpose : This function  defines the color code of the BTS (base
/*           transceiver station color code, BTS color code = BCC).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwIdenBcc (ViSession  instrSession,
                                                                       ViInt32    BTSColorCode,
                                                                       ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, BTSColorCode, RSCMU_BCC_MIN, RSCMU_BCC_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:IDEN:BCC %d", BTSColorCode);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Set Location Area Code (LAC)
/* Purpose : This function defines the location area code.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwIdenLac (ViSession  instrSession,
                                                                       ViInt32    LocationAreaCode,
                                                                       ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, LocationAreaCode, RSCMU_LAC_MIN, RSCMU_LAC_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  // ... exception:
  if (LocationAreaCode == 65534)
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:IDEN:LAC %d", LocationAreaCode);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      SYSTEM PARAPETERS
 *      This subsystem defines systems parameters for the radio
 *      connection.It corresponds to the table field 'System parameters'
 *      in the popup menu 'Network'.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Access to Radio Cells
/* Purpose : This function enables or disables the radio cell for
/*             mobiles.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSystCacc (ViSession instrSession,
                                                                        ViInt32   radioCellsAccess,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    accessMode[] = {"BARR","NBAR"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, radioCellsAccess, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:SYST:CACC %s", accessMode[radioCellsAccess]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: EPC RX Quality
/* Purpose : This function outputs the received EPC signal quality that the
/*           mobile reports to the CMU, expressed in dimensionless quality
/*           levels
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepRepc (ViSession instrSession,
                                              ViInt32 *EPCRXQuality,
                                              ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_getViInt32(instrSession, "RREP:REPC?",
                            EPCRXQuality,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Set Reserved Blocks Number
/* Purpose : This function sets the number of data blocks to be reserved
/*           for the granted access (access grant channel = AGC) within
/*           the BCCH (basic services access grant blocks reserved).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSystBsag (ViSession instrSession,
                                                                        ViInt32   BlocksNumberforBCCH,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, BlocksNumberforBCCH, 0, RSCMU_NBBLCKSRES_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:SYST:BSAG %d", BlocksNumberforBCCH);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Set Paging Request interval
/* Purpose : This function sets the interval between two paging requests
/*           in a multiframe in frames (basic services paging blocks
/*           available per multiframe).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSystBsp (ViSession instrSession,
                                                                       ViInt32   PagingReqInterval,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, PagingReqInterval, RSCMU_PAGINGREQINT_MIN, RSCMU_PAGINGREQINT_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:SYST:BSP %d", PagingReqInterval);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set Paging Reorganization parameter
/* Purpose : This function switches the paging reorganization parameter
/*           on and off. In the OFF state, the mobile is prevented from
/*           switching to the idle mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSystBspr (ViSession instrSession,
                                                                         ViInt32   Frames,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrPagingReorg[]={"OFF","ON"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Frames,0,1,RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:SYST:BSPR %s",StrPagingReorg[Frames]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Access Class
/* Purpose : This function prevents mobile stations of definite access
/*           classes from making access attempts when the CMU starts
/*           transmitting its BCCH channel. The 16 bit value is written to
/*           the RACH Control Parameter information element and broadcast to
/*           the MS. Each true bit (no. 0 to 15, starting with the least
/*           significant bit) means that the corresponding access class is
/*           barred. Barring the network access is useful to establish an
/*           off-air connection to a mobile station with a particular access
/*           class while preventing other mobiles from making access
/*           attempts. The feature is not available in manual control. The
/*           default value (no access class barred) is restored each time the
/*           CMU is rebooted.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSystAcl (ViSession instrSession,
                                                                        ViInt32   Class,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      Bits[16];
  ViInt32     Index;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Class, 0, 65535, RSCMU_ERROR_PARAMETER2, errorMessage);

  for(Index = 0; Index < 16; Index++, Class >>=1)
    if(Class & 1) Bits[Index] = '1';
    else Bits[Index] = '0';

  sprintf (wrtBuf, "CONF:NETW:SYST:ACL %s", Bits);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}


/*===========================================================================*/
/* Function: DL/UL Swap
/* Purpose : This function is only useful for specially equipped MS. The
/*           setting of the DL/UL Swap parameter to ON with a normal MS will
/*           cause measurement problems. If the MS is not equipped with a
/*           specially suited chipset, leave this parameter OFF. The
/*           parameter can only be changed in the Signal OFF signalling state
/*           as a security precaution, in order to avoid accidental
/*           activation.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSystDusw (ViSession instrSession,
                                                  ViBoolean DLULSwap,
                                                  ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG (RSCMU_checkVersion (instrSession, RSCMU200_V4_30, RSCMU_ERROR_FW_VERSION_4_30));

    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:NETW:SYST:DUSW",
                           DLULSwap,
                           mode_On_Off,
                           RSCMU_ERROR_PARAMETER2));
    
}

/*===========================================================================*/
/* Function: Band Indicator
/* Purpose : This function sets the band indicator of the MS under test.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSystBandInd (ViSession instrSession,
                                                     ViInt32   Band,
                                                     ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[] = {"G18", "G19", VI_NULL};

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_10, RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:NETW:SYST:BIND",
                         Band, list,
                         RSCMU_ERROR_PARAMETER2));
}


/*===========================================================================*/
/* Function: Periodic Location Update
/* Purpose : This function sets the value of the timer T3212 of the periodic location
/*           updating procedure. The unit decihours corresponds to 6 minutes or 360 seconds..
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSystPLUpdate (ViSession instrSession,
                                                      ViInt32   t3212,
                                                      ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_10, RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_setViInt32(instrSession, "CONF:NETW:SYST:PLUP",
                            t3212, 0, 255,
                            RSCMU_ERROR_PARAMETER2));
}


/*
 * ----------------------------------------------------------------------------
 *      TIMEOUTS
 *      This subsystem defines timeouts foraborting an unused radio link
 *      or an unsuccessfull call to the mobile.It corresponds to the
 *      table field 'Timeouts' in the popup menu 'Network'.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Radio Link Timeout
/* Purpose : This function sets the maximum number of SACCH blocks which
/*           may be missing before a mobile phone considers the radio
/*           link to be interrupted (radio link timeout)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwTimRlin (ViSession instrSession,
                                                                        ViInt32   timeLimitforRadioLink,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, timeLimitforRadioLink, RSCMU_SACCHBLOCKS_MIN, RSCMU_SACCHBLOCKS_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:TIM:RLIN %d", timeLimitforRadioLink);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Set TestSet  Timeout
/* Purpose : This function sets the maximum number of SACCH blocks which
/*           may be missing before the CMU considers the radio link to
/*           be interrupted (radio link timeout for test set).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwTimRlinTest (ViSession instrSession,
                                                                            ViInt32   setTimeLimit,
                                                                            ViInt32   timeLimitforTestSet,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) setTimeLimit, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (setTimeLimit == RSCMU_ON)
  {
    CHECK_VI_INT32_RANGE(instrSession, timeLimitforTestSet, RSCMU_TESTSET_TIMEOUT_MIN, RSCMU_TESTSET_TIMEOUT_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
    sprintf (wrtBuf, "CONF:NETW:TIM:RLIN:TEST %d", timeLimitforTestSet);
  }
  else sprintf (wrtBuf, "CONF:NETW:TIM:RLIN:TEST OFF");

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Set MTC Timeout
/* Purpose : This function sets the maximum dialing time until the
/*           mobile accepts the call (mobile terminated call timeout);
/*           after this time, the attempted call setup is aborted.
/*           In the setting OFF, dialing is possible for an unlimited
/*           period of time.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwTimMtc (ViSession instrSession,
                                                                       ViInt32   setTimeLimit,
                                                                       ViInt32   timeLimitforDialing,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) setTimeLimit, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (setTimeLimit == RSCMU_ON)
  {
    CHECK_VI_INT32_RANGE(instrSession, timeLimitforDialing, 0, RSCMU_MTC_TIMEOUT, RSCMU_ERROR_PARAMETER3, errorMessage);
    sprintf (wrtBuf, "CONF:NETW:TIM:MTC %d", timeLimitforDialing);
  }
  else sprintf (wrtBuf, "CONF:NETW:TIM:MTC OFF");

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Enable 3G neighbor cell information
/* Purpose : This function enables or disables the transfer of 3G neighbor cell
/*           information including the selected UARFCN and primary SC.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetw3GNCellEnable (ViSession instrSession,
                                                       ViBoolean enable,
                                                       ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_50, RSCMU_ERROR_FW_VERSION_3_50));

    RETMSG(RSCMU_setEnum(instrSession, "CONFigure:NETWork:SI2Quater:NC3G:ENABle", enable, mode_On_Off,
                       RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: 3G ARFCN
/* Purpose : This function defines the UTRAN Radio Frequency Channel number
/*           of the 3G neighbor cell.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetw3GNCellChannel (ViSession instrSession,
                                                        ViInt32   arfcn,
                                                        ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

    RETMSG(RSCMU_setViInt32(instrSession, "CONFigure:NETWork:SI2Quater:NC3G:FDD:ARFCN",
                            arfcn, 10562, 10838,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: 3G Primary Scrambling Code
/* Purpose : This function defines the Primary SC characterizing the 3G neighbor cell.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetw3GNCellPSCode (ViSession instrSession,
                                                       ViInt32   primarySCode_Hex,
                                                       ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    GET_WRT_BUF(instrSession);

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

    CHECK_VI_INT32_RANGE(instrSession, primarySCode_Hex, 0, 16777215, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf (wrtBuf, "CONFigure:NETWork:SI2Quater:NC3G:FDD:PSCode #h%X", primarySCode_Hex);
    RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Enable Enhanced Meas Report
/* Purpose : This function enables or disables the enhanced Measurement
/*           Report with support for Receiver Quality measurements including
/*           2G/3G neighbor cells.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwEmr (ViSession instrSession,
                                             ViBoolean EMREnable,
                                             ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:NETW:EMR",
                         EMREnable, mode_On_Off,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: T200 Auto
/* Purpose : This function enables or disables the automatic setting of the
/*           T200 data link resolution timer.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwT2A (ViSession instrSession,
                                             ViBoolean t200Auto,
                                             ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_23,RSCMU_ERROR_FW_VERSION_4_23));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:NETW:T2A",
                         t200Auto, mode_On_Off,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: T200
/* Purpose : This function sets T200 to <nr> FACCH data blocks
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwT2 (ViSession instrSession,
                                            ViInt32 t200, ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      command[WR_BUFFER_SIZE];

    // Version manager
    CHECKRETMSG (RSCMU_checkVersion (instrSession, RSCMU200_V4_23, RSCMU_ERROR_FW_VERSION_4_23));
    CHECK_VI_INT32_RANGE (instrSession, t200, 4, 9, RSCMU_ERROR_PARAMETER2, errorMessage);
    sprintf (command, "CONF:NETW:T2 DB%ld", t200);

    RETMSG (RSCMU_sendCmd (instrSession,command));
}

/*===========================================================================*/
/* Function: Neighbor Cell
/* Purpose : This function defines a list of up to 16 GSM or 6 WCDMA neighbor
/*           cells.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwNCell (ViSession instrSession,
                                               ViInt32 generation,
                                               ViInt32 neighborCell,
                                               ViBoolean state,
                                               ViInt32 RFChannel,
                                               ViInt32 BSICScramblingCode,
                                               ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));
    CHECK_VI_INT32_RANGE (instrSession,generation,0,1,RSCMU_ERROR_PARAMETER2,errorMessage);
    CHECK_VI_BOOLEAN_RANGE (instrSession,state,RSCMU_ERROR_PARAMETER4,errorMessage);
    
    switch (generation)
    {
        case RSCMU_GSM_2G:
            CHECK_VI_INT32_RANGE (instrSession,neighborCell,1,16,RSCMU_ERROR_PARAMETER3,errorMessage);
            CHECK_VI_INT32_RANGE (instrSession,RFChannel,0,1023,RSCMU_ERROR_PARAMETER5,errorMessage);
            CHECK_VI_INT32_RANGE (instrSession,BSICScramblingCode,0,63,RSCMU_ERROR_PARAMETER6,errorMessage);
            sprintf (wrtBuf, "CONF:NETW:NCEL:%s%ld %s,%ld,%ld", generationArr [generation], neighborCell, mode_On_Off[state],RFChannel,BSICScramblingCode);
            break;
        case RSCMU_GSM_3G:
            CHECK_VI_INT32_RANGE (instrSession,neighborCell,1,6,RSCMU_ERROR_PARAMETER3,errorMessage);
            CHECK_VI_INT32_RANGE (instrSession,RFChannel,412,10838,RSCMU_ERROR_PARAMETER5,errorMessage);
            CHECK_VI_INT32_RANGE (instrSession,BSICScramblingCode,0,0x1FF,RSCMU_ERROR_PARAMETER6,errorMessage);
            sprintf (wrtBuf, "CONF:NETW:NCEL:%s%ld %s,%ld,%x", generationArr [generation], neighborCell, mode_On_Off[state],RFChannel,BSICScramblingCode);
            break;
    }

    RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Default Settings
/* Purpose : This function sets all parameters of the subsystem to their
/*           default values
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqMrepContDef (ViSession instrSession,
                                                    ViBoolean state,
                                                    ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:RXQ:MREP:CONT:DEF",
                         state, mode_On_Off,
                         RSCMU_ERROR_PARAMETER2));

}


/*===========================================================================*/
/* Function: Q Search C
/* Purpose : This function defines a threshold and also indicates whether the
/*           search, identification and measurements of neighboring 3G cells
/*           are to be performed when the average of the received signal
/*           level measurement samples (in dBm) taken on the SACCH D/L
/*           channel of the serving BCCH carrier is below or above the
/*           defined threshold.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqMrepContQsc (ViSession instrSession,
                                                    ViInt32 qSearchC,
                                                    ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setViInt32(instrSession, "CONF:RXQ:MREP:CONT:QSC",
                            qSearchC, 0, 15,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: 3G Search Priority
/* Purpose : This function enables or disables the search for 3G cells when
/*           BSIC decoding is required.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqMrepContTgsp (ViSession instrSession,
                                                     ViBoolean state,
                                                     ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:RXQ:MREP:CONT:TGSP",
                         state, mode_On_Off,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Q Search I
/* Purpose : This function defines the search for 3G cells if the signal level 
/*           is below (numbers 0-7) or above (numbers 8-15) threshold value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatQsi (ViSession instrSession,
                                                 ViInt32 qSearchI,
                                                 ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setViInt32(instrSession, "CONF:NETW:PDAT:QSI",
                            qSearchI, 0, 15,
                            RSCMU_ERROR_PARAMETER2));
}
    

/*===========================================================================*/
/* Function: FDD QOffset
/* Purpose : This function defines the offset to RLA_C for cell re-selection 
/*           to access FDD mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatFqoffset
             (ViSession instrSession, ViInt32 FDDQOffset,
              ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setViInt32(instrSession, "CONF:NETW:PDAT:FQOF",
                            FDDQOffset, 0, 15,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: FDD QMin
/* Purpose : This function applies a minimum threshold for Ec/No for FDD cell
/*           re-selection.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatFqmin (ViSession instrSession,
                                                   ViInt32 FDDQMin,
                                                   ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setViInt32(instrSession, "CONF:NETW:PDAT:FQM",
                            FDDQMin, 0, 7,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: FDD Rep Quadrant
/* Purpose : This function controls whether the measurement quantities Ec/No
/*           or RSCP are used as reporting indicators on the Common Pilot
/*           Channel (CPICH) for FDD cells.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqMrepContFrq (ViSession instrSession,
                                                    ViInt32 FDDREPQuadrant,
                                                    ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:RXQ:MREP:CONT:FRQ",
                         FDDREPQuadrant, quadrantArr,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: GSM Neighbor Cells
/* Purpose : This function returns the neighbor cell parameters related to
/*           the BA list used for the enhanced measurement report.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepNcelGsm (ViSession instrSession,
                                                 ViInt32 neighborCell,
                                                 ViInt32 *RFChannel,
                                                 ViInt32 *GSMBSIC,
                                                 ViInt32 *indicator_ofRxLevel,
                                                 ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));
    CHECK_VI_INT32_RANGE (instrSession,neighborCell,1,6,RSCMU_ERROR_PARAMETER2,errorMessage);

    sprintf (wrtBuf, "RREP:NCEL%ld:GSM?", neighborCell);
    CHECKRETMSG(RSCMU_getViString(instrSession, wrtBuf,
                                  rdBuf, RD_BUFFER_SIZE,
                                  RSCMU_ERROR_PARAMETER1));
    if (RFChannel == NULL)
        RETMSG (RSCMU_ERROR_PARAMETER3);
    if (GSMBSIC == NULL)
        RETMSG (RSCMU_ERROR_PARAMETER4);
    if (indicator_ofRxLevel == NULL)
        RETMSG (RSCMU_ERROR_PARAMETER5);
    
    sscanf (rdBuf, "%ld,%ld,%ld",RFChannel,GSMBSIC,indicator_ofRxLevel);
    
    return RSCMU_Status;
}

/*===========================================================================*/
/* Function: UTRA FDD Neighbor Cells
/* Purpose : This function returns the neighbor cell parameters related to
/*           the BA list used for the enhanced measurement report.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepNcelUfdd (ViSession instrSession,
                                                  ViInt32 neighborCell,
                                                  ViInt32 *RFChannel,
                                                  ViInt32 *scramblingCode,
                                                  ViInt32 *CPICH,
                                                  ViReal64 *signalStrength,
                                                  ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));
    CHECK_VI_INT32_RANGE (instrSession,neighborCell,1,6,RSCMU_ERROR_PARAMETER2,errorMessage);

    sprintf (wrtBuf, "RREP:NCEL%ld:UFDD?", neighborCell);
    CHECKRETMSG(RSCMU_getViString(instrSession, wrtBuf,
                                  rdBuf, RD_BUFFER_SIZE,
                                  RSCMU_ERROR_PARAMETER1));
    if (RFChannel == NULL)
        RETMSG (RSCMU_ERROR_PARAMETER3);
    if (scramblingCode == NULL)
        RETMSG (RSCMU_ERROR_PARAMETER4);
    if (CPICH == NULL)
        RETMSG (RSCMU_ERROR_PARAMETER5);
    if (signalStrength == NULL)
        RETMSG (RSCMU_ERROR_PARAMETER6);
    
    sscanf (rdBuf, "%ld,%x,%ld,%Le",RFChannel,scramblingCode,CPICH,signalStrength);
    
    return RSCMU_Status;
}


/* ----------------------------------------------------------------------------
 *      Network Hopping
 *-----------------------------------------------------------------------------
 */

/*===========================================================================*/
/* Function: Hopping Sequence Number
/* Purpose : This function defines the Hopping Sequence that is used for
/*           channel hopping.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwHoppHsn (ViSession instrSession,
                                                 ViInt32 hoppingSequenceNumber,
                                                 ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_50,RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setViInt32(instrSession, "CONF:NETW:HOPP:HSN",
                            hoppingSequenceNumber, 0, 63,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Mobile Allocation Index Offset
/* Purpose : This function defines the offset where to start in the channel
/*           hopping sequence.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwHoppMaio (ViSession instrSession,
                                                  ViInt32 indexOffset,
                                                  ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_50,RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setViInt32(instrSession, "CONF:NETW:HOPP:MAIO",
                            indexOffset, 0, 63,
                            RSCMU_ERROR_PARAMETER2));
}

/* ----------------------------------------------------------------------------
 *      Network SMS
 *-----------------------------------------------------------------------------
 */

/*===========================================================================*/
/* Function: Reload SMS File
/* Purpose : This function (re-)loads the selected SMS message file.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReloadNetwSmsFile (ViSession instrSession,
                                               ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V5_00, RSCMU_ERROR_FW_VERSION_5_00));

    RETMSG(RSCMU_sendCmd(instrSession, "RELoad:NETWork:SMS:FILE"));
}

/*===========================================================================*/
/* Function: Save Incoming SMS
/* Purpose : This function defines whether or not incoming SMS are saved in a
/*           file.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmsIncSav (ViSession instrSession,
                                                   ViBoolean automaticSaving,
                                                   ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG (RSCMU_checkVersion (instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:NETW:SMS:INC:SAV",
                           automaticSaving,
                           mode_On_Off,
                           RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Automatic Inc Filename
/* Purpose : This function defines or returns whether or not incoming SMS are
/*           saved using an autoincremented filename, e.g. out_msg1.sms,
/*           out_msg2.sms, etc.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmsIncAinc
             (ViSession instrSession, ViBoolean automaticInc,
              ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG (RSCMU_checkVersion (instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:NETW:SMS:INC:AINC",
                           automaticInc,
                           mode_On_Off,
                           RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Last Saved SMS File
/* Purpose : This function returns the full path and filename of the last
/*           saved SMS.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmsIncLast
             (ViSession instrSession, ViChar SMSFile[],
              ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_50,RSCMU_ERROR_FW_VERSION_4_50));

    return RSCMU_getViString(instrSession, "CONF:NETW:SMS:INC:LAST?", SMSFile,
                             MID_BUFFER_SIZE, RSCMU_ERROR_PARAMETER2);
}

/*===========================================================================*/
/* Function: Reload Status
/* Purpose : This function verifies whether or not the specified file has
/*           been loaded successfully.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwSmsFileStat (ViSession instrSession,
                                                 ViInt32 *reloadStatus,
                                                 ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
            
    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_50,RSCMU_ERROR_FW_VERSION_4_50));

    sprintf(wrtBuf, ":NETW:SMS:FILE:STAT?");
    
    RETMSG(RSCMU_getEnum(instrSession, wrtBuf,
                            reloadStatus,
                            reloadStatusArr,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Last Received SMS Text
/* Purpose : This function returns the text of the last received short
/*           message.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_CswSms (ViSession instrSession,
                                        ViChar SMSText[],
                                        ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_50,RSCMU_ERROR_FW_VERSION_4_50));

    return RSCMU_getViString(instrSession, ":SIGN:CSW:SMS?", SMSText,
                             MID_BUFFER_SIZE, RSCMU_ERROR_PARAMETER2);
}

/*===========================================================================*/
/* Function: Last Received Encoding
/* Purpose : This function returns the encoding of the last received SMS,
/*           which is either 7-bit (ASCII text), 8-bit (binary) or 16-bit
/*           (limited UTF-16).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_CswSmsLrecEnc (ViSession instrSession,
                                               ViInt32 *encoding,
                                               ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_50,RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_getViInt32(instrSession, ":SIGN:CSW:SMS:LREC:ENC?",
                            encoding,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Last Received SMS Length
/* Purpose : This function returns the length of the last received short
/*           message.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_CswSmsLrecLeng (ViSession instrSession,
                                                ViInt32 *length,
                                                ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_50,RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_getViInt32(instrSession, ":SIGN:CSW:SMS:LREC:LENG?",
                            length,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Outgoing Message Handle
/* Purpose : This function qualifies whether the outgoing SMS message content
/*           is entered manually (using RC
/*           CONFigure:NETWork:SMS[:INTernal]:TEXT) or is taken from an
/*           existing file, which is specified
/*           using CONFigure:NETWork:SMS:FILE.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmsHand (ViSession instrSession,
                                                 ViInt32 SMSContent,
                                                 ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG (RSCMU_checkVersion (instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:NETW:SMS:HAND",
                           SMSContent,
                           netwSmsContentArr,
                           RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Outgoing SMS Message Class
/* Purpose : This function defines the SMS message class information which is
/*           transferred with an outgoing short message.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmsClass (ViSession instrSession,
                                                 ViInt32 SMSMessageClass,
                                                 ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG (RSCMU_checkVersion (instrSession, RSCMU200_V5_00, RSCMU_ERROR_FW_VERSION_5_00));

    RETMSG (RSCMU_setEnum (instrSession,
                           "CONF:NETW:SMS:CLAS",
                           SMSMessageClass,
                           netwSmsMsgClassArr,
                           RSCMU_ERROR_PARAMETER2));
}


/*===========================================================================*/
/* Function: Outgoing SMS File
/* Purpose : This function sets the index of the file containing the outgoing
/*           SMS content.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmsFile (ViSession instrSession,
                                                 ViInt32 messageContentIndex,
                                                 ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setViInt32(instrSession, "CONF:NETW:SMS:FILE",
                            messageContentIndex, 1, 3,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Outgoing SMS Length
/* Purpose : This function returns the length of the SMS message referenced
/*           by CONFigure:NETWork:SMS:FILE.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmsFileLeng
             (ViSession instrSession, ViInt32 *length,
              ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_50,RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_getViInt32(instrSession, "CONF:NETW:SMS:FILE:LENG?",
                            length,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Outgoing SMS Encoding
/* Purpose : This function returns the encoding of the outgoing SMS, which is
/*           either 7-bit (ASCII text), 8-bit (octet unspecified) or 16-bit
/*           (limited UCS2 Unicode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmsFileEnc
             (ViSession instrSession, ViInt32 *encoding,
              ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_50,RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_getViInt32(instrSession, "CONF:NETW:SMS:FILE:ENC?",
                            encoding,
                            RSCMU_ERROR_PARAMETER2));
}


/*===========================================================================*/
/* Function: Outgoing SMS Text
/* Purpose : This function returns the encoding of the outgoing SMS, which is
/*           either 7-bit (ASCII text), 8-bit (octet unspecified) or 16-bit
/*           (limited UCS2 Unicode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmsFileText
             (ViSession instrSession, ViChar messageText[],
              ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_50,RSCMU_ERROR_FW_VERSION_4_50));

    return RSCMU_getViString(instrSession, "CONF:NETW:SMS:FILE:TEXT?", messageText,
                             MID_BUFFER_SIZE, RSCMU_ERROR_PARAMETER2);

}


/**********************************************

/*===========================================================================*/
/* Function: Enable Repeated DL FACCH
/* Purpose : This function returns the 3G neighbor cell parameters related to
/*           the 3G Neighbor Cell Description used for the enhanced
/*           measurement report.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqFfacContRdf (ViSession instrSession,
                                                    ViBoolean enable,
                                                    ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:RXQ:FFAC:CONT:RDF",
                         enable, enaDisaArr,
                         RSCMU_ERROR_PARAMETER2));
}

/* ----------------------------------------------------------------------------
 *      INPUT AND OUTPUT CONNECTORS
 *      The subsystem IOConnector contains the commands for
 *      configuration of the input and output connectors.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set INPUT Connector
/* Purpose : This function determines the connector to be used for
/*           incoming RF signals.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Inp (ViSession instrSession,
                                                            ViInt32   Input,
                                                            ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_Inp (instrSession, Input, errorMessage);
}
/*===========================================================================*/
/* Function: Set OUTPUT Connector
/* Purpose : This function determines the connector to be used for outcoming
/*           RF signals.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Outp (ViSession instrSession,
                                                             ViInt32   Output,
                                                             ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_Outp (instrSession,  Output, errorMessage);
}
/*===========================================================================*/
/* Function: Sense Ext. Attenuation at Input
/* Purpose : This function queries the external attenuation value at one
/*           of the inputs defined.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensCorrLossInp (ViSession instrSession,
                                                                        ViInt32   InputConnector,
                                                                        ViReal64  externalAttenuation,
                                                                        ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_SensCorrLossInp(instrSession, InputConnector, externalAttenuation, errorMessage);
}
/*===========================================================================*/
/* Function: Set Ext. Attenuation at Output
/* Purpose : This function assigns an external attenuation value to one
/*           of the outputs defined.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SourCorrLossOutp (ViSession instrSession,
                                                                         ViInt32   OutputConnector,
                                                                         ViReal64  externalAttenuation,
                                                                         ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_SourCorrLossOutp (instrSession, OutputConnector, externalAttenuation, errorMessage);
}

/*===========================================================================*/
/* Function: Speech Encoder
/* Purpose : This command determines the input source that feeds the CMU speech
/*           encoder (option CMU-B52).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_RoutSpenInp (ViSession  instrSession,
                                                                    ViInt32    SpeechEncoder,
                                                                    ViChar     errorMessage[])
{
  return RSCMU_GSM_NSig_RoutSpenInp (instrSession, SpeechEncoder, errorMessage);
}

/*===========================================================================*/
/* Function: Speech Decoder
/* Purpose : This command routes the CMU speech decoder output (option CMU-B52).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_RoutSpdOutp (ViSession instrSession,
                                                                    ViInt32   SpeechDecoder,
                                                                    ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_RoutSpdOutp (instrSession, SpeechDecoder, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      SYNCHRONISATION
 *      Subsystem REFerence (Synchronization)
 *      The subsystem REFerence contains the commands for setting a system clock
 *      specific to the network. This frquency is set in the index card Synch. in
 *      the popup menu Connect. Control.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Switching on/off and setting the system clock
/* Purpose : This commands switches the system clock specific to the
/*           network at the REF OUT 2 connector on or off, and determines
/*           the system clock frequency applied to REF OUT 2.
/*           The frequency entered is internally rounded to one of a
/*           discrete values defined in the operating manual.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SourDmCloc (ViSession  instrSession,
                                                                   ViInt32    Mode,
                                                                   ViReal64   Frequency,
                                                                   ViChar     errorMessage[])
{
  return RSCMU_GSM_NSig_SourDmCloc (instrSession, Mode, Frequency, errorMessage);
}

/*===========================================================================*/
/* Workstation Port number
/* This function sets the port number of the workstation
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_WsPort (ViSession instrSession,
                                        ViInt32 port_number,
                                        ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_80, RSCMU_ERROR_FW_VERSION_3_80));

    RETMSG(RSCMU_setViInt32(instrSession,
                            "CONFigure:ATESt:WSPort",
                            port_number,
                            0, 65535    ,
                            RSCMU_ERROR_PARAMETER2));
}



/*===========================================================================*/
/* Workstation Port number
/* This function sets the IP Adress of the workstation
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_WsIpAddress (ViSession instrSession,
                                             ViInt32 _1st, ViInt32 _2nd,
                                             ViInt32 _3rd, ViInt32 _4th,
                                             ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    GET_WRT_BUF(instrSession);

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_80, RSCMU_ERROR_FW_VERSION_3_80));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, _1st, 0, 255, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, _2nd, 0, 255, RSCMU_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, _3rd, 0, 255, RSCMU_ERROR_PARAMETER4, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, _4th, 0, 255, RSCMU_ERROR_PARAMETER5, errorMessage);

    sprintf (wrtBuf, "CONFigure:ATESt:WSIPaddress %d,%d,%d,%d", _1st, _2nd, _3rd, _4th);

    RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Start Application Test
/* This function starts application test and connect workstation.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_StartApplTest (ViSession instrSession,
                                               ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_80, RSCMU_ERROR_FW_VERSION_3_80));

    RETMSG(RSCMU_sendCmd(instrSession, "PROCedure:SIGNalling:PDATa:ACTion SATest"));
}

/*
 *-----------------------------------------------------------------------------
 *      Layer 3 Message Logging
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function:
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_L3MLogChangeDest (ViSession instrSession,
                                                  ViChar fileName[],
                                                  ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    GET_WRT_BUF(instrSession);

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_10, RSCMU_ERROR_FW_VERSION_3_10));

    sprintf (wrtBuf, "MMEM:L3MS:CDES \"%s\"" , fileName);

    RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));

}

/*===========================================================================*/
/* Function:
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_L3MLogEnableBuffWrite (ViSession instrSession,
                                                       ViInt32 bufferWriting,
                                                       ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_10, RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_setEnum(instrSession, "MMEM:L3MS:BWR", bufferWriting, mode_On_Off,
                       RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function:
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_L3MLogSave (ViSession instrSession,
                                            ViChar fileName[],
                                            ViInt32 storageDevice,
                                            ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    StrSorageDevice[] = {"INTERNAL","EXTERNAL", "", VI_NULL};
    GET_WRT_BUF(instrSession);

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_10, RSCMU_ERROR_FW_VERSION_3_10));

    CHECK_VI_INT32_RANGE(instrSession, storageDevice, 0, 1, RSCMU_ERROR_PARAMETER4, errorMessage);

    sprintf (wrtBuf, "MMEM:L3MS:SAVE \"%s\",%s" , fileName, StrSorageDevice[storageDevice]);

    RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function:
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_L3MLogBufferEmpty (ViSession instrSession,
                                                   ViInt32 *bufferEmpty,
                                                   ViChar errorMessage[])
{
    ViString    list[]={"EMPT", "FULL", VI_NULL};
    ViStatus    RSCMU_Status = VI_SUCCESS;
    GET_WRT_BUF(instrSession);

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_getEnum(instrSession, "MMEM:L3MS:BEMP?",
                         bufferEmpty, list,0));
}

/*
 *-----------------------------------------------------------------------------
 *  Pseudo Test Object RREPorts
 *  The subsystem RREPorts contains the commands for requesting the receiver
 *  report of the mobile.
 *  Together with NETWork[:MS] the subsystem corresponds to the softkey MS Rcv.
 *  Reports in the main menu GSM900-MS Overview. The receiver characteristics
 *  do not really represent a measured value, since the values are
 *  automatically transmitted during signalling. The output of "NAN" (not a
 *  number) implies that there is no measured value at present.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Sense RX Level
/* Purpose : This function outputs the receiving level that the mobile
/*           reports to the CMU, expressed in levels without dimension.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepRxl (ViSession  instrSession,
                                                                    ViInt32   *RxLev,
                                                                    ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViReal64    RxLevTmp;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_50,RSCMU_ERROR_FW_VERSION_4_50));
  
  if ((RSCMU_Status = RSCMU_Query (instrSession, "SENS:RREP:RXL?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  if (strcmp (rdBuf, "NAN") != 0)
  {
    sscanf (rdBuf, "%lf", &RxLevTmp);
    RxLevTmp += 0.001; // To avoid a problem due to the fraction part
    *RxLev = (ViInt32) RxLevTmp;
  }
  else
  {
    *RxLev = RSCMU_NAN_VI_INT32;
  }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Sense RX Level Full
/* Purpose : This function returns the received signal level RX Level Full
/*           that the mobile reports to the CMU, expressed as dimensionless
/*           numbers.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepRxlFull (ViSession  instrSession,
                                                                    ViInt32   *RxLevFull,
                                                                    ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViReal64    RxLevTmp;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V5_00,RSCMU_ERROR_FW_VERSION_5_00));
    
  if ((RSCMU_Status = RSCMU_Query (instrSession, "SENS:RREP:RXL:FULL?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  if (strcmp (rdBuf, "NAN") != 0)
  {
    sscanf (rdBuf, "%lf", &RxLevTmp);
    RxLevTmp += 0.001; // To avoid a problem due to the fraction part
    *RxLevFull = (ViInt32) RxLevTmp;
  }
  else
  {
    *RxLevFull = RSCMU_NAN_VI_INT32;
  }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Sense RX Level Sub
/* Purpose : This function returns returns the received signal level RX Level
/*           Sub that the mobile reports to the CMU, expressed as
             dimensionless numbers.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepRxlSub (ViSession  instrSession,
                                                                    ViInt32   *RxLevSub,
                                                                    ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViReal64    RxLevTmp;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V5_00,RSCMU_ERROR_FW_VERSION_5_00));
    
  if ((RSCMU_Status = RSCMU_Query (instrSession, "SENS:RREP:RXL:SUB?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  if (strcmp (rdBuf, "NAN") != 0)
  {
    sscanf (rdBuf, "%lf", &RxLevTmp);
    RxLevTmp += 0.001; // To avoid a problem due to the fraction part
    *RxLevSub = (ViInt32) RxLevTmp;
  }
  else
  {
    *RxLevSub = RSCMU_NAN_VI_INT32;
  }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Sense RX Quality
/* Purpose : This function outputs the received signal quality that the
/*           mobile reports to the CMU, expressed in quality levels
/*           without dimension.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepRxq (ViSession   instrSession,
                                                                    ViInt32    *RxQual,
                                                                    ViChar      errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViReal64    RxQualTmp;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_50,RSCMU_ERROR_FW_VERSION_4_50));

  
  if ((RSCMU_Status = RSCMU_Query (instrSession, "SENS:RREP:RXQ?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  if (strcmp (rdBuf, "NAN") != 0)
  {
    sscanf (rdBuf, "%lf", &RxQualTmp);
    RxQualTmp += 0.001; // To avoid a problem due to the fraction part
    *RxQual = (ViInt32) RxQualTmp;
  }
  else
  {
    *RxQual = RSCMU_NAN_VI_INT32;
  }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Sense RX Quality Full
/* Purpose : This function returns the received signal quality that the
/*           mobile reports to the CMU, expressed a dimensionless numbers
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepRxqFull (ViSession   instrSession,
                                                                    ViInt32    *RxQualFull,
                                                                    ViChar      errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViReal64    RxQualTmp;

     // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V5_00,RSCMU_ERROR_FW_VERSION_5_00));

    
  if ((RSCMU_Status = RSCMU_Query (instrSession, "SENS:RREP:RXQ:FULL?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  if (strcmp (rdBuf, "NAN") != 0)
  {
    sscanf (rdBuf, "%lf", &RxQualTmp);
    RxQualTmp += 0.001; // To avoid a problem due to the fraction part
    *RxQualFull = (ViInt32) RxQualTmp;
  }
  else
  {
    *RxQualFull = RSCMU_NAN_VI_INT32;
  }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Sense RX Quality Sub
/* Purpose : This function returns the received signal quality RX Quality Sub
/*           that the mobile reports to the CMU, expressed a dimensionless
/*           numbers.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepRxqSub (ViSession   instrSession,
                                                                    ViInt32    *RxQualSub,
                                                                    ViChar      errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViReal64    RxQualTmp;

     // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V5_00,RSCMU_ERROR_FW_VERSION_5_00));

    
  if ((RSCMU_Status = RSCMU_Query (instrSession, "SENS:RREP:RXQ:FULL?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  if (strcmp (rdBuf, "NAN") != 0)
  {
    sscanf (rdBuf, "%lf", &RxQualTmp);
    RxQualTmp += 0.001; // To avoid a problem due to the fraction part
    *RxQualSub = (ViInt32) RxQualTmp;
  }
  else
  {
    *RxQualSub = RSCMU_NAN_VI_INT32;
  }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Received level at adjacent cells
/* Purpose : This function returns the channel number and the signal level
/*           for six adjacent channels.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepNceli (ViSession  instrSession,
                                                                      ViInt32    ChannelNb[],
                                                                      ViReal64   LevelAtAdjacentCells[],
                                                                      ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViChar      tab[100][100];
  ViUInt16    i, j;

  // Sense the current signalling state of the CMU
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, "SENSe:RREPorts:NCELl?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the channel number of the 6 adjacent cells:
  j = 0;
  for (i = 0; i < 12; i +=2) // on the even index
  {
    if (strcmp (tab[i], "NAN") != 0)
      sscanf (tab[i], "%d", &ChannelNb[j]);
    else
      ChannelNb[j] = RSCMU_NAN_VI_INT32;
    j++;
  }
  // Get the received level at the 6 adjacent cells:
  j = 0;
  for (i = 1; i < 12; i +=2) // on the odd index
  {
    if (strcmp (tab[i], "NAN") != 0)
      sscanf (tab[i], "%lf", &LevelAtAdjacentCells[j]);
    else
      LevelAtAdjacentCells[j] = RSCMU_NAN;
    j++;
  }
  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Report PCL
/* Purpose : This function returns the transmitter output power in PCL units
/*           that the MS reports to the network/ CMU.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepRPcl (ViSession  instrSession,
                                                                     ViInt32   *ReportPCL,
                                                                     ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarSession;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  if (p_globalvarSession->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Get the reference level
  if ((RSCMU_Status = RSCMU_Query (instrSession, "RREP:RPCL?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  if (strcmp (rdBuf, "NAN") != 0)
  {
    ViReal64 tmp;
    sscanf (rdBuf, "%lf", &tmp);
    tmp += 0.001; // To avoid a problem due to the fraction part
    *ReportPCL = (ViInt32) tmp;
  }
  else
    *ReportPCL = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: DTX mode of mobile phone
/* Purpose : This function outputs the DTX mode (discontinuous transmission
/*           mode) currently used by the mobile phone.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepDtx (ViSession  instrSession,
                                                                    ViInt32   *DTXmode,
                                                                    ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";

  if ((RSCMU_Status = RSCMU_Query (instrSession, "SENS:RREP:DTX?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  if (strncmp ("OFF", rdBuf, 3) == 0)
    *DTXmode = RSCMU_OFF;
  else if (strncmp ("ON", rdBuf, 2) == 0)
    *DTXmode = RSCMU_ON;
  else if (strcmp (rdBuf, "NAN") != 0)
    *DTXmode = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Number of Measurement Reports
/* Purpose : This function returns the number of receiver reports transmitted
             since the call was established.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepCount (ViSession   instrSession,
                                                                      ViInt32     *Number_of_Measurements_Reports,
                                                                      ViChar      errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";

  if ((RSCMU_Status = RSCMU_Query (instrSession, "SENS:RREP:COUN?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

    sscanf (rdBuf, "%d", Number_of_Measurements_Reports);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: C Value
/* Purpose : This function returns the normalized received signal level at the MS.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepCValue (ViSession instrSession,
                                                ViInt32  *c_value,
                                                ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  CHECKRETMSG(RSCMU_getViString(instrSession,"SENSe:RREPorts:CVALue?",rdBuf,RD_BUFFER_SIZE,0));

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf,"%d", c_value);
  else *c_value = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: signal variance
/* Purpose : This function returns the variance of the received signal level.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepSVar (ViSession instrSession,
                                              ViInt32  *signal_variance,
                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  CHECKRETMSG(RSCMU_getViString(instrSession,"SENSe:RREPorts:SVARiance?",rdBuf,RD_BUFFER_SIZE,0));

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf,"%d", signal_variance);
  else *signal_variance = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: mean BEP GMSK
/* Purpose : This function returns the average Bit Error Probability (BEP) of
/*           GMSK-modulated radio blocks, respectively.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepGmeanBep (ViSession instrSession,
                                                  ViInt32  *meanBEPGMSK,
                                                  ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  CHECKRETMSG(RSCMU_getViString(instrSession,"SENSe:RREPorts:GMBep?",rdBuf,RD_BUFFER_SIZE,0));

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf,"%d", meanBEPGMSK);
  else *meanBEPGMSK = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: mean BEP 8PSK
/* Purpose : This function returns the average Bit Error Probability (BEP) of
/*           8PSK-modulated radio blocks, respectively.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrep8meanBep (ViSession instrSession,
                                                  ViInt32  *meanBEP8PSK,
                                                  ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  CHECKRETMSG(RSCMU_getViString(instrSession,"SENSe:RREPorts:EMBep?",rdBuf,RD_BUFFER_SIZE,0));

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf,"%d", meanBEP8PSK);
  else *meanBEP8PSK = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: CV BEP GMSK
/* Purpose : This function returns the Coefficient of Variation of the Bit Error
/*           Probability (BEP) of GMSK-modulated radio blocks, respectively.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepGCVBep (ViSession instrSession,
                                                ViInt32  *cvBEPGMSK,
                                                ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  CHECKRETMSG(RSCMU_getViString(instrSession,"SENSe:RREPorts:GCBep?",rdBuf,RD_BUFFER_SIZE,0));

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf,"%d", cvBEPGMSK);
  else *cvBEPGMSK = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: CV BEP 8PSK
/* Purpose : This function returns the Coefficient of Variation of the Bit Error
/*           Probability (BEP) of 8PSK-modulated radio blocks, respectively.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrep8CVBep (ViSession instrSession,
                                                ViInt32  *cvBEP8PSK,
                                                ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  CHECKRETMSG(RSCMU_getViString(instrSession,"SENSe:RREPorts:ECBep?",rdBuf,RD_BUFFER_SIZE,0));

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf,"%d", cvBEP8PSK);
  else *cvBEP8PSK = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}


/*===========================================================================*/
/* Function: Enhanced Measure Report: Switch on/off
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwEnhMeasureRep (ViSession instrSession,
                                                       ViBoolean enhancedMeasureReport,
                                                       ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

  RETMSG(RSCMU_setEnum(instrSession, "CONFigure:NETWork:CSWitched:EMReports",
                       enhancedMeasureReport, mode_On_Off,
                       RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Enhanced Measure Report: Mean BEP
/*===========================================================================*/

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepMeanBepEH (ViSession instrSession,
                                                   ViInt32 *meanBEP,
                                                   ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

  CHECKRETMSG(RSCMU_getViString(instrSession,"SENSe:RREPorts:MBEP?",rdBuf,RD_BUFFER_SIZE,0));

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf,"%d", meanBEP);
  else *meanBEP = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Enhanced Measure Report: CV BEP
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepCVBepEH (ViSession instrSession,
                                                 ViInt32 *CVBEP,
                                                 ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

  CHECKRETMSG(RSCMU_getViString(instrSession,"SENSe:RREPorts:CBEP?",rdBuf,RD_BUFFER_SIZE,0));

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf,"%d", CVBEP);
  else *CVBEP = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Enhanced Measure Report: Nr. of Blocks
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepNrBlocksEH (ViSession instrSession,
                                                    ViInt32 *nr_ofBlocks,
                                                    ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

  CHECKRETMSG(RSCMU_getViString(instrSession,"SENSe:RREPorts:NRBlocks?",rdBuf,RD_BUFFER_SIZE,0));

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf,"%d", nr_ofBlocks);
  else *nr_ofBlocks = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}

/*
 *-----------------------------------------------------------------------------
 *  SIGNALLING INFO
 *  Pseudo Measurement Object MSSinfo
 *  (Signalling information of mobile phone)
 *  This subsystem contains the functions for requesting the
 *  signalling characteristics of the mobile.
 *  The subsystem corresponds to the softkey Signalling Info in the
 *  main menu GSM900-MS Overview or in the popup menu Connection
 *  Control - BS Signal (Call Established).
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Sense Mobile IMSI
/* Purpose : This function reads the international mobile subscriber
/*           identification code (IMSI) of the mobile. It consists of
/*           the mobile country code (MCC), the mobile network code
/*           (MNC) and the mobile subscriber identification no.(MSIN).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssImsi (ViSession instrSession,
                                                                    ViInt32   *mobileCountryCodeMCC,
                                                                    ViInt32   *mobileNetworkCodeMNC,
                                                                    ViChar    mobileSubscriberIdNoMSIN[],
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";

  // Get the Mobile Country Code
  if ((RSCMU_Status = RSCMU_Query (instrSession, "SENS:MSS:IMSI:MCC?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf,"%d", mobileCountryCodeMCC);
  else *mobileCountryCodeMCC = RSCMU_NAN_VI_INT32;

  // Get the Mobile Network Code
  if ((RSCMU_Status = RSCMU_Query (instrSession, "SENS:MSS:IMSI:MNC?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf,"%d", mobileNetworkCodeMNC);
  else *mobileNetworkCodeMNC = RSCMU_NAN_VI_INT32;

  // Get the Mobile Subscriber Identification Number
  if ((RSCMU_Status = RSCMU_Query (instrSession, "SENS:MSS:IMSI:MSIN?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  strncpy (mobileSubscriberIdNoMSIN, rdBuf,  strlen(rdBuf));
  mobileSubscriberIdNoMSIN [strlen(rdBuf)] = 0;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Sense Mobile IMEI
/* Purpose : This function reads the international mobile station
/*           equipment identity (IMEI)of mobile phone.
/*           It consists of a type approval code (TCC), the final
/*           assembly code (FAC), the serial number (SNR) and the
/*           software version number (SVR).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssImei (ViSession instrSession,
                                             ViChar    TAC[],
                                             ViChar    FAC[],
                                             ViChar    SNR[],
                                             ViChar    SVN[],
                                             ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";

  // Get the Type Approval Code
  if ((RSCMU_Status = RSCMU_Query (instrSession, "MSS:IMEI:TAC?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;
  strncpy (TAC, rdBuf,  strlen(rdBuf));
  TAC[strlen(rdBuf)] = 0;

  // Get the Mobile Country Code
  if ((RSCMU_Status = RSCMU_Query (instrSession, "MSS:IMEI:FAC?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;
  strncpy (FAC, rdBuf,  strlen(rdBuf));
  FAC[strlen(rdBuf)] = 0;

  // Get the Mobile Subscriber Identification Number
  if ((RSCMU_Status = RSCMU_Query (instrSession, "MSS:IMEI:SNR?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;
  strncpy (SNR, rdBuf,  strlen(rdBuf));
  SNR[strlen(rdBuf)] = 0;

  // Get the Mobile Subscriber Identification Number
  if ((RSCMU_Status = RSCMU_Query (instrSession, "MSS:IMEI:SVN?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;
  strncpy (SVN, rdBuf,  strlen(rdBuf));
  SVN[strlen(rdBuf)] = 0;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Sense GSM Phase
/* Purpose : This function reads the dialed number if a call is made
/*           to the mobile. (max. 20-Digit)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssRev (ViSession  instrSession,
                                                                   ViInt32   *GSMPhase,
                                                                   ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";

  // Sense the current signalling state of the CMU
  if ((RSCMU_Status = RSCMU_Query (instrSession, "MSS:REV?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Extract the CMU response:
  if (strncmp ("PH1", rdBuf, 3) == 0)
    *GSMPhase = RSCMU_PH1;
  else if (strncmp ("PH2", rdBuf, 3) == 0)
    *GSMPhase = RSCMU_PH2;
  else if (strncmp ("PH2P", rdBuf, 4) == 0)
    *GSMPhase = RSCMU_PH2P;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Sense dialed Number
/* Purpose : This function reads the dialed number if a call is made
/*           to the mobile. (max. 20-Digit)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssDnum (ViSession instrSession,
                                                                    ViChar    dialedNumber[],
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";

  // Get the Dialed Number
  if ((RSCMU_Status = RSCMU_Query (instrSession, "MSS:DNUM?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  strncpy (dialedNumber, rdBuf,  strlen(rdBuf));
  dialedNumber [strlen(rdBuf)] = 0;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Sense Speech Coding in TCh
/* Purpose : This function returns the speech coding and voice
/*           transmission in the traffic channels (full-rate channel,
/*           half-rate channel, full-rate channel with variable
/*           transmission rate).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssTraf (ViSession instrSession,
                                             ViInt32   *SpeechCoding,
                                             ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";

  // Sense the current signalling state of the CMU
  if ((RSCMU_Status = RSCMU_Query (instrSession, "MSS:TRAF?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Extract the CMU response:
  if (strncmp ("FRV1", rdBuf, 4) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_FRV1;
  else if (strncmp ("FRV2", rdBuf, 4) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_FRV2;
  else if (strncmp ("HRV1", rdBuf, 4) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_HRV1;
  else if (strncmp ("FD24", rdBuf, 4) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_FD24;
  else if (strncmp ("FD48", rdBuf, 4) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_FD48;
  else if (strncmp ("FD96", rdBuf, 4) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_FD96;
  else if (strncmp ("HD24", rdBuf, 4) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_HD24;
  else if (strncmp ("HD48", rdBuf, 4) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_HD48;
  else if (strncmp ("FD14", rdBuf, 4) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_FD14;
  else if (strncmp ("C1TM", rdBuf, 4) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_C1TM;
  else if (strncmp ("C2TM", rdBuf, 4) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_C2TM;
  else if (strncmp ("C3TM", rdBuf, 4) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_C3TM;
  else if (strncmp ("C4TM", rdBuf, 4) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_C4TM;
  else if (strncmp ("MC1T", rdBuf, 5) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_MC1TM;
  else if (strncmp ("MC2T", rdBuf, 5) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_MC2TM;
  else if (strncmp ("MC3T", rdBuf, 5) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_MC3TM;
  else if (strncmp ("MC4T", rdBuf, 5) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_MC4TM;
  else if (strncmp ("MC5T", rdBuf, 5) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_MC5TM;
  else if (strncmp ("MC6T", rdBuf, 5) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_MC6TM;
  else if (strncmp ("MC7T", rdBuf, 5) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_MC7TM;
  else if (strncmp ("MC8T", rdBuf, 5) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_MC8TM;
  else if (strncmp ("MC9T", rdBuf, 5) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_MC9TM;
  else if (strncmp ("AMRF", rdBuf, 4) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_AMR_FR;
  else if (strncmp ("AMRH", rdBuf, 4) == 0)
    *SpeechCoding = RSCMU_SPEECH_CODING_AMR_HR;
  else *SpeechCoding = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Sense mobile power class
/* Purpose : This function returns the mobile power class.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssPowClas (ViSession  instrSession,
                                                                       ViInt32   *mobilePowerClass,
                                                                       ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";

  // Get the Mobile Power Class
  if ((RSCMU_Status = RSCMU_Query (instrSession, "MSS:POW:CLAS?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf,"%d", mobilePowerClass);
  else *mobilePowerClass = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Sense CTM Text Telephony
/* Purpose : This function verifies whether or not the specified file has
/*           been loaded successfully.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssCtt (ViSession instrSession,
                                                 ViInt32 *CTMTextTelephony,
                                                 ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
            
    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V5_00,RSCMU_ERROR_FW_VERSION_5_00));

    sprintf(wrtBuf, "MSS:CTT?");
    
    RETMSG(RSCMU_getEnum(instrSession, wrtBuf,
                            CTMTextTelephony,
                            CTMTextTelephonyArr,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Sense mobile power class
/* Purpose : This function returns a list of the supported GSM, WCDMA and
/*           CDMA2000 bands and the GMSK and 8PSK power classes of the mobile.
/*           If the optional band parameter is omitted, 3 values are returned
/*           for each band. Otherwise, 3 values for the selected band are returned.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssBand (ViSession instrSession,
                                             ViInt32 band, ViChar support[],
                                             ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;
    //ViChar      TableOfDataValues[100][100];
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    sprintf(wrtBuf, "MSS:BAND? %s", bandArr[band]);

    return RSCMU_getViString(instrSession, wrtBuf, support, MID_BUFFER_SIZE, RSCMU_ERROR_PARAMETER3);

    // Get the Mobile Power Class
    //if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    //  return RSCMU_Status;

    // Split the multiple data values separated by a comma:
    //RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

    //strcpy (support, rdBuf);

    //return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Sense mobile power class
/* Purpose : This function returns a list of the supported GSM, WCDMA and
/*           CDMA2000 bands of the mobile.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssSban (ViSession instrSession,
                                             ViChar band[],
                                             ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;
    //ViChar      TableOfDataValues[100][100];

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    //sprintf(wrtBuf, "MSS:SBAN?");

    return RSCMU_getViString(instrSession, "MSS:SBAN?", band, MID_BUFFER_SIZE, RSCMU_ERROR_PARAMETER2);

    // Get the Mobile Power Class
    //if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    //  return RSCMU_Status;

    // Split the multiple data values separated by a comma:
    //RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

    //strcpy (band, rdBuf);

    //return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Sense multislot class circuit switched
/* Purpose : This function is always a query and returns the multislot class
/*           of the mobile while it operates in circuit switched mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssMsclCsw (ViSession  instrSession,
                                                                       ViInt32   *multislotClass,
                                                                       ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";

  // Get the Multislot Class
  if ((RSCMU_Status = RSCMU_Query (instrSession, "MSS:MSCL:CSW?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf,"%d", multislotClass);
  else *multislotClass = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Sense multislot class packet data GPRS
/* Purpose : This function is always a query and returns the multislot class
/*           of the mobile while it operates in packet data GPRS.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssMsclPdatGprs (ViSession  instrSession,
                                                     ViInt32   *multislotClass,
                                                     ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_10, RSCMU_ERROR_FW_VERSION_3_10));

  // Get the Multislot Class
  if ((RSCMU_Status = RSCMU_Query (instrSession, "MSS:MSCL:PDAT:GPRS?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf,"%d", multislotClass);
  else *multislotClass = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Sense multislot class packet data EGPRS
/* Purpose : This function is always a query and returns the multislot class
/*           of the mobile while it operates in packet data EGPRS.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssMsclPdatEgprs (ViSession  instrSession,
                                                      ViInt32   *multislotClass,
                                                      ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_10, RSCMU_ERROR_FW_VERSION_3_10));

  // Get the Multislot Class
  if ((RSCMU_Status = RSCMU_Query (instrSession, "MSS:MSCL:PDAT:EGPR?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf,"%d", multislotClass);
  else *multislotClass = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Rate Set WB
/* Purpose : This function selects four codec modes and define the decision
/*           thresholds for changing the codec mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbFrRSet (ViSession instrSession,
                                                 ViInt32 independentValue,
                                                 ViInt32 codec4,
                                                 ViInt32 codec3,
                                                 ViInt32 codec2,
                                                 ViInt32 codec1,
                                                 ViReal64 down4,
                                                 ViReal64 up3,
                                                 ViReal64 down3,
                                                 ViReal64 up2,
                                                 ViReal64 down2,
                                                 ViReal64 up1,
                                                 ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViString    list[] = {"OFF","C0660","C0885","C1265","C1585","C2385", VI_NULL};
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_23,RSCMU_ERROR_FW_VERSION_4_23));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, independentValue, RSCMU_DEF, RSCMU_CUR, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codec4,RSCMU_OFF,RSCMU_AMR_WB_CODMODE_23_85, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codec3,RSCMU_OFF,RSCMU_AMR_WB_CODMODE_23_85, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codec2,RSCMU_OFF,RSCMU_AMR_WB_CODMODE_23_85, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codec1,RSCMU_OFF,RSCMU_AMR_WB_CODMODE_23_85, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, down4, 0.0, 31.5, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, up3, 0.0, 31.5, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, down3, 0.0, 31.5, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, up2, 0.0, 31.5, RSCMU_ERROR_PARAMETER10, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, down2, 0.0, 31.5, RSCMU_ERROR_PARAMETER11, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, up1, 0.0, 31.5, RSCMU_ERROR_PARAMETER12, errorMessage);

  sprintf (wrtBuf, "%s:NETWork:CSWitched:AMR:WB:FRATe:RSETting %s, %s, %s, %s, %lf, %lf, %lf, %lf, %lf, %lf" ,
                        confProcArr[independentValue],list[codec4],list[codec3],list[codec2],list[codec1],down4, up3, down3, up2, down2, up1);
  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: CMC Stress
/* Purpose : This function sets CMC Stress ON or OFF.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrFrUlcmCstr (ViSession instrSession,
                                                   ViBoolean CMCStress,
                                                   ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:NETW:CSW:AMR:FRAT:ULCM:CSTR", CMCStress, mode_On_Off,
                       RSCMU_ERROR_PARAMETER2));
}   

/*===========================================================================*/
/* Function: CMC Stress WB
/* Purpose : This function sets CMC Stress ON or OFF.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbFrUlcmCstr (ViSession instrSession,
                                                   ViBoolean CMCStress,
                                                   ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:NETW:CSW:AMR:WB:FRAT:ULCM:CSTR", CMCStress, mode_On_Off,
                       RSCMU_ERROR_PARAMETER2));
}   

/*===========================================================================*/
/* Function: Codec Mode Downlink
/* Purpose : This function sets the codec mode that the CMU uses to generate
/*           the speech data transmitted to the MS under test.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrHrECModeDL (ViSession instrSession,
                                                  ViInt32 independentValue,
                                                  ViInt32 codecModeDL,
                                                  ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, independentValue, RSCMU_DEF, RSCMU_CUR, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codecModeDL,1,4, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "%s:NETWork:CSWitched:AMR:HRATe:EPSK:DLCMode %s" , confProcArr[independentValue],codecModeList[codecModeDL]);
  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Codec Mode WB Downlink
/* Purpose : This function sets the codec mode that the CMU uses to generate
/*           the speech data transmitted to the MS under test.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbHrECModeDL (ViSession instrSession,
                                                     ViInt32 independentValue,
                                                     ViInt32 codecModeDL,
                                                     ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_23,RSCMU_ERROR_FW_VERSION_4_23));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, independentValue, RSCMU_DEF, RSCMU_CUR, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codecModeDL,1,3, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "%s:NETW:AMR:WB:HRAT:EPSK:DLCM %s" , confProcArr[independentValue],codecModeList[codecModeDL]);
  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Codec Mode Uplink
/* Purpose : This command sets the codec mode that the mobile under test shall 
/*           use in uplink direction.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrHrECModeUL (ViSession instrSession,
                                                  ViInt32 independentValue,
                                                  ViInt32 codecModeUL,
                                                  ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_20,RSCMU_ERROR_FW_VERSION_3_20));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, independentValue, RSCMU_DEF, RSCMU_CUR, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codecModeUL,1,4, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "%s:NETWork:CSWitched:AMR:HRATe:EPSK:ULCMode %s" , confProcArr[independentValue],codecModeList[codecModeUL]);
  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Codec Mode WB UL
/* Purpose : This function sets the codec mode that the mobile under test
/*           shall use in uplink direction. The setting is valid for Half
/*           Rate AMR wideband speech coder tests with 8PSK modulation.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbHrECModeUL (ViSession instrSession,
                                                     ViInt32 independentValue,
                                                     ViInt32 codecModeUL,
                                                     ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_23,RSCMU_ERROR_FW_VERSION_4_23));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, independentValue, RSCMU_DEF, RSCMU_CUR, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codecModeUL,1,3, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "%s:NETW:AMR:WB:HRAT:EPSK:ULCM %s" , confProcArr[independentValue],codecModeList[codecModeUL]);
  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Rate set
/* Purpose : This function selects four codec modes and define the decision
/* thresholds for changing the codec mode. The settings are valid for EPSK Half Rate
/* AMR speech coder tests. The instrument rejects the settings (SCPI error -221,
/* Settings conflict) unless the values meet all of the following conditions:
/* - The rates must be in descending order so that <CM4> is the
/*   largest bit rate.
/* - Up to 3 codec modes can be switched off. OFF must be the
/*   first values of the parameter list, preceding the used
/*   codec modes.
/* - Thresholds must be in descending order so that
/*   <ThrDown2> =<ThrDown3> =<ThrDown4> and
/*   <ThrUp1> =<ThrUp2> =<ThrUp3>.
/* - The hysteresis must be positive so that Up (j) =Down (j + 1)
/*   for j= 
1 to 3
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrHrERSet (ViSession instrSession,
                                               ViInt32 independentValue,
                                               ViInt32 codecMode4,
                                               ViInt32 codecMode3,
                                               ViInt32 codecMode2,
                                               ViInt32 codecMode1,
                                               ViReal64 thresholdDown4,
                                               ViReal64 thresholdUp3,
                                               ViReal64 thresholdDown3,
                                               ViReal64 thresholdUp2,
                                               ViReal64 thresholdDown2,
                                               ViReal64 thresholdUp1,
                                               ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViString    list[] = {"OFF","C0475","C0515","C0590","C0670","C0740","C0795","C1020","C1220",  VI_NULL};
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, independentValue, RSCMU_DEF, RSCMU_CUR, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codecMode4,RSCMU_OFF,RSCMU_AMR_CODMODE_12_2, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codecMode3,RSCMU_OFF,RSCMU_AMR_CODMODE_12_2, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codecMode2,RSCMU_OFF,RSCMU_AMR_CODMODE_12_2, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codecMode1,RSCMU_OFF,RSCMU_AMR_CODMODE_12_2, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, thresholdDown4, 0.0, 31.5, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, thresholdUp3, 0.0, 31.5, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, thresholdDown3, 0.0, 31.5, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, thresholdUp2, 0.0, 31.5, RSCMU_ERROR_PARAMETER10, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, thresholdDown2, 0.0, 31.5, RSCMU_ERROR_PARAMETER11, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, thresholdUp1, 0.0, 31.5, RSCMU_ERROR_PARAMETER12, errorMessage);

  sprintf (wrtBuf, "%s:NETWork:CSWitched:AMR:HRATe:EPSK:RSETting %s, %s, %s, %s, %lf, %lf, %lf, %lf, %lf, %lf" ,
                        confProcArr[independentValue],list[codecMode4],list[codecMode3],list[codecMode2],list[codecMode1],thresholdDown4, thresholdUp3, thresholdDown3, thresholdUp2, thresholdDown2, thresholdUp1);
  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Rate set
/* Purpose : This function selects four codec modes and define the decision
/*           thresholds for changing the codec mode. The settings are valid
/*           for Half Rate 8PSK AMR wideband speech coder tests.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbHrERSet (ViSession instrSession,
                                                  ViInt32 independentValue,
                                                  ViInt32 codec4,
                                                  ViInt32 codec3,
                                                  ViInt32 codec2,
                                                  ViInt32 codec1,
                                                  ViReal64 down4,
                                                  ViReal64 up3,
                                                  ViReal64 down3,
                                                  ViReal64 up2,
                                                  ViReal64 down2,
                                                  ViReal64 up1,
                                                  ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViString    list[] = {"OFF","C0660","C0885","C1265","C1585","C2385", VI_NULL};
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, independentValue, RSCMU_DEF, RSCMU_CUR, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codec4,RSCMU_OFF,RSCMU_AMR_WB_CODMODE_23_85, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codec3,RSCMU_OFF,RSCMU_AMR_WB_CODMODE_23_85, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codec2,RSCMU_OFF,RSCMU_AMR_WB_CODMODE_23_85, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codec1,RSCMU_OFF,RSCMU_AMR_WB_CODMODE_23_85, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, down4, 0.0, 31.5, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, up3, 0.0, 31.5, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, down3, 0.0, 31.5, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, up2, 0.0, 31.5, RSCMU_ERROR_PARAMETER10, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, down2, 0.0, 31.5, RSCMU_ERROR_PARAMETER11, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, up1, 0.0, 31.5, RSCMU_ERROR_PARAMETER12, errorMessage);

  sprintf (wrtBuf, "%s:NETW:AMR:WB:HRAT:EPSK:RSET %s, %s, %s, %s, %lf, %lf, %lf, %lf, %lf, %lf" ,
                        confProcArr[independentValue],list[codec4],list[codec3],list[codec2],list[codec1],down4, up3, down3, up2, down2, up1);
  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: CMC Stress 
/* Purpose : This function sets CMC Stress ON or OFF.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrHrEUlcmCstr (ViSession instrSession,
                                                   ViBoolean CMCStress,
                                                   ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:NETW:CSW:AMR:HRAT:EPSK:ULCM:CSTR", CMCStress, mode_On_Off,
                       RSCMU_ERROR_PARAMETER2));
}   

/*===========================================================================*/
/* Function: CMC Stress WB
/* Purpose : This function sets CMC Stress ON or OFF.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbHrEUlcmCstr (ViSession instrSession,
                                                   ViBoolean CMCStress,
                                                   ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:NETW:CSW:AMR:WB:HRAT:EPSK:ULCM:CSTR", CMCStress, mode_On_Off,
                       RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Codec Mode WB Downlink
/* Purpose : This function sets codec mode that the CMU uses to generate the
/*           speech data transmitted to the MS under test. The setting is
/*           valid for Full Rate AMR wideband speech coder tests with 8PSK
/*           modulation
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbFrECModeDL (ViSession instrSession,
                                                     ViInt32 independentValue,
                                                     ViInt32 codecModeDL,
                                                     ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_23,RSCMU_ERROR_FW_VERSION_4_23));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, independentValue, RSCMU_DEF, RSCMU_CUR, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codecModeDL,1,3, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "%s:NETW:AMR:WB:FRAT:EPSK:DLCM %s" , confProcArr[independentValue],codecModeList[codecModeDL]);
  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Codec Mode WB Uplink
/* Purpose : This function sets the codec mode that the mobile under test
/*           shall use in uplink direction. The setting is valid for Full
/*           Rate AMR wideband speech coder tests with 8PSK modulation.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbFrECModeUL (ViSession instrSession,
                                                     ViInt32 independentValue,
                                                     ViInt32 codecModeUL,
                                                     ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_23,RSCMU_ERROR_FW_VERSION_4_23));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, independentValue, RSCMU_DEF, RSCMU_CUR, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codecModeUL,1,3, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "%s:NETW:AMR:WB:FRAT:EPSK:ULCM %s" , confProcArr[independentValue],codecModeList[codecModeUL]);
  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Rate set
/* Purpose : This function selects four codec modes and define the decision
/*           thresholds for changing the codec mode. The settings are valid
/*           for Half Rate 8PSK AMR wideband speech coder tests.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbFrECSet (ViSession instrSession,
                                                  ViInt32 independentValue,
                                                  ViInt32 codec4,
                                                  ViInt32 codec3,
                                                  ViInt32 codec2,
                                                  ViInt32 codec1,
                                                  ViReal64 down4,
                                                  ViReal64 up3,
                                                  ViReal64 down3,
                                                  ViReal64 up2,
                                                  ViReal64 down2,
                                                  ViReal64 up1,
                                                  ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViString    list[] = {"OFF","C0660","C0885","C1265","C1585","C2385", VI_NULL};
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_23,RSCMU_ERROR_FW_VERSION_4_23));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, independentValue, RSCMU_DEF, RSCMU_CUR, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codec4,RSCMU_OFF,RSCMU_AMR_WB_CODMODE_23_85, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codec3,RSCMU_OFF,RSCMU_AMR_WB_CODMODE_23_85, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codec2,RSCMU_OFF,RSCMU_AMR_WB_CODMODE_23_85, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codec1,RSCMU_OFF,RSCMU_AMR_WB_CODMODE_23_85, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, down4, 0.0, 31.5, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, up3, 0.0, 31.5, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, down3, 0.0, 31.5, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, up2, 0.0, 31.5, RSCMU_ERROR_PARAMETER10, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, down2, 0.0, 31.5, RSCMU_ERROR_PARAMETER11, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, up1, 0.0, 31.5, RSCMU_ERROR_PARAMETER12, errorMessage);

  sprintf (wrtBuf, "%s:NETW:AMR:WB:FRAT:EPSK:RSET %s, %s, %s, %s, %lf, %lf, %lf, %lf, %lf, %lf" ,
                        confProcArr[independentValue],list[codec4],list[codec3],list[codec2],list[codec1],down4, up3, down3, up2, down2, up1);
  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: CMC Stress WB
/* Purpose : This function sets CMC Stress ON or OFF.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbFrEUlcmCstr (ViSession instrSession,
                                                   ViBoolean CMCStress,
                                                   ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:NETW:CSW:AMR:WB:FRAT:EPSK:ULCM:CSTR", CMCStress, mode_On_Off,
                       RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Sense AMR Full Rate Codec Mode Downlink
/* Purpose : This function is always a query and returns the codec mode that
/*           the MS requests according to the AMR Rate Set settings.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrFrDl (ViSession instrSession,
                                                ViInt32 *codecMode,
                                                ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_20, RSCMU_ERROR_FW_VERSION_3_20));

  // Get the Codec Mode
  CHECKRETMSG(RSCMU_getViString(instrSession,"SENSe:MSSinfo:AMR:FRATe:DLCMode?",rdBuf,RD_BUFFER_SIZE,0));

  if      (strncmp (rdBuf,"CM1", 3) == 0)
    *codecMode = 1;
  else if (strncmp (rdBuf,"CM2", 3) == 0)
    *codecMode = 2;
  else if (strncmp (rdBuf,"CM3", 3) == 0)
    *codecMode = 3;
  else if (strncmp (rdBuf,"CM4", 3) == 0)
    *codecMode = 4;
  else if (strcmp (rdBuf, "NAN") == 0)
    *codecMode = RSCMU_NAN_VI_INT32;


  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Codec Mode WB Downlink
/* Purpose : This function is always a query and returns the codec mode that
/*           the MS requests according to the AMR Rate Set settings.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrWbFrDl (ViSession instrSession,
                                                  ViInt32 *codecMode,
                                                  ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    GET_RD_BUF(instrSession);

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_23,RSCMU_ERROR_FW_VERSION_4_23));

    // Get the Codec Mode
    CHECKRETMSG(RSCMU_getViString(instrSession,"MSS:AMR:WB:FRAT:DLCM?",rdBuf,RD_BUFFER_SIZE,0));

    if      (strncmp (rdBuf,"CM1", 3) == 0)
    *codecMode = 1;
    else if (strncmp (rdBuf,"CM2", 3) == 0)
    *codecMode = 2;
    else if (strncmp (rdBuf,"CM3", 3) == 0)
    *codecMode = 3;
    else if (strncmp (rdBuf,"CM4", 3) == 0)
    *codecMode = 4;
    else if (strncmp (rdBuf, "NAN",3) == 0)
    *codecMode = RSCMU_NAN_VI_INT32;
    
    RETMSG (RSCMU_Status);
}

/*===========================================================================*/
/* Function: Codec Mode WB Uplink
/* Purpose : This function returns the codec mode used by MS.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrWbFrUl (ViSession instrSession,
                                                  ViInt32 *codecMode,
                                                  ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    GET_RD_BUF(instrSession);

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_23,RSCMU_ERROR_FW_VERSION_4_23));

    // Get the Codec Mode
    CHECKRETMSG(RSCMU_getViString(instrSession,"MSS:AMR:WB:FRAT:ULCM?",rdBuf,RD_BUFFER_SIZE,0));

    if      (strncmp (rdBuf,"CM1", 3) == 0)
    *codecMode = 1;
    else if (strncmp (rdBuf,"CM2", 3) == 0)
    *codecMode = 2;
    else if (strncmp (rdBuf,"CM3", 3) == 0)
    *codecMode = 3;
    else if (strncmp (rdBuf,"CM4", 3) == 0)
    *codecMode = 4;
    else if (strncmp (rdBuf, "NAN",3) == 0)
    *codecMode = RSCMU_NAN_VI_INT32;
    
    RETMSG (RSCMU_Status);
}

/*===========================================================================*/
/* Function: Sense AMR Full Rate Codec Mode Uplink
/* Purpose : This function is always a query and returns the actual UL codec mode
/*           used by the MS, irrespective of the commanded codec mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrFrUl (ViSession instrSession,
                                                ViInt32 *codecMode,
                                                ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_20, RSCMU_ERROR_FW_VERSION_3_20));

  // Get the Codec Mode
  CHECKRETMSG(RSCMU_getViString(instrSession,"SENSe:MSSinfo:AMR:FRATe:ULCMode?",rdBuf,RD_BUFFER_SIZE,0));

  if      (strncmp (rdBuf,"CM1", 3) == 0)
    *codecMode = 1;
  else if (strncmp (rdBuf,"CM2", 3) == 0)
    *codecMode = 2;
  else if (strncmp (rdBuf,"CM3", 3) == 0)
    *codecMode = 3;
  else if (strncmp (rdBuf,"CM4", 3) == 0)
    *codecMode = 4;
  else if (strncmp (rdBuf, "NAN",3) == 0)
    *codecMode = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Sense AMR Half Rate Codec Mode Downlink
/* Purpose : This function is always a query and returns the codec mode that
/*           the MS requests according to the AMR Rate Set settings.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrHrDl (ViSession instrSession,
                                                ViInt32 *codecMode,
                                                ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_20, RSCMU_ERROR_FW_VERSION_3_20));

  // Get the Codec Mode
  CHECKRETMSG(RSCMU_getViString(instrSession,"SENSe:MSSinfo:AMR:HRATe:DLCMode?",rdBuf,RD_BUFFER_SIZE,0));

  if      (strncmp (rdBuf,"CM1", 3) == 0)
    *codecMode = 1;
  else if (strncmp (rdBuf,"CM2", 3) == 0)
    *codecMode = 2;
  else if (strncmp (rdBuf,"CM3", 3) == 0)
    *codecMode = 3;
  else if (strncmp (rdBuf,"CM4", 3) == 0)
    *codecMode = 4;
  else if (strncmp (rdBuf, "NAN",3) == 0)
    *codecMode = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Sense AMR Half Rate Codec Mode Uplink
/* Purpose : This function is always a query and returns the actual UL codec mode
/*           used by the MS, irrespective of the commanded codec mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrHrUl (ViSession instrSession,
                                                ViInt32 *codecMode,
                                                ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_20, RSCMU_ERROR_FW_VERSION_3_20));

  // Get the Codec Mode
  CHECKRETMSG(RSCMU_getViString(instrSession,"SENSe:MSSinfo:AMR:HRATe:ULCMode?",rdBuf,RD_BUFFER_SIZE,0));

  if      (strncmp (rdBuf,"CM1", 3) == 0)
    *codecMode = 1;
  else if (strncmp (rdBuf,"CM2", 3) == 0)
    *codecMode = 2;
  else if (strncmp (rdBuf,"CM3", 3) == 0)
    *codecMode = 3;
  else if (strncmp (rdBuf,"CM4", 3) == 0)
    *codecMode = 4;
  else if (strcmp (rdBuf,"NAN") == 0)
    *codecMode = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}


/*
 *-----------------------------------------------------------------------------
 *    I/Q-IF Interface
 *    The subsystem IQIF configures the signal paths for I/Q and IF signals
 *    provided by option CMU-B17, I/Q and IF Interfaces.
 *    It corresponds to the I/Q-IF tab of the Connection Control menu.
 * ----------------------------------------------------------------------------
 */

/*===========================================================================*/
/* Function: I/Q-IF
/* Purpose : This I/Q-IF parameter sets the both RX and TX path
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_SigNSig_ConfIQIFRXTX (ViSession instrSession,
                                                    ViInt32 iqif,
                                                     ViChar errorMessage[])
{
    ViString    list[] = {"BYP","BYIQ","XOIO","IOIO","IOXO","FPAT","UDEF", VI_NULL};
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:IQIF:RXTX",
                         iqif, list,
                         RSCMU_ERROR_PARAMETER2));
}


/*===========================================================================*/
/* Function: I/Q-IF RX Path
/* Purpose : This I/Q-IF parameter sets the RX path
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_SigNSig_ConfIQIFRXPath (ViSession instrSession,
                                                      ViInt32 RXPath,
                                                       ViChar errorMessage[])
{
    ViString    list[] = {"BYP","BYIQ","XOIO","IOIO","IOXO", VI_NULL};
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:IQIF:RXP",
                         RXPath, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: I/Q-IF TX Path
/* Purpose : This I/Q-IF parameter sets the TX path
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_SigNSig_ConfIQIFTXPath (ViSession instrSession,
                                                      ViInt32 TXPath,
                                                       ViChar errorMessage[])
{
    ViString    list[] = {"BYP","BYIQ","XOIO","IOIO","IOXO", VI_NULL};
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:IQIF:TXP",
                         TXPath, list,
                         RSCMU_ERROR_PARAMETER2));
}


/*
 *-----------------------------------------------------------------------------
 *    POWER DURING CALL SETUP
 *    The subsystem WPOWer contains the commands for measuring the
 *    power of the signal sent by the mobile phone.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Init Measurements
/* Purpose : This function start the measurement,
/*           setting it to the status beyond.
/*           RUN        Start measurement without waiting
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_InitSpow (ViSession instrSession,
                                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Version Manager
  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V2_15)
  {
    if ((RSCMU_Status = RSCMU_Query (instrSession, "INIT:WPOW", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
      return RSCMU_Status;
  }
  else
    if ((RSCMU_Status = RSCMU_Query (instrSession, "INIT:SPOW", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
      return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Abort Measurements
/* Purpose : This function abort running signal-power measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborSpow (ViSession instrSession,
                                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Version Manager
  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V2_15)
  {
    if ((RSCMU_Status = RSCMU_Query (instrSession, "ABOR:WPOW", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
      return RSCMU_Status;
  }
  else
    if ((RSCMU_Status = RSCMU_Query (instrSession, "ABOR:SPOW", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
      return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Stop Measurements
/* Purpose : This function stop measurement after current statistic cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopSpow (ViSession instrSession,
                                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Version Manager
  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V2_15)
  {
    if ((RSCMU_Status = RSCMU_Query (instrSession, "STOP:WPOW", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
      return RSCMU_Status;
  }
  else
    if ((RSCMU_Status = RSCMU_Query (instrSession, "STOP:SPOW", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
      return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Run Next Measurement Step
/* Purpose : This function runs next signal-power measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContSpow (ViSession instrSession,
                                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Version Manager
  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V2_15)
  {
    if ((RSCMU_Status = RSCMU_Query (instrSession, "CONT:WPOW", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
      return RSCMU_Status;
  }
  else
    if ((RSCMU_Status = RSCMU_Query (instrSession, "CONT:SPOW", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
      return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpowErep (ViSession  instrSession,
                                                                     ViInt32    Mode,
                                                                     ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"OFF","SRQ","SOPC","SRSQ"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Version Manager
  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V2_15)
    sprintf (wrtBuf, "CONF:WPOW:EREP %s", StrMode[Mode]);
  else
    sprintf (wrtBuf, "CONF:SPOW:EREP %s", StrMode[Mode]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Wideband Power Measurement Status
/* Purpose : This function returns the status of the current wideband power
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSpowStat (ViSession  instrSession,
                                                                     ViInt32    *MeasurementStatus,
                                                                     ViInt32    *CountingNo,
                                                                     ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Fetch the status of the wideband power measurement:
  // Version Manager
  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V2_15)
  {
    if ((RSCMU_Status = RSCMU_Query (instrSession, "FETC:WPOW:STAT?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
      return RSCMU_Status;
  }
  else
    if ((RSCMU_Status = RSCMU_Query (instrSession, "FETC:SPOW:STAT?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
      return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Get the status of the measurement:
  if ((RSCMU_Status = RSCMU_GetMeasStatVal (MeasurementStatus, TableOfDataValues, 0)) < 0)
    return RSCMU_Status;

  // Get the current value of the statistics counter (the number of the current statistics cycle):
  if ((RSCMU_Status = RSCMU_GetCountingNo (CountingNo, TableOfDataValues, 1)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: DTM GPRS
/* Purpose : This function returns the DTM multislot class of a mobile.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssMsclDtmGprs (ViSession instrSession,
                                                    ViInt32 *multislotClass,
                                                    ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE] = "";

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));

    // Get the Multislot Class
    if ((RSCMU_Status = RSCMU_Query (instrSession, "MSS:MSCL:DTM?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;

    if (strncmp (rdBuf, "NAN", 3) != 0)
        sscanf (rdBuf,"CL%d", multislotClass);
    else *multislotClass = RSCMU_NAN_VI_INT32;

    return RSCMU_Status;
}

/*===========================================================================*/
/* Function: DTM EGPRS
/* Purpose : This function returns the DTM multislot class of a mobile.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssMsclDtmEgprs (ViSession instrSession,
                                                     ViInt32 *multislotClass,
                                                     ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE] = "";

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));

    // Get the Multislot Class
    if ((RSCMU_Status = RSCMU_Query (instrSession, "MSS:MSCL:DTM:EGPR?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;

    if (strncmp (rdBuf, "NAN", 3) != 0)
        sscanf (rdBuf,"CL%d", multislotClass);
    else *multislotClass = RSCMU_NAN_VI_INT32;

    return RSCMU_Status;
}

/*===========================================================================*/
/* Function: GMSK Power Class
/* Purpose : This function returns he GPRS or EGPRS power classes of the mobile.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssPowClasGmsk (ViSession instrSession,
                                                    ViInt32 *powerClass,
                                                    ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE] = "";

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));

    // Get the Multislot Class
    if ((RSCMU_Status = RSCMU_Query (instrSession, "MSS:POW:CLAS?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;

    if (strncmp (rdBuf, "INV", 3) != 0)
        sscanf (rdBuf,"%d", powerClass);
    else *powerClass = RSCMU_INV;

    return RSCMU_Status;
}

/*===========================================================================*/
/* Function: EPSK Power Class
/* Purpose : This function returns he GPRS or EGPRS power classes of the mobile.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssPowClasEpsk (ViSession instrSession,
                                                    ViInt32 *powerClass,
                                                    ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE] = "";

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));

    // Get the Multislot Class
    if ((RSCMU_Status = RSCMU_Query (instrSession, "MSS:POW:CLAS:EPSK?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;

    if (strncmp (rdBuf, "INV", 3) != 0)
        sscanf (rdBuf,"E%d", powerClass);
    else *powerClass = RSCMU_INV;

    return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpowContRep (ViSession instrSession,
                                                                       ViInt32   Repetition,
                                                                       ViInt32   StopCondition,
                                                                       ViInt32   StepMode,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) Repetition, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Configure tests cycles:
  // Version Manager
  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V2_15)
    sprintf (wrtBuf, "CONF:WPOW:CONT:REP %s,%s,%s", StrRepetition[Repetition], StrStopCondition[StopCondition], StrStepMode[StepMode]);
  else
    sprintf (wrtBuf, "CONF:SPOW:CONT:REP %s,%s,%s", StrRepetition[Repetition], StrStopCondition[StopCondition], StrStepMode[StepMode]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Meas. Peak Burst Power
/* Purpose : This function starts the measurement of the maximum burst
/*           power of the signals sent by the mobile (peak burst power)
/*           and outputs the result.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSpow (ViSession instrSession,
                                                                ViReal64 *MaxBurstPower,
                                                                ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Version Manager
  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V2_15)
  {
    if ((RSCMU_Status = RSCMU_Query (instrSession, "READ:WPOW?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
      return RSCMU_Status;
  }
  else
    if ((RSCMU_Status = RSCMU_Query (instrSession, "READ:SPOW?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
      return RSCMU_Status;

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf, "%lf", MaxBurstPower);
  else
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_NAN, errorMessage);

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Meas. Peak Burst Power
/* Purpose : This function starts the measurement of the maximum burst
/*           power of the signals sent by the mobile (peak burst power)
/*           and outputs the result.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSpow (ViSession instrSession,
                                                                ViReal64 *MaxBurstPower,
                                                                ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Version Manager
  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V2_15)
  {
    if ((RSCMU_Status = RSCMU_Query (instrSession, "FETC:WPOW?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
      return RSCMU_Status;
  }
  else
    if ((RSCMU_Status = RSCMU_Query (instrSession, "FETC:SPOW?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
      return RSCMU_Status;

  // Extract the CMU_response
  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf, "%lf", MaxBurstPower);
  else
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_NAN, errorMessage);

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Meas. Peak Burst Power
/* Purpose : This function starts the measurement of the maximum burst
/*           power of the signals sent by the mobile (peak burst power)
/*           and outputs the result.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSpow (ViSession instrSession,
                                                                ViReal64 *MaxBurstPower,
                                                                ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Version Manager
  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V2_15)
  {
    if ((RSCMU_Status = RSCMU_Query (instrSession, "SAMP:WPOW?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
      return RSCMU_Status;
  }
  else
    if ((RSCMU_Status = RSCMU_Query (instrSession, "SAMP:SPOW?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
      return RSCMU_Status;

  // Extract the CMU_response
  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf, "%lf", MaxBurstPower);
  else
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_NAN, errorMessage);

  return RSCMU_Status;
}
/*
 *-----------------------------------------------------------------------------
 *    STATISTICS
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpowContRepStat (ViSession  instrSession,
                                                                            ViInt32    NbRepetition,
                                                                            ViInt32    StopCondition,
                                                                            ViInt32    StepMode,
                                                                            ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU_MULT_MEAS_MIN, RSCMU_MULT_MEAS_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Configure tests cycles:
  // Version Manager
  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V2_15)
    sprintf (wrtBuf, "CONF:WPOW:CONT:REP %d,%s,%s", NbRepetition, StrStopCondition[StopCondition], StrStepMode[StepMode]);
  else
    sprintf (wrtBuf, "CONF:SPOW:CONT:REP %d,%s,%s", NbRepetition, StrStopCondition[StopCondition], StrStepMode[StepMode]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*
 *-----------------------------------------------------------------------------
 * MEASUREMENT OBJECT NARROW-BAND POWER
 *
 * The subsystem NPOWer measures the power of the signal transmitted by the
 * mobile phone using the RF analyzer configuration of the POWer measurement.
 * Compared to WPOWer, the NPOWer measurement uses a narrow-band (500 kHz Gauss)
 * filter. The narrow-band NPOWer measurement yields the average, maximum and
 * minimum burst power of the current burst (display mode Current) and of the
 * averaged measurement curve (display mode Average).
 * The entire measurement curves (arrays) are not available, and no limit check
 * is performed. NPOWer is a quick and precise alternative to the WPOWer or
 * POWer measurements if only scalar results are needed.
 * Note: A Free Run trigger (TRIGger[:SEQuence]:SOURce FRUN) should be avoided
 * because it delays the NPOWer measurement.
 * ----------------------------------------------------------------------------
 *      MEASUREMENT CONTROL
 *      This subsystem contains the functions for general control of the
 *      narrow-band power measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start new measurement
/* Purpose : This function starts the narrow-band power measurement, setting it
/*           to the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_InitNpow (ViSession instrSession,
                                                                 ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_NPOW, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Abort running measurement and switch off
/* Purpose : This function stops the narrow-band power measurement, setting it
/*           to the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborNpow (ViSession instrSession,
                                                                 ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_NPOW, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: stop measurement after current statistic cycle
/* Purpose : This function stops the narrow-band power measurement, setting it
/*           to the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopNpow (ViSession instrSession,
                                                                 ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_NPOW, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Next Measurement Step
/* Purpose : This function continues the narrow-band power measurement, setting
/*           it to the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContNpow (ViSession instrSession,
                                                                 ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_NPOW, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the measurement
/*           is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNpowErep (ViSession  instrSession,
                                                                     ViInt32    Report,
                                                                     ViChar     errorMessage[])
{
  return RSCMU_ConfReporting (instrSession, RSCMU_NPOW, RSCMU_NONE, Report, errorMessage);
}

/*===========================================================================*/
/* Function: Power/t Measurement Status
/* Purpose : This function returns the status of the current narrow-band power
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcNpowStat (ViSession  instrSession,
                                                                     ViInt32   *MeasurementStatus,
                                                                     ViInt32   *CountingNo,
                                                                     ViInt32   *StatisticNo,
                                                                     ViChar     errorMessage[])
{
  return RSCMU_FetcStatus (instrSession, RSCMU_NPOW, RSCMU_GMSK, MeasurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of Measurement
/* Purpose : This function selects the type of measured values and determines
/*           the number of bursts forming one statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNpowCont (ViSession instrSession,
                                                                     ViInt32   NbBurst,
                                                                     ViInt32   repetition,
                                                                     ViInt32   NbRepetition,
                                                                     ViInt32   StopCondition,
                                                                     ViInt32   StepMode,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_ConfNpowCont (instrSession, NbBurst, repetition, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNpowContRep (ViSession  instrSession,
                                                                        ViInt32    Repetition,
                                                                        ViInt32    StopCondition,
                                                                        ViInt32    StepMode,
                                                                        ViChar     errorMessage[])
{
  return RSCMU_ConfControlRep (instrSession, RSCMU_NPOW, RSCMU_NONE, Repetition, StopCondition, StepMode, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Statistic Count
/* Purpose : This function selects the type of measured values and determines
/*           the number of bursts forming one statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNpowContStat (ViSession instrSession,
                                                                         ViInt32   NbBurst,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version Manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_07, errorMessage);

  // Check if the calling function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NbBurst, 1, 1000, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf, "CONF:NPOW:CONT:STAT %d", NbBurst);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNpowContRepStat (ViSession instrSession,
                                                                            ViInt32   NbRepetition,
                                                                            ViInt32   StopCondition,
                                                                            ViInt32   StepMode,
                                                                            ViChar    errorMessage[])
{
  return RSCMU_ConfContRepStat (instrSession, RSCMU_NPOW, RSCMU_NONE, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      RESULTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Read Scalar
/* Purpose : This function starts the NPOWer measurement and returns the
/*           results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadNpow (ViSession  instrSession,
                                                                 ViReal64  *AvgPowCurr,
                                                                 ViReal64  *MinPowCurr,
                                                                 ViReal64  *MaxPowCurr,
                                                                 ViReal64  *AvgPowAvg,
                                                                 ViReal64  *MinPowAvg,
                                                                 ViReal64  *MaxPowAvg,
                                                                 ViChar     errorMessage[])
{
  return RSCMU_MeasNpow (instrSession, RSCMU_COMMAND_READ, AvgPowCurr, MinPowCurr, MaxPowCurr,
    AvgPowAvg, MinPowAvg, MaxPowAvg, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Scalar
/* Purpose : This function reads out measurements (unsynchronized) and returns
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcNpow (ViSession  instrSession,
                                                                 ViReal64  *AvgPowCurr,
                                                                 ViReal64  *MinPowCurr,
                                                                 ViReal64  *MaxPowCurr,
                                                                 ViReal64  *AvgPowAvg,
                                                                 ViReal64  *MinPowAvg,
                                                                 ViReal64  *MaxPowAvg,
                                                                 ViChar     errorMessage[])
{
  return RSCMU_MeasNpow (instrSession, RSCMU_COMMAND_FETC, AvgPowCurr, MinPowCurr, MaxPowCurr,
    AvgPowAvg, MinPowAvg, MaxPowAvg, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Scalar
/* Purpose : This function reads out measurements (synchronized) and returns
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampNpow (ViSession  instrSession,
                                                                 ViReal64  *AvgPowCurr,
                                                                 ViReal64  *MinPowCurr,
                                                                 ViReal64  *MaxPowCurr,
                                                                 ViReal64  *AvgPowAvg,
                                                                 ViReal64  *MinPowAvg,
                                                                 ViReal64  *MaxPowAvg,
                                                                 ViChar     errorMessage[])
{
  return RSCMU_MeasNpow (instrSession, RSCMU_COMMAND_SAMP, AvgPowCurr, MinPowCurr, MaxPowCurr,
    AvgPowAvg, MinPowAvg, MaxPowAvg, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT POWER/T
 *    This subsystem POWer contains the functions for measurement of
 *    the signal power.
 *    It corresponds to the measurement menu Power versus Time and the
 *    associated popup menu Power vs Time Configuration.
 * ----------------------------------------------------------------------------
 *      CONTROL OF POWER MEASUREMENT
 *      This subsystem contains the functions for general control of the
 *      power measurement.
 *-----------------------------------------------------------------------------
 */

/*===========================================================================*/
/* Function: StartMeasurements
/* Purpose : This function start measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_InitPow (ViSession instrSession,
                                                                ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_POW, RSCMU_GMSK, errorMessage);
}

/*===========================================================================*/
/* Function: StartMeasurements
/* Purpose : This function start measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborPow (ViSession instrSession,
                                                                ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_POW, RSCMU_GMSK, errorMessage);
}

/*===========================================================================*/
/* Function: StartMeasurements
/* Purpose : This function start measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopPow (ViSession instrSession,
                                                                ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_POW, RSCMU_GMSK, errorMessage);
}
/*===========================================================================*/
/* Function: StartMeasurements
/* Purpose : This function start measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContPow (ViSession instrSession,
                                                                ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_POW, RSCMU_GMSK, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowErep (ViSession  instrSession,
                                                                    ViInt32    Report,
                                                                    ViChar     errorMessage[])
{
  return RSCMU_ConfReporting (instrSession, RSCMU_POW, RSCMU_GMSK, Report, errorMessage);
}

/*===========================================================================*/
/* Function: Power/t Measurement Status
/* Purpose : This function returns the status of the current Power/t
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowStat (ViSession  instrSession,
                                                                    ViInt32    *MeasurementStatus,
                                                                    ViInt32    *CountingNo,
                                                                    ViInt32    *StatisticNo,
                                                                    ViChar     errorMessage[])
{
  return RSCMU_FetcStatus (instrSession, RSCMU_POW, RSCMU_GMSK, MeasurementStatus, CountingNo, StatisticNo, errorMessage);
}
/*
 *-----------------------------------------------------------------------------
 *      CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of Measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowCont (ViSession instrSession,
                                                                    ViInt32   MeasuredValuesType,
                                                                    ViInt32   NbBurst,
                                                                    ViChar    errorMessage[])
{
  return RSCMU_ConfControl (instrSession, RSCMU_POW, RSCMU_GMSK, MeasuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowContRep (ViSession  instrSession,
                                                                       ViInt32    Repetition,
                                                                       ViInt32    StopCondition,
                                                                       ViInt32    StepMode,
                                                                       ViChar     errorMessage[])
{
  return RSCMU_ConfControlRep (instrSession, RSCMU_POW, RSCMU_GMSK, Repetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Set Grid (ON/OFF)
/* Purpose : This function switches the grid lines in the test diagrams
/*           on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_DispPowContGrid (ViSession instrSession,
                                                                        ViInt32   gridLines,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) gridLines, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DISP:POW:CONT:GRID %s", mode_On_Off[gridLines]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*
 *-----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Statistics Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowContRepStat (ViSession  instrSession,
                                                                           ViInt32    NbRepetition,
                                                                           ViInt32    StopCondition,
                                                                           ViInt32    StepMode,
                                                                           ViChar     errorMessage[])
{
  return RSCMU_ConfPowContRepStat(instrSession, RSCMU_GMSK, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      STATISTICS
 *      The functions of the following subsystems define the parameters
 *      of the signal power measurement. GSM signals are transferred in
 *      the form of bursts, which are divided up into different
 *      tolerance ranges according to the standard.
 *-----------------------------------------------------------------------------
 *        LIMIT LINES
 *-----------------------------------------------------------------------------
 */

/*===========================================================================*/
/* Function: Set Default limit Lines (ON/OFF)
/* Purpose : This function switches the default limit lines on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowLimLineDef (ViSession  instrSession,
                                                                          ViInt32    DefaultLimitLines,
                                                                          ViChar     errorMessage[])
{

  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, DefaultLimitLines, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:POW:LIM:LINE:DEF %s", mode_On_Off[DefaultLimitLines]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Upper limit Line
/* Purpose : This function activates and defines upper limit lines for normal
/*           bursts. The limit lines are defined section by section.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowLimLineUpp (ViSession instrSession,
                                                                          ViInt32   Area,
                                                                          ViInt32   StartTimeOnOff,
                                                                          ViReal64  StartTime,
                                                                          ViInt32   EndTimeOnOff,
                                                                          ViReal64  EndTime,
                                                                          ViInt32   StartRelLevOnOff,
                                                                          ViReal64  StartRelLev,
                                                                          ViInt32   EndRelLevOnOff,
                                                                          ViReal64  EndRelLev,
                                                                          ViInt32   StartAbsLevOnOff,
                                                                          ViReal64  StartAbsLev,
                                                                          ViInt32   EndAbsLevOnOff,
                                                                          ViReal64  EndAbsLev,
                                                                          ViInt32   Visibility,
                                                                          ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_ConfPowLimLineUpp (instrSession, Area, StartTimeOnOff, StartTime, EndTimeOnOff, EndTime,
    StartRelLevOnOff, StartRelLev, EndRelLevOnOff, EndRelLev, StartAbsLevOnOff, StartAbsLev, EndAbsLevOnOff, EndAbsLev, Visibility, errorMessage);
}

/*===========================================================================*/
/* Function: Upper limit Line
/* Purpose : This function activates and defines lower limit lines for normal
/*           bursts. The limit lines are defined section by section.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowLimLineLow (ViSession instrSession,
                                                                          ViInt32   Area,
                                                                          ViInt32   StartTimeOnOff,
                                                                          ViReal64  StartTime,
                                                                          ViInt32   EndTimeOnOff,
                                                                          ViReal64  EndTime,
                                                                          ViInt32   StartRelLevOnOff,
                                                                          ViReal64  StartRelLev,
                                                                          ViInt32   EndRelLevOnOff,
                                                                          ViReal64  EndRelLev,
                                                                          ViInt32   StartAbsLevOnOff,
                                                                          ViReal64  StartAbsLev,
                                                                          ViInt32   EndAbsLevOnOff,
                                                                          ViReal64  EndAbsLev,
                                                                          ViInt32   Visibility,
                                                                          ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_ConfPowLimLineLow (instrSession, Area, StartTimeOnOff, StartTime, EndTimeOnOff, EndTime,
    StartRelLevOnOff, StartRelLev, EndRelLevOnOff, EndRelLev, StartAbsLevOnOff, StartAbsLev, EndAbsLevOnOff, EndAbsLev, Visibility, errorMessage);
}

/*===========================================================================*/
/* Function: Dynamic Correction of Upper limit Line
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowLimLineUppDyn (ViSession instrSession,
                                                                             ViInt32   Area,
                                                                             ViInt32   TPCLRange,
                                                                             ViInt32   FromTPCLOnOff,
                                                                             ViInt32   FromTPCL,
                                                                             ViInt32   ToTPCLOnOff,
                                                                             ViInt32   ToTPCL,
                                                                             ViInt32   CorrectionOnOff,
                                                                             ViReal64  Correction,
                                                                             ViInt32   Enable,
                                                                             ViChar    errorMessage[])
{
    return RSCMU_ConfPowLimLineUppDyn (instrSession, RSCMU_GMSK, Area, TPCLRange, FromTPCLOnOff, FromTPCL, ToTPCLOnOff,
                                       ToTPCL, CorrectionOnOff, Correction, Enable, errorMessage);
}

/*===========================================================================*/
/* Function: Dynamic Correction of Lower limit Line
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowLimLineLowDyn (ViSession instrSession,
                                                                             ViInt32   Area,
                                                                             ViInt32   TPCLRange,
                                                                             ViInt32   FromTPCLOnOff,
                                                                             ViInt32   FromTPCL,
                                                                             ViInt32   ToTPCLOnOff,
                                                                             ViInt32   ToTPCL,
                                                                             ViInt32   CorrectionOnOff,
                                                                             ViReal64  Correction,
                                                                             ViInt32   Enable,
                                                                             ViChar    errorMessage[])
{
    return RSCMU_ConfPowLimLineLowDyn (instrSession, RSCMU_GMSK, Area, TPCLRange, FromTPCLOnOff, FromTPCL, ToTPCLOnOff,
                                       ToTPCL, CorrectionOnOff, Correction, Enable, errorMessage);
}

/*===========================================================================*/
/* Function: Dynamic Correction of Upper limit Line On/Off
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowLimUppDynMod (ViSession instrSession,
                                                                            ViInt32   area,
                                                                            ViInt32   enable,
                                                                            ViChar    errorMessage[])
{
    return RSCMU_ConfPowLimUppDynMod (instrSession, RSCMU_GMSK, area, enable, errorMessage);
}

/*===========================================================================*/
/* Function: Dynamic Correction of Lower limit Line On/Off
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowLimLowDynMod (ViSession instrSession,
                                                                            ViInt32   area,
                                                                            ViInt32   enable,
                                                                            ViChar    errorMessage[])
{
    return RSCMU_ConfPowLimLowDynMod (instrSession, RSCMU_GMSK, area, enable, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *        AVERAGED BURST POWER LIMIT VALUES
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Average Burst Power limit lines
/* Purpose : This Function determine the tolerances for ranges of power
/*           control levels (PCLs).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowLimAbp (ViSession instrSession,
                                                                      ViInt32   group,
                                                                      ViInt32   enable,
                                                                      ViInt32   StartPCL_ON_OFF,
                                                                      ViInt32   StartPCL,
                                                                      ViInt32   EndPCL_ON_OFF,
                                                                      ViInt32   EndPCL,
                                                                      ViInt32   LowerLimit_ON_OFF,
                                                                      ViReal64  LowerLimit,
                                                                      ViInt32   UpperLimit_ON_OFF,
                                                                      ViReal64  UpperLimit,
                                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      StartPCLBuf[64]= "",EndPCLBuf[64]= "",
              LowerLimitBuf[64]= "", UpperLimitBuf[64]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, group, 1, 10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) enable, RSCMU_ERROR_PARAMETER3, errorMessage);

  switch (StartPCL_ON_OFF)
  {
    case RSCMU_ON:
      sprintf(StartPCLBuf, "%d", StartPCL);
      break;
    case RSCMU_OFF:
      sprintf(StartPCLBuf, "%s", "OFF");
      break;
    case RSCMU_VAL_MAX:
      sprintf(StartPCLBuf, "%s", "MAX");
      break;
  }

  switch (EndPCL_ON_OFF)
  {
    case RSCMU_ON:
      sprintf(EndPCLBuf, "%d", EndPCL);
      break;
    case RSCMU_OFF:
      sprintf(EndPCLBuf, "%s", "OFF");
      break;
    case RSCMU_VAL_MAX:
      sprintf(EndPCLBuf, "%s", "MAX");
      break;
  }

  if (LowerLimit_ON_OFF == RSCMU_ON)
    sprintf(LowerLimitBuf, "%lf", LowerLimit);
  else sprintf(LowerLimitBuf, "%s", "OFF");

  if (UpperLimit_ON_OFF == RSCMU_ON)
    sprintf(UpperLimitBuf, "%lf", UpperLimit);
  else sprintf(UpperLimitBuf, "%s", "OFF");


  sprintf (wrtBuf, "CONF:POW:LIM:ABP%d:ENAB %s",group,  mode_On_Off[enable]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  sprintf (wrtBuf, "CONF:POW:LIM:ABP%d %s,%s,%s,%s", group, StartPCLBuf, EndPCLBuf, LowerLimitBuf, UpperLimitBuf);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*
 *-----------------------------------------------------------------------------
 *        POSITIONNING BURST IN TIME
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Positionning Burst in Time  (not used anymore in 3.05)
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowTimeMode (ViSession instrSession,
                                                                        ViInt32   TimeMode,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TimeMode, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (TimeMode == RSCMU_GSM)
    sprintf (wrtBuf, "CONF:POW:TIME:MODE GSM");
  else  sprintf (wrtBuf, "CONF:POW:TIME:MODE OFFS");

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set offset time
/* Purpose : This function defines an offset time by which the burst is shifted
/*           relative to the time axis and the tolerance template
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowTimeBoff (ViSession instrSession,
                                                                        ViReal64  Offset,
                                                                        ViChar    errorMessage[])
{
  return RSCMU_ConfPowTimeBoff(instrSession, RSCMU_GMSK, Offset, errorMessage);
}

/*===========================================================================*/
/* Function: Filter
/* Purpose : This function selects the measurement filter for the P/t
/*           measurement. The default filter setting differs for the two
/*           modulation schemes.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowFilt (ViSession instrSession,
                                                                    ViInt32   Filter,
                                                                    ViChar    errorMessage[])
{
  return RSCMU_ConfFilt(instrSession, RSCMU_POW, RSCMU_GMSK, Filter, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      MEASURED VALUES
 *      The functions of the following subsystems determine and output
 *      the results of the signal power measurement.
 *-----------------------------------------------------------------------------
 *        MEASUREMENT AND BURST POWER
 *        It contains the commands for measurement and output of the
 *        burst power and its comparison with tolerance values.
 *-----------------------------------------------------------------------------
 */


/*===========================================================================*/
/* Function: Invalid Result Detect Timeout
/* Purpose : This function defines the time after which the access burst
/*           measurement with unvalid results will be stopped in
/*           remote mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowAbursIrdt (ViSession instrSession,
                                                  ViInt32 detectionTimeout,
                                                  ViChar _VI_FAR errorMessage[])

{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:POW:ABUR:IRDT", detectionTimeout, aburstDetectTimeoutArr,
                       RSCMU_ERROR_PARAMETER2));
}
                                                                     
/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function starts a single shot power vs. time measurement
/*           and output all scalar measurement results. These are:
/*             Average power of current burst
/*             Peak power of current burst
/*             Power control level
/*             Timing advance error
/*             Bursts out of tolerance
/*             Burst template matching
/*             Average power of averaged trace
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPow (ViSession  instrSession,
                                                                ViReal64  *AvgBurstPwCurr,
                                                                ViReal64  *PeakBurstPwCurr,
                                                                ViInt32   *PowerControlLevel,
                                                                ViReal64  *TimingAdvError,
                                                                ViReal64  *BurstOutOfTol,
                                                                ViInt32   *BurstMatching,
                                                                ViReal64  *AvgBurstPwAvg,
                                                                ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  if ((RSCMU_Status = RSCMU_Query (instrSession, "READ:POW?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Scan the results of power:
  RSCMU_Status = RSCMU_Sig_ScanPow (TableOfDataValues, AvgBurstPwCurr, PeakBurstPwCurr, PowerControlLevel,
    TimingAdvError, BurstOutOfTol, BurstMatching, AvgBurstPwAvg);

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function starts a power vs. time measurement and output all
/*           scalar measurement results (unsynchronized). These are:
/*             Average power of current burst
/*             Peak power of current burst
/*             Power control level
/*             Timing advance error
/*             Bursts out of tolerance
/*             Burst template matching
/*             Average power of averaged trace
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPow (ViSession  instrSession,
                                                                ViReal64  *AvgBurstPwCurr,
                                                                ViReal64  *PeakBurstPwCurr,
                                                                ViInt32   *PowerControlLevel,
                                                                ViReal64  *TimingAdvError,
                                                                ViReal64  *BurstOutOfTol,
                                                                ViInt32   *BurstMatching,
                                                                ViReal64  *AvgBurstPwAvg,
                                                                ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  if ((RSCMU_Status = RSCMU_Query (instrSession, "FETC:POW?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Scan the results of power:
  RSCMU_Status = RSCMU_Sig_ScanPow (TableOfDataValues, AvgBurstPwCurr, PeakBurstPwCurr, PowerControlLevel,
    TimingAdvError, BurstOutOfTol, BurstMatching, AvgBurstPwAvg);

  return RSCMU_Status;

}
/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function starts a power vs. time measurement and output all
/*           scalar measurement results (synchronized). These are:
/*             Average power of current burst
/*             Peak power of current burst
/*             Power control level
/*             Timing advance error
/*             Bursts out of tolerance
/*             Burst template matching
/*             Average power of averaged trace
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampPow (ViSession  instrSession,
                                                                ViReal64  *AvgBurstPwCurr,
                                                                ViReal64  *PeakBurstPwCurr,
                                                                ViInt32   *PowerControlLevel,
                                                                ViReal64  *TimingAdvError,
                                                                ViReal64  *BurstOutOfTol,
                                                                ViInt32   *BurstMatching,
                                                                ViReal64  *AvgBurstPwAvg,
                                                                ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  if ((RSCMU_Status = RSCMU_Query (instrSession, "SAMP:POW?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Scan the results of power:
  RSCMU_Status = RSCMU_Sig_ScanPow (TableOfDataValues, AvgBurstPwCurr, PeakBurstPwCurr, PowerControlLevel,
    TimingAdvError, BurstOutOfTol, BurstMatching, AvgBurstPwAvg);

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Request Tolerance On Values
/* Purpose : This function indicates whether and in which way the per-
/*           missible tolerances for the scalar measured values  have
/*           been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcPowLimMatc (ViSession instrSession,
                                                                       ViInt32  *AvgBurstPowCurr,
                                                                       ViInt32  *PeakBurstPowCurr,
                                                                       ViInt32  *TimingAdvanceErr,
                                                                       ViInt32  *BurstMatching,
                                                                       ViInt32  *AvgBurstPowAvg,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  if ((RSCMU_Status = RSCMU_Query (instrSession, "CALC:POW:LIM:MATC?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Average Burst Power (Current Burst)
  RSCMU_Status = RSCMU_GetMatchingValue (AvgBurstPowCurr,TableOfDataValues,0);

  //Peak Burst Power (CurrentBurst)
  RSCMU_Status = RSCMU_GetMatchingValue (PeakBurstPowCurr,TableOfDataValues,1);

  // Timing Advance Error
  RSCMU_Status = RSCMU_GetMatchingValue (TimingAdvanceErr,TableOfDataValues,2);

  // Burst Template Matching
  RSCMU_Status = RSCMU_GetMatchingValue (BurstMatching,TableOfDataValues,3);

  // Average Burst Power of average trace
  RSCMU_Status = RSCMU_GetMatchingValue (AvgBurstPowAvg,TableOfDataValues,4);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcPowMprLimMatc ( ViSession  instrSession,
                                                                           ViInt32    StatisticsMode,
                                                                           ViInt32   *AverBurstPow,
                                                                           ViInt32   *PeakBurstPow,
                                                                           ViInt32   *BurstMatching,
                                                                           ViInt32   *phErrPeak,
                                                                           ViInt32   *phErrRMS,
                                                                           ViInt32   *freqErr,
                                                                           ViInt32   *avgBurstPowerCurr,
                                                                           ViChar     errorMessage[])
{
  return RSCMU_GSM_NSig_CalcPowMprLimMatc ( instrSession, StatisticsMode, AverBurstPow, PeakBurstPow,
                                            BurstMatching, phErrPeak, phErrRMS, freqErr,
                                            avgBurstPowerCurr, errorMessage);
}

/*===========================================================================*/
/* Function: Type of decoding
/* Purpose : This function selects the type of decoding applied for the
/*           determination of phase and frequency errors.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModTimeDec (ViSession instrSession,
                                                                       ViBoolean typeOfDecoding,
                                                                       ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_ConfModTimeDec (instrSession, typeOfDecoding, errorMessage);
}

/*===========================================================================*/
/* Function: Filter
/* Purpose : This function selects the measurement filter for the Modulation
/*           PERR measurement. The default filter setting differs for the two
/*           modulation schemes.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModFilt (ViSession instrSession,
                                             ViInt32 filter,
                                             ViChar errorMessage[])
{
  return RSCMU_ConfFilt(instrSession, RSCMU_MOD, RSCMU_GMSK, filter, errorMessage);
}

/*===========================================================================*/
/* Function: Set modulation range
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubModRang (ViSession instrSession,
                                                                       ViInt32   Mode,
                                                                       ViReal64  startTime,
                                                                       ViInt32   numberofsamples,
                                                                       ViChar    errorMessage[])
{
  return  RSCMU_GSM_NSig_ConfSubModRang (instrSession, Mode, startTime, numberofsamples,errorMessage);
}

/*===========================================================================*/
/* Function: Read Burst Power...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrPowBurs (ViSession instrSession,
                                                                       ViInt32   Mode,
                                                                       ViReal64  BurstPower[],
                                                                       ViChar    errorMessage[])
{
  return  RSCMU_GSM_NSig_ReadArrPowBurs (instrSession, Mode, BurstPower, errorMessage);
}
/*===========================================================================*/
/* Function: Fetch Burst Power...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrPowBurs (ViSession instrSession,
                                                                       ViInt32   Mode,
                                                                       ViReal64  BurstPower[],
                                                                       ViChar    errorMessage[])
{
  return  RSCMU_GSM_NSig_FetcArrPowBurs (instrSession, Mode, BurstPower, errorMessage);
}
/*===========================================================================*/
/* Function: Sample Burst Power...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrPowBurs (ViSession instrSession,
                                                                       ViInt32   Mode,
                                                                       ViReal64  BurstPower[],
                                                                       ViChar    errorMessage[])
{
  return  RSCMU_GSM_NSig_SampArrPowBurs (instrSession, Mode, BurstPower, errorMessage);
}
/*===========================================================================*/
/* Function: Read Burst Power...(SubArray)
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrPowBurs (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    errorMessage[])
{
  return  RSCMU_GSM_NSig_ReadSubArrPowBurs (instrSession, Mode, BurstPower, errorMessage);
}
/*===========================================================================*/
/* Function: Fetch Burst Power.  (SubArray)
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrPowBurs (ViSession  instrSession,
                                                                          ViInt32    Mode,
                                                                          ViReal64   BurstPower[],
                                                                          ViChar     errorMessage[])
{
  return  RSCMU_GSM_NSig_FetcSubArrPowBurs (instrSession, Mode, BurstPower, errorMessage);
}
/*===========================================================================*/
/* Function: Sample Burst Power...(SubArray)
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrPowBurs (ViSession  instrSession,
                                                                          ViInt32    Mode,
                                                                          ViReal64   BurstPower[],
                                                                          ViChar     errorMessage[])
{
  return  RSCMU_GSM_NSig_SampSubArrPowBurs (instrSession, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Set power subranges
/* Purpose : This function configures the read, fetch and sample commands.
/*           It restricts the measurement to up to 32 subranges where either
/*           all measurement results or a single statistical value is returned
/*===========================================================================*/

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubPowRang (ViSession instrSession,
                                                                       ViInt32   Mode,
                                                                       ViReal64  startTime,
                                                                       ViInt32   Nbofsamples,
                                                                       ViChar    errorMessage[])
{
  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, startTime, -10.0, 156.75, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Nbofsamples, 0, 668, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSubarrays (instrSession, RSCMU_POW, RSCMU_GMSK, Mode, startTime, Nbofsamples, errorMessage);
}

/*===========================================================================*/
/* Function: ToleranceError of Power Meas...
/* Purpose : This function indicates whether and in which way
/*           permissible tolerances for the burst power have been
/*           exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcPowBursLimMatc (ViSession instrSession,
                                                                           ViInt32   StatisticsMode,
                                                                           ViInt32  *ToleranceError,
                                                                           ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_CalcPowBursLimMatc (instrSession, StatisticsMode, ToleranceError, errorMessage);
}
/*===========================================================================*/
/* Function: Range Violation
/* Purpose : This command is always query. ANy set bit of the two returned
/*           fiels indicates the violation of the corresponding section
/*           of the limit times
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcPowResAreaLimMatc (ViSession   instrSession,
                                                                              ViInt32     StatisticsMode,
                                                                              ViInt32    *UpperLimitMatching,
                                                                              ViInt32    *LowerLimitMatching,
                                                                              ViChar      errorMessage[])
{


  return RSCMU_GSM_NSig_CalcPowResAreaLimMatc (instrSession, StatisticsMode, UpperLimitMatching,LowerLimitMatching, errorMessage);
}
/*===========================================================================*/
/* Function: Read MPR
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrPowMprBurs ( ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViReal64  BurstPower[],
                                                                           ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_ReadArrPowMprBurs ( instrSession, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch MPR
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrPowMprBurs ( ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViReal64  BurstPower[],
                                                                           ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_FetcArrPowMprBurs ( instrSession, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample MPR
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrPowMprBurs ( ViSession  instrSession,
                                                                           ViInt32    Mode,
                                                                           ViReal64   BurstPower[],
                                                                           ViChar     errorMessage[])
{
  return RSCMU_GSM_NSig_SampArrPowMprBurs ( instrSession, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Read MPR (SubArray)
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrPowMprBurs ( ViSession  instrSession,
                                                                              ViInt32    Mode,
                                                                              ViReal64   BurstPower[],
                                                                              ViChar     errorMessage[])
{
  return RSCMU_GSM_NSig_ReadSubArrPowMprBurs ( instrSession, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch MPR (SubArray)
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrPowMprBurs ( ViSession  instrSession,
                                                                              ViInt32    Mode,
                                                                              ViReal64   BurstPower[],
                                                                              ViChar     errorMessage[])
{
  return RSCMU_GSM_NSig_FetcSubArrPowMprBurs ( instrSession, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample MPR (SubArray)
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrPowMprBurs ( ViSession  instrSession,
                                                                              ViInt32    Mode,
                                                                              ViReal64   BurstPower[],
                                                                              ViChar     errorMessage[])
{
  return RSCMU_GSM_NSig_SampSubArrPowMprBurs ( instrSession, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Set power subranges
/* Purpose : This function configures the read, fetch and sample commands.
/*           It restricts the measurement to up to 32 subranges where either
/*           all measurement results or a single statistical value is returned
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMprSubRang (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViInt32   startTime,
                                                                          ViInt32   numberofsamples,
                                                                          ViChar    errorMessage[])
{
  return  RSCMU_GSM_NSig_ConfPowMprSubRang (instrSession, Mode, startTime, numberofsamples,errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT POWER/T MULTISLOT
 *
 * The subsystem POWer:MSLot measures the MS output carrier power versus time
 * in up to 4 consecutive timeslots. The subsystem corresponds to the
 * measurement menu Power, application P/t Multislot, and the associated popup
 * menu Power Configuration.
 * Note: The POWer:MSLot measurement can not be carried out with a Free Run
 * trigger (TRIG-ger[:SEQuence]:SOURce FRUN).
 * ----------------------------------------------------------------------------
 *      CONTROL OF POWER MEASUREMENT
 *      This subsystem contains the functions for general control of the
 *      power measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start Measurements
/* Purpose : This function starts measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_InitPowMsl (ViSession instrSession,
                                                                   ViChar errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_POWMSL, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Abort Measurements
/* Purpose : This function abort measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborPowMsl (ViSession instrSession,
                                                                   ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_POWMSL, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Stop Measurements
/* Purpose : This function stops measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopPowMsl (ViSession instrSession,
                                                                   ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_POWMSL, RSCMU_NONE, errorMessage);
}
/*===========================================================================*/
/* Function: Continue Measurements
/* Purpose : This function continues measurement after stop,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContPowMsl (ViSession instrSession,
                                                                   ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_POWMSL, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Measurement Status
/* Purpose : This function returns the status of the current Power/t multislot
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowMslStat (ViSession  instrSession,
                                                                       ViInt32    *MeasurementStatus,
                                                                       ViInt32    *CountingNo,
                                                                       ViInt32    *StatisticNo,
                                                                       ViChar     errorMessage[])
{
  return RSCMU_FetcStatus (instrSession, RSCMU_POWMSL, RSCMU_NONE, MeasurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMslErep (ViSession  instrSession,
                                                                       ViInt32    Report,
                                                                       ViChar     errorMessage[])
{
  return RSCMU_ConfReporting (instrSession, RSCMU_POWMSL, RSCMU_NONE, Report, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      CONFIGURATION CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMslContRep (ViSession  instrSession,
                                                                          ViInt32    Repetition,
                                                                          ViInt32    StopCondition,
                                                                          ViInt32    StepMode,
                                                                          ViChar     errorMessage[])
{
  return RSCMU_ConfControlRep (instrSession, RSCMU_POWMSL, RSCMU_NONE, Repetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Set Grid (ON/OFF)
/* Purpose : This function switches the grid lines in the test diagrams
/*           on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_DispPowMslContGrid (ViSession instrSession,
                                                                           ViInt32   gridLines,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) gridLines, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DISP:POW:MSL:CONT:GRID %s", mode_On_Off[gridLines]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Off Template
/* Purpose : This function defines the reference for the upper limit line
/*           in inactive slots.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMslLimLineOtem (ViSession instrSesstion,
                                                       ViBoolean off_template,
                                                       ViChar errorMessage[])
{
    return RSCMU_GSM_NSig_ConfPowMslLimLineOtem (instrSesstion, off_template, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of Measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMslCont (ViSession instrSession,
                                                                       ViInt32   MeasuredValuesType,
                                                                       ViInt32   NbBurst,
                                                                       ViChar    errorMessage[])
{
  return RSCMU_ConfControl (instrSession, RSCMU_POWMSL, RSCMU_NONE, MeasuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistics Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMslContRepStat (ViSession  instrSession,
                                                                              ViInt32    NbRepetition,
                                                                              ViInt32    StopCondition,
                                                                              ViInt32    StepMode,
                                                                              ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU_MULT_MEAS_MIN, RSCMU_MULT_MEAS_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  sprintf (wrtBuf, "CONF:POW:MSL:CONT:REP %d,%s,%s", NbRepetition, StrStopCondition[StopCondition], StrStepMode[StepMode]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: TSA Level
/* Purpose : This function defines defines a signal level relative to the Max.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMslTsal (ViSession instrSession,
                                                ViReal64 level,
                                                ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    CHECK_VI_REAL64_RANGE(instrSession, level, -60.0, 10.0, RSCMU_ERROR_PARAMETER2, errorMessage);

    RETMSG(RSCMU_setViReal64(instrSession, "CONF:POW:MSL:TSAL",
                            level,
                            -60.0, 10.0,
                            RSCMU_ERROR_PARAMETER2));
}

/*
 *-----------------------------------------------------------------------------
 *      TEST CONFIGURATION
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Modulation view
/* Purpose : This function defines the modulation schemes and power/time
/*           templates for the Meas. Timeslot -1, Meas. Timeslot and the two
/*           following timeslots. Values for timeslots that are currently
/*           switched off (see function RSCMU_GSM_Sig_ConfPowMslSco) are not
/*           taken into consideration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMslMvi (ViSession  instrSession,
                                               ViInt32   timeslot_m1,
                                               ViInt32   timeslot,
                                               ViInt32   timeslot_p1,
                                               ViInt32   timeslot_p2,
                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViString    StrModView[] = {"GMSK","EPSK","ANY","OFF","ABUR"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_52)
  {
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, timeslot_m1, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, timeslot   , 0, 3, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, timeslot_p1, 0, 3, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, timeslot_p2, 0, 3, RSCMU_ERROR_PARAMETER5, errorMessage);
  }
  {
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, timeslot_m1, 0, 4, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, timeslot   , 0, 4, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, timeslot_p1, 0, 4, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, timeslot_p2, 0, 4, RSCMU_ERROR_PARAMETER5, errorMessage);
  }


  sprintf (wrtBuf, "CONF:POW:MSL:MVI %s,%s,%s,%s", StrModView[timeslot_m1]
                                                 , StrModView[timeslot]
                                                 , StrModView[timeslot_p1]
                                                 , StrModView[timeslot_p2]);
  RETMSG(RSCMU_sendCmd (instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Slot count
/* Purpose : This function defines the number of timeslots measured and
/*           determines the length of the measurement arrays.
/*           (see READ:ARRay:POWer:MSLot[:RESult]... commands).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMslSco (ViSession instrSession,
                                                                      ViInt32   nbr_of_timeslots,
                                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, nbr_of_timeslots, 1, 4, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  sprintf (wrtBuf, "CONF:POW:MSL:SCO %d", nbr_of_timeslots);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: timing offset
/* Purpose : This function defines an offset time by which the burst is
/*           shifted relative to the time axis and the tolerance template.
/*           The values entered are rounded to  symbol steps.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMslToff (ViSession instrSession,
                                                                       ViReal64  offset,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, offset, -4.0, 4.0, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  sprintf (wrtBuf, "CONF:POW:MSL:TOFF %lf", offset);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: multislot guard
/* Purpose : This function defines the raising of the upper limit line in the
/*           guard period between two consecutive bursts.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMslLimGlev (ViSession instrSession,
                                                                          ViReal64  level,
                                                                          ViChar    errorMessage[])

{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, level, 0.0, 10.0, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  sprintf (wrtBuf, "CONF:POW:MSL:LIM:LINE:GLEV %lf", level);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: configure subarrays
/* Purpose : This function configures the read, fetch and sample subarray
/*           functions. It restricts the measurement to up to 32 subranges
/*           where either all measurement results (the number of which is
/*           given by the second numerical parameter) or a single statistical
/*           value is returned. The subranges are defined by the start time
/*           and the number of test points which are located on a fixed,
/*           equidistant grid with a step width of  symbols. If <Start> does
/*           not coincide with a test point then the range will start at the
/*           next test point that is larger than <Start>.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubPowMslRang (ViSession instrSession,
                                                                          ViInt32   Statistics,
                                                                          ViInt32   startTime,
                                                                          ViInt32   Nbofsamples,
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Statistics, 0, 4, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, startTime, -180, 520, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Nbofsamples, 0, 10452, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:POW:MSL %s,%d,%d", StrStatistics[Statistics], startTime, Nbofsamples);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*
 *-----------------------------------------------------------------------------
 *      MEASURED VALUES
 *      The functions of the following subsystems determine and output
 *      the results of the signal power measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function starts a single shot measurement and returns the
/*           results. For more details refer to the description of measurement
/*           control in chapter 5 of the CMU200 operating manual.
/*
/*           These are:
/*           Burst out of tolerance
/*           Average burst power (current burst)
/*           Average burst power of average trace
/*           Peak burst power (current burst)
/*           Timing advance error
/*           Burst template matching
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowMsl (ViSession  instrSession,
                                                                   ViReal64  *BurstOutOfTol,
                                                                   ViReal64  *AvgBurstPwCurr,
                                                                   ViReal64  *AvgBurstPwAvg,
                                                                   ViReal64  *PeakBurstPwCurr,
                                                                   ViReal64  *TimingAdvError,
                                                                   ViInt32   *BurstMatching,
                                                                   ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  if ((RSCMU_Status = RSCMU_Query (instrSession, "READ:POW:MSL?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Scan the results of power:
  RSCMU_Status = RSCMU_Sig_ScanPowMsl (TableOfDataValues, BurstOutOfTol, AvgBurstPwCurr,
    AvgBurstPwAvg, PeakBurstPwCurr, TimingAdvError, BurstMatching);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function returns the results. For more details refer to the
/*           description of measurement control in chapter 5 of the CMU200
/*           operating manual.
/*
/*           These are:
/*           Burst out of tolerance
/*           Average burst power (current burst)
/*           Average burst power of average trace
/*           Peak burst power (current burst)
/*           Timing advance error
/*           Burst template matching
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowMsl (ViSession  instrSession,
                                                                   ViReal64  *BurstOutOfTol,
                                                                   ViReal64  *AvgBurstPwCurr,
                                                                   ViReal64  *AvgBurstPwAvg,
                                                                   ViReal64  *PeakBurstPwCurr,
                                                                   ViReal64  *TimingAdvError,
                                                                   ViInt32   *BurstMatching,
                                                                   ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  if ((RSCMU_Status = RSCMU_Query (instrSession, "FETC:POW:MSL?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Scan the results of power:
  RSCMU_Status = RSCMU_Sig_ScanPowMsl (TableOfDataValues, BurstOutOfTol, AvgBurstPwCurr,
    AvgBurstPwAvg, PeakBurstPwCurr, TimingAdvError, BurstMatching);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function waits until the results are valid (depending on
/*           the statistic count) and then returns the results. For more
/*           details refer to the description of measurement control in
/*           chapter 5 of the CMU200 operating manual.
/*
/*           These are:
/*           Burst out of tolerance
/*           Average burst power (current burst)
/*           Average burst power of average trace
/*           Peak burst power (current burst)
/*           Timing advance error
/*           Burst template matching
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampPowMsl (ViSession  instrSession,
                                                                   ViReal64  *BurstOutOfTol,
                                                                   ViReal64  *AvgBurstPwCurr,
                                                                   ViReal64  *AvgBurstPwAvg,
                                                                   ViReal64  *PeakBurstPwCurr,
                                                                   ViReal64  *TimingAdvError,
                                                                   ViInt32   *BurstMatching,
                                                                   ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  if ((RSCMU_Status = RSCMU_Query (instrSession, "SAMP:POW:MSL?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Scan the results of power:
  RSCMU_Status = RSCMU_Sig_ScanPowMsl (TableOfDataValues, BurstOutOfTol, AvgBurstPwCurr,
    AvgBurstPwAvg, PeakBurstPwCurr, TimingAdvError, BurstMatching);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Request Tolerance On Values
/* Purpose : This function indicates whether and in which way the per-
/*           missible tolerances for the scalar measured values have
/*           been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcPowMslLimMatc (ViSession  instrSession,
                                                                          ViInt32   *AvgBurstPowCurr,
                                                                          ViInt32   *AvgBurstPowAvg,
                                                                          ViInt32   *PeakBurstPowCurr,
                                                                          ViInt32   *TimingAdvanceErr,
                                                                          ViInt32   *BurstMatching,
                                                                          ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  if ((RSCMU_Status = RSCMU_Query (instrSession, "CALC:POW:MSL:LIM:MATC?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Average Burst Power (Current Burst)
  RSCMU_Status = RSCMU_GetMatchingValue (AvgBurstPowCurr, TableOfDataValues, 0);

  // Average Burst Power of average trace
  RSCMU_Status = RSCMU_GetMatchingValue (AvgBurstPowAvg, TableOfDataValues, 1);

  //Peak Burst Power (CurrentBurst)
  RSCMU_Status = RSCMU_GetMatchingValue (PeakBurstPowCurr, TableOfDataValues, 2);

  // Timing Advance Error
  RSCMU_Status = RSCMU_GetMatchingValue (TimingAdvanceErr,TableOfDataValues,3);

  // Burst Template Matching
  RSCMU_Status = RSCMU_GetMatchingValue (BurstMatching,TableOfDataValues,4);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Read Power/t multislot array
/* Purpose : This function starts a single shot measurement and returns the
/*           burst power relative to the average burst power in the measurement
/*           slot at n equidistant measurement points with a fixed  symbol
/*           spacing. The time range measured corresponds to 1 to 4 entire
/*           timeslots plus 18  symbol periods before the beginning (symbol 0)
/*           of the first slot and 10 symbol periods after the end of the last
/*           slot. The resulting array lengths n are listed below.
/*
/*           Number of timeslots (according to     1      2      3      4
/*           RSCMU_GSM_Sig_ConfPowMslSco)
/*           n                                   738   1363   1988   2613
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrPowMsl (ViSession instrSession,
                                                                      ViInt32   Mode,
                                                                      ViReal64  BurstPower[],
                                                                      ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPowerMsl (instrSession, RSCMU_COMMAND_READ, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Power/t multislot array
/* Purpose : This function returns the burst power relative to the average
/*           burst power in the measurement slot at n equidistant measurement
/*           points with a fixed  symbol spacing. The time range measured
/*           corresponds to 1 to 4 entire timeslots plus 18  symbol periods
/*           before the beginning (symbol 0) of the first slot and 10 symbol
/*           periods after the end of the last slot. The resulting array
/*           lengths n are listed below.
/*
/*           Number of timeslots (according to     1      2      3      4
/*           RSCMU_GSM_Sig_ConfPowMslSco)
/*           n                                   738   1363   1988   2613
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrPowMsl (ViSession instrSession,
                                                                      ViInt32   Mode,
                                                                      ViReal64  BurstPower[],
                                                                      ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPowerMsl (instrSession, RSCMU_COMMAND_FETC, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Power/t multislot array
/* Purpose : This function waits until the results are valid (depending on
/*           the statistic count) and then returns the burst power relative
/*           to the average burst power in the measurement slot at n
/*           equidistant measurement points with a fixed  symbol spacing.
/*           The time range measured corresponds to 1 to 4 entire timeslots
/*           plus 18  symbol periods before the beginning (symbol 0) of the
/*           first slot and 10 symbol periods after the end of the last slot.
/*           The resulting array lengths n are listed below.
/*
/*           Number of timeslots (according to     1      2      3      4
/*           RSCMU_GSM_Sig_ConfPowMslSco)
/*           n                                   738   1363   1988   2613
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrPowMsl (ViSession instrSession,
                                                                      ViInt32   Mode,
                                                                      ViReal64  BurstPower[],
                                                                      ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPowerMsl (instrSession, RSCMU_COMMAND_SAMP, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Global burst matching
/* Purpose : This function indicates whether and in which way the per-
/*           missible tolerances for the scalar measured values have
/*           been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcArrPowMslLimMatc (ViSession  instrSession,
                                                                             ViInt32    Mode,
                                                                             ViInt32   *ToleranceError,
                                                                             ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CALC:ARR:POW:MSL:LIM:MATC:%s?", StrStatMode[Mode]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Get the tolerance error value
  RSCMU_SeparateDataValues (rdBuf, ",", tab);
  RSCMU_GetMatchingValue (ToleranceError, tab, 0);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: area limit matching
/* Purpose : A bit in the two output values is set if the corresponding
/*           section of the limit lines is exceeded. n is the total number of
/*           areas in the limit lines, depending on the number of bursts
/*           measured (according to RSCMU_GSM_Sig_ConfPowMslSco).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcPowMslAreaLimMatc (ViSession  instrSession,
                                                                              ViInt32    StatisticsMode,
                                                                              ViInt32   *UpperLimit,
                                                                              ViInt32   *LowerLimit,
                                                                              ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  sprintf (wrtBuf, "CALC:ARR:POW:MSL:AREA:LIM:MATC:%s?", StrStatMode[StatisticsMode]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the upper Limit Matching
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%d", UpperLimit);
  else *UpperLimit = RSCMU_NAN_VI_INT32;

  // Get the lower Limit Matching
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%d", LowerLimit);
  else *LowerLimit = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Read subarrays
/* Purpose : This function outputs the burst power versus time multislot in a
/*           fixed -bit pattern and in subranges defined ny means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrPowMsl (ViSession  instrSession,
                                                                         ViInt32    Mode,
                                                                         ViReal64   BurstPower[],
                                                                         ViChar     errorMessage[])
{
  return RSCMU_MeasSubarraysPowerMsl (instrSession, RSCMU_COMMAND_READ, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch subarrays
/* Purpose : This function outputs the burst power versus time multislot in a
/*           fixed -bit pattern and in subranges defined ny means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrPowMsl (ViSession  instrSession,
                                                                         ViInt32    Mode,
                                                                         ViReal64   BurstPower[],
                                                                         ViChar     errorMessage[])
{
  return RSCMU_MeasSubarraysPowerMsl (instrSession, RSCMU_COMMAND_FETC, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample subarrays
/* Purpose : This function outputs the burst power versus time multislot in a
/*           fixed -bit pattern and in subranges defined ny means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrPowMsl (ViSession  instrSession,
                                                                         ViInt32    Mode,
                                                                         ViReal64   BurstPower[],
                                                                         ViChar     errorMessage[])
{
  return RSCMU_MeasSubarraysPowerMsl (instrSession, RSCMU_COMMAND_SAMP, Mode, BurstPower, errorMessage);
}


/*===========================================================================*/
/* Invalid Result detect timeout
/* This function defines the Invalid Result Detected Timeout.
/* It is valid for the Power/Time Measurements.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_PowerTimeMeasTimeout (ViSession instrSession,
                                                      ViInt32   invalidResultDetectedTimeout,
                                                      ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[]= {"NORMal", "MEDium", "SHORt", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    RETMSG(RSCMU_setEnum(instrSession, "CONFigure:POWer:PVT:IRDTimeout",
                         invalidResultDetectedTimeout, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT POWER ACCESS BURST
 *
 *    The subsystem POWer:ABURst measures the MS output carrier power versus time
 *    for access bursts. The subsystem corresponds to the measurement menu Power,
 *    application P/t Access..., and the associated popup menu Power Configuration.
 *    It contains all commands for measurement control and for the output of
 *    measurement results. The limit lines, however, are taken from the POWer[:NBURst]
 *    subsystem and adapted to the shortened access burst:
 *
 *    - The central part (area no. 5 of the upper limit line and area no. 3 of the
 *      lower limit line) is 60 bits shorter.
 *    - The position of areas around the falling edge is adapted to the shortened
 *      central part: Aras no. 6 to 8 of the upper limit line and area no. 3 of the
 *      lower limit line are shifted by -60 bit.
 *
 *    Note that access burst measurements are always made on a single burst, so no
 *    :CONTrol subsystem and no display modes [:CURRent], :AVERage, MINimum,
 *    :MAXimum are needed.
 * ----------------------------------------------------------------------------
 *      CONFIGURATION
 *        CONTROL
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set offset time
/* Purpose : This function defines an offset time by which the burst is shifted
/*           relative to the time axis and the tolerance template
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowAburTimeBoff (ViSession instrSession,
                                                                            ViReal64  Offset,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, Offset, -4.0, 4.0, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:POW:ABUR:TIME:BOFF %lf", Offset);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/* ----------------------------------------------------------------------------
 *        MEASUREMENT
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set power subranges
/* Purpose : This function configures the read, fetch and sample commands.
/*           It restricts the measurement to up to 32 subranges where either
/*           all measurement results or a single statistical value is returned
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubPowAburRang (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViReal64  startTime,
                                                                           ViInt32   Nbofsamples,
                                                                           ViChar    errorMessage[])
{
  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, startTime, -10.0, 96.75, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Nbofsamples, 0, 428, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSubarrays (instrSession, RSCMU_POWABUR, RSCMU_GMSK, Mode, startTime, Nbofsamples, errorMessage);
}

/* ----------------------------------------------------------------------------
 *      CONTROL OF POWER ACCCESS BURST MEASUREMENT
 *      This subsystem contains the functions for general control of the
 *      power measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start Measurements
/* Purpose : This function start measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_InitPowAbur (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_POWABUR, RSCMU_GMSK, errorMessage);
}

/*===========================================================================*/
/* Function: StartMeasurements
/* Purpose : This function start measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborPowAbur (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_POWABUR, RSCMU_GMSK, errorMessage);
}

/*===========================================================================*/
/* Function: StartMeasurements
/* Purpose : This function start measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopPowAbur (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_POWABUR, RSCMU_GMSK, errorMessage);
}
/*===========================================================================*/
/* Function: StartMeasurements
/* Purpose : This function start measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContPowAbur (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_POWABUR, RSCMU_GMSK, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowAburErep (ViSession  instrSession,
                                                                        ViInt32    Report,
                                                                        ViChar     errorMessage[])
{
  return RSCMU_ConfReporting (instrSession, RSCMU_POWABUR, RSCMU_GMSK, Report, errorMessage);
}

/*===========================================================================*/
/* Function: Power/t Measurement Status
/* Purpose : This function returns the status of the current Power/t
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowAburStat (ViSession  instrSession,
                                                                        ViInt32    *MeasurementStatus,
                                                                        ViInt32    *CountingNo,
                                                                        ViInt32    *StatisticNo,
                                                                        ViChar     errorMessage[])
{
  return RSCMU_FetcStatus (instrSession, RSCMU_POWABUR, RSCMU_GMSK, MeasurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      RESULTS
 *
 *      The subsystem POWer:ABURst...[:RESULT] contains the commands for measurement
 *      and output of the access burst power and its comparison with tolerance values.
 *      The subsystem corresponds to the graphical measurement menu Power.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Read scalar
/* Purpose : This function starts a single shot measurement and returns the
/*           results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowAbur (ViSession  instrSession,
                                                                    ViReal64  *avgBurstPowerCurr,
                                                                    ViReal64  *timeArrival,
                                                                    ViInt32   *TSCDetect,
                                                                    ViInt32   *burstMatching,
                                                                    ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage);

  if ((RSCMU_Status = RSCMU_Query (instrSession, "READ:POW:ABUR?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Get the average burst power (current burst):
  if (strcmp (TableOfDataValues[0], "NAN") != 0)
    sscanf (TableOfDataValues[0], "%lf", avgBurstPowerCurr);
  else
    *avgBurstPowerCurr = RSCMU_NAN;

  // Get the time arrival:
  if (strcmp (TableOfDataValues[1], "NAN") != 0)
    sscanf (TableOfDataValues[1], "%lf", timeArrival);
  else
    *timeArrival = RSCMU_NAN;

  // Get the trainning sequence
  if (strncmp ("OFF", TableOfDataValues[2], 3) == 0)
    *TSCDetect = RSCMU_OFF;
  else if (strncmp ("GSM0", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM0;
  else if (strncmp ("GSM1", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM1;
  else if (strncmp ("GSM2", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM2;
  else if (strncmp ("GSM3", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM3;
  else if (strncmp ("GSM4", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM4;
  else if (strncmp ("GSM5", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM5;
  else if (strncmp ("GSM6", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM6;
  else if (strncmp ("GSM7", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM7;
  else if (strncmp ("DUMM", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_DUMMY;
  else
    *TSCDetect = RSCMU_NAN_VI_INT32;

  // Get the matching
  RSCMU_Status = RSCMU_GetMatchingValue (burstMatching, TableOfDataValues, 3);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Fetch scalar
/* Purpose : This function outputs the results without taking care of the
/*           measurement state.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowAbur (ViSession  instrSession,
                                                                    ViReal64  *avgBurstPowerCurr,
                                                                    ViReal64  *timeArrival,
                                                                    ViInt32   *TSCDetect,
                                                                    ViInt32   *burstMatching,
                                                                    ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage);

  if ((RSCMU_Status = RSCMU_Query (instrSession, "FETC:POW:ABUR?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Get the average burst power (current burst):
  if (strcmp (TableOfDataValues[0], "NAN") != 0)
    sscanf (TableOfDataValues[0], "%lf", avgBurstPowerCurr);
  else
    *avgBurstPowerCurr = RSCMU_NAN;

  // Get the time arrival:
  if (strcmp (TableOfDataValues[1], "NAN") != 0)
    sscanf (TableOfDataValues[1], "%lf", timeArrival);
  else
    *timeArrival = RSCMU_NAN;

  // Get the trainning sequence
  if (strncmp ("OFF", TableOfDataValues[2], 3) == 0)
    *TSCDetect = RSCMU_OFF;
  else if (strncmp ("GSM0", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM0;
  else if (strncmp ("GSM1", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM1;
  else if (strncmp ("GSM2", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM2;
  else if (strncmp ("GSM3", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM3;
  else if (strncmp ("GSM4", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM4;
  else if (strncmp ("GSM5", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM5;
  else if (strncmp ("GSM6", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM6;
  else if (strncmp ("GSM7", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM7;
  else if (strncmp ("DUMM", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_DUMMY;
  else
    *TSCDetect = RSCMU_NAN_VI_INT32;

  // Get the matching
  RSCMU_Status = RSCMU_GetMatchingValue (burstMatching, TableOfDataValues, 3);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Sample scalar
/* Purpose : This function waits until the results are valid for the first
/*           time (depending on the chosen statistic count) and then outputs
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampPowAbur (ViSession  instrSession,
                                                                    ViReal64  *avgBurstPowerCurr,
                                                                    ViReal64  *timeArrival,
                                                                    ViInt32   *TSCDetect,
                                                                    ViInt32   *burstMatching,
                                                                    ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage);

  if ((RSCMU_Status = RSCMU_Query (instrSession, "SAMP:POW:ABUR?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Get the average burst power (current burst):
  if (strcmp (TableOfDataValues[0], "NAN") != 0)
    sscanf (TableOfDataValues[0], "%lf", avgBurstPowerCurr);
  else
    *avgBurstPowerCurr = RSCMU_NAN;

  // Get the time arrival:
  if (strcmp (TableOfDataValues[1], "NAN") != 0)
    sscanf (TableOfDataValues[1], "%lf", timeArrival);
  else
    *timeArrival = RSCMU_NAN;

  // Get the trainning sequence
  if (strncmp ("OFF", TableOfDataValues[2], 3) == 0)
    *TSCDetect = RSCMU_OFF;
  else if (strncmp ("GSM0", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM0;
  else if (strncmp ("GSM1", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM1;
  else if (strncmp ("GSM2", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM2;
  else if (strncmp ("GSM3", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM3;
  else if (strncmp ("GSM4", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM4;
  else if (strncmp ("GSM5", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM5;
  else if (strncmp ("GSM6", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM6;
  else if (strncmp ("GSM7", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_GSM7;
  else if (strncmp ("DUMM", TableOfDataValues[2], 4) == 0)
    *TSCDetect = RSCMU_DUMMY;
  else
    *TSCDetect = RSCMU_NAN_VI_INT32;

  // Get the matching
  RSCMU_Status = RSCMU_GetMatchingValue (burstMatching, TableOfDataValues, 3);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Request Tolerance On Values
/* Purpose : This function indicates whether and in which way the per-
/*           missible tolerances for the scalar measured values  have
/*           been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcPowAburLimMatc (ViSession instrSession,
                                                                           ViInt32  *AvgBurstPowCurr,
                                                                           ViInt32  *BurstMatching,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage);

  if ((RSCMU_Status = RSCMU_Query (instrSession, "CALC:POW:ABUR:LIM:MATC?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Average Burst Power (Current Burst)
  RSCMU_Status = RSCMU_GetMatchingValue (AvgBurstPowCurr,TableOfDataValues,0);

  // Burst Template Matching
  RSCMU_Status = RSCMU_GetMatchingValue (BurstMatching,TableOfDataValues,1);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Read array
/* Purpose : This function returns the different power values of the bursts
/*           in a fixed -bit pattern. The number of measured values is 428,
/*           corresponding to a time range of -10 Bit to 96  Bit.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrPowAbur (ViSession instrSession,
                                                                       ViReal64  BurstPower[],
                                                                       ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPower (instrSession, RSCMU_COMMAND_READ, RSCMU_POWABUR, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch array
/* Purpose : This function returns the different power values of the bursts
/*           in a fixed -bit pattern. The number of measured values is 428,
/*           corresponding to a time range of -10 Bit to 96  Bit.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrPowAbur (ViSession instrSession,
                                                                       ViReal64  BurstPower[],
                                                                       ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPower (instrSession, RSCMU_COMMAND_FETC, RSCMU_POWABUR, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample array
/* Purpose : This function returns the different power values of the bursts
/*           in a fixed -bit pattern. The number of measured values is 428,
/*           corresponding to a time range of -10 Bit to 96  Bit.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrPowAbur (ViSession instrSession,
                                                                       ViReal64  BurstPower[],
                                                                       ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPower (instrSession, RSCMU_COMMAND_SAMP, RSCMU_POWABUR, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Array matching
/* Purpose : This function indicates whether and in which way permissible
/*           tolerances for the burst power (see command above) have been
/*           exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcArrPowAburLimMatc (ViSession  instrSession,
                                                                              ViInt32   *matching,
                                                                              ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage);

  if ((RSCMU_Status = RSCMU_Query (instrSession, "CALC:ARR:POW:ABUR:LIM:MATC?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Get the matching value:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);
  RSCMU_GetMatchingValue (matching, tab, 0);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Area matching
/* Purpose : This function is always a query. Any set bit of the two returned
/*           fields indicates the violation of the corresponding section of the
/*           limit lines.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcPowAburAreaLimMatc (ViSession  instrSession,
                                                                               ViInt32   *UpperLimit,
                                                                               ViInt32   *LowerLimit,
                                                                               ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage);

  if ((RSCMU_Status = RSCMU_Query (instrSession, "CALC:ARR:POW:ABUR:AREA:LIM:MATC?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the upper Limit Matching
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%d", UpperLimit);
  else *UpperLimit = RSCMU_NAN_VI_INT32;

  // Get the lower Limit Matching
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%d", LowerLimit);
  else *LowerLimit = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Read Subarray
/* Purpose : This function returns an array of the different power values of
/*           the bursts in a fixed -bit pattern. The number of measured
/*           values is max. 428 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrPowAbur (ViSession instrSession,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPower (instrSession, RSCMU_COMMAND_READ, RSCMU_POWABUR, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Subarray
/* Purpose : This function returns an array of the different power values of
/*           the bursts in a fixed -bit pattern. The number of measured
/*           values is max. 428 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrPowAbur (ViSession instrSession,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPower (instrSession, RSCMU_COMMAND_FETC, RSCMU_POWABUR, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Subarray
/* Purpose : This function returns an array of the different power values of
/*           the bursts in a fixed -bit pattern. The number of measured
/*           values is max. 428 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrPowAbur (ViSession instrSession,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPower (instrSession, RSCMU_COMMAND_SAMP, RSCMU_POWABUR, BurstPower, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT POWER/SLOT
 * ----------------------------------------------------------------------------
*/
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowSlotContDef (ViSession instrSession,
                                                                           ViInt32   DefaultValues,
                                                                           ViChar    errorMessage[])
{
  return RSCMU_ConfContDef(instrSession, RSCMU_POWSLOT, RSCMU_NONE, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowSlotContRep (ViSession instrSession,
                                                                           ViInt32   Repetition,
                                                                           ViInt32   StopCondition,
                                                                           ViInt32   StepMode,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) Repetition, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:POW:SLOT:CONT:REP %s,%s,%s", StrRepetition[Repetition], StrStopCondition[StopCondition], StrStepMode[StepMode]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Sets Tests Repetition
/* Purpose : This function defines three GSM channel numbers for the P/Slot
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowSlotContRepStat (ViSession instrSession,
                                                                               ViInt32   NbRepetition,
                                                                               ViInt32   StopCondition,
                                                                               ViInt32   StepMode,
                                                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU_MULT_MEAS_MIN, RSCMU_MULT_MEAS_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:POW:SLOT:CONT:REP %d,%s,%s", NbRepetition, StrStopCondition[StopCondition], StrStepMode[StepMode]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set power subranges
/* Purpose : This function configures the read, fetch and sample commands.
/*           It restricts the measurement to up to 32 subranges where either
/*           all measurement results or a single statistical value is returned
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubPowSlot (ViSession instrSession,
                                                                        ViInt32   mode,
                                                                        ViInt32   startTime,
                                                                        ViInt32   numberOfsamples,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, startTime, 0, 7, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, numberOfsamples, 1, 8, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:POW:SLOT %s,%d,%d", StrStatistics[mode], startTime, numberOfsamples);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Start Power/Slot Measurements
/* Purpose : This function start the Power/Slot measurement,
/*           setting it to the status beyond.
/*           RUN        Start measurement without waiting
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_InitPowSlot (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU_Status = RSCMU_Query (instrSession, "INIT:POW:SLOT", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Abort running measurement and switch off
/* Purpose : This function stops the power/Slot measurement, setting it to
/*           the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborPowSlot (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU_Status = RSCMU_Query (instrSession, "ABOR:POW:SLOT", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: stop measurement after current statistic cycle
/* Purpose : This function stops the power/Slot measurement, setting it to
/*           the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopPowSlot (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU_Status = RSCMU_Query (instrSession, "STOP:POW:SLOT", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Next Measurement Step (restart measurement)
/* Purpose : This function continue the power/PCL measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContPowSlot (ViSession instrSession,
                                                                   ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if ((RSCMU_Status = RSCMU_Query (instrSession, "CONT:POW:SLOT", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: P/SLOT Measurement Status
/* Purpose : This function returns the status of the current P/PCL measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowSlotStat (ViSession instrSession,
                                                                        ViInt32   *measurementStatus,
                                                                        ViInt32   *countingNo,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  // Fetch the status of the current P/Slot measurement:
  if ((RSCMU_Status = RSCMU_Query (instrSession, "FETC:POW:SLOT:STAT?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Get the status of the measurement:
  if ((RSCMU_Status = RSCMU_GetMeasStatVal (measurementStatus, TableOfDataValues, 0)) < 0)
    return RSCMU_Status;

  // Get the current value of the statistics counter (the number of the current statistics cycle):
  if ((RSCMU_Status = RSCMU_GetCountingNo (countingNo, TableOfDataValues, 1)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowSlotErep (ViSession instrSession,
                                                                        ViInt32   mode,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"OFF","SRQ","SOPC","SRSQ"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:POW:SLOT:EREP %s", StrMode[mode]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Start single shot P/PCL measurement.
/* Purpose : This function starts a single shot measurement and returns all
/*           measurement results. The returned list contains all possible
/*           PCLs of the mobile phone together with the measured MS output
/*           powers in the three selected channels.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowSlot (ViSession instrSession,
                                                                    ViReal64  slotlist[],
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  ViInt32     i_Index;

  if ((RSCMU_Status = RSCMU_Query (instrSession, "READ:POW:SLOT?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the Average Burst Power in the eight timeslot
  for (i_Index=0;i_Index<8;i_Index++)
  {
    if (strcmp (tab [i_Index], "NAN") != 0)
      sscanf (tab [i_Index], "%lf", &slotlist[i_Index]);
    else slotlist[i_Index] = RSCMU_NAN;
  }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: P/Slot Measurement Status
/* Purpose : This function returns the status of the current P/Slot measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowSlot (ViSession instrSession,
                                                                    ViReal64  slotlist[],
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  ViInt32     i_Index;

  if ((RSCMU_Status = RSCMU_Query (instrSession, "FETC:POW:SLOT?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the Average Burst Power in the eight timeslot
  for (i_Index=0;i_Index<8;i_Index++)
  {
    if (strcmp (tab [i_Index], "NAN") != 0)
      sscanf (tab [i_Index], "%lf", &slotlist[i_Index]);
    else slotlist[i_Index] = RSCMU_NAN;
  }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: P/Slot Measurement Status
/* Purpose : This function waits until the results are valid for the first
/*           time (depending on the chosen statistic count) and then outputs
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampPowSlot (ViSession instrSession,
                                                                    ViReal64  slotlist[],
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  ViInt32     i_Index;

  if ((RSCMU_Status = RSCMU_Query (instrSession, "SAMP:POW:SLOT?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the Average Burst Power in the eight timeslot
  for (i_Index=0;i_Index<8;i_Index++)
  {
    if (strcmp (tab [i_Index], "NAN") != 0)
      sscanf (tab [i_Index], "%lf", &slotlist[i_Index]);
    else slotlist[i_Index] = RSCMU_NAN;
  }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Read average power in selected slot (FW >= 2.15)
/* Purpose : This function outputs the average power value of the
/*           selected timeslot (from 0 to 7)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowSlotSpow (ViSession  instrSession,
                                                                        ViInt32    timeslot,
                                                                        ViReal64  *avgPower,
                                                                        ViChar     errorMessage[])
{
  return RSCMU_MeasScalarPower(instrSession, RSCMU_COMMAND_READ, RSCMU_POWSLOT, timeslot, avgPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch average power in selected slot (FW >= 2.15)
/* Purpose : This function outputs the average power value of the
/*           selected timeslot (from 0 to 7)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowSlotSpow (ViSession  instrSession,
                                                                        ViInt32    timeslot,
                                                                        ViReal64  *avgPower,
                                                                        ViChar     errorMessage[])
{
  return RSCMU_MeasScalarPower(instrSession, RSCMU_COMMAND_FETC, RSCMU_POWSLOT, timeslot, avgPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample average power in selected slot (FW >= 2.15)
/* Purpose : This function outputs the average power value of the
/*           selected timeslot (from 0 to 7)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampPowSlotSpow (ViSession  instrSession,
                                                                        ViInt32    timeslot,
                                                                        ViReal64  *avgPower,
                                                                        ViChar     errorMessage[])
{
  return RSCMU_MeasScalarPower(instrSession, RSCMU_COMMAND_SAMP, RSCMU_POWSLOT, timeslot, avgPower, errorMessage);
}

/*===========================================================================*/
/* Function: Read power in all timeslots
/* Purpose : This function outputs the average all power values of the
/*           selected timeslot (from 0 to 7)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrPowSlot (ViSession instrSession,
                                                                       ViReal64  slotPowerValues[],
                                                                       ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPower(instrSession, RSCMU_COMMAND_READ, RSCMU_POWSLOT, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch power in all timeslots
/* Purpose : This function outputs the average all power values of the
/*           selected timeslot (from 0 to 7)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrPowSlot (ViSession instrSession,
                                                                       ViReal64  slotPowerValues[],
                                                                       ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPower(instrSession, RSCMU_COMMAND_FETC, RSCMU_POWSLOT, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Sample power in all timeslots
/* Purpose : This function outputs the average all power values of the
/*           selected timeslot (from 0 to 7)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrPowSlot (ViSession instrSession,
                                                                       ViReal64  slotPowerValues[],
                                                                       ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPower(instrSession, RSCMU_COMMAND_SAMP, RSCMU_POWSLOT, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Read all power in all slots
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrPowSlot (ViSession instrSession,
                                                                          ViReal64  slotPowerValues[],
                                                                          ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPower(instrSession, RSCMU_COMMAND_READ, RSCMU_POWSLOT, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch all power in all slots
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrPowSlot (ViSession instrSession,
                                                                          ViReal64  slotPowerValues[],
                                                                          ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPower(instrSession, RSCMU_COMMAND_FETC, RSCMU_POWSLOT, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Sample all power in all slots
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrPowSlot (ViSession instrSession,
                                                                         ViReal64  slotPowerValues[],
                                                                         ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPower(instrSession, RSCMU_COMMAND_SAMP, RSCMU_POWSLOT, slotPowerValues, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT POWER VERSUS SLOT TABLE MEASUREMENT
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowXslContDef (ViSession instrSession,
                                                                          ViInt32   DefaultValues,
                                                                          ViChar    errorMessage[])
{
  return RSCMU_ConfContDef(instrSession, RSCMU_POWXSL, RSCMU_NONE, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowXslContRep (ViSession instrSession,
                                                                          ViInt32   repetition,
                                                                          ViInt32   stopCondition,
                                                                          ViInt32   stepMode,
                                                                          ViChar    errorMessage[])
{
  return RSCMU_ConfControlRep(instrSession, RSCMU_POWXSL, RSCMU_NONE, repetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowXslContRepStat (ViSession instrSession,
                                                                              ViInt32   NbRepetition,
                                                                              ViInt32   stopCondition,
                                                                              ViInt32   stepMode,
                                                                              ViChar    errorMessage[])
{
  return RSCMU_ConfContRepStat(instrSession, RSCMU_POWXSL, RSCMU_NONE, NbRepetition, stopCondition, stepMode, errorMessage);
}


/*===========================================================================*/
/* Function: Set power subranges
/* Purpose : This function configures the read, fetch and sample commands.
/*           It restricts the measurement to up to 32 subranges where either
/*           all measurement results or a single statistical value is returned
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubPowXsl (ViSession instrSession,
                                                                      ViInt32   statMode,
                                                                      ViInt32   startTime,
                                                                      ViInt32   numberOfsamples,
                                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, statMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, startTime, 0, 127, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, numberOfsamples, 1, 128, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:POW:XSL %s,%d,%d", StrStatistics[statMode], startTime, numberOfsamples);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Slot Count
/* Purpose : This function defines the total number of slots measured.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowXslSco (ViSession instrSession,
                                                                      ViInt32   slotCount,
                                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrSlotCount[]={"S128","S256","S384","S512"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, slotCount, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Configure  slot count
  sprintf (wrtBuf, "CONF:POW:XSL:SCO %s", StrSlotCount[slotCount]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Slot Count for FW >= 3.05
/* Purpose : This function defines the total number of slots measured.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowXslSco305 (ViSession instrSession,
                                                                         ViInt32   Group,
                                                                         ViInt32   SlotCount,
                                                                         ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_ConfPowXslSco305 (instrSession, Group, SlotCount, errorMessage);
}

/*===========================================================================*/
/* Function: Start new measurement
/* Purpose : This function starts the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_InitPowXsl (ViSession instrSession,
                                                                   ViChar errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_POWXSL, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Abort running measurement and switch off
/* Purpose : This function stopss the power measurement, setting it to
/*           the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborPowXsl (ViSession instrSession,
                                                                   ViChar errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_POWXSL, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: stop measurement after current statistic cycle
/* Purpose : This function stops the power measurement, setting it to
/*           the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopPowXsl (ViSession instrSession,
                                                                   ViChar errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_POWXSL, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Next Measurement Step
/* Purpose : This function continue the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContPowXsl (ViSession instrSession,
                                                                   ViChar errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_POWXSL, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Combined Power & Modulation Measurement Status
/* Purpose : This function returns the status of the current Power versus
/*           slot measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowXslStat (ViSession instrSession,
                                                                       ViInt32  *measStatus,
                                                                       ViInt32  *CurrCycleCounter,
                                                                       ViChar    errorMessage[])
{
  ViInt32 EvalPeriodCounter; //only needed to allow  call of RSCMU_FetcStatus()

  return RSCMU_FetcStatus(instrSession, RSCMU_POWXSL, RSCMU_NONE, measStatus, CurrCycleCounter, &EvalPeriodCounter, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowXslErep (ViSession instrSession,
                                                                       ViInt32   Report,
                                                                       ViChar    errorMessage[])
{
   return RSCMU_ConfReporting(instrSession, RSCMU_POWXSL, RSCMU_NONE, Report, errorMessage);
}

/*===========================================================================*/
/* Function: Read average power in selected slot
/* Purpose : This function outputs the average power value of the
/*           selected timeslot (from 0 to 127)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowXslSpow (ViSession instrSession,
                                                                       ViInt32   timeslot,
                                                                       ViReal64 *avgPower,
                                                                       ViChar    errorMessage[])
{
  return RSCMU_MeasScalarPower(instrSession, RSCMU_COMMAND_READ, RSCMU_POWXSL, timeslot, avgPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetches average power in selected slot
/* Purpose : This function outputs the average power value of the
/*           selected timeslot (from 0 to 127)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowXslSpow (ViSession instrSession,
                                                                       ViInt32   timeslot,
                                                                       ViReal64 *avgPower,
                                                                       ViChar    errorMessage[])
{
   return RSCMU_MeasScalarPower(instrSession, RSCMU_COMMAND_FETC, RSCMU_POWXSL, timeslot, avgPower, errorMessage);
}

/*===========================================================================*/
/* Function: Samples average power in selected slot
/* Purpose : This function outputs the average power value of the
/*           selected timeslot (from 0 to 127)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampPowXslSpow (ViSession instrSession,
                                                                       ViInt32   timeslot,
                                                                       ViReal64 *avgPower,
                                                                       ViChar    errorMessage[])
{
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, timeslot, 0, 127, RSCMU_ERROR_PARAMETER2, errorMessage);

  return RSCMU_MeasScalarPower(instrSession, RSCMU_COMMAND_SAMP, RSCMU_POWXSL, timeslot, avgPower, errorMessage);
}

/*===========================================================================*/
/* Function: Read average power in all slots
/* Purpose : This function outputs the average power value of all
/*           timeslots (from 0 to 127)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrPowXsl (ViSession instrSession,
                                                                      ViReal64  slotPowerValues[],
                                                                      ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPower(instrSession, RSCMU_COMMAND_READ, RSCMU_POWXSL, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetches average power in all slots
/* Purpose : This function outputs the average power value of all
/*           timeslots (from 0 to 127)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrPowXsl (ViSession instrSession,
                                                                      ViReal64  slotPowerValues[],
                                                                      ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPower(instrSession, RSCMU_COMMAND_FETC, RSCMU_POWXSL, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Samples average power in all slots
/* Purpose : This function outputs the average power value of all
/*           timeslots (from 0 to 127)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrPowXsl (ViSession instrSession,
                                                                      ViReal64  slotPowerValues[],
                                                                      ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPower(instrSession, RSCMU_COMMAND_SAMP, RSCMU_POWXSL, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Reads all power in all slots
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrPowXsl (ViSession instrSession,
                                                                         ViReal64  slotPowerValues[],
                                                                         ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPower(instrSession, RSCMU_COMMAND_READ, RSCMU_POWXSL, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetches all power in all slots
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrPowXsl (ViSession instrSession,
                                                                         ViReal64  slotPowerValues[],
                                                                         ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPower(instrSession, RSCMU_COMMAND_FETC, RSCMU_POWXSL, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Samples all power in all slots
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrPowXsl (ViSession instrSession,
                                                                         ViReal64  slotPowerValues[],
                                                                         ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPower(instrSession, RSCMU_COMMAND_SAMP, RSCMU_POWXSL, slotPowerValues, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT POWER VERSUS FRAME MEASUREMENT
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowFramContDef (ViSession instrSession,
                                                                           ViInt32   defaultValues,
                                                                           ViChar    errorMessage[])
{
  return RSCMU_ConfContDef(instrSession, RSCMU_POWFRAM, RSCMU_NONE, defaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowFramContRep (ViSession instrSession,
                                                                           ViInt32   repetition,
                                                                           ViInt32   stopCondition,
                                                                           ViInt32   stepMode,
                                                                           ViChar    errorMessage[])
{
  return RSCMU_ConfControlRep(instrSession, RSCMU_POWFRAM, RSCMU_NONE, repetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowFramContRepStat (ViSession instrSession,
                                                                               ViInt32   NbRepetition,
                                                                               ViInt32   stopCondition,
                                                                               ViInt32   stepMode,
                                                                               ViChar    errorMessage[])
{
  return RSCMU_ConfContRepStat(instrSession, RSCMU_POWFRAM, RSCMU_NONE, NbRepetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Set power subranges
/* Purpose : This function configures the read, fetch and sample commands.
/*           It restricts the measurement to up to 32 subranges where either
/*           all measurement results or a single statistical value is returned
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubPowFram (ViSession instrSession,
                                                                       ViInt32   statMode,
                                                                       ViInt32   startTime,
                                                                       ViInt32   numberOfsamples,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, statMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, startTime, 0, 127, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, numberOfsamples, 1, 128, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:POW:FRAM %s,%d,%d", StrStatistics[statMode], startTime, numberOfsamples);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Start new measurement
/* Purpose : This function starts the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_InitPowFram (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_POWFRAM, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Abort running measurement and switch off
/* Purpose : This function stopss the power measurement, setting it to
/*           the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborPowFram (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_POWFRAM, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Stop measurement after current statistic cycle
/* Purpose : This function stops the power measurement, setting it to
/*           the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopPowFram (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_POWFRAM, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Next Measurement Step
/* Purpose : This function continue the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContPowFram (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_POWFRAM, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Power vs Frame Measurement Status
/* Purpose : This function returns the status of the current Power versus
/*           Frame measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowFramStat (ViSession instrSession,
                                                                        ViInt32  *measStatus,
                                                                        ViInt32  *CurrCycleCounter,
                                                                        ViChar    errorMessage[])
{
  ViInt32 EvalPeriodCounter; //only needed to allow  call of RSCMU_FetcStatus()

  return RSCMU_FetcStatus(instrSession, RSCMU_POWFRAM, RSCMU_NONE, measStatus, CurrCycleCounter, &EvalPeriodCounter, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowFramErep (ViSession instrSession,
                                                                        ViInt32   Report,
                                                                        ViChar    errorMessage[])
{
  return RSCMU_ConfReporting(instrSession, RSCMU_POWFRAM, RSCMU_NONE, Report, errorMessage);
}

/*===========================================================================*/
/* Function: Reads average power in selected slot
/* Purpose : This function outputs the average power value of the
/*           selected frame (from 1 to 128)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowFramFpow (ViSession instrSession,
                                                                        ViInt32   timeslot,
                                                                        ViReal64 *avgPower,
                                                                        ViChar    errorMessage[])
{
  return RSCMU_MeasScalarPower(instrSession, RSCMU_COMMAND_READ, RSCMU_POWFRAM, timeslot, avgPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetches average power in selected slot
/* Purpose : This function outputs the average power value of the
/*           selected frame (from 1 to 128)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowFramFpow (ViSession instrSession,
                                                                        ViInt32   timeslot,
                                                                        ViReal64 *avgPower,
                                                                        ViChar    errorMessage[])
{
  return RSCMU_MeasScalarPower(instrSession, RSCMU_COMMAND_FETC, RSCMU_POWFRAM, timeslot, avgPower, errorMessage);
}

/*===========================================================================*/
/* Function: Samples average power in selected slot
/* Purpose : This function outputs the average power value of the
/*           selected frame (from 1 to 128)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampPowFramFpow (ViSession instrSession,
                                                                        ViInt32   timeslot,
                                                                        ViReal64 *avgPower,
                                                                        ViChar    errorMessage[])
{
  return RSCMU_MeasScalarPower(instrSession, RSCMU_COMMAND_SAMP, RSCMU_POWFRAM, timeslot, avgPower, errorMessage);
}

/*===========================================================================*/
/* Function: Reads average power in selected slot
/* Purpose : This function outputs the average burst power value in the 128
/*           consecutive timeslots (from 1 to 128)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrPowFram (ViSession instrSession,
                                                                       ViReal64  slotPowerValues[],
                                                                       ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPower(instrSession, RSCMU_COMMAND_READ, RSCMU_POWFRAM, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetches average power in selected slot
/* Purpose : This function outputs the average burst power value in the 128
/*           consecutive timeslots (from 1 to 128)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrPowFram (ViSession instrSession,
                                                                       ViReal64  slotPowerValues[],
                                                                       ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPower(instrSession, RSCMU_COMMAND_FETC, RSCMU_POWFRAM, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Samples average power in selected slot
/* Purpose : This function outputs the average burst power value in the 128
/*           consecutive timeslots (from 1 to 128)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrPowFram (ViSession instrSession,
                                                                       ViReal64  slotPowerValues[],
                                                                       ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPower(instrSession, RSCMU_COMMAND_SAMP, RSCMU_POWFRAM, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Reads all power in all slots
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrPowFram (ViSession instrSession,
                                                                          ViReal64  slotPowerValues[],
                                                                          ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPower(instrSession, RSCMU_COMMAND_READ, RSCMU_POWFRAM, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Reads all power in all slots
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrPowFram (ViSession instrSession,
                                                                          ViReal64  slotPowerValues[],
                                                                          ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPower(instrSession, RSCMU_COMMAND_FETC, RSCMU_POWFRAM, slotPowerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Reads all power in all slots
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrPowFram (ViSession instrSession,
                                                                          ViReal64  slotPowerValues[],
                                                                          ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPower(instrSession, RSCMU_COMMAND_SAMP, RSCMU_POWFRAM, slotPowerValues, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT POWER/PCL
 * ----------------------------------------------------------------------------
*/
/*===========================================================================*/
/* Function: Start new measurement
/* Purpose : This function starts the power/PCL measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_InitPowPcl (ViSession       instrSession,
                                                                    ViChar  errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_POWPCL, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Abort running measurement and switch off
/* Purpose : This function stops the power/PCL measurement, setting it to
/*           the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborPowPcl (ViSession       instrSession,
                                                                    ViChar  errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_POWPCL, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: stop measurement after current statistic cycle
/* Purpose : This function stops the power/PCL measurement, setting it to
/*           the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopPowPcl (ViSession       instrSession,
                                                                    ViChar  errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_POWPCL, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Next Measurement Step (restart measurement)
/* Purpose : This function continue the power/PCL measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContPowPcl (ViSession       instrSession,
                                                                    ViChar  errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_POWPCL, RSCMU_NONE, errorMessage);
}


/*===========================================================================*/
/* Function: Retrieve P/PCL measurement results.
/* Purpose : This function returns all measurement results.The results can be
/*           retrieved by means of the FETCh, SAMPle or READ query. The
/*           returned list contains all possible PCLs of the mobile phone
/*           together with the measured MS output powers in the three selected
/*           channels.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_MeasCommPowPcl (ViSession  instrSession,
                                                                   ViInt32    MeasCommand,
                                                                   ViReal64   PCLChannelTable1[],
                                                                   ViReal64   PCLChannelTable2[],
                                                                   ViReal64   PCLChannelTable3[],
                                                                   ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf [WR_BUFFER_SIZE], rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViChar      TableOfToken[100][100];
  ViChar      *Token;
  ViInt16     Index = 0;
  ViInt32     PCLi;
  ViInt16     NbOfToken;

  for (PCLi=0; PCLi<31; PCLi++)
  {
    PCLChannelTable1[PCLi] = RSCMU_NAN;
    PCLChannelTable2[PCLi] = RSCMU_NAN;
    PCLChannelTable3[PCLi] = RSCMU_NAN;
  }

  switch (MeasCommand)
  {
    case RSCMU_COMMAND_READ:
      sprintf (wrtBuf, "READ:POW:PCL?");
    break;
    case RSCMU_COMMAND_FETC:
      sprintf (wrtBuf, "FETC:POW:PCL?");
    break;
    case RSCMU_COMMAND_SAMP:
      sprintf (wrtBuf, "SAMP:POW:PCL?");
    break;
  }

  // Write data to the CMU
  if ((RSCMU_Status = RSCMU_Write (instrSession, wrtBuf, RSCMU_STB_ON, strlen(wrtBuf), errorMessage)) < 0)
    return RSCMU_Base_errorMessage (instrSession, RSCMU_Status, errorMessage);

  // Read the resulting output
  if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
    return RSCMU_Base_errorMessage (instrSession, RSCMU_Status, errorMessage);

  // Separate the CMU response:
  Token = strtok (rdBuf, ",");

  while (Token)
  {
    strcpy (TableOfToken[Index++], Token);
    Token = strtok (NULL, ",");
  }

  NbOfToken = Index;
  Index = 0;

  while (Index < NbOfToken)
  {
    // Get the PCL of the mobile:
    if ((RSCMU_Status = RSCMU_GetViInt32Value (TableOfToken, Index++, &PCLi)) < 0)
      return RSCMU_Status;

    // Get the average burst power for the current PCLi and first defined channel:
    if ((RSCMU_Status = RSCMU_GetViReal64Value (TableOfToken, Index++, &PCLChannelTable1[PCLi])) < 0)
      return RSCMU_Status;

    // Get the average burst power for the current PCLi and second defined channel:
    if ((RSCMU_Status = RSCMU_GetViReal64Value (TableOfToken, Index++, &PCLChannelTable2[PCLi])) < 0)
      return RSCMU_Status;

    // Get the average burst power for the current PCLi and third defined channel:
    if ((RSCMU_Status = RSCMU_GetViReal64Value (TableOfToken, Index++, &PCLChannelTable3[PCLi])) < 0)
      return RSCMU_Status;
  }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Start single shot P/PCL measurement.
/* Purpose : This function starts a single shot measurement and returns all
/*           measurement results. The returned list contains all possible
/*           PCLs of the mobile phone together with the measured MS output
/*           powers in the three selected channels.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowPcl (ViSession  instrSession,
                                                                   ViReal64   PCLChannelTable1[],
                                                                   ViReal64   PCLChannelTable2[],
                                                                   ViReal64   PCLChannelTable3[],
                                                                   ViChar     errorMessage[])
{
  return (RSCMU_GSM_MeasCommPowPcl (instrSession, RSCMU_COMMAND_READ, PCLChannelTable1, PCLChannelTable2, PCLChannelTable3, errorMessage));
}

/*===========================================================================*/
/* Function: Read out P/PCL measurement (unsynchronized).
/* Purpose : This functions reads out measurement results (unsynchronized).
/*           The returned list contains all possible PCLs of the mobile phone
/*           together with the measured MS output powers in the three
/*           selected channels.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowPcl (ViSession  instrSession,
                                                                   ViReal64   PCLChannelTable1[],
                                                                   ViReal64   PCLChannelTable2[],
                                                                   ViReal64   PCLChannelTable3[],
                                                                   ViChar     errorMessage[])
{
  return (RSCMU_GSM_MeasCommPowPcl (instrSession, RSCMU_COMMAND_FETC, PCLChannelTable1, PCLChannelTable2, PCLChannelTable3, errorMessage));
}

/*===========================================================================*/
/* Function: Read out P/PCL measurement (synchronized).
/* Purpose : This functions reads out measurement results (synchronized). The
/*           returned list contains all possible PCLs of the mobile phone
/*           together with the measured MS output powers in the three
/*           selected channels.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampPowPcl (ViSession  instrSession,
                                                                   ViReal64   PCLChannelTable1[],
                                                                   ViReal64   PCLChannelTable2[],
                                                                   ViReal64   PCLChannelTable3[],
                                                                   ViChar     errorMessage[])
{
  return (RSCMU_GSM_MeasCommPowPcl (instrSession, RSCMU_COMMAND_SAMP, PCLChannelTable1, PCLChannelTable2, PCLChannelTable3, errorMessage));
}

/*===========================================================================*/
/* Function: Read out power at one particular PCL
/* Purpose : This function starts a measurement and returns the mobile output
/*           power at one particular PCL specified with the parameter PCL Number
/*           and for the channels specified via the functions 3 Channels or 7
/*           Channels. The total number n of channels measured is either 3 or 7,
/*           depending on the Channel count setting.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowPclp (ViSession instrSession,
                                                                    ViInt32   PCLNumber,
                                                                    ViReal64  outputPower[],
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf [WR_BUFFER_SIZE], rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViChar      tab[100][100];
  ViInt32     i;

  // Initializes the 4 last results with NAN in case of 3 channel measurement
  if(PCLNumber == 3)
  {
    for(i=3;i<7;i++)
      strcpy(tab[i], "NAN");
  }

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, PCLNumber, 0, 31, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "READ:POW:PCL:PCLP%d?", PCLNumber);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the output power values
  RSCMU_Status = RSCMU_GetViReal64Value(tab, 0, outputPower);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Read out power at one particular PCL
/* Purpose : This function starts a measurement and returns the mobile output
/*           power at one particular PCL specified with the parameter PCL Number
/*           and for the channels specified via the functions 3 Channels or 7
/*           Channels. The total number n of channels measured is either 3 or 7,
/*           depending on the Channel count setting.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowPclp (ViSession instrSession,
                                                                    ViInt32   PCLNumber,
                                                                    ViReal64  outputPower[],
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf [WR_BUFFER_SIZE], rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViChar      tab[100][100];
  ViInt32     i;

  // Initializes the 4 last results with NAN in case of 3 channel measurement
  if(PCLNumber == 3)
  {
    for(i=3;i<7;i++)
      strcpy(tab[i], "NAN");
  }

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, PCLNumber, 0, 31, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "FETC:POW:PCL:PCLP%d?", PCLNumber);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the output power values
  RSCMU_Status = RSCMU_GetViReal64Value(tab, 0, outputPower);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Read out power at one particular PCL
/* Purpose : This function starts a measurement and returns the mobile output
/*           power at one particular PCL specified with the parameter PCL Number
/*           and for the channels specified via the functions 3 Channels or 7
/*           Channels. The total number n of channels measured is either 3 or 7,
/*           depending on the Channel count setting.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampPowPclp (ViSession instrSession,
                                                                    ViInt32   PCLNumber,
                                                                    ViReal64  outputPower[],
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf [WR_BUFFER_SIZE], rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViChar      tab[100][100];
  ViInt32     i;

  // Initializes the 4 last results with NAN in case of 3 channel measurement
  if(PCLNumber == 3)
  {
    for(i=3;i<7;i++)
      strcpy(tab[i], "NAN");
  }

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, PCLNumber, 0, 31, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "SAMP:POW:PCL:PCLP%d?", PCLNumber);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the output power values
  RSCMU_Status = RSCMU_GetViReal64Value(tab, 0, outputPower);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: P/PCL Limit Check
/* Purpose : This function indicates whether and in which way the permissible
/*           tolerances for the burst power versus PCL application for three
/*           selected channels are exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcPowPclLimMatc (ViSession       instrSession,
                                                                          ViInt32         PCLChannelTable1[],
                                                                          ViInt32         PCLChannelTable2[],
                                                                          ViInt32         PCLChannelTable3[],
                                                                          ViChar  errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViChar      TableOfToken[100][100];
  ViChar      *Token;
  ViInt16     Index = 0;
  ViInt32     PCLi;
  ViInt16     NbOfToken;

  for (PCLi=0; PCLi<31; PCLi++)
  {
    PCLChannelTable1[PCLi] = RSCMU_NAN_VI_INT32;
    PCLChannelTable2[PCLi] = RSCMU_NAN_VI_INT32;
    PCLChannelTable3[PCLi] = RSCMU_NAN_VI_INT32;
  }

  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, "CALC:POW:PCL:LIM:MATC?", rdBuf, RSCMU_STB_OFF, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  Token = strtok (rdBuf, ",");

  while (Token)
  {
    strcpy (TableOfToken[Index++], Token);
    Token = strtok (NULL, ",");
  }

  NbOfToken = Index;
  Index = 0;

  while (Index < NbOfToken)
  {
    // Get the PCL of the mobile:
    if ((RSCMU_Status = RSCMU_GetViInt32Value (TableOfToken, Index++, &PCLi)) < 0)
      return RSCMU_Status;

    // Get the limit check for the current PCLi and first defined channel:
    if ((RSCMU_Status = RSCMU_GetLimitCheckValue (TableOfToken, Index++, &PCLChannelTable1[PCLi])) < 0)
      return RSCMU_Status;

    // Get the limit check for the current PCLi and second defined channel:
    if ((RSCMU_Status = RSCMU_GetLimitCheckValue (TableOfToken, Index++, &PCLChannelTable2[PCLi])) < 0)
      return RSCMU_Status;

    // Get the limit check for the current PCLi and third defined channel:
    if ((RSCMU_Status = RSCMU_GetLimitCheckValue (TableOfToken, Index++, &PCLChannelTable3[PCLi])) < 0)
      return RSCMU_Status;
  }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: P/PCL Measurement Status
/* Purpose : This function returns the status of the current P/PCL measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowPclStat (ViSession       instrSession,
                                                                       ViPInt32        MeasurementStatus,
                                                                       ViPInt32        CountingNo,
                                                                       ViChar  errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  // Fetch the status of the current P/PCL measurement:
  if ((RSCMU_Status = RSCMU_Query (instrSession, "FETC:POW:PCL:STAT?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Get the status of the measurement:
  if ((RSCMU_Status = RSCMU_GetMeasStatVal (MeasurementStatus, TableOfDataValues, 0)) < 0)
    return RSCMU_Status;

  // Get the current value of the statistics counter (the number of the current statistics cycle):
  if ((RSCMU_Status = RSCMU_GetCountingNo (CountingNo, TableOfDataValues, 1)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowPclErep (ViSession  instrSession,
                                                                       ViInt32    Mode,
                                                                       ViChar     errorMessage[])
{
  return RSCMU_ConfReporting(instrSession, RSCMU_POWPCL, RSCMU_NONE, Mode, errorMessage);
}


/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowPclContRep (ViSession  instrSession,
                                                                           ViInt32    repetition,
                                                                           ViInt32    stopCondition,
                                                                           ViInt32    stepMode,
                                                                           ViChar     errorMessage[])
{
  return RSCMU_ConfControlRep(instrSession, RSCMU_POWPCL, RSCMU_NONE, repetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowPclContRepStat (ViSession instrSession,
                                                                              ViInt32   NbRepetition,
                                                                              ViInt32   stopCondition,
                                                                              ViInt32   stepMode,
                                                                              ViChar    errorMessage[])
{
  return RSCMU_ConfContRepStat(instrSession, RSCMU_POWPCL, RSCMU_NONE, NbRepetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Channel Count
/* Purpose : This function defines whether three or seven different channels
/*           are measured in the P/PCL measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowPclChanCount (ViSession instrSession,
                                                                            ViInt32   NbChannels,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  if((NbChannels != 3) && (NbChannels != 7))
    return RSCMU_Base_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf, "CONF:POW:PCL:CCO C%d", NbChannels);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;

}

/*===========================================================================*/
/* Function:
/* Purpose : This function defines three GSM channel numbers for the P/PCL
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowPclChan (ViSession  instrSession,
                                                                       ViInt32    Channel1,
                                                                       ViInt32    Channel2,
                                                                       ViInt32    Channel3,
                                                                       ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Set the three channels:
  sprintf (wrtBuf, "CONF:POW:PCL:CHAN %d,%d,%d", Channel1, Channel2, Channel3);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function:
/* Purpose : This function defines seven GSM channel numbers for the P/PCL
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowPcl7Chan (ViSession  instrSession,
                                                                        ViInt32    Channel1,
                                                                        ViInt32    Channel2,
                                                                        ViInt32    Channel3,
                                                                        ViInt32    Channel4,
                                                                        ViInt32    Channel5,
                                                                        ViInt32    Channel6,
                                                                        ViInt32    Channel7,
                                                                        ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Set the seven channels:
  sprintf (wrtBuf, "CONF:POW:PCL:CHAN %d,%d,%d,%d,%d,%d,%d", Channel1, Channel2, Channel3, Channel4, Channel5, Channel6, Channel7);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT MODULATION
 *    The subsystem MODulation contains the commands for the
 *    measurement of the modulation parameters, ie the frequency and
 *    measured bursts phase error.
 * ----------------------------------------------------------------------------
 *      CONTROL OF MODULATION MEAS
 *      It contains the functions for general control of the modulation
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: StartMeasurements
/* Purpose : This function start measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_InitMod (ViSession instrSession,
                                                                ViChar    errorMessage[])
{
    return RSCMU_GSM_NSig_InitMod (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Start Combined Power/Modulation Measurements
/* Purpose : This function start the Combined Power/Modulation measurement,
/*           setting it to the status beyond.
/*           RUN        Start measurement without waiting
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_InitPowMpr (ViSession instrSession, ViChar errorMessage[])
{
    return RSCMU_GSM_NSig_InitPowMpr (  instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: StartMeasurements
/* Purpose : This function start measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborMod (ViSession instrSession,
                                                                ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_AborMod (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: StartMeasurements
/* Purpose : This function start measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborPowMpr (ViSession instrSession,
                                                                   ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_AborPowMpr (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Stop Measurements
/* Purpose : This function stop measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopMod (ViSession instrSession,
                                                                ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_StopMod (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Stop Measurements
/* Purpose : This function stop measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopPowMpr (ViSession instrSession, ViChar errorMessage[])
{
  return RSCMU_GSM_NSig_StopPowMpr (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: StartMeasurements
/* Purpose : This function start measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContMod (ViSession instrSession,
                                                                ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_ContMod (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Cont Measurements
/* Purpose : This function cont measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContPowMpr (ViSession instrSession, ViChar errorMessage[])
{
  return RSCMU_GSM_NSig_ContPowMpr (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurementis terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModErep (ViSession  instrSession,
                                                                    ViInt32    Mode,
                                                                    ViChar     errorMessage[])
{
  return RSCMU_GSM_NSig_ConfModErep (instrSession, Mode, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurementis terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMprErep (ViSession  instrSession,
                                                                       ViInt32    Mode,
                                                                       ViChar     errorMessage[])
{
  return RSCMU_GSM_NSig_ConfPowMprErep (instrSession, Mode, errorMessage);
}

/*===========================================================================*/
/* Function: Modulation Measurement Status
/* Purpose : This function returns the status of the current Modulation
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcModStat (ViSession      instrSession,
                                                                    ViInt32       *MeasurementStatus,
                                                                    ViInt32       *CountingNo,
                                                                    ViInt32       *StatisticNo,
                                                                    ViChar errorMessage[])
{
  return RSCMU_GSM_NSig_FetcModStat (instrSession, MeasurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*===========================================================================*/
/* Function: Combined Power & Modulation Measurement Status
/* Purpose : This function returns the status of the current combined Power
/*           & Modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowMprStat (ViSession      instrSession,
                                                                       ViInt32       *MeasurementStatus,
                                                                       ViInt32       *CountingNo,
                                                                       ViInt32       *StatisticNo,
                                                                       ViChar errorMessage[])
{
  return RSCMU_GSM_NSig_FetcPowMprStat (instrSession, MeasurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      CONTROL
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModCont (ViSession instrSession,
                                                                    ViInt32   MeasuredValuesType,
                                                                    ViInt32   NbBurst,
                                                                    ViChar    errorMessage[])
{
    ViChar      wrBuf[WR_BUFFER_SIZE]= "";

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, MeasuredValuesType,0,1, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, NbBurst, 1, 1000, RSCMU_ERROR_PARAMETER4, errorMessage);

    sprintf(wrBuf, "CONF:MOD:CONT %s,%d", mode_ScopeMeas[MeasuredValuesType], NbBurst);

    RETMSG(RSCMU_sendCmd(instrSession, wrBuf));
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModContRep (ViSession  instrSession,
                                                                       ViInt32    Repetition,
                                                                       ViInt32    multipleMeasurement,
                                                                       ViInt32    StopCondition,
                                                                       ViInt32    StepMode,
                                                                       ViChar     errorMessage[])
{
    ViStatus    RSCMU_Status;
    ViChar      wrBuf[WR_BUFFER_SIZE]= "";
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    if (Repetition != RSCMU_MULT)
    {
        sprintf(wrBuf, "CONF:MOD:CONT:REP %s,%s,%s",
                                            repetitionArr[Repetition],
                                            stopConditionArr[StopCondition],
                                            stepModeArr[StepMode]);
    }
    else
    {
        sprintf(wrBuf, "CONF:MOD:CONT:REP %d,%s,%s",
                                            multipleMeasurement,
                                            stopConditionArr[StopCondition],
                                            stepModeArr[StepMode]);
    }

    RETMSG(RSCMU_sendCmd(instrSession, wrBuf));


  //return RSCMU_GSM_NSig_ConfModContRep (instrSession, Repetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Set Scope of measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMprCont (ViSession instrSession,
                                                                       ViInt32   MeasuredValuesType,
                                                                       ViInt32   NbBurst,
                                                                       ViChar    errorMessage[])
{
 return  RSCMU_GSM_NSig_ConfPowMprCont (instrSession, MeasuredValuesType, NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMprContRep (ViSession  instrSession,
                                                                          ViInt32    Repetition,
                                                                          ViInt32    StopCondition,
                                                                          ViInt32    StepMode,
                                                                          ViChar     errorMessage[])
{
    return RSCMU_GSM_NSig_ConfPowMprContRep (instrSession, Repetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModContDef (ViSession instrSession,
                                                    ViBoolean setDefaultValues,
                                                    ViChar errorMessage[])
{
    return RSCMU_ConfContDef(instrSession, RSCMU_MOD, RSCMU_GMSK, setDefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Set Default limit Lines (ON/OFF)
/* Purpose : This function switches the default limit lines on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModLimDef (ViSession instrSession,
                                               ViBoolean defaultLimitLines,
                                               ViChar errorMessage[])
{
  ViStatus    RSCMU_Status;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) defaultLimitLines, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:LIM:DEF %s", mode_On_Off[defaultLimitLines]);

  return RSCMU_sendCmd (instrSession, wrtBuf);
}

/* ----------------------------------------------------------------------------
 *      LIMITS
 *      The subsystem MODulation:LIMit contains the functions for
 *      definition of tolerance values for the modulation measurement.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: ErrorLimits
/* Purpose : This function defines the upper limits for the peak and rms
/*           phase error as well as for the frequency error in the
/*           current burst.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModLim (ViSession instrSession,
                                                                   ViInt32   KindOfBurst,
                                                                   ViReal64  MaxPhaseErrorLimit,
                                                                   ViReal64  RMSPhaseErrorLimit,
                                                                   ViReal64  FrequencyErrorLimit,
                                                                   ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) KindOfBurst, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, MaxPhaseErrorLimit, 0, RSCMU_PHASE_ERROR_LIM_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, RMSPhaseErrorLimit, 0, RSCMU_PHASE_ERROR_LIM_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, FrequencyErrorLimit, 0, RSCMU_FREQ_ERROR_LIM_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);

  switch (KindOfBurst)
  {
    case RSCMU_CURRENT:
      sprintf (wrtBuf, "CONF:MOD:LIM %lf,%lf,%lf", MaxPhaseErrorLimit, RMSPhaseErrorLimit, FrequencyErrorLimit);
      break;
    case RSCMU_AVERAGE:
      sprintf (wrtBuf, "CONF:MOD:LIM:AVER %lf,%lf,%lf", MaxPhaseErrorLimit, RMSPhaseErrorLimit, FrequencyErrorLimit);
      break;
  }
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Limit Upper Mode
/* Purpose : This function switches the upper limit checking
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModLimUppMod (ViSession instrSession,
                                                                         ViBoolean upperlimitcheck,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrUpperLimitCheckOnOff[] = {"OFF","ON"};

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) upperlimitcheck, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:LIM:UPP:MODE %s", StrUpperLimitCheckOnOff[upperlimitcheck]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Limit Lower Mode
/* Purpose : This function switches the lower limit checking
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModLimLowMod (ViSession instrSession,
                                                                         ViBoolean lowerlimitcheck,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrLowerLimitCheckOnOff[] = {"OFF","ON"};

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) lowerlimitcheck, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:LIM:LOW:MODE %s", StrLowerLimitCheckOnOff[lowerlimitcheck]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}


/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 * ----------------------------------------------------------------------------
 */

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMprContRepStat (ViSession  instrSession,
                                                                              ViInt32    NbRepetition,
                                                                              ViInt32    StopCondition,
                                                                              ViInt32    StepMode,
                                                                              ViChar     errorMessage[])
{
    return RSCMU_GSM_NSig_ConfPowMprContRepStat (instrSession, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModContRepStat (ViSession  instrSession,
                                                                           ViInt32    NbRepetition,
                                                                           ViInt32    StopCondition,
                                                                           ViInt32    StepMode,
                                                                           ViChar     errorMessage[])
{
  return RSCMU_GSM_NSig_ConfModContRepStat (instrSession, NbRepetition, StopCondition, StepMode, errorMessage);
}
/*
 * ----------------------------------------------------------------------------
 *      RESULTS: FREQUENCY AND PHASE ERROR
 *      The subsystem MODulation[:RESULT] contains the commands for
 *      measurement and output of the frequency and phase error and
 *      their comparison with the tolerance values.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This funcyion start a measurement and output all scalar,
/*           numeric measurement results.
/*      These are:
/*  Maximum phase error with single-value measurement
/*             => phase error peak current
/*  Maximum phase error with average measurement
/*             => phase error peak average
/*  Maximum phase error with extreme-value measurement
/*             => phase error peak max./min.
/*  Rms phase error with single-value measurement
/*             => phase error RMS current
/*  Rms phase error with average measurement
/*             => phase error RMS average
/*  Rms phase error with extreme-value measurement
/*             => phase error RMS max./min.
/*  Frequency error with single-value measurement
/*             => frequency error current
/*  Frequency error with average measurement
/*             => frequency error average
/*  Frequency error with extreme-value measurement
/*             => frequency error max./min.
/*  Average burst power with single-value measurement
/*             => avg. burst power current
/*  Relative portion of faulty burst
/*             => bursts out of tolerance
/*
/*      Average measurement means that the results of the single-value
/*      measurement are averaged over several bursts. Extreme-value
/*      measurement means that the extreme value is determined from the
/*      results of the single-value measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadMod (ViSession instrSession,
                                                                ViInt32   StatisticsMode,
                                                                ViReal64 *phErrPeak,
                                                                ViReal64 *phErrRMS,
                                                                ViReal64 *freqErr,
                                                                ViReal64 *avgBurstPowerCurr,
                                                                ViReal64 *burstOutOfTol,
                                                                ViChar    errorMessage[])
{
 return RSCMU_GSM_NSig_ReadMod (instrSession, StatisticsMode, phErrPeak,  phErrRMS,
                    freqErr,  avgBurstPowerCurr,burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This funcyion start a measurement and output all scalar,
/*           numeric measurement results.
/*      These are:

/*      Average measurement means that the results of the single-value
/*      measurement are averaged over several bursts. Extreme-value
/*      measurement means that the extreme value is determined from the
/*      results of the single-value measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcMod (ViSession instrSession,
                                                                ViInt32   StatisticsMode,
                                                                ViReal64 *phErrPeak,
                                                                ViReal64 *phErrRMS,
                                                                ViReal64 *freqErr,
                                                                ViReal64 *avgBurstPowerCurr,
                                                                ViReal64 *burstOutOfTol,
                                                                ViChar    errorMessage[])
{
 return RSCMU_GSM_NSig_FetcMod (instrSession, StatisticsMode, phErrPeak,  phErrRMS,
                    freqErr,avgBurstPowerCurr,burstOutOfTol, errorMessage);
}


/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function outputs all scalar, numeric measurement results.
/*      Average measurement means that the results of the single-value
/*      measurement are averaged over several bursts. Extreme-value
/*      measurement means that the extreme value is determined from the
/*      results of the single-value measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowMpr (ViSession   instrSession,
                                                                   ViInt32     StatisticsMode,
                                                                   ViReal64   *AvgBurstPwCurr,
                                                                   ViReal64   *PeakBurstPwCurr,
                                                                   ViInt32    *PowerControlLevel,
                                                                   ViReal64   *TimingAdvError,
                                                                   ViReal64   *BurstOutOfTol,
                                                                   ViInt32    *BurstMatching,
                                                                   ViReal64   *PhErrPeak,
                                                                   ViReal64   *PhErrRMS,
                                                                   ViReal64   *FreqErr,
                                                                   ViReal64   *AvgBurstPwAvg,
                                                                   ViChar      errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  if ((RSCMU_Status = RSCMU_Query (instrSession, "FETC:POW:MPR?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Scan the results of combined power & modulation:
  RSCMU_Sig_ScanPowMpr (TableOfDataValues,
                        StatisticsMode,
                        AvgBurstPwCurr,
                        PeakBurstPwCurr,
                        PowerControlLevel,
                        TimingAdvError,
                        BurstOutOfTol,
                        BurstMatching,
                        PhErrPeak,
                        PhErrRMS,
                        FreqErr,
                        AvgBurstPwAvg);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function start a measurement and output all scalar,
/*           numeric measurement results.
/*      Average measurement means that the results of the single-value
/*      measurement are averaged over several bursts. Extreme-value
/*      measurement means that the extreme value is determined from the
/*      results of the single-value measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowMpr (ViSession   instrSession,
                                                                   ViInt32     StatisticsMode,
                                                                   ViReal64   *AvgBurstPwCurr,
                                                                   ViReal64   *PeakBurstPwCurr,
                                                                   ViInt32    *PowerControlLevel,
                                                                   ViReal64   *TimingAdvError,
                                                                   ViReal64   *BurstOutOfTol,
                                                                   ViInt32    *BurstMatching,
                                                                   ViReal64   *PhErrPeak,
                                                                   ViReal64   *PhErrRMS,
                                                                   ViReal64   *FreqErr,
                                                                   ViReal64   *AvgBurstPwAvg,
                                                                   ViChar      errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  if ((RSCMU_Status = RSCMU_Query (instrSession, "READ:POW:MPR?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Scan the results of combined power & modulation:
  RSCMU_Sig_ScanPowMpr (TableOfDataValues,
                        StatisticsMode,
                        AvgBurstPwCurr,
                        PeakBurstPwCurr,
                        PowerControlLevel,
                        TimingAdvError,
                        BurstOutOfTol,
                        BurstMatching,
                        PhErrPeak,
                        PhErrRMS,
                        FreqErr,
                        AvgBurstPwAvg);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This funcyion start a measurement and output all scalar,
/*           numeric measurement results.
/*      Average measurement means that the results of the single-value
/*      measurement are averaged over several bursts. Extreme-value
/*      measurement means that the extreme value is determined from the
/*      results of the single-value measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampPowMpr (ViSession   instrSession,
                                                                   ViInt32     StatisticsMode,
                                                                   ViReal64   *AvgBurstPwCurr,
                                                                   ViReal64   *PeakBurstPwCurr,
                                                                   ViInt32    *PowerControlLevel,
                                                                   ViReal64   *TimingAdvError,
                                                                   ViReal64   *BurstOutOfTol,
                                                                   ViInt32    *BurstMatching,
                                                                   ViReal64   *PhErrPeak,
                                                                   ViReal64   *PhErrRMS,
                                                                   ViReal64   *FreqErr,
                                                                   ViReal64   *AvgBurstPwAvg,
                                                                   ViChar      errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  if ((RSCMU_Status = RSCMU_Query (instrSession, "SAMP:POW:MPR?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Scan the results of combined power & modulation:
  RSCMU_Sig_ScanPowMpr (TableOfDataValues,
                        StatisticsMode,
                        AvgBurstPwCurr,
                        PeakBurstPwCurr,
                        PowerControlLevel,
                        TimingAdvError,
                        BurstOutOfTol,
                        BurstMatching,
                        PhErrPeak,
                        PhErrRMS,
                        FreqErr,
                        AvgBurstPwAvg);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This funcyion start a measurement and output all scalar,
/*           numeric measurement results.
/*      These are:
/*  Maximum phase error with single-value measurement
/*             => phase error peak current
/*  Maximum phase error with average measurement
/*             => phase error peak average
/*  Maximum phase error with extreme-value measurement
/*             => phase error peak max./min.
/*  Rms phase error with single-value measurement
/*             => phase error RMS current
/*  Rms phase error with average measurement
/*             => phase error RMS average
/*  Rms phase error with extreme-value measurement
/*             => phase error RMS max./min.
/*  Frequency error with single-value measurement
/*             => frequency error current
/*  Frequency error with average measurement
/*             => frequency error average
/*  Frequency error with extreme-value measurement
/*             => frequency error max./min.
/*  Average burst power with single-value measurement
/*             => avg. burst power current
/*  Relative portion of faulty burst
/*             => bursts out of tolerance
/*
/*      Average measurement means that the results of the single-value
/*      measurement are averaged over several bursts. Extreme-value
/*      measurement means that the extreme value is determined from the
/*      results of the single-value measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampMod (ViSession instrSession,
                                                                ViInt32   StatisticsMode,
                                                                ViReal64 *phErrPeak,
                                                                ViReal64 *phErrRMS,
                                                                ViReal64 *freqErr,
                                                                ViReal64 *avgBurstPowerCurr,
                                                                ViReal64 *burstOutOfTol,
                                                                ViChar    errorMessage[])
{
 return RSCMU_GSM_NSig_SampMod (instrSession, StatisticsMode, phErrPeak,  phErrRMS,
                    freqErr,avgBurstPowerCurr,burstOutOfTol, errorMessage);
}
/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcModLimMatc (ViSession instrSession,
                                                                       ViInt32   StatisticsMode,
                                                                       ViInt32  *phErrPeak,
                                                                       ViInt32  *phErrRMS,
                                                                       ViInt32  *freqErr,
                                                                       ViInt32  *avgBurstPowerCurr,
                                                                       ViChar    errorMessage[])
{
  return RSCMU_GSM_NSig_CalcModLimMatc (instrSession, StatisticsMode, phErrPeak, phErrRMS, freqErr, avgBurstPowerCurr,errorMessage);
}


/*===========================================================================*/
/* Function: Read Phase Error in Burst...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrModBurs (ViSession instrSession,
                                                                       ViInt32   selectMeas,
                                                                       ViReal64  PhaseErrorValues[],
                                                                       ViChar    errorMessage[])
{
  return  RSCMU_GSM_NSig_ReadArrModBurs (instrSession, selectMeas, PhaseErrorValues, errorMessage);
}
/*===========================================================================*/
/* Function: Fetc Phase Error in Burst...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrModBurs (ViSession instrSession,
                                                                       ViInt32   selectMeas,
                                                                       ViReal64  PhaseErrorValues[],
                                                                       ViChar    errorMessage[])
{
  return  RSCMU_GSM_NSig_FetcArrModBurs (instrSession, selectMeas, PhaseErrorValues, errorMessage);
}
/*===========================================================================*/
/* Function: Sample Phase Error in Burst...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrModBurs (ViSession instrSession,
                                                                       ViInt32   selectMeas,
                                                                       ViReal64  PhaseErrorValues[],
                                                                       ViChar    errorMessage[])
{
  return  RSCMU_GSM_NSig_SampArrModBurs (instrSession, selectMeas, PhaseErrorValues, errorMessage);
}

/*===========================================================================*/
/* Function: Read Phase Error in Burst...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrModBurs (ViSession instrSession,
                                                                          ViInt32   selectMeas,
                                                                          ViReal64  PhaseErrorValues[],
                                                                          ViChar    errorMessage[])
{
  return  RSCMU_GSM_NSig_ReadSubArrModBurs (instrSession, selectMeas, PhaseErrorValues, errorMessage);
}
/*===========================================================================*/
/* Function: Fetc Phase Error in Burst...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrModBurs (ViSession instrSession,
                                                                          ViInt32   selectMeas,
                                                                          ViReal64  PhaseErrorValues[],
                                                                          ViChar    errorMessage[])
{
  return  RSCMU_GSM_NSig_FetcSubArrModBurs (instrSession, selectMeas, PhaseErrorValues, errorMessage);
}
/*===========================================================================*/
/* Function: Sample Phase Error in Burst...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrModBurs (ViSession instrSession,
                                                                          ViInt32   selectMeas,
                                                                          ViReal64  PhaseErrorValues[],
                                                                          ViChar    errorMessage[])
{
  return  RSCMU_GSM_NSig_SampSubArrModBurs (instrSession, selectMeas, PhaseErrorValues, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT MODULATION XPERror
 *    The subsystem MODulation:XPERror measures the modulation parameters (frequency
 *    and errors) in GMSK modulation including the I/Q Imbalance and the Origin
 *    Offset in the I/Q constellation diagram. The subsystem corresponds to the
 *    measurement menu Modulation, application Ext. Phase Err. GMSK, and the
 *    associated popup menu Modulation Configuration.
 * ----------------------------------------------------------------------------
 *      CONTROL OF MODULATION MEAS
 *      It contains the functions for general control of the modulation
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start Modulation Measurements
/* Purpose : This function start the modulation measurement,
/*           setting it to the status beyond.
/*           RUN        Start measurement without waiting
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_InitModXper (ViSession instrSession, ViChar errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_MODXPER, RSCMU_GMSK, errorMessage);
}

/*===========================================================================*/
/* Function: Abort Modulation Measurements
/* Purpose : This function abort the running modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborModXper (ViSession instrSession, ViChar errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_MODXPER, RSCMU_GMSK, errorMessage);
}

/*===========================================================================*/
/* Function: Stop Modulation Measurements
/* Purpose : This function stop measurement after current statistic cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopModXper (ViSession instrSession, ViChar errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_MODXPER, RSCMU_GMSK, errorMessage);
}

/*===========================================================================*/
/* Function: Run next measurement step
/* Purpose : This function runs next modulation measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContModXper (ViSession instrSession, ViChar errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_MODXPER, RSCMU_GMSK, errorMessage);
}

/*===========================================================================*/
/* Function: Modulation Measurement Status
/* Purpose : This function returns the status of the current Modulation
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcModXperStat (ViSession  instrSession,
                                                                        ViInt32   *measStatus,
                                                                        ViInt32   *CountingNo,
                                                                        ViInt32   *StatisticNo,
                                                                        ViChar     errorMessage[])
{
  return RSCMU_FetcStatus(instrSession, RSCMU_MODXPER, RSCMU_GMSK, measStatus, CountingNo, StatisticNo, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModXperErep (ViSession instrSession,
                                                                        ViInt32   Report,
                                                                        ViChar    errorMessage[])
{
  return RSCMU_ConfReporting(instrSession, RSCMU_MODXPER, RSCMU_NONE, Report, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      CONFIGURATION
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModXperCont (ViSession instrSession,
                                                                        ViInt32   measuredValuesType,
                                                                        ViInt32   NbBurst,
                                                                        ViChar    errorMessage[])
{
  return RSCMU_ConfControl (instrSession, RSCMU_MODXPER, RSCMU_GMSK, measuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModXperContRepStat (ViSession instrSession,
                                                                               ViInt32   NbRepetition,
                                                                               ViInt32   stopCondition,
                                                                               ViInt32   stepMode,
                                                                               ViChar    errorMessage[])
{
  return RSCMU_ConfContRepStat(instrSession, RSCMU_MODXPER, RSCMU_GMSK, NbRepetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModXperContRep (ViSession instrSession,
                                                                           ViInt32   repetition,
                                                                           ViInt32   stopCondition,
                                                                           ViInt32   stepMode,
                                                                           ViChar    errorMessage[])
{
  return RSCMU_ConfControlRep(instrSession, RSCMU_MODXPER, RSCMU_GMSK, repetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModXperContDef (ViSession instrSession,
                                                                           ViInt32   defaultValues,
                                                                           ViChar    errorMessage[])
{
  return RSCMU_ConfContDef(instrSession, RSCMU_MODXPER, RSCMU_GMSK, defaultValues, errorMessage);
}

/* ----------------------------------------------------------------------------
 *      LIMITS
 *      The subsystem MODulation:LIMit contains the commands for
 *      definition of tolerance values for the modulation measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Upper ErrorLimits
/* Purpose : This function defines the upper limits for the peak and rms
/*           phase error as well as for the frequency error in the
/*           current burst.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModXperLim (ViSession instrSession,
                                                                       ViBoolean kindOfBurst,
                                                                       ViReal64  phaseErrorPeakLimit,
                                                                       ViReal64  phaseErrorRMSLimit,
                                                                       ViReal64  originOffsetLimit,
                                                                       ViReal64  IQImbalanceLimit,
                                                                       ViReal64  frequencyErrorLowerLimit,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) kindOfBurst, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, phaseErrorPeakLimit, 0.0, RSCMU_PHASE_ERROR_LIM_MAX, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, phaseErrorRMSLimit, 0.0, RSCMU_PHASE_ERROR_LIM_MAX, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, originOffsetLimit, RSCMU_ORIGIN_OFFSET_LIM_MIN, RSCMU_ORIGIN_OFFSET_LIM_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, IQImbalanceLimit, RSCMU_ORIGIN_OFFSET_LIM_MIN, RSCMU_ORIGIN_OFFSET_LIM_MAX, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, frequencyErrorLowerLimit, 0.0, RSCMU_FREQ_ERROR_LIM_MAX, RSCMU_ERROR_PARAMETER7, errorMessage);

  switch (kindOfBurst)
  {
    case RSCMU_CURRENT:
      sprintf (wrtBuf, "CONF:MOD:XPER:LIM %lf,%lf,%lf,%lf,%lf", phaseErrorPeakLimit, phaseErrorRMSLimit, originOffsetLimit, IQImbalanceLimit, frequencyErrorLowerLimit);
      break;
    case RSCMU_AVERAGE:
      sprintf (wrtBuf, "CONF:MOD:XPER:LIM:AVER %lf,%lf,%lf,%lf,%lf", phaseErrorPeakLimit, phaseErrorRMSLimit, originOffsetLimit, IQImbalanceLimit, frequencyErrorLowerLimit);
      break;
  }
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Limit Upper Mode
/* Purpose : This function switches the upper limit checking
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModXperLimUppMod (ViSession instrSession,
                                                                             ViBoolean upperlimitcheck,
                                                                             ViChar    errorMessage[])
{
  return RSCMU_ConfModLimMod(instrSession, RSCMU_UPP, RSCMU_MODXPER, upperlimitcheck, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lower Mode
/* Purpose : This function switches the lower limit checking
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModXperLimLowMod (ViSession instrSession,
                                                                             ViBoolean upperlimitcheck,
                                                                             ViChar    errorMessage[])
{
  return RSCMU_ConfModLimMod(instrSession, RSCMU_LOW, RSCMU_MODXPER, upperlimitcheck, errorMessage);
}

/*===========================================================================*/
/* Function: Type of decoding
/* Purpose : This function selects the type of decoding applied for the
/*           determination of phase and frequency errors.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModXperTimeDec (ViSession instrSession,
                                                                           ViBoolean typeOfDecoding,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) typeOfDecoding, RSCMU_ERROR_PARAMETER2, errorMessage);

  switch (typeOfDecoding)
  {
    case RSCMU_STAN:
      strcpy (wrtBuf, "CONF:MOD:XPER:TIME:DEC STAN");
      break;
    case RSCMU_GTB:
      strcpy (wrtBuf, "CONF:MOD:XPER:TIME:DEC GTB");
      break;
  }
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Raw Symbol Timing Recovery
/* Purpose : This function specifies how the R&S CMU determines the raw symbol
/*           timing in order to demodulate the signal and calculate the
/*           modulation results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModXperRstr (ViSession instrSession,
                                                 ViBoolean raw_symbol_timing_recovery,
                                                 ViChar errorMessage[])
{
    return RSCMU_GSM_NSig_ConfModXperRstr (instrSession, raw_symbol_timing_recovery, errorMessage);
}

/*===========================================================================*/
/* Function: Filter
/* Purpose : This function selects the measurement filter for the Modulation
/*           XPER measurement. The default filter setting differs for the two
/*           modulation schemes.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModXperFilt (ViSession instrSession,
                                                                        ViInt32   Filter,
                                                                        ViChar    errorMessage[])
{
  return RSCMU_ConfFilt(instrSession, RSCMU_MODXPER, RSCMU_GMSK, Filter, errorMessage);
}

/*===========================================================================*/
/* Function: Configure Subranges...
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubModXper (ViSession instrSession,
                                                                       ViInt32   statistics,
                                                                       ViReal64  startTime,
                                                                       ViInt32   samples,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, statistics, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SUB:MOD:XPER %s,%lf,%d", StrStatistics[statistics],startTime*1E-6,samples);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      RESULTS: FREQUENCY AND PHASE ERROR
 *      The subsystem MODulation[:RESULT] contains the commands for
 *      measurement and output of the frequency and phase error and
 *      their comparison with the tolerance values.
 *-----------------------------------------------------------------------------
 *        SCALAR for FW 2.15
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function start a measurement and output all scalar,
/*           numeric measurement results.
/*      These are:
/*  Phase error Peak with single-value measurement
/*             => phase error peak current
/*  Phase error Peak with average measurement
/*             => phase error peak average
/*  Phase error Peak with extreme-value measurement
/*             => phase error peak max./min.
/*  Phase error RMS with single-value measurement
/*             => phase error RMS current
/*  Phase error RMS with average measurement
/*             => phase error RMS average
/*  Phase error RMS with extreme-value measurement
/*             => phase error RMS max./min.
/*  Origin Offset with single-value measurement
/*             => Origin offset current
/*  Origin Offset with average measurement
/*             => Origin offset average
/*  Origin Offset with extreme-value measurement
/*             => Origin offset max./min.
/*  I/Q Imbalanced with single-value measurement
/*             => I/Q Imbalanced current
/*  I/Q Imbalanced with average measurement
/*             => I/Q Imbalanced average
/*  I/Q Imbalanced with extreme-value measurement
/*             => I/Q Imbalanced max./min.
/*  Frequency error with single-value measurement
/*             => frequency error current
/*  Frequency error with average measurement
/*             => frequency error average
/*  Frequency error with extreme-value measurement
/*             => frequency error max./min.
/*  Average burst power with single-value measurement
/*             => avg. burst power current
/*  Relative portion of faulty burst
/*             => bursts out of tolerance
/*
/*      Average measurement means that the results of the single-value
/*      measurement are averaged over several bursts. Extreme-value
/*      measurement means that the extreme value is determined from the
/*      results of the single-value measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadModXper (ViSession instrSession,
                                                                    ViInt32   statistics,
                                                                    ViReal64 *phErrPeak,
                                                                    ViReal64 *phErrRMS,
                                                                    ViReal64 *originOffset,
                                                                    ViReal64 *IQImbalance,
                                                                    ViReal64 *freqErr,
                                                                    ViReal64 *avgBurstPowerCurr,
                                                                    ViReal64 *burstOutOfTol_,
                                                                    ViChar    errorMessage[])
{
  ViReal64 PhaseOfOriginOffsetVector;

  return RSCMU_MeasModXper(instrSession, RSCMU_MODXPER, RSCMU_COMMAND_READ, statistics, phErrPeak, phErrRMS, originOffset, IQImbalance, freqErr, avgBurstPowerCurr, burstOutOfTol_, &PhaseOfOriginOffsetVector, errorMessage);
}


/*===========================================================================*/
/* Function: All Measured Values
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcModXper (ViSession instrSession,
                                                                    ViInt32   statistics,
                                                                    ViReal64 *phErrPeak,
                                                                    ViReal64 *phErrRMS,
                                                                    ViReal64 *originOffset,
                                                                    ViReal64 *IQImbalance,
                                                                    ViReal64 *freqErr,
                                                                    ViReal64 *avgBurstPowerCurr,
                                                                    ViReal64 *burstOutOfTol,
                                                                    ViChar    errorMessage[])
{
  ViReal64 PhaseOfOriginOffsetVector;

  return RSCMU_MeasModXper(instrSession, RSCMU_MODXPER, RSCMU_COMMAND_FETC, statistics, phErrPeak, phErrRMS, originOffset, IQImbalance, freqErr, avgBurstPowerCurr, burstOutOfTol, &PhaseOfOriginOffsetVector, errorMessage);
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampModXper (ViSession instrSession,
                                                                    ViInt32   statistics,
                                                                    ViReal64 *phErrPeak,
                                                                    ViReal64 *phErrRMS,
                                                                    ViReal64 *originOffset,
                                                                    ViReal64 *IQImbalance,
                                                                    ViReal64 *freqErr,
                                                                    ViReal64 *avgBurstPowerCurr,
                                                                    ViReal64 *burstOutOfTol,
                                                                    ViChar    errorMessage[])
{
  ViReal64 PhaseOfOriginOffsetVector;

  return RSCMU_MeasModXper(instrSession, RSCMU_MODXPER, RSCMU_COMMAND_SAMP, statistics, phErrPeak, phErrRMS, originOffset, IQImbalance, freqErr, avgBurstPowerCurr, burstOutOfTol, &PhaseOfOriginOffsetVector, errorMessage);
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcModXperLimMatc (ViSession instrSession,
                                                                           ViInt32   statistics,
                                                                           ViInt32  *phErrPeak,
                                                                           ViInt32  *phErrRMS,
                                                                           ViInt32  *originOffset,
                                                                           ViInt32  *IQImbalance,
                                                                           ViInt32  *freqErr,
                                                                           ViInt32  *avgBurstPowerCurr,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, statistics, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  if ((RSCMU_Status = RSCMU_Query (instrSession, "CALC:MOD:XPER:LIM:MATC?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  switch (statistics)
  {
    case RSCMU_CURRENT:
      // Max phase error with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrPeak,TableOfDataValues,0);
      // RMS phase error with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrRMS,TableOfDataValues,3);
      // Origin Offset with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (originOffset,TableOfDataValues,6);
      // I/Q Imbalance with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (IQImbalance,TableOfDataValues,9);
      // Frequency error with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (freqErr,TableOfDataValues,12);
    break;
    case RSCMU_AVERAGE:
      // Max phase error with average measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrPeak, TableOfDataValues, 1);
      // RMS phase error with average measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrRMS, TableOfDataValues, 4);
      // Origin Offset with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (originOffset,TableOfDataValues,7);
      // I/Q Imbalance with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (IQImbalance,TableOfDataValues,10);
      // Frequency error with average measurement
      RSCMU_Status = RSCMU_GetMatchingValue (freqErr, TableOfDataValues, 13);
    break;
    case RSCMU_MAXMIN:
      // Max phase error with extreme-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrPeak,TableOfDataValues, 2);
      // RMS phase error with extreme-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrRMS,TableOfDataValues, 5);
      // Origin Offset with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (originOffset,TableOfDataValues,8);
      // I/Q Imbalance with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (IQImbalance,TableOfDataValues,11);
      // Frequency error with extreme-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (freqErr,TableOfDataValues, 14);
    break;
  }
  // Average burst power with single-value measurement
  RSCMU_Status = RSCMU_GetMatchingValue (avgBurstPowerCurr, TableOfDataValues, 15);

  return RSCMU_Status;
}

/*
 *-----------------------------------------------------------------------------
 *        SCALAR for FW >= 2.16
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function start a measurement and output all scalar,
/*           numeric measurement results.
/*      These are:
/*  Phase error Peak with single-value measurement
/*             => phase error peak current
/*  Phase error Peak with average measurement
/*             => phase error peak average
/*  Phase error Peak with extreme-value measurement
/*             => phase error peak max./min.
/*  Phase error RMS with single-value measurement
/*             => phase error RMS current
/*  Phase error RMS with average measurement
/*             => phase error RMS average
/*  Phase error RMS with extreme-value measurement
/*             => phase error RMS max./min.
/*  Origin Offset with single-value measurement
/*             => Origin offset current
/*  Origin Offset with average measurement
/*             => Origin offset average
/*  Origin Offset with extreme-value measurement
/*             => Origin offset max./min.
/*  I/Q Imbalanced with single-value measurement
/*             => I/Q Imbalanced current
/*  I/Q Imbalanced with average measurement
/*             => I/Q Imbalanced average
/*  I/Q Imbalanced with extreme-value measurement
/*             => I/Q Imbalanced max./min.
/*  Frequency error with single-value measurement
/*             => frequency error current
/*  Frequency error with average measurement
/*             => frequency error average
/*  Frequency error with extreme-value measurement
/*             => frequency error max./min.
/*  Average burst power with single-value measurement
/*             => avg. burst power current
/*  Relative portion of faulty burst
/*             => bursts out of tolerance
/*  Phase of origin offset vector
/*
/*      Average measurement means that the results of the single-value
/*      measurement are averaged over several bursts. Extreme-value
/*      measurement means that the extreme value is determined from the
/*      results of the single-value measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadModXperPoov (ViSession instrSession,
                                                                        ViInt32   statistics,
                                                                        ViReal64 *phErrPeak,
                                                                        ViReal64 *phErrRMS,
                                                                        ViReal64 *originOffset,
                                                                        ViReal64 *IQImbalance,
                                                                        ViReal64 *freqErr,
                                                                        ViReal64 *avgBurstPowerCurr,
                                                                        ViReal64 *burstOutOfTol_,
                                                                        ViReal64 *PhaseOfOriginOffsetVector,
                                                                        ViChar    errorMessage[])
{
  return RSCMU_MeasModXper(instrSession, RSCMU_MODXPER, RSCMU_COMMAND_READ, statistics, phErrPeak, phErrRMS, originOffset, IQImbalance, freqErr, avgBurstPowerCurr, burstOutOfTol_, PhaseOfOriginOffsetVector, errorMessage);
}


/*===========================================================================*/
/* Function: All Measured Values
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcModXperPoov (ViSession instrSession,
                                                                        ViInt32   statistics,
                                                                        ViReal64 *phErrPeak,
                                                                        ViReal64 *phErrRMS,
                                                                        ViReal64 *originOffset,
                                                                        ViReal64 *IQImbalance,
                                                                        ViReal64 *freqErr,
                                                                        ViReal64 *avgBurstPowerCurr,
                                                                        ViReal64 *burstOutOfTol,
                                                                        ViReal64 *PhaseOfOriginOffsetVector,
                                                                        ViChar    errorMessage[])
{
  return RSCMU_MeasModXper(instrSession, RSCMU_MODXPER, RSCMU_COMMAND_FETC, statistics, phErrPeak, phErrRMS, originOffset, IQImbalance, freqErr, avgBurstPowerCurr, burstOutOfTol, PhaseOfOriginOffsetVector, errorMessage);
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampModXperPoov (ViSession instrSession,
                                                                        ViInt32   statistics,
                                                                        ViReal64 *phErrPeak,
                                                                        ViReal64 *phErrRMS,
                                                                        ViReal64 *originOffset,
                                                                        ViReal64 *IQImbalance,
                                                                        ViReal64 *freqErr,
                                                                        ViReal64 *avgBurstPowerCurr,
                                                                        ViReal64 *burstOutOfTol,
                                                                        ViReal64 *PhaseOfOriginOffsetVector,
                                                                        ViChar    errorMessage[])
{
  return RSCMU_MeasModXper(instrSession, RSCMU_MODXPER, RSCMU_COMMAND_SAMP, statistics, phErrPeak, phErrRMS, originOffset, IQImbalance, freqErr, avgBurstPowerCurr, burstOutOfTol, PhaseOfOriginOffsetVector, errorMessage);
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcModXperPoovLimMatc (ViSession instrSession,
                                                                               ViInt32   statistics,
                                                                               ViInt32  *phErrPeak,
                                                                               ViInt32  *phErrRMS,
                                                                               ViInt32  *originOffset,
                                                                               ViInt32  *IQImbalance,
                                                                               ViInt32  *freqErr,
                                                                               ViInt32  *avgBurstPowerCurr,
                                                                               ViInt32  *PhaseOfOriginOffsetVector,
                                                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, statistics, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  if ((RSCMU_Status = RSCMU_Query (instrSession, "CALC:MOD:XPER:LIM:MATC?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  switch (statistics)
  {
    case RSCMU_CURRENT:
      // Max phase error with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrPeak,TableOfDataValues,0);
      // RMS phase error with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrRMS,TableOfDataValues,3);
      // Origin Offset with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (originOffset,TableOfDataValues,6);
      // I/Q Imbalance with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (IQImbalance,TableOfDataValues,9);
      // Frequency error with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (freqErr,TableOfDataValues,12);
    break;
    case RSCMU_AVERAGE:
      // Max phase error with average measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrPeak, TableOfDataValues, 1);
      // RMS phase error with average measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrRMS, TableOfDataValues, 4);
      // Origin Offset with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (originOffset,TableOfDataValues,7);
      // I/Q Imbalance with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (IQImbalance,TableOfDataValues,10);
      // Frequency error with average measurement
      RSCMU_Status = RSCMU_GetMatchingValue (freqErr, TableOfDataValues, 13);
    break;
    case RSCMU_MAXMIN:
      // Max phase error with extreme-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrPeak,TableOfDataValues, 2);
      // RMS phase error with extreme-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (phErrRMS,TableOfDataValues, 5);
      // Origin Offset with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (originOffset,TableOfDataValues,8);
      // I/Q Imbalance with single-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (IQImbalance,TableOfDataValues,11);
      // Frequency error with extreme-value measurement
      RSCMU_Status = RSCMU_GetMatchingValue (freqErr,TableOfDataValues, 14);
    break;
  }
  // Average burst power with single-value measurement
  RSCMU_Status = RSCMU_GetMatchingValue (avgBurstPowerCurr, TableOfDataValues, 15);

  // Phase of the origin offset vector
  RSCMU_Status = RSCMU_GetMatchingValue (PhaseOfOriginOffsetVector, TableOfDataValues, 16);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Reads Phase Error in Burst...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 588 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrModXper (ViSession instrSession,
                                                                       ViInt32   statistics,
                                                                       ViReal64  phaseError_inBurstValues[],
                                                                       ViChar    errorMessage[])
{
  return RSCMU_MeasArrModXper(instrSession, RSCMU_COMMAND_READ, statistics, phaseError_inBurstValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetches Phase Error in Burst...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 588 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrModXper (ViSession instrSession,
                                                                       ViInt32   statistics,
                                                                       ViReal64  phaseError_inBurstValues[],
                                                                       ViChar    errorMessage[])
{
  return RSCMU_MeasArrModXper(instrSession, RSCMU_COMMAND_FETC, statistics, phaseError_inBurstValues, errorMessage);
}

/*===========================================================================*/
/* Function: Samples Phase Error in Burst...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 588 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrModXper (ViSession instrSession,
                                                                       ViInt32   statistics,
                                                                       ViReal64  phaseError_inBurstValues[],
                                                                       ViChar    errorMessage[])
{
  return RSCMU_MeasArrModXper(instrSession, RSCMU_COMMAND_SAMP, statistics, phaseError_inBurstValues, errorMessage);
}

/*===========================================================================*/
/* Function: Read Phase Error in Burst (SubArray)...
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrModXper (ViSession instrSession,
                                                                          ViInt32   statistics,
                                                                          ViReal64  phaseError_inBurstValues[],
                                                                          ViChar    errorMessage[])
{
  return RSCMU_MeasSubArrModXper(instrSession, RSCMU_COMMAND_READ, statistics, phaseError_inBurstValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetches Phase Error in Burst (SubArray)...
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrModXper (ViSession instrSession,
                                                                          ViInt32   statistics,
                                                                          ViReal64  phaseError_inBurstValues[],
                                                                          ViChar    errorMessage[])
{
  return RSCMU_MeasSubArrModXper(instrSession, RSCMU_COMMAND_FETC, statistics, phaseError_inBurstValues, errorMessage);
}

/*===========================================================================*/
/* Function: Samples Phase Error in Burst (SubArray)...
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrModXper (ViSession instrSession,
                                                                          ViInt32   statistics,
                                                                          ViReal64  phaseError_inBurstValues[],
                                                                          ViChar    errorMessage[])
{
  return RSCMU_MeasSubArrModXper(instrSession, RSCMU_COMMAND_SAMP, statistics, phaseError_inBurstValues, errorMessage);
}




/*===========================================================================*/
/* Invalid Result detect timeout
/* This function defines the Invalid Result Detected Timeout.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ModulationMeasTimeout (ViSession instrSession,
                                                       ViInt32   invalidResultDetectedTimeout,
                                                       ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[]= {"NORMal", "MEDium", "SHORt", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

    RETMSG(RSCMU_setEnum(instrSession, "CONFigure:MODulation:IRDTimeout",
                         invalidResultDetectedTimeout, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT SPECTRUM/SWITCHING
 *-----------------------------------------------------------------------------
 */

/*===========================================================================*/
/* Function: Select Limit Line Template
/* Purpose : These function selects the limit line to be applied.
/*           The current template can be queried using
/*           [SENSe:]SPECtrum:<Application>:LIMit:LINE:USED?.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecLimLineSel (ViSession instrSession,
                                                    ViInt32   select,
                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViString    list[] = {"GMSK","EPSK","AUTO", VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  RETMSG(RSCMU_setEnum(instrSession, "CONFigure:SPECtrum:LIMit:LINE:SELect", select, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Trigger Mode
/* This function selects the Trigger Mode for Spectrum Measurements.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecTriggerMode (ViSession instrSession,
                                                     ViInt32   triggerMode,
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViString    list[] = {"NORMal","CAMSlot","CAOSlots", VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

  RETMSG(RSCMU_setEnum(instrSession, "CONFigure:SPECtrum:TMODe", triggerMode, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Resolution
/* Purpose : This function defines the resolution bandwidth of the resolution
/*           filter for spectrum due to modulation and switching
/*           measurements.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecBand (ViSession instrSession,
                                              ViInt32 resolution,
                                              ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViString    list[] = {"B10","B30", VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_23,RSCMU_ERROR_FW_VERSION_4_23));

  RETMSG(RSCMU_setEnum(instrSession, "CONF:SPEC:BAND", resolution, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Invalid Result detect timeout
/* This function defines the Invalid Result Detected Timeout.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SpectrumMeasTimeout (ViSession instrSession,
                                                       ViInt32   invalidResultDetectedTimeout,
                                                       ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[]= {"NORMal", "MEDium", "SHORt", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V5_00,RSCMU_ERROR_FW_VERSION_5_00));

    RETMSG(RSCMU_setEnum(instrSession, "CONFigure:SPECtrum:IRDTimeout",
                         invalidResultDetectedTimeout, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitContDef (ViSession instrSession,
                                                                            ViInt32   DefaultValues,
                                                                            ViChar    errorMessage[])
{
  return RSCMU_ConfContDef(instrSession, RSCMU_SPECSWIT, RSCMU_NONE, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitContRep (ViSession  instrSession,
                                                                             ViInt32    Repetition,
                                                                             ViInt32    StopCondition,
                                                                             ViInt32    StepMode,
                                                                             ViChar     errorMessage[])
{
  return RSCMU_ConfControlRep(instrSession, RSCMU_SPECSWIT, RSCMU_NONE, Repetition, StopCondition, StepMode, errorMessage);
}




/*===========================================================================*/
/* Function: continuous statistical mode
/* Purpose : This function defines the continuous statistical mode for the
/*           Spectrum due to Switching measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SpecSwitContStatMod (ViSession instrSession,
                                                         ViInt32   continuousStatisticalMode,
                                                         ViChar    errorMessage[])
{
    return RSCMU_ConfSpecSwitContStatMod (instrSession, RSCMU_GMSK, continuousStatisticalMode, errorMessage);
}


/*===========================================================================*/
/* Function: Nr. of Slots
/* Purpose : This function sets the Number of slots per TDMA frame measured
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SpecSwitNoOfSlot (ViSession instrSession,
                                                  ViInt32   nr_ofSlots,
                                                  ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  RETMSG(RSCMU_setViInt32(instrSession,
                          "CONFigure:SPECtrum:SWITching:NOSLots",
                          nr_ofSlots,
                          1, 8,
                          RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Slot Count
/* Purpose : Don' use this function - only for compatibility
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SpecSwitSlotCount (ViSession instrSession,
                                                       ViInt32   slotCount,
                                                       ViChar    errorMessage[])
{
    return RSCMU_ConfSpecSwitSlotCount (instrSession, RSCMU_GMSK, slotCount, errorMessage);
}

/*===========================================================================*/
/* Function: Frequency Select f. Time Domain
/* Purpose : These function selects the measurement frequency for the time
/*           domain (power vs. time) measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitFSelFTimeD (ViSession instrSession,
                                                        ViInt32   select,
                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViString    list[] = {"OFF","N180","N160","N140","N120","N100","N080","N060","N040","N025","N020","N010",
                        "REF","P010","P020","P025","P040","P060","P080","P100","P120","P140","P160","P180",
                        "NV4","NV3","NV2","NV1","PV1","PV2","PV3","PV4", VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  RETMSG(RSCMU_setEnum(instrSession, "CONFigure:SPECtrum:SWITching:TDFSelect", select, list,
                                      RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Grid On/Off
/* Purpose : This function switches the grid lines in the test diagrams on or
/*           off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_DispSpecSwitContGrid (ViSession instrSession,
                                                                              ViInt32   gridLines,
                                                                              ViChar    errorMessage[])
{
  return RSCMU_DisplayGrid (instrSession, RSCMU_SPECSWIT, RSCMU_NONE, gridLines, errorMessage);
}

/*===========================================================================*/
/* Function: Default Limit Lines
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitLimLineDef (ViSession instrSession,
                                                                                ViInt32   DefaultValues,
                                                                                ViChar    errorMessage[])
{
  return RSCMU_ConfLimLineDef (instrSession, RSCMU_SPECSWIT, RSCMU_NONE, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines
/* Purpose : These commands activate and define limit lines for the spectrum
/*           due to switching measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitLimLine (ViSession instrSession,
                                                                             ViInt32   PowerLevel,
                                                                             ViReal64  power,
                                                                             ViInt32   enable,
                                                                             ViReal64  value1,
                                                                             ViReal64  value2,
                                                                             ViReal64  value3,
                                                                             ViReal64  value4,
                                                                             ViChar    errorMessage[])
{
  return RSCMU_ConfSpecSwitLimLine (instrSession, RSCMU_NONE, PowerLevel, power, enable, value1, value2, value3, value4, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines On/Off
/* Purpose : This function switches the limit checking for all measurepoints.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitLimLineMode (ViSession instrSession,
                                                                                 ViInt32   limitLines,
                                                                                 ViChar    errorMessage[])
{
  return RSCMU_ConfSpecSwitLimLineMod(instrSession, RSCMU_NONE, limitLines, errorMessage);
}

/*===========================================================================*/
/* Function: Statistic Count
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitCont (ViSession instrSession,
                                                                          ViInt32   MeasuredValuesType,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    errorMessage[])
{
  return RSCMU_ConfControl (instrSession, RSCMU_SPECSWIT, RSCMU_NONE, MeasuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitContRepStat (ViSession  instrSession,
                                                                                 ViInt32    NbRepetition,
                                                                                 ViInt32    StopCondition,
                                                                                 ViInt32    StepMode,
                                                                                 ViChar     errorMessage[])
{
  return RSCMU_ConfContRepStat(instrSession, RSCMU_SPECSWIT, RSCMU_NONE, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Measure Points
/* Purpose : This function permits to select which frequencies a spectrum
/*           switching measurement is performed. A reduction of the
/*           measurement points enhances the measurement speed.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitContMpo (ViSession  instrSession,
                                                                             ViInt32    MeasurePoint,
                                                                             ViInt32    Enable,
                                                                             ViChar     errorMessage[])
{
  return RSCMU_ConfSpecSwitContMpo (instrSession, RSCMU_NONE, MeasurePoint, Enable, errorMessage);
}

/*===========================================================================*/
/* Function: Variable Measure Points
/* Purpose : This function sets and enables additional pairs of
/*           measurement points at up to 4 variable offset frequencies
/*           (numbered by the numeric suffix <nr> = 1 to 4).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitVarMpo (ViSession instrSession,
                                                    ViInt32   nr,
                                                    ViInt32   enable,
                                                    ViReal64  frequencyMHz,
                                                    ViChar    errorMessage[])
{
  return RSCMU_MeasSpecVarMeaPoint(instrSession, "CONFigure:SPECtrum:SWITching:CONTrol:VMPOint", nr, enable, frequencyMHz, errorMessage);
}

/*===========================================================================*/
/* Function: Burst Power SubRanges
/* Purpose : This function configurates the READ..., FETCh... and
/*           SAMPle:SUBarray:SPECtrum:SWITching commands.
/*           If the requested number of results exceeds the measurement
/*           range, the count parameter will be corrected by the system.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubSpecSwit (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  FirstMeasurementFreq,
                                                                        ViInt32   MeasureResultsNumber,
                                                                        ViChar    errorMessage[])
{
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, FirstMeasurementFreq, -1.8, 1.8, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, MeasureResultsNumber, 1, 9, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSubarrays (instrSession, RSCMU_SPECSWIT, RSCMU_NONE, Mode, FirstMeasurementFreq, MeasureResultsNumber, errorMessage);
}

/*===========================================================================*/
/* Function: Configure TimeDomain SubRanges
/* Purpose : This function configurates the READ..., FETCh... and
/*           SAMPle:SSUBarrays:SPECtrum:<Application>:TDOMain commands.
/*           If the requested number of results exceeds the measurement
/*           range, the count parameter will be corrected by the system.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubSpecSwitTime (ViSession instrSession,
                                                     ViInt32   mode,
                                                     ViReal64  startTime,
                                                     ViInt32   numberOfSamples,
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, mode, 0, 4, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, startTime, -186, 1111, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, numberOfSamples, 1, 3894, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSub (instrSession, "SPECtrum:SWITching:TDOMain", mode, startTime, numberOfSamples, errorMessage);
}

/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_InitSpecSwit (ViSession instrSession,
                                                                       ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_SPECSWIT, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : Abort measurement and switch off => OFF
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborSpecSwit (ViSession instrSession,
                                                                       ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_SPECSWIT, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : Stop measurement => STOP
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopSpecSwit (ViSession instrSession,
                                                                       ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_SPECSWIT, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : Next measurement step (only counting mode) => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContSpecSwit (ViSession instrSession,
                                                                       ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_SPECSWIT, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Spectrum Switching Measurement Status
/* Purpose : This function returns the status of the current Spectrum Switching
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSpecSwitStat (ViSession  instrSession,
                                                                         ViInt32   *MeasurementStatus,
                                                                         ViInt32   *CountingNo,
                                                                         ViInt32   *StatisticNo,
                                                                         ViChar     errorMessage[])
{
  return RSCMU_FetcStatus (instrSession, RSCMU_SPECSWIT, RSCMU_NONE, MeasurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*===========================================================================*/
/* Function: Event Reporting Mode
/* Purpose : This function defines the events to be reported during the
/*           measurement (event reporting, see chapter 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitErep (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViChar    errorMessage[])
{
  return RSCMU_ConfReporting (instrSession, RSCMU_SPECSWIT, RSCMU_NONE, Mode, errorMessage);
}

/*===========================================================================*/
/* Function: Read
/* Purpose : This function starts the measurement and outputs some results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSpecSwit (ViSession  instrSession,
                                                                     ViReal64  *referencePower,
                                                                     ViInt32   *matching,
                                                                     ViChar     errorMessage[])
{
  return RSCMU_MeasSpecSwit (instrSession, RSCMU_COMMAND_READ, RSCMU_NONE, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This function only outputs the results without any care of the
/*           measurement state.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSpecSwit (ViSession  instrSession,
                                                                     ViReal64  *referencePower,
                                                                     ViInt32   *matching,
                                                                     ViChar     errorMessage[])
{
  return RSCMU_MeasSpecSwit (instrSession, RSCMU_COMMAND_FETC, RSCMU_NONE, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This function waits until the results are valid for the first
/*           time (depending on the chosen statistic count) and then outputs
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSpecSwit (ViSession  instrSession,
                                                                     ViReal64  *referencePower,
                                                                     ViInt32   *matching,
                                                                     ViChar     errorMessage[])
{
  return RSCMU_MeasSpecSwit (instrSession, RSCMU_COMMAND_SAMP, RSCMU_NONE, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Read
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrSpecSwit (ViSession instrSession,
                                                                        ViReal64  BurstPower[],
                                                                        ViChar    errorMessage[])
{
  return RSCMU_MeasArrSpecSwit (instrSession, RSCMU_COMMAND_READ, RSCMU_NONE, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrSpecSwit (ViSession instrSession,
                                                                        ViReal64  BurstPower[],
                                                                        ViChar    errorMessage[])
{
  return RSCMU_MeasArrSpecSwit (instrSession, RSCMU_COMMAND_FETC, RSCMU_NONE, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrSpecSwit (ViSession instrSession,
                                                                        ViReal64  BurstPower[],
                                                                        ViChar    errorMessage[])
{
  return RSCMU_MeasArrSpecSwit (instrSession, RSCMU_COMMAND_SAMP, RSCMU_NONE, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: area limit matching
/* Purpose : A bit in the output values is set if the corresponding fixed
/*           measurement point exceeds the limit.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcSpecSwiAreaLimMatc (ViSession instrSession,
                                                        ViInt32  *limitMatching,
                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  CHECKRETMSG(RSCMU_getViString(instrSession,"CALCulate:ARRay:SPECtrum:SWITching:AREA:LIMit:MATChing?",rdBuf,RD_BUFFER_SIZE,0));

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf,"%d", limitMatching);
  else *limitMatching = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Read Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrVarSpecSwit (ViSession instrSession,
                                                    ViReal64  burstPower[],
                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "READ:ARRay:SPECtrum:SWitching:VMPoint", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrVarSpecSwit (ViSession instrSession,
                                                    ViReal64  burstPower[],
                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:SWitching:VMPoint", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrVarSpecSwit (ViSession instrSession,
                                                    ViReal64  burstPower[],
                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:SWitching:VMPoint", burstPower, errorMessage);
}



/*===========================================================================*/
/* Function: Read Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrSpecSwitTime (ViSession instrSession,
                                                     ViReal64  burstPower[],
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "READ:ARRay:SPECtrum:SWITching:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrSpecSwitTime (ViSession instrSession,
                                                     ViReal64  burstPower[],
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:SWITching:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrSpecSwitTime (ViSession instrSession,
                                                     ViReal64  burstPower[],
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:SWITching:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Read (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrSpecSwit (ViSession instrSession,
                                                                           ViReal64  BurstPower[],
                                                                           ViChar    errorMessage[])
{
  return RSCMU_MeasSubArrSpecSwit (instrSession, RSCMU_COMMAND_READ, RSCMU_NONE, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrSpecSwit (ViSession instrSession,
                                                                           ViReal64  BurstPower[],
                                                                           ViChar    errorMessage[])
{
  return RSCMU_MeasSubArrSpecSwit (instrSession, RSCMU_COMMAND_FETC, RSCMU_NONE, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrSpecSwit (ViSession instrSession,
                                                                           ViReal64  BurstPower[],
                                                                           ViChar    errorMessage[])
{
  return RSCMU_MeasSubArrSpecSwit (instrSession, RSCMU_COMMAND_SAMP, RSCMU_NONE, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Read SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrSpecSwitTime (ViSession instrSession,
                                                        ViReal64  burstPower[],
                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "READ:SUBarrays:SPECtrum:SWITching:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrSpecSwitTime (ViSession instrSession,
                                                        ViReal64  burstPower[],
                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "FETCh:SUBarrays:SPECtrum:SWITching:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrSpecSwitTime (ViSession instrSession,
                                                        ViReal64  burstPower[],
                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "SAMPle:SUBarrays:SPECtrum:SWITching:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Current Limit Line Template
/* Purpose : These function is always a query and returns the
/*           current limit line template.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensSpecSwiLimLineUsed (ViSession instrSession,
                                                        ViInt32  *currLimLine,
                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  CHECKRETMSG(RSCMU_getViString(instrSession,"SENSe:SPECtrum:SWITching:LIMit:LINE:USED?",rdBuf,RD_BUFFER_SIZE,0));

  // Extract the CMU response:
  if (strncmp ("GMSK", rdBuf, 4) == 0)
    *currLimLine = RSCMU_GMSK;
  else if (strncmp ("EPSK", rdBuf, 4) == 0)
    *currLimLine = RSCMU_EPSK;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Configure Additional Measurepoints
/* Purpose : This function permits to configure the frequencies for two
/*           additional Measurepoints for spectrum switching measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitConfAMP (ViSession instrSession,
                                                     ViInt32   enableMP1,
                                                     ViReal64  frequencyMP1,
                                                     ViInt32   enableMP2,
                                                     ViReal64  frequencyMP2,
                                                     ViChar    errorMessage[])
{
  return RSCMU_ConfSpecSwitAddMeaPoints (instrSession, RSCMU_GMSK, enableMP1, frequencyMP1, enableMP2, frequencyMP2, errorMessage);
}



/*===========================================================================*/
/* Function: Fetch scalar results for Additional Measurepoints
/* Purpose : This function output the off-carrier power due to switching
/*           in the additional Measurepoints.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSpecSwitAMP (ViSession instrSession,
                                                 ViReal64  *valueMP1Neg,
                                                 ViReal64  *valueMP1Pos,
                                                 ViReal64  *valueMP2Neg,
                                                 ViReal64  *valueMP2Pos,
                                                 ViChar    errorMessage[])
{
  return RSCMU_FetcSpecSwitAddMeaPoints (instrSession, RSCMU_GMSK, valueMP1Neg, valueMP1Pos, valueMP2Neg, valueMP2Pos, errorMessage);
}



/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT SPECTRUM/MODULATION
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModContDef (ViSession instrSession,
                                                                           ViInt32   DefaultValues,
                                                                           ViChar    errorMessage[])
{
  return RSCMU_ConfContDef(instrSession, RSCMU_SPECMOD, RSCMU_NONE, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Averaging Areas
/* Purpose : These function selects one or two 40-bit sections of the burst which
/*           are measured and averaged in order to calculate the Modulation results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SpecModAvgAreas (ViSession instrSession,
                                                 ViInt32   averaging_area,
                                                 ViChar    errorMessage[])
{
    ViString    list[] = {"A","B","AB", VI_NULL};
    ViStatus    RSCMU_Status = VI_SUCCESS;

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_50, RSCMU_ERROR_FW_VERSION_3_50));

    RETMSG(RSCMU_setEnum(instrSession, "CONFigure:SPECtrum:MODulation:AVGareas",
                         averaging_area, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModContRep (ViSession  instrSession,
                                                                           ViInt32    Repetition,
                                                                           ViInt32    StopCondition,
                                                                           ViInt32    StepMode,
                                                                           ViChar     errorMessage[])
{
  return RSCMU_ConfControlRep(instrSession, RSCMU_SPECMOD, RSCMU_NONE, Repetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Frequency Select f. Time Domain
/* Purpose : These function selects the measurement frequency for the time
/*           domain (power vs. time) measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModFSelFTimeD (ViSession instrSession,
                                                        ViInt32   select,
                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViString    list[] = {"OFF","N180","N160","N140","N120","N100","N080","N060","N040","N025","N020","N010",
                        "REF","P010","P020","P025","P040","P060","P080","P100","P120","P140","P160","P180",
                        "NV4","NV3","NV2","NV1","PV1","PV2","PV3","PV4", VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  RETMSG(RSCMU_setEnum(instrSession, "CONFigure:SPECtrum:MODulation:TDFSelect", select, list,
                                      RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Grid On/Off
/* Purpose : This function switches the grid lines in the test diagrams on or
/*           off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_DispSpecModContGrid (ViSession instrSession,
                                                                            ViInt32   gridLines,
                                                                            ViChar    errorMessage[])
{
  return RSCMU_DisplayGrid (instrSession, RSCMU_SPECMOD, RSCMU_NONE, gridLines, errorMessage);
}

/*===========================================================================*/
/* Function: Default limit Lines
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModLimLineDef (ViSession instrSession,
                                                                              ViInt32   DefaultValues,
                                                                              ViChar    errorMessage[])
{
  return RSCMU_ConfLimLineDef (instrSession, RSCMU_SPECMOD, RSCMU_NONE, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Reference Power
/* Purpose : This function defines the MS carrier output power domain where
/*           the limit lines are to be determined by linear interpolation
/*           (see Table 1). Below Min. Power, the lower limit line applies,
/*           above Max. Power, the upper limit line applies.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModLimLineRefp (ViSession instrSession,
                                                                               ViReal64  minPower,
                                                                               ViReal64  maxPower,
                                                                               ViChar    errorMessage[])
{
  return RSCMU_ConfSpecModLimLineRefp (instrSession, RSCMU_NONE, minPower, maxPower, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines
/* Purpose : These commands activate and define limit lines for the spectrum
/*           due to modulation measurement.
/*           The limit lines for the spectrum due to modulation as specified
/*           in standard GSM 05.05 depend on the GSM band, the frequency, and
/*           (for frequencies that differ from the carrier frequency by more
/*           than 400 kHz) on the output power of the mobile station.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModLimLine (ViSession instrSession,
                                                                           ViInt32   measurePoint,
                                                                           ViInt32   enable,
                                                                           ViReal64  minPower,
                                                                           ViReal64  maxPower,
                                                                           ViReal64  AbsLevel,
                                                                           ViChar    errorMessage[])
{
  return RSCMU_ConfSpecModLimLine (instrSession, RSCMU_NONE, measurePoint, enable, minPower, maxPower, AbsLevel, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines On/Off
/* Purpose : This function switches the limit checking for all measurepoints.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModLimLineMod (ViSession instrSession,
                                                                              ViInt32   limitLines,
                                                                              ViChar    errorMessage[])
{
  return RSCMU_ConfSpecModLimLineMod (instrSession, RSCMU_NONE, limitLines, errorMessage);
}

/*===========================================================================*/
/* Function: Statistic Count
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModCont (ViSession instrSession,
                                                                        ViInt32   MeasuredValuesType,
                                                                        ViInt32   NbBurst,
                                                                        ViChar    errorMessage[])
{
  return RSCMU_ConfControl (instrSession, RSCMU_SPECMOD, RSCMU_NONE, MeasuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModContRepStat (ViSession  instrSession,
                                                                               ViInt32    NbRepetition,
                                                                               ViInt32    StopCondition,
                                                                               ViInt32    StepMode,
                                                                               ViChar     errorMessage[])
{
  return RSCMU_ConfContRepStat(instrSession, RSCMU_SPECMOD, RSCMU_NONE, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Measure Points
/* Purpose : This function permits to select which frequencies a spectrum
/*           modulation measurement is performed. A reduction of the
/*           measurement points enhances the measurement speed.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModContMpo (ViSession  instrSession,
                                                                           ViInt32    MeasurePoint,
                                                                           ViInt32    Enable,
                                                                           ViChar     errorMessage[])
{
  return RSCMU_ConfSpecModContMpo (instrSession, RSCMU_NONE, MeasurePoint, Enable, errorMessage);
}

/*===========================================================================*/
/* Function: Variable Measure Points
/* Purpose : This function sets and enables additional pairs of
/*           measurement points at up to 4 variable offset frequencies
/*           (numbered by the numeric suffix <nr> = 1 to 4).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModVarMpo (ViSession instrSession,
                                                   ViInt32   nr,
                                                   ViInt32   enable,
                                                   ViReal64  frequencyMHz,
                                                   ViChar    errorMessage[])
{
  return RSCMU_MeasSpecVarMeaPoint(instrSession, "CONFigure:SPECtrum:MODulation:CONTrol:VMPOint", nr, enable, frequencyMHz, errorMessage);
}

/*===========================================================================*/
/* Function: Burst Power SubRanges
/* Purpose : This function configurates the READ..., FETCh... and
/*           SAMPle:SUBArrays:MODulation:SWITching commands.
/*           If the requested number of results exceeds the measurement
/*           range, the count parameter will be corrected by the system.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubSpecMod (ViSession instrSession,
                                                                      ViInt32   Mode,
                                                                      ViReal64  FirstMeasurementFreq,
                                                                      ViInt32   MeasureResultsNumber,
                                                                      ViChar    errorMessage[])
{
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, FirstMeasurementFreq, -1.8, 1.8, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, MeasureResultsNumber, 1, 23, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSubarrays (instrSession, RSCMU_SPECMOD, RSCMU_NONE, Mode, FirstMeasurementFreq, MeasureResultsNumber, errorMessage);
}

/*===========================================================================*/
/* Function: Configure TimeDomain SubRanges
/* Purpose : This function configurates the READ..., FETCh... and
/*           SAMPle:SSUBarrays:SPECtrum:<Application>:TDOMain commands.
/*           If the requested number of results exceeds the measurement
/*           range, the count parameter will be corrected by the system.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubSpecModTime (ViSession instrSession,
                                                    ViInt32   mode,
                                                    ViReal64  startTime,
                                                    ViInt32   numberOfSamples,
                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, mode, 0, 4, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, startTime, -30, 175, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, numberOfSamples, 1, 618, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSub (instrSession, "SPECtrum:MODulation:TDOMain", mode, startTime, numberOfSamples, errorMessage);
}

/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_InitSpecMod (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_SPECMOD, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : Abort measurement and switch off => OFF
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborSpecMod (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_SPECMOD, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : Stop measurement => STOP
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopSpecMod (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_SPECMOD, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : Next measurement step (only counting mode) => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContSpecMod (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_SPECMOD, RSCMU_NONE, errorMessage);
}

/*===========================================================================*/
/* Function: Spectrum Modulation Measurement Status
/* Purpose : This function returns the status of the current Spectrum
/*           Modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSpecModStat (ViSession  instrSession,
                                                                        ViInt32   *MeasurementStatus,
                                                                        ViInt32   *CountingNo,
                                                                        ViInt32   *StatisticNo,
                                                                        ViChar     errorMessage[])
{
  return RSCMU_FetcStatus (instrSession, RSCMU_SPECMOD, RSCMU_NONE, MeasurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*===========================================================================*/
/* Function: Event Reporting Mode
/* Purpose : This function defines the events to be reported during the
/*           measurement (event reporting, see chapter 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModErep (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViChar    errorMessage[])
{
  return RSCMU_ConfReporting (instrSession, RSCMU_SPECMOD, RSCMU_NONE, Mode, errorMessage);
}

/*===========================================================================*/
/* Function: Start single shot measurement and return results
/* Purpose : This function starts a single shot measurement and returns the
/*           results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSpecMod (ViSession  instrSession,
                                                                    ViReal64  *ReferencePower,
                                                                    ViInt32   *Matching,
                                                                    ViChar     errorMessage[])
{
  return RSCMU_MeasSpecMod (instrSession, RSCMU_COMMAND_READ, RSCMU_NONE, ReferencePower, Matching, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This function only outputs the results without any care of the
/*           measurement state.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSpecMod (ViSession  instrSession,
                                                                    ViReal64  *ReferencePower,
                                                                    ViInt32   *Matching,
                                                                    ViChar     errorMessage[])
{
  return RSCMU_MeasSpecMod (instrSession, RSCMU_COMMAND_FETC, RSCMU_NONE, ReferencePower, Matching, errorMessage);
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This function waits until the results are valid for the first
/*           time (depending on the chosen statistic count) and then outputs
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSpecMod (ViSession  instrSession,
                                                                    ViReal64  *ReferencePower,
                                                                    ViInt32   *Matching,
                                                                    ViChar     errorMessage[])
{
  return RSCMU_MeasSpecMod (instrSession, RSCMU_COMMAND_SAMP, RSCMU_NONE, ReferencePower, Matching, errorMessage);
}

/*===========================================================================*/
/* Function: Read
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrSpecMod (ViSession instrSession,
                                                                       ViReal64  BurstPower[],
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, "READ:ARR:SPEC:MOD?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, BurstPower);

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Fetch
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrSpecMod (ViSession  instrSession,
                                                                       ViReal64   BurstPower[],
                                                                       ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, "FETC:ARR:SPEC:MOD?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, BurstPower);

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Sample
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrSpecMod (ViSession instrSession,
                                                                       ViReal64  BurstPower[],
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, "SAMP:ARR:SPEC:MOD?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, BurstPower);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: area limit matching
/* Purpose : A bit in the output values is set if the corresponding fixed
/*           measurement point exceeds the limit.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcSpecModAreaLimMatc (ViSession instrSession,
                                                        ViInt32  *limitMatching,
                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  CHECKRETMSG(RSCMU_getViString(instrSession,"CALCulate:ARRay:SPECtrum:MODulation:AREA:LIMit:MATChing?",rdBuf,RD_BUFFER_SIZE,0));

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf,"%d", limitMatching);
  else *limitMatching = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Read Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrVarSpecMod (ViSession instrSession,
                                                   ViReal64  burstPower[],
                                                   ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "READ:ARRay:SPECtrum:MODulation:VMPoint", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrVarSpecMod (ViSession instrSession,
                                                   ViReal64  burstPower[],
                                                   ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:MODulation:VMPoint", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Array Variable Measurepoints
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrVarSpecMod (ViSession instrSession,
                                                   ViReal64  burstPower[],
                                                   ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:MODulation:VMPoint", burstPower, errorMessage);
}


/*===========================================================================*/
/* Function: Read Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrSpecModTime (ViSession instrSession,
                                                    ViReal64  burstPower[],
                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "READ:ARRay:SPECtrum:MODulation:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrSpecModTime (ViSession instrSession,
                                                    ViReal64  burstPower[],
                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "FETCh:ARRay:SPECtrum:MODulation:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Array Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrSpecModTime (ViSession instrSession,
                                                    ViReal64  burstPower[],
                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "SAMPle:ARRay:SPECtrum:MODulation:TDOMain", burstPower, errorMessage);
}


/*===========================================================================*/
/* Function: Read (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrSpecMod (ViSession instrSession,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, "READ:SUB:SPEC:MOD?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, BurstPower);

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Fetch (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrSpecMod (ViSession  instrSession,
                                                                          ViReal64   BurstPower[],
                                                                          ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, "FETC:SUB:SPEC:MOD?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, BurstPower);

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Sample (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrSpecMod (ViSession instrSession,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, "SAMP:SUB:SPEC:MOD?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, BurstPower);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Read SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrSpecModTime (ViSession instrSession,
                                                       ViReal64  burstPower[],
                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "READ:SUBarrays:SPECtrum:MODulation:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrSpecModTime (ViSession instrSession,
                                                       ViReal64  burstPower[],
                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "FETCh:SUBarrays:SPECtrum:MODulation:TDOMain", burstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample SubArray Time Domain
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrSpecModTime (ViSession instrSession,
                                                       ViReal64  burstPower[],
                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  return RSCMU_MeasArray(instrSession, "SAMPle:SUBarrays:SPECtrum:MODulation:TDOMain", burstPower, errorMessage);
}


/*===========================================================================*/
/* Function: Current Limit Line Template
/* Purpose : These function is always a query and returns the
/*           current limit line template.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensSpecModLimLineUsed (ViSession instrSession,
                                                        ViInt32  *currLimLine,
                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_RD_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));
  CHECKRETMSG(RSCMU_getViString(instrSession,"SENSe:SPECtrum:MODulation:LIMit:LINE:USED?",rdBuf,RD_BUFFER_SIZE,0));

  // Extract the CMU response:
  if (strncmp ("GMSK", rdBuf, 4) == 0)
    *currLimLine = RSCMU_GMSK;
  else if (strncmp ("EPSK", rdBuf, 4) == 0)
    *currLimLine = RSCMU_EPSK;

  return RSCMU_Status;
}


/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT SENSITIVITY   FW VERSION 2.0
 *    The subsystem SENSITIVITY contains the functions for measurement of the
 *    bit error rate as a measure of the quality of transmission
 *    between the CMU and the test object.
 * ----------------------------------------------------------------------------
 *      GENERAL CONTROL OF SENSITIVITY MEASUREMENT
 *      The subsystem SENSITIVITY contains the commands for general control of
 *      the SENSITIVITY measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: StartMeasurement
/* Purpose : This function start measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_InitSens (ViSession instrSession,
                                                                 ViInt32   measurementType,
                                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMeasType[]= {"CONT","SSH"};
  ViString    StrRxqMeasType[] = {"BAV", "BER"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    sprintf(wrtBuf,"INIT:SENS:%s", StrMeasType[measurementType]);
  else
    sprintf(wrtBuf,"INIT:RXQ:%s", StrRxqMeasType[measurementType]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: AbortMeasurement
/* Purpose : This function aborts running measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborSens (ViSession instrSession,
                                                                 ViInt32   measurementType,
                                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMeasType[]= {"CONT","SSH"};
  ViString    StrRxqMeasType[] = {"BAV", "BER"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    sprintf(wrtBuf,"ABOR:SENS:%s", StrMeasType[measurementType]);
  else
    sprintf(wrtBuf,"ABOR:RXQ:%s", StrRxqMeasType[measurementType]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: StopMeasurement
/* Purpose : This function stops running measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopSens (ViSession instrSession,
                                                                 ViInt32   measurementType,
                                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMeasType[]= {"CONT","SSH"};
  ViString    StrRxqMeasType[] = {"BAV", "BER"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    sprintf(wrtBuf,"STOP:SENS:%s", StrMeasType[measurementType]);
  else
    sprintf(wrtBuf,"STOP:RXQ:%s", StrRxqMeasType[measurementType]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: ContMeasurement
/* Purpose : This function proceed with next measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContSens (ViSession instrSession,
                                                                 ViInt32   measurementType,
                                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMeasType[]= {"CONT","SSH"};
  ViString    StrRxqMeasType[] = {"BAV", "BER"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    sprintf(wrtBuf,"CONT:SENS:%s", StrMeasType[measurementType]);
  else
    sprintf(wrtBuf,"CONT:RXQ:%s", StrRxqMeasType[measurementType]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Progress Time
/* Purpose : This function returns the progress time for a running BER test,
/*           irrespective of the selected Meas. Mode
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSensStatProg (ViSession instrSession,
                                                        ViInt32  *progressTime,
                                                        ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V5_00,RSCMU_ERROR_FW_VERSION_5_00));

    RETMSG(RSCMU_getViInt32(instrSession, "FETC:RXQ:BER:STAT:PROG?",
                            progressTime,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Sensitivity Measurement Status
/* Purpose : This function returns the status of the current sensitivity
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSensStat (ViSession instrSession,
                                                                     ViInt32   MeasType,
                                                                     ViPInt32  MeasurementStatus,
                                                                     ViPInt32  CountingNo,
                                                                     ViPInt32  StatisticNo,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];
  ViString    StrMeasType[]= {"CONT","SSH"};
  ViString    StrRxqMeasType[] = {"BAV", "BER"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    sprintf(wrtBuf,"FETC:SENS:%s:STAT?", StrMeasType[MeasType]);
  else
    sprintf(wrtBuf,"FETC:RXQ:%s:STAT?", StrRxqMeasType[MeasType]);

  // Fetch the status of the sensitivity measurement:
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15)
  {
    // Get the status of the measurement:
    if ((RSCMU_Status = RSCMU_GetMeasStatVal (MeasurementStatus, TableOfDataValues, 0)) < 0)
      return RSCMU_Status;

    // Get the current value of the statistics counter (the number of the current statistics cycle):
    if ((RSCMU_Status = RSCMU_GetCountingNo (CountingNo, TableOfDataValues, 1)) < 0)
      return RSCMU_Status;

    // Get the current evaluation period within a statistics cycle:
    if ((RSCMU_Status = RSCMU_GetStatisticNo (StatisticNo, TableOfDataValues, 2)) < 0)
      return RSCMU_Status;
  }

  else
  {
    // Get the status of the measurement:
    if ((RSCMU_Status = RSCMU_GetMeasStatVal (MeasurementStatus, TableOfDataValues, 0)) < 0)
      return RSCMU_Status;

    // statistic counter not used!
    *CountingNo = RSCMU_NONE;

    // Get the counter for current eval period (Single shot) or number of frames to average (continuous)
    if ((RSCMU_Status = RSCMU_GetStatisticNo (StatisticNo, TableOfDataValues, 1)) < 0)
      return RSCMU_Status;
  }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensErep (ViSession instrSession,
                                                                     ViInt32   MeasType,
                                                                     ViInt32   Mode,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"OFF","SRQ","SOPC","SRSQ"};
  ViString    StrMeasType[]= {"CONT","SSH"};
  ViString    StrRxqMeasType[] = {"BAV", "BER"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    sprintf (wrtBuf, "CONF:SENS:%s:EREP %s", StrMeasType[MeasType], StrMode[Mode]);
  else
    sprintf (wrtBuf, "CONF:RXQ:%s:EREP %s", StrRxqMeasType[MeasType], StrMode[Mode]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*-----------------------------------------------------------------------------
 *      CONFIGURATION CONTROL
 *-----------------------------------------------------------------------------
/*===========================================================================*/
/* Function: Data set as Application
/* Purpose : This function selects one out of 10 data sets as
/*           application, enabling 10 different BER measurements that
/*           can be parameterized.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensTset (ViSession instrSession,
                                                                     ViInt32   testSetup,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    mode_Applications[]= {"","AP1","AP2","AP3","AP4","AP5","AP6","AP7","AP8","AP9","AP10"};
  ViString    StrTestSetup[]= {"","T1","T2","T3","T4","T5","T6","T7","T8","T9","T10"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, testSetup, 1, 10, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15)
    sprintf (wrtBuf, "CONF:SENS:SSH:TSET %s", mode_Applications[testSetup]);
  else
    sprintf (wrtBuf, "CONF:RXQ:BER:TSET %s", StrTestSetup[testSetup]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set Scope Of Measurement
/* Purpose : This function defines the measured value, the number of
/*           frames to be averaged in a continuous measurement, and the
/*           number of frames to be sent in a single shot measurement,
/*           constituting a  statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensCont (ViSession instrSession,
                                                                     ViInt32   testSetup,
                                                                     ViInt32   measurementType,
                                                                     ViInt32   mode,
                                                                     ViInt32   numberOfFrames,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrMode[] = {"BER", "RFER", "BBB","BDBL","AIBF","BFI","SRES","SREV","RUFR","AEVS","AEVR",VI_NULL};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, testSetup, 1, 10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER3, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
  {
    CHECK_VI_INT32_RANGE(instrSession, mode, 0, 3, RSCMU_ERROR_PARAMETER4, errorMessage);
  }
  else
  {
      if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V4_20)
      {
        CHECK_VI_INT32_RANGE(instrSession, mode, 0, 4, RSCMU_ERROR_PARAMETER4, errorMessage);
      }
      else
      {
        CHECK_VI_INT32_RANGE(instrSession, mode, 0, 10, RSCMU_ERROR_PARAMETER4, errorMessage);
      }
  }

  if (measurementType) // single shot
  {
    CHECK_VI_INT32_RANGE(instrSession, numberOfFrames, RSCMU_NBFRAMES_MIN, RSCMU_NBFRAMES_SENT_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);
  }
  else // continuous
  {
    CHECK_VI_INT32_RANGE(instrSession, numberOfFrames, RSCMU_NBFRAMES_MIN, RSCMU_NBFRAMES_AVER_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);
  }

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
  {
    if (measurementType) // single shot
      sprintf (wrtBuf, "CONF:SENS:SSH%d:CONT %s,%d" , testSetup, StrMode[mode], numberOfFrames);
    else // continuous
      sprintf (wrtBuf, "CONF:SENS:CONT:CONT %s,%d" , StrMode[mode], numberOfFrames);
  }
  else if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_20)
  {
    if (measurementType) // single shot - BER
    {
        sprintf (wrtBuf, "CONF:RXQ:BER%d:CONT %s,%d" , testSetup, StrMode[mode], numberOfFrames);
    }
    else // continuous - BAV
    {
        sprintf (wrtBuf, "CONF:RXQ:BAV:CONT %s,%d" , StrMode[mode], numberOfFrames);
    }
  }
  else
  {
    if (measurementType) // single shot - BER
    {
        sprintf (wrtBuf, "CONFigure:RXQuality:BER%d:CONTrol:CSWitched %s,%d" , testSetup, StrMode[mode], numberOfFrames);
    }
    else // continuous - BAV
    {
        sprintf (wrtBuf, "CONFigure:RXQuality:BAV:CONTrol %s,%d" , StrMode[mode], numberOfFrames);
    }
  }

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;


  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set Scope Of Measurement Packet Data
/* Purpose : This function defines the measured value, the number of
/*           frames to be averaged in a continuous measurement, and the
/*           number of frames to be sent in a single shot measurement,
/*           constituting a  statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensContPData (ViSession instrSession,
                                                   ViInt32   testSetup,
                                                   ViInt32   measurementType,
                                                   ViInt32   mode,
                                                   ViInt32   numberOfFrames,
                                                   ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViString    StrMode[] = {"", "", "","BDBL"};
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_20, RSCMU_ERROR_FW_VERSION_3_20));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, testSetup, 1, 10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, mode, 3, 3, RSCMU_ERROR_PARAMETER4, errorMessage);

  if (measurementType) // single shot
  {
    CHECK_VI_INT32_RANGE(instrSession, numberOfFrames, RSCMU_NBFRAMES_MIN, RSCMU_NBFRAMES_SENT_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);
  }
  else // continuous
  {
    CHECK_VI_INT32_RANGE(instrSession, numberOfFrames, RSCMU_NBFRAMES_MIN, RSCMU_NBFRAMES_AVER_MAX, RSCMU_ERROR_PARAMETER5, errorMessage);
  }

  if (measurementType) // single shot - BER
    sprintf (wrtBuf, "CONFigure:RXQuality:BER%d:CONTrol:PDATa %s,%d" , testSetup, StrMode[mode], numberOfFrames);
  else // continuous - BAV
    sprintf (wrtBuf, "CONFigure:RXQuality:BAV:CONTrol:PDATa %s,%d" , StrMode[mode], numberOfFrames);

  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Set Sensitivity Tests Cycles
/* Purpose : This function determines the stop condition and the
/*           stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensContRep (ViSession instrSession,
                                                 ViInt32   testSetup,
                                                 ViInt32   measurementType,
                                                 ViInt32   StopCondition,
                                                 ViInt32   StepMode,
                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViString    StrStopConditionBER[] = {"NONE","ALIM","FLIM","CLEV","RFLS"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, testSetup, 1, 10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) StepMode, RSCMU_ERROR_PARAMETER5, errorMessage);

  if ((p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_40) && (measurementType == RSCMU_SINGLE_SHOT))
  {
    CHECK_VI_INT32_RANGE(instrSession, StopCondition, RSCMU_NONE, RSCMU_STOP_FLIM, RSCMU_ERROR_PARAMETER4, errorMessage);
  }
  else if ( (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V3_40) &&
            (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60) && (measurementType == RSCMU_SINGLE_SHOT))
  {
    CHECK_VI_INT32_RANGE(instrSession, StopCondition, RSCMU_NONE, RSCMU_STOP_CLEV, RSCMU_ERROR_PARAMETER4, errorMessage);
  }
  else if ( (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V3_60) && (measurementType == RSCMU_SINGLE_SHOT))
  {
    CHECK_VI_INT32_RANGE(instrSession, StopCondition, RSCMU_NONE, RSCMU_STOP_RFLS, RSCMU_ERROR_PARAMETER4, errorMessage);
  }

  // Configure  tests cycles:
  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
  {
    if (measurementType)  // single shot
      sprintf (wrtBuf, "CONF:SENS:SSH%d:CONT:REP %s,%s", testSetup
                                                       , StrStopConditionBER[StopCondition]
                                                       , StrStepMode[StepMode]);
    else // continuous
      sprintf (wrtBuf, "CONF:SENS:CONT:CONT:REP %s,%s", StrStopConditionBER[StopCondition]
                                                      , StrStepMode[StepMode]);
  }
  else
  {
    if (measurementType)  // single shot
      sprintf (wrtBuf, "CONF:RXQ:BER%d:CONT:REP %s,%s", testSetup
                                                      , StrStopConditionBER[StopCondition]
                                                      , StrStepMode[StepMode]);
    else // continuous
      sprintf (wrtBuf, "CONF:RXQ:BAV:CONT:REP %s,%s", StrStopConditionBER[StopCondition]
                                                    , StrStepMode[StepMode]);
  }

  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Level in the used timeslot
/* Purpose : This function sets the TCH absolute level in the used
/*           timeslot. The permissible value range depends on the used
/*           RF output of the CMU and the external attenuation set.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensContLevUtim (ViSession instrSession,
                                                                            ViInt32   testSetup,
                                                                            ViInt32   measurementType,
                                                                            ViReal64  Level,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used
  CHECK_VI_INT32_RANGE(instrSession, testSetup, 1, 10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER3, errorMessage);
//  CHECK_VI_REAL64_RANGE(instrSession, Level, RSCMU_USEDSLOTMIN, RSCMU_USEDSLOTMAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set absolute level in used timeslot
  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
  {
    if (measurementType) // single shot
      sprintf (wrtBuf, "CONF:SENS:SSH%d:CONT:LEV:UTIM %lf",testSetup, Level);
    else
      sprintf (wrtBuf, "CONF:SENS:CONT:CONT:LEV:UTIM %lf", Level);
  }
  else
  {
    if (measurementType) // single shot
      sprintf (wrtBuf, "CONF:RXQ:BER%d:CONT:LEV:UTIM %lf",testSetup, Level);
    else
      sprintf (wrtBuf, "CONF:RXQ:BAV:CONT:LEV:UTIM %lf", Level);
  }

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Level in the unused timeslots
/* Purpose : This function sets the TCH relative level in the unused
/*           timeslots relative to the level in the used timeslot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensContLevUnt (ViSession instrSession,
                                                                           ViInt32   testSetup,
                                                                           ViInt32   measurementType,
                                                                           ViReal64  Level,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, testSetup, 1, 10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER3, errorMessage);
//  CHECK_VI_REAL64_RANGE(instrSession, Level, RSCMU_GSM_SIG_UNUSEDSLOTMIN, RSCMU_GSM_SIG_UNUSEDSLOTMAX, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Set absolute level for Unused Slots
  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
  {
    if (measurementType) // single shot)
      sprintf (wrtBuf, "CONF:SENS:SSH%d:CONT:LEV:UNT %lf",testSetup, Level);
    else // continuous
      sprintf (wrtBuf, "CONF:SENS:CONT:CONT:LEV:UNT %lf", Level);
  }
  else
  {
    if (measurementType) // single shot)
      sprintf (wrtBuf, "CONF:RXQ:BER%d:CONT:LEV:UNT %lf",testSetup, Level);
    else // continuous
      sprintf (wrtBuf, "CONF:RXQ:BAV:CONT:LEV:UNT %lf", Level);
  }

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set hold off times
/* Purpose : This command defines hold off times during which the mobile
/*           can adapt itself to the new RF level at the beginning of
/*           the BER measurement  and send back the bit stream received.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensContHtim (ViSession instrSession,
                                                                         ViReal64  AGCTime,
                                                                         ViReal64  synchTime,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, AGCTime, 0.0, 100.0, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, synchTime, 0.0, 100.0, RSCMU_ERROR_PARAMETER3, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    sprintf (wrtBuf, "CONF:SENS:CONT:HTIM %lf,%lf", AGCTime, synchTime);
  else
    sprintf (wrtBuf, "CONF:RXQ:CONT:HTIM %lf,%lf", AGCTime, synchTime);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}



/*===========================================================================*/
/* Function: Conf. Bit Stream Sensitivity
/* Purpose : This command defines the pseudo random bit sequence that the CMU transmits to the MS
/*           during Receiver Quality measurements.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensBitStream (ViSession instrSession,
                                                   ViInt32 bitStream,
                                                   ViInt32 networkMainService,
                                                   ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE];
  ViString    StrBitStream[] = {"","","PR9","PR11","PR15","PR16", VI_NULL};
  ViString    StrNetwServ[] = {"CSW","PDAT", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, bitStream, RSCMU_SPEECH_PR9, RSCMU_SPEECH_PR16, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, networkMainService, RSCMU_CSW, RSCMU_PDAT, RSCMU_ERROR_PARAMETER3, errorMessage);

    sprintf (wrtBuf, "CONF:RXQ:%s:BITS %s", StrNetwServ[networkMainService], StrBitStream[bitStream]);

    RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: AGC Time
/* Purpose : This function defines hold off times during which the mobile can
/*           adapt itself to the new RF level at the beginning of the Receiver
/*           Quality measurement. A short holdoff time accelerates the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqContAgct (ViSession instrSession,
                                                 ViReal64 AGCHoldoffTime,
                                                 ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    CHECK_VI_REAL64_RANGE(instrSession, AGCHoldoffTime, 0, 100, RSCMU_ERROR_PARAMETER2, errorMessage);

    RETMSG(RSCMU_setViReal64(instrSession, "CONF:RXQ:CONT:AGCT",
                            AGCHoldoffTime,
                            0.0,100.0,
                            RSCMU_ERROR_PARAMETER2));
}

/*-----------------------------------------------------------------------------
 *      Confidence BER Settings
 *---------------------------------------------------------------------------*/

/*===========================================================================*/
/* Function: Early Fail
/* Purpose : This function defines the confidence level for early fail decisions.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensConfEarlyFail (ViSession instrSession,
                                                       ViInt32 earlyFail,
                                                       ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViString    list[] = {"C500", "C900", "C980", "C998", VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_40,RSCMU_ERROR_FW_VERSION_3_40));

  RETMSG(RSCMU_setEnum(instrSession, "CONFigure:RXQuality:CONTrol:CONFidence:FAIL",
                       earlyFail, list,
                       RSCMU_ERROR_PARAMETER2));
}


/*===========================================================================*/
/* Function: Early Pass
/* Purpose : This function defines the confidence level for early pass decisions.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensConfEarlyPass (ViSession instrSession,
                                                       ViInt32 earlyPass,
                                                       ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViString    list[] = {"C500", "C900", "C980", "C998", VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_40,RSCMU_ERROR_FW_VERSION_3_40));

  RETMSG(RSCMU_setEnum(instrSession, "CONFigure:RXQuality:CONTrol:CONFidence:PASS",
                       earlyPass, list,
                       RSCMU_ERROR_PARAMETER2));
}


/*===========================================================================*/
/* Function: Result Window
/* Purpose : This function selects the BER range factor for statistical
/*           dual-limit BER tests..
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensConfResWind (ViSession instrSession,
                                                     ViInt32 resWind,
                                                     ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViString    list[] = {"OFF", "P10", "P20", "P30", VI_NULL};

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_40,RSCMU_ERROR_FW_VERSION_3_40));

  RETMSG(RSCMU_setEnum(instrSession, "CONFigure:RXQuality:CONTrol:CONFidence:RWINdow",
                       resWind, list,
                       RSCMU_ERROR_PARAMETER2));
}


/*===========================================================================*/
/* Function: Minimum Test Time
/* Purpose : This function defines the minimum test time before a check of
/*           the early pass and early fail limits can stop the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensConfMinTTime (ViSession instrSession,
                                                      ViReal64 minTTime,
                                                      ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_40,RSCMU_ERROR_FW_VERSION_3_40));

  RETMSG(RSCMU_setViReal64(instrSession, "CONFigure:RXQuality:CONTrol:CONFidence:MTTime",
                             minTTime, 0.0,100000.0,
                             RSCMU_ERROR_PARAMETER2));
}




/*===========================================================================*/
/* Function: Search Max Cycles
/* Purpose : This function defines the maximum number of single measurements
/*           in a RF level search iteration
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensSearchMaxCycles (ViSession instrSession,
                                                         ViInt32   maxCycles,
                                                         ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_60,RSCMU_ERROR_FW_VERSION_3_60));

    RETMSG(RSCMU_setViInt32(instrSession, "CONFigure:RXQuality:CONT:SEARch:MCYCles",
                            maxCycles, 0, 100,
                            RSCMU_ERROR_PARAMETER2));

}

/*===========================================================================*/
/* Function: Search Upper Level Limit
/* Purpose : This function defines the maximum allowed RF level
/*           during the search procedure.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensSearchUppLevLim (ViSession instrSession,
                                                         ViReal64  upperLevelLimit,
                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_60,RSCMU_ERROR_FW_VERSION_3_60));

  RETMSG(RSCMU_setViReal64(instrSession, "CONFigure:RXQuality:CONT:SEARCH:ULIMit",
                             upperLevelLimit, -200.0, 0.0,
                             RSCMU_ERROR_PARAMETER2));

}

/*===========================================================================*/
/* Function: Search Lower Level Limit
/* Purpose : This function defines the minimum allowed RF level
/*           during the search procedure.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensSearchLowLevLim (ViSession instrSession,
                                                         ViReal64 lowerLevelLimit,
                                                         ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_60,RSCMU_ERROR_FW_VERSION_3_60));

  RETMSG(RSCMU_setViReal64(instrSession, "CONFigure:RXQuality:CONT:SEARCH:LLIMit",
                             lowerLevelLimit, -200.0, 0.0,
                             RSCMU_ERROR_PARAMETER2));

}

/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensContDef (ViSession instrSession,
                                                                        ViInt32   testSetup,
                                                                        ViInt32   measurementType,
                                                                        ViInt32   enableDefaultParameters,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, testSetup, 1, 10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) enableDefaultParameters, RSCMU_ERROR_PARAMETER4, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
  {
    if (measurementType) // single shot
      sprintf (wrtBuf, "CONF:SENS:SSH%d:CONT:DEF %s", testSetup, mode_On_Off[enableDefaultParameters]);
    else // continuous
      sprintf (wrtBuf, "CONF:SENS:CONT:CONT:DEF %s", mode_On_Off[enableDefaultParameters]);
  }
  else
  {
    if (measurementType) // single shot - BER
      sprintf (wrtBuf, "CONF:RXQ:BER%d:CONT:DEF %s", testSetup, mode_On_Off[enableDefaultParameters]);
    else // continuous - BAV
      sprintf (wrtBuf, "CONF:RXQ:BAV:CONT:DEF %s", mode_On_Off[enableDefaultParameters]);
  }

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      TOLERANCE VALUES  for FW VERSION 2.0
 *      This subsystem (SENS:LIM) contains the functions for definition of
 *      tolerance values for the Sensitivity measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Bit Error Class 2
/* Purpose : This function defines an upper limit for the bit error rate
/*           of class II (unprotected bits, see chapter 4)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensLimCLII (ViSession instrSession,
                                                                        ViInt32   testSetup,
                                                                        ViInt32   measurementType,
                                                                        ViReal64  Limit,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, testSetup, 1, 10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, Limit, 0, 100, RSCMU_ERROR_PARAMETER4, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
  {
    if (measurementType) // single shot
      sprintf (wrtBuf, "CONF:SENS:SSH%d:LIM:CLII %lf",testSetup, Limit);
    else // continuous
      sprintf (wrtBuf, "CONF:SENS:CONT:LIM:CLII %lf", Limit);
  }
  else
  {
    if (measurementType) // single shot
      sprintf (wrtBuf, "CONF:RXQ:BER%d:LIM:CLII %lf",testSetup, Limit);
    else // continuous
      sprintf (wrtBuf, "CONF:RXQ:BAV:LIM:CLII %lf", Limit);
  }

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Bit Error Class 1b
/* Purpose : This function defines an upper limit for the bit error rate
/*           of class IB.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensLimCLIB (ViSession instrSession,
                                                                        ViInt32   testSetup,
                                                                        ViInt32   measurementType,
                                                                        ViReal64  Limit,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, testSetup, 1, 10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, Limit, 0, 100, RSCMU_ERROR_PARAMETER4, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
  {
    if (measurementType) // single shot
      sprintf (wrtBuf, "CONF:SENS:SSH%d:LIM:CLIB %lf",testSetup, Limit);
    else // continuous
      sprintf (wrtBuf, "CONF:SENS:CONT:LIM:CLIB %lf", Limit);
  }
  else
  {
    if (measurementType) // single shot
      sprintf (wrtBuf, "CONF:RXQ:BER%d:LIM:CLIB %lf",testSetup, Limit);
    else // continuous
      sprintf (wrtBuf, "CONF:RXQ:BAV:LIM:CLIB %lf", Limit);
  }

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Frame error rate
/* Purpose : This function defines an upper limit for the relative
/*           portion of invalid and therefore erased frames in the
/*           measurementof the sensisitivity.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensLimFERR (ViSession instrSession,
                                                                        ViInt32   testSetup,
                                                                        ViInt32   measurementType,
                                                                        ViReal64  Limit,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, testSetup, 1, 10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, Limit, 0, 100, RSCMU_ERROR_PARAMETER4, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
  {
    if (measurementType) // single shot
      sprintf (wrtBuf, "CONF:SENS:SSH%d:LIM:FERR %lf",testSetup, Limit);
    else // continuous
      sprintf (wrtBuf, "CONF:SENS:CONT:LIM:FERR %lf", Limit);
  }
  else
  {
    if (measurementType) // single shot
      sprintf (wrtBuf, "CONF:RXQ:BER%d:LIM:FERR %lf",testSetup, Limit);
    else // continuous
      sprintf (wrtBuf, "CONF:RXQ:BAV:LIM:FERR %lf", Limit);
  }

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Data Block error rate
/* Purpose : This function defines an upper limit for the data BLER in the
/*           test setup <nr>. Irrespective of the test setup, the default
/*           setting is 10.0 %.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensLimDBLER (ViSession instrSession,
                                                                         ViInt32   testSetup,
                                                                         ViInt32   measurementType,
                                                                         ViReal64  Limit,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, testSetup, 1, 10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, Limit, 0, 100, RSCMU_ERROR_PARAMETER4, errorMessage);

  if (measurementType) // single shot
    sprintf (wrtBuf, "CONF:RXQ:BER%d:LIM:DBL %lf",testSetup, Limit);
  else // continuous
    sprintf (wrtBuf, "CONF:RXQ:BAV:LIM:DBL %lf", Limit);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: USF Block error rate
/* Purpose : This function defines an upper limit for the USF BLER in the
/*           test setup <nr>. Irrespective of the test setup, the default
/*           setting is 10.0 %.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensLimUSFB (ViSession instrSession,
                                                                        ViInt32   testSetup,
                                                                        ViInt32   measurementType,
                                                                        ViReal64  Limit,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, testSetup, 1, 10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, Limit, 0, 100, RSCMU_ERROR_PARAMETER4, errorMessage);

  if (measurementType) // single shot
    sprintf (wrtBuf, "CONF:RXQ:BER%d:LIM:USFB %lf",testSetup, Limit);
  else // continuous
    sprintf (wrtBuf, "CONF:RXQ:BAV:LIM:USFB %lf", Limit);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Reference Level, Multislot
/* Purpose : This function defines the reference value for the individual
/*           downlink (BS) TCH signal levels used for the multislot BER test
/*           on circuit switched channels. See commands CONFigure:RXQuality:
/*           BER<nr>:CONTrol[:CSWitched][:TCH]:MSLot:LEVel:INDividual on p.
/*           6.148.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensContMslRlev (ViSession instrSession,
                                                                            ViInt32   testSetup,
                                                                            ViInt32   measurementType,
                                                                            ViReal64  level,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, testSetup, 1, 10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, level, -137, 13, RSCMU_ERROR_PARAMETER4, errorMessage);

  if (measurementType) // single shot
    sprintf (wrtBuf, "CONF:RXQ:BER%d:CONT:MSL:RLEV %lf",testSetup, level);
  else // continuous
    sprintf (wrtBuf, "CONF:RXQ:BAV:CONT:MSL:RLEV %lf", level);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Reference Level, Multislot
/* Purpose : This function defines the reference value for the individual
/*           downlink (BS) TCH signal levels used for the multislot BER test
/*           on packet data channels.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensMslRlevPdata (ViSession instrSession,
                                                      ViInt32   testSetup,
                                                      ViInt32   measurementType,
                                                      ViReal64  level,
                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, testSetup, 1, 10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, level, -137, 13, RSCMU_ERROR_PARAMETER4, errorMessage);

  if (measurementType) // single shot
    sprintf (wrtBuf, "CONFigure:RXQuality:BER%d:CONTrol:PDATa:TCH:MSLot:RLEVel %lf",testSetup, level);
  else // continuous
    sprintf (wrtBuf, "CONFigure:RXQuality:BAV:CONTrol:PDATa:TCH:MSLot:RLEVel %lf", level);

  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Slot Configuration: Individual (Multislot)
/* Purpose : This function defines the levels in all 8 timeslots of the
/*           downlink (BS) TCH signal relative to the Reference Level set via
/*           CONFigure:RXQuality:BER<nr>:CONTrol[:CSWitched][:TCH]:MSLot:RLEV
/*           (see p. 6.148). The levels are valid for BER tests if the MS is
/*           set to multislot operation.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensContMslLevInd (ViSession instrSession,
                                                                              ViInt32   testSetup,
                                                                              ViInt32   measurementType,
                                                                              ViInt32   switched,
                                                                              ViReal64  LvlBsTs0,
                                                                              ViReal64  LvlBsTs1,
                                                                              ViReal64  LvlBsTs2,
                                                                              ViReal64  LvlBsTs3,
                                                                              ViReal64  LvlBsTs4,
                                                                              ViReal64  LvlBsTs5,
                                                                              ViReal64  LvlBsTs6,
                                                                              ViReal64  LvlBsTs7,
                                                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrSwitched[] = {"CSW","PDAT"};

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, testSetup, 1, 10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) switched, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, LvlBsTs0, -137, 13, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, LvlBsTs1, -137, 13, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, LvlBsTs2, -137, 13, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, LvlBsTs3, -137, 13, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, LvlBsTs4, -137, 13, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, LvlBsTs5, -137, 13, RSCMU_ERROR_PARAMETER10, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, LvlBsTs6, -137, 13, RSCMU_ERROR_PARAMETER11, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, LvlBsTs7, -137, 13, RSCMU_ERROR_PARAMETER12, errorMessage);

  if (measurementType) // single shot
    sprintf (wrtBuf, "CONF:RXQ:BER%d:CONT:%s:MSL:LEV:IND %lf,%lf,%lf,%lf,%lf,%lf,%lf,%lf",testSetup, StrSwitched[switched],
              LvlBsTs0, LvlBsTs1, LvlBsTs2, LvlBsTs3, LvlBsTs4, LvlBsTs5, LvlBsTs6, LvlBsTs7);
  else // continuous
    sprintf (wrtBuf,  "CONF:RXQ:BAV:CONT:%s:MSL:LEV:IND %lf,%lf,%lf,%lf,%lf,%lf,%lf,%lf", StrSwitched[switched],
              LvlBsTs0, LvlBsTs1, LvlBsTs2, LvlBsTs3, LvlBsTs4, LvlBsTs5, LvlBsTs6, LvlBsTs7);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Slot Configuration: Circuit Switched Individual (Single-Slot)
/* Purpose : This function defines the levels in all 8 timeslots of the
/*           downlink (BS) TCH signal relative to the Reference Level set via
/*           CONFigure:RXQuality:BER<nr>:CONTrol[:CSWitched][:TCH]:LEVel:REFL
/*           (see p. 6.148). The levels are valid for BER tests if the MS is
/*           set to multislot operation.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensContMslLevSlot (ViSession instrSession,
                                                                               ViInt32   testSetup,
                                                                               ViInt32   measurementType,
                                                                               ViInt32   slot,
                                                                               ViReal64  power,
                                                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrSlot[] = {"ZERO","ONE","TWO","THR","FOUR","FIVE","SIX","SEV"};

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, testSetup, 1, 10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, slot, 0, 7, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, power, -137, 13, RSCMU_ERROR_PARAMETER5, errorMessage);

  if (measurementType) // single shot
    sprintf (wrtBuf, "CONF:RXQ:BER%d:CONT:LEV:%s %lf", testSetup, StrSlot[slot], power);
  else // continuous
    sprintf (wrtBuf, "CONF:RXQ:BAV:CONT:LEV:%s %lf", StrSlot[slot], power);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Slot Configuration: Individual (Multislot)
/* Purpose : This function defines the levels in all 8 timeslots of the
/*           downlink (BS) TCH signal relative to the Reference Level set via
/*           CONFigure:RXQuality:BER<nr>:CONTrol[:CSWitched][:TCH]:MSLot:RLEV
/*           (see p. 6.148). The levels are valid for BER tests if the MS is
/*           set to multislot operation.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensContMslLevIndPd (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViInt32 application,
                                                         ViInt32 switched,
                                                         ViReal64 levelBSTS0_dB,
                                                         ViReal64 levelBSTS1_dB,
                                                         ViReal64 levelBSTS2_dB,
                                                         ViReal64 levelBSTS3_dB,
                                                         ViReal64 levelBSTS4_dB,
                                                         ViReal64 levelBSTS5_dB,
                                                         ViReal64 levelBSTS6_dB,
                                                         ViReal64 levelBSTS7_dB,
                                                         ViChar errorMessage[])
{
    return RSCMU_GSM_Sig_ConfSensContMslLevInd (instrSession,
                                                          testSetup,
                                                          application,
                                                          switched,
                                                          levelBSTS0_dB,
                                                          levelBSTS1_dB,
                                                          levelBSTS2_dB,
                                                          levelBSTS3_dB,
                                                          levelBSTS4_dB,
                                                          levelBSTS5_dB,
                                                          levelBSTS6_dB,
                                                          levelBSTS7_dB,
                                                          errorMessage);

}

/*===========================================================================*/
/* Function: Slot Configuration: Packet Data Individual (Single-Slot)
/* Purpose : This function defines the levels in all 8 timeslots of the
/*           downlink (BS) TCH signal relative to the Reference Level.
/*           The levels are valid for BER tests if the MS is
/*           set to multislot operation.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensMslLevSlotPdata (ViSession instrSession,
                                                         ViInt32 testSetup,
                                                         ViInt32 application,
                                                         ViInt32 slot,
                                                         ViReal64 power,
                                                         ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViString    StrSlot[] = {"ZERO","ONE","TWO","THR","FOUR","FIVE","SIX","SEV"};

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_21, RSCMU_ERROR_FW_VERSION_3_21));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, testSetup, 1, 10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) application, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, slot, 0, 7, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, power, -137, 13, RSCMU_ERROR_PARAMETER5, errorMessage);

  sprintf (wrtBuf, "CONFigure:RXQuality:BER%d:CONTrol:PDATa:TCH:MSLot:LEVel:SLOT:%s %lf", testSetup, StrSlot[slot], power);

  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}


/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensLimDef (ViSession instrSession,
                                                                       ViInt32   testSetup,
                                                                       ViInt32   measurementType,
                                                                       ViInt32   enableDefaultParameters,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    return RSCMU_Base_errorMessage (instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, testSetup, 1, 10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) enableDefaultParameters, RSCMU_ERROR_PARAMETER4, errorMessage);

  if (measurementType) // single shot - BER
    sprintf (wrtBuf, "CONF:RXQ:BER%d:LIM:DEF %s", testSetup, mode_On_Off[enableDefaultParameters]);
  else // continuous - BAV
    sprintf (wrtBuf, "CONF:RXQ:BAV:LIM:DEF %s", mode_On_Off[enableDefaultParameters]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;
  return RSCMU_Status;
}

/*
 * ----------------------------------------------------------------------------
 *      RESULTS: BIT ERROR RATE  FOR FW VERSION 2.0
 *      This subsystem (SENS[:RESULT]) contains the functions for measurement
 *      and output of the bit error rate and its comparison with the
 *      tolerance values. The subsystem corresponds to the measurement
 *      menus Bit Error Rate for the different types of measurement
 *      (single shot or continuous) and
 *      measured values (BER, RFER, BBB).
 *-----------------------------------------------------------------------------
 *        RFER MEASUREMENTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: RFER: measured values...
/* Purpose : This function start a bit-error-rate test and output the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Rfer_ReadSens (ViSession instrSession,
                                                                      ViInt32   measurementType,
                                                                      ViPReal64 progressTime,
                                                                      ViPReal64 RBERClass2Bits,
                                                                      ViPReal64 RBERClass1bBits,
                                                                      ViPReal64 frameErasureRate,
                                                                      ViPInt32  CRCerrors,
                                                                      ViPInt32  measurementStatus,
                                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  ViString    StrMeasType[] = {"CONT","SSH"};
  ViString    StrRxqMeasType[] = {"BAV","BER"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    sprintf(wrtBuf,"READ:SENS:%s?", StrMeasType[measurementType]);
  else
    sprintf(wrtBuf,"READ:RXQ:%s?", StrRxqMeasType[measurementType]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Scan results
  if ((RSCMU_Status = RSCMU_ScanSensRfer (tab, 0, progressTime, RBERClass2Bits, RBERClass1bBits, frameErasureRate, CRCerrors, measurementStatus)) < 0)
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: RBER: fetch measured values...
/* Purpose : This function output the last
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Rfer_FetcSens (ViSession instrSession,
                                                                      ViInt32   measurementType,
                                                                      ViPReal64 progressTime,
                                                                      ViPReal64 RBERClass2Bits,
                                                                      ViPReal64 RBERClass1bBits,
                                                                      ViPReal64 frameErasureRate,
                                                                      ViPInt32  CRCerrors,
                                                                      ViPInt32  measurementStatus,
                                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  ViString    StrMeasType[] = {"CONT","SSH"};
  ViString    StrRxqMeasType[] = {"BAV","BER"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    sprintf(wrtBuf,"FETC:SENS:%s?", StrMeasType[measurementType]);
  else
    sprintf(wrtBuf,"FETC:RXQ:%s?", StrRxqMeasType[measurementType]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Scan results
  if ((RSCMU_Status = RSCMU_ScanSensRfer (tab, 0, progressTime, RBERClass2Bits, RBERClass1bBits, frameErasureRate, CRCerrors, measurementStatus)) < 0)
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: RBER: sample measured values...
/* Purpose : This function output the last
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Rfer_SampSens (ViSession instrSession,
                                                                     ViInt32   measurementType,
                                                                     ViPReal64 progressTime,
                                                                     ViPReal64 RBERClass2Bits,
                                                                     ViPReal64 RBERClass1bBits,
                                                                     ViPReal64 frameErasureRate,
                                                                     ViPInt32  CRCerrors,
                                                                     ViPInt32  measurementStatus,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  ViString    StrMeasType[] = {"CONT","SSH"};
  ViString    StrRxqMeasType[] = {"BAV","BER"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    sprintf(wrtBuf,"SAMP:SENS:%s?", StrMeasType[measurementType]);
  else
    sprintf(wrtBuf,"SAMP:RXQ:%s?", StrRxqMeasType[measurementType]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Scan results
  if ((RSCMU_Status = RSCMU_ScanSensRfer (tab, 0, progressTime, RBERClass2Bits, RBERClass1bBits, frameErasureRate, CRCerrors, measurementStatus)) < 0)
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: RFER: measured values... with statistical results and RF Search
/* Purpose : The statistical result is available only if statistical BER testing
/*           is activated via CONFigure:RXQuality:BER<nr>:CONTrol:REPetition (see p. 6.156)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Res_Rfer (ViSession instrSession,
                                          ViInt32   command,
                                          ViReal64  *progressTime,
                                          ViReal64  *RBERClass2Bits,
                                          ViReal64  *RBERClass1bBits,
                                          ViReal64  *frameErasureRate,
                                          ViInt32   *CRCerrors,
                                          ViInt32   *measurementStatus,
                                          ViInt32   *statisticalResult,
                                          ViInt32   *RFSearchLevel,
                                          ViReal64  *RFSearchLevelValue,
                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_40, RSCMU_ERROR_FW_VERSION_3_40));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, command, RSCMU_COMMAND_READ, RSCMU_COMMAND_SAMP, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf,"%s:SCALar:RXQuality:BER?", StrCommand[command]);

  CHECKRETMSG(RSCMU_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%lf", progressTime);
  else *progressTime = RSCMU_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%lf", RBERClass2Bits);
  else *RBERClass2Bits = RSCMU_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%lf", RBERClass1bBits);
  else *RBERClass1bBits = RSCMU_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%lf", frameErasureRate);
  else *frameErasureRate = RSCMU_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%d", CRCerrors);
  else *CRCerrors = RSCMU_NAN_VI_INT32;

  // Get the statistical results
  if (strncmp ("RUN", tab[6], 3) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_RUN;
  else if (strncmp ("EFAI", tab[6], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_EFAIL;
  else if (strncmp ("EPAS", tab[6], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_EPASS;
  else if (strncmp ("FAIL", tab[6], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_FAIL;
  else if (strncmp ("PASS", tab[6], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_PASS;
  else if (strncmp ("THIG", tab[6], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_THIGH;
  else if (strncmp ("TLOW", tab[6], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_TLOW;
  else *statisticalResult = RSCMU_NAN_VI_INT32;

  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V3_60)
  {
      // Get the number of RF Search Level Value
      if (strncmp (tab[7], "NAN", 3) != 0)
      {
        if (!sscanf (tab[7], "%lf", RFSearchLevelValue))
          CHECKRETMSG(RSCMU_getIndexFromString(instrSession, tab[7], searchLevelArr, RFSearchLevel));
        else *RFSearchLevel = RSCMU_VAL;
      }
      else
      {
          *RFSearchLevelValue = RSCMU_NAN;
          *RFSearchLevel = RSCMU_VAL;
      }
  }

  // Get the measurement status
  return RSCMU_GetSensMeasStatVal (measurementStatus, tab, 5);
}

/*===========================================================================*/
/* Function: BER: Matching Tolerances
/* Purpose : This Function indicates whether and in which way the
/*           permissibleerror limits for the measured values of the bit
/*           error rate test have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Rfer_CalcSensLimMatc (ViSession instrSession,
                                                                             ViInt32   measurementType,
                                                                             ViPInt32  total,
                                                                             ViPInt32  RBERClass2Bits,
                                                                             ViPInt32  RBERClass1bBits,
                                                                             ViPInt32  frameErasureRate,
                                                                             ViPInt32  CRCErrors,
                                                                             ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];
  ViString    StrMeasType[]= {"CONT","SSH"};
  ViString    StrRxqMeasType[] = {"BAV","BER"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    sprintf(wrtBuf,"CALC:SENS:%s:LIM:MATC?", StrMeasType[measurementType]);
  else
    sprintf(wrtBuf,"CALC:RXQ:%s:LIM:MATC?", StrRxqMeasType[measurementType]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Get the measurement status
  if ((RSCMU_Status = RSCMU_GetSensMeasStatVal (total, TableOfDataValues, 0)) < 0)
  return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  // RBER for Class2 Bits
  RSCMU_Status = RSCMU_GetMatchingValue (RBERClass2Bits, TableOfDataValues, 1);

  // RBER for Class1b Bits
  RSCMU_Status = RSCMU_GetMatchingValue (RBERClass1bBits, TableOfDataValues, 2);

  // Frame erasure rate
  RSCMU_Status = RSCMU_GetMatchingValue (frameErasureRate, TableOfDataValues, 3);

  // Cyclic redundancy check
  RSCMU_Status = RSCMU_GetMatchingValue (CRCErrors, TableOfDataValues, 4);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: RFER: measured values... with statistical results
/* Purpose : The statistical result is available only if statistical BER testing
/*           is activated via CONFigure:RXQuality:BER<nr>:CONTrol:REPetition (see p. 6.156)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Res_Confidence_Rfer (ViSession instrSession,
                                                     ViInt32   command,
                                                     ViPReal64 progressTime,
                                                     ViPReal64 RBERClass2Bits,
                                                     ViPReal64 RBERClass1bBits,
                                                     ViPReal64 frameErasureRate,
                                                     ViPInt32  CRCerrors,
                                                     ViPInt32  measurementStatus,
                                                     ViPInt32  statisticalResult,
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_40, RSCMU_ERROR_FW_VERSION_3_40));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, command, RSCMU_COMMAND_READ, RSCMU_COMMAND_SAMP, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf,"%s:SCALar:RXQuality:BER?", StrCommand[command]);

  CHECKRETMSG(RSCMU_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%lf", progressTime);
  else *progressTime = RSCMU_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%lf", RBERClass2Bits);
  else *RBERClass2Bits = RSCMU_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%lf", RBERClass1bBits);
  else *RBERClass1bBits = RSCMU_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%lf", frameErasureRate);
  else *frameErasureRate = RSCMU_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%d", CRCerrors);
  else *CRCerrors = RSCMU_NAN_VI_INT32;

  // Get the measurement status
  return RSCMU_GetSensMeasStatVal (measurementStatus, tab, 5);
}

/*
 *-----------------------------------------------------------------------------
 *        BER MEASUREMENTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: BER: measured values...
/* Purpose : This function start a bit-error-rate test and output the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Ber_ReadSens (ViSession instrSession,
                                                                     ViInt32   measurementType,
                                                                     ViPReal64 progressTime,
                                                                     ViPReal64 BERClass2Bits,
                                                                     ViPReal64 BERClass1bBits,
                                                                     ViPInt32  CRCerrors,
                                                                     ViPInt32  measurementStatus,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  ViString    StrMeasType[]= {"CONT","SSH"};
  ViString    StrRxqMeasType[] = {"BAV","BER"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    sprintf(wrtBuf,"READ:SENS:%s?", StrMeasType[measurementType]);
  else
    sprintf(wrtBuf,"READ:RXQ:%s?", StrRxqMeasType[measurementType]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Scan results
  if ((RSCMU_Status = RSCMU_ScanSensBer (tab, 0, progressTime, BERClass2Bits, BERClass1bBits, CRCerrors, measurementStatus)) < 0)
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: BER: measured values...
/* Purpose : This function start a bit-error-rate test and output the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Ber_FetcSens (ViSession instrSession,
                                                                    ViInt32   measurementType,
                                                                    ViPReal64 progressTime,
                                                                    ViPReal64 BERClass2Bits,
                                                                    ViPReal64 BERClass1bBits,
                                                                    ViPInt32  CRCerrors,
                                                                    ViPInt32  measurementStatus,
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  ViString    StrMeasType[]= {"CONT","SSH"};
  ViString    StrRxqMeasType[] = {"BAV","BER"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    sprintf(wrtBuf,"FETC:SENS:%s?", StrMeasType[measurementType]);
  else
    sprintf(wrtBuf,"FETC:RXQ:%s?", StrRxqMeasType[measurementType]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Scan results
  if ((RSCMU_Status = RSCMU_ScanSensBer (tab, 0, progressTime, BERClass2Bits, BERClass1bBits, CRCerrors, measurementStatus)) < 0)
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: BER: measured values...
/* Purpose : This function start a bit-error-rate test and output the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Ber_SampSens (ViSession instrSession,
                                                                     ViInt32   measurementType,
                                                                     ViPReal64 progressTime,
                                                                     ViPReal64 BERClass2Bits,
                                                                     ViPReal64 BERClass1bBits,
                                                                     ViPInt32  CRCerrors,
                                                                     ViPInt32  measurementStatus,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  ViString    StrMeasType[]= {"CONT","SSH"};
  ViString    StrRxqMeasType[] = {"BAV","BER"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    sprintf(wrtBuf,"SAMP:SENS:%s?", StrMeasType[measurementType]);
  else
    sprintf(wrtBuf,"SAMP:RXQ:%s?", StrRxqMeasType[measurementType]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Scan results
  if ((RSCMU_Status = RSCMU_ScanSensBer (tab, 0, progressTime, BERClass2Bits, BERClass1bBits, CRCerrors, measurementStatus)) < 0)
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: BER: measured values... with statistical results and RF search
/* Purpose : The statistical result is available only if statistical BER testing
/*           is activated via CONFigure:RXQuality:BER<nr>:CONTrol:REPetition (see p. 6.156)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Res_BER (ViSession instrSession,
                                         ViInt32   command,
                                         ViReal64  *progressTime,
                                         ViReal64  *RBERClass2Bits,
                                         ViReal64  *RBERClass1bBits,
                                         ViInt32   *CRCerrors,
                                         ViInt32   *measurementStatus,
                                         ViInt32   *statisticalResult,
                                         ViInt32   *RFSearchLevel,
                                         ViReal64  *RFSearchLevelValue,
                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_40, RSCMU_ERROR_FW_VERSION_3_40));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, command, RSCMU_COMMAND_READ, RSCMU_COMMAND_SAMP, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf,"%s:SCALar:RXQuality:BER?", StrCommand[command]);

  CHECKRETMSG(RSCMU_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%lf", progressTime);
  else *progressTime = RSCMU_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%lf", RBERClass2Bits);
  else *RBERClass2Bits = RSCMU_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%lf", RBERClass1bBits);
  else *RBERClass1bBits = RSCMU_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%d", CRCerrors);
  else *CRCerrors = RSCMU_NAN_VI_INT32;

  // Get the statistical results
  if (strncmp ("RUN", tab[5], 3) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_RUN;
  else if (strncmp ("EFAI", tab[5], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_EFAIL;
  else if (strncmp ("EPAS", tab[5], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_EPASS;
  else if (strncmp ("FAIL", tab[5], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_FAIL;
  else if (strncmp ("PASS", tab[5], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_PASS;
  else if (strncmp ("THIG", tab[5], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_THIGH;
  else if (strncmp ("TLOW", tab[5], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_TLOW;
  else *statisticalResult = RSCMU_NAN_VI_INT32;

  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V3_60)
  {
      // Get the number of RF Search Level Value
      if (strncmp (tab[6], "NAN", 3) != 0)
      {
        if (!sscanf (tab[6], "%lf", RFSearchLevelValue))
          CHECKRETMSG(RSCMU_getIndexFromString(instrSession, tab[6], searchLevelArr, RFSearchLevel));
        else *RFSearchLevel = RSCMU_VAL;
      }
      else
      {
          *RFSearchLevelValue = RSCMU_NAN;
          *RFSearchLevel = RSCMU_VAL;
      }
  }

  // Get the measurement status
  return RSCMU_GetSensMeasStatVal (measurementStatus, tab, 4);
}

/*===========================================================================*/
/* Function: RBER: Matching Tolerances
/* Purpose : This Function indicates whether and in which way the
/*           permissible error limits for the measured values of the bit
/*           error rate test have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Ber_CalcSensLimMatc (ViSession instrSession,
                                                                            ViInt32   measurementType,
                                                                            ViPInt32  total,
                                                                            ViPInt32  BERClass2Bits,
                                                                            ViPInt32  BERClass1bBits,
                                                                            ViPInt32  CRCErrors,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];
  ViString    StrMeasType[]= {"CONT","SSH"};
  ViString    StrRxqMeasType[] = {"BAV","BER"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    sprintf(wrtBuf,"CALC:SENS:%s:LIM:MATC?",StrMeasType[measurementType]);
  else
    sprintf(wrtBuf,"CALC:RXQ:%s:LIM:MATC?",StrRxqMeasType[measurementType]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Get the measurement status
  if ((RSCMU_Status = RSCMU_GetSensMeasStatVal (total, TableOfDataValues, 0)) < 0)
  return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  // RBER for Class2 Bits
  RSCMU_Status = RSCMU_GetMatchingValue (BERClass2Bits,TableOfDataValues,1);

  // RBER for Class1b Bits
  RSCMU_Status = RSCMU_GetMatchingValue (BERClass1bBits,TableOfDataValues,2);

  // Cyclic redundancy check
  RSCMU_Status = RSCMU_GetMatchingValue (CRCErrors,TableOfDataValues,3);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: BER: measured values... with statistical results
/* Purpose : The statistical result is available only if statistical BER testing
/*           is activated via CONFigure:RXQuality:BER<nr>:CONTrol:REPetition (see p. 6.156)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Res_Confidence_BER  (ViSession instrSession,
                                                     ViInt32   command,
                                                     ViPReal64 progressTime,
                                                     ViPReal64 RBERClass2Bits,
                                                     ViPReal64 RBERClass1bBits,
                                                     ViPInt32  CRCerrors,
                                                     ViPInt32  measurementStatus,
                                                     ViPInt32  statisticalResult,
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_40, RSCMU_ERROR_FW_VERSION_3_40));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, command, RSCMU_COMMAND_READ, RSCMU_COMMAND_SAMP, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf,"%s:SCALar:RXQuality:BER?", StrCommand[command]);

  CHECKRETMSG(RSCMU_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%lf", progressTime);
  else *progressTime = RSCMU_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%lf", RBERClass2Bits);
  else *RBERClass2Bits = RSCMU_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%lf", RBERClass1bBits);
  else *RBERClass1bBits = RSCMU_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%d", CRCerrors);
  else *CRCerrors = RSCMU_NAN_VI_INT32;

  // Get the measurement status
  return RSCMU_GetSensMeasStatVal (measurementStatus, tab, 4);
}

/*
 *-----------------------------------------------------------------------------
 *        FAST BER MEASUREMENTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: FAST: measured values...
/* Purpose : This function start a bit-error-rate test and output the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Bbb_ReadSens (ViSession instrSession,
                                                                     ViInt32   measurementType,
                                                                     ViPReal64 progressTime,
                                                                     ViPReal64 Ber,
                                                                     ViPInt32  CRCerrors,
                                                                     ViPInt32  measurementStatus,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  ViString    StrMeasType[]= {"CONT","SSH"};
  ViString    StrRxqMeasType[] = {"BAV","BER"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    sprintf(wrtBuf,"READ:SENS:%s?",StrMeasType[measurementType]);
  else
    sprintf(wrtBuf,"READ:RXQ:%s?",StrRxqMeasType[measurementType]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Scan Results
  if ((RSCMU_Status = RSCMU_ScanSensBbb (tab, 0, progressTime, Ber, CRCerrors, measurementStatus)) < 0)
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: FAST: measured values...
/* Purpose : This function start a bit-error-rate test and output the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Bbb_FetcSens (ViSession instrSession,
                                                                     ViInt32   measurementType,
                                                                     ViPReal64 progressTime,
                                                                     ViPReal64 Ber,
                                                                     ViPInt32  CRCerrors,
                                                                     ViPInt32  measurementStatus,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  ViString    StrMeasType[]= {"CONT","SSH"};
  ViString    StrRxqMeasType[] = {"BAV","BER"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    sprintf(wrtBuf,"FETC:SENS:%s?",StrMeasType[measurementType]);
  else
    sprintf(wrtBuf,"FETC:RXQ:%s?",StrRxqMeasType[measurementType]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Scan Results
  if ((RSCMU_Status = RSCMU_ScanSensBbb (tab, 0, progressTime, Ber, CRCerrors, measurementStatus)) < 0)
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: FAST: measured values...
/* Purpose : This function start a bit-error-rate test and output the
/*           measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Bbb_SampSens (ViSession instrSession,
                                                                     ViInt32   measurementType,
                                                                     ViPReal64 progressTime,
                                                                     ViPReal64 Ber,
                                                                     ViPInt32  CRCerrors,
                                                                     ViPInt32  measurementStatus,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  ViString    StrMeasType[]= {"CONT","SSH"};
  ViString    StrRxqMeasType[] = {"BAV","BER"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    sprintf(wrtBuf,"SAMP:SENS:%s?",StrMeasType[measurementType]);
  else
    sprintf(wrtBuf,"SAMP:RXQ:%s?",StrRxqMeasType[measurementType]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Scan Results
  if ((RSCMU_Status = RSCMU_ScanSensBbb (tab, 0, progressTime, Ber, CRCerrors, measurementStatus)) < 0)
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: FAST: measured values... with statistical results and RF search
/* Purpose : The statistical result is available only if statistical BER testing
/*           is activated via CONFigure:RXQuality:BER<nr>:CONTrol:REPetition (see p. 6.156)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Res_Bbb (ViSession instrSession,
                                         ViInt32   command,
                                         ViReal64  *progressTime,
                                         ViReal64  *ber,
                                         ViInt32   *CRCerrors,
                                         ViInt32   *measurementStatus,
                                         ViInt32   *statisticalResult,
                                         ViInt32   *RFSearchLevel,
                                         ViReal64  *RFSearchLevelValue,
                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_40, RSCMU_ERROR_FW_VERSION_3_40));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, command, RSCMU_COMMAND_READ, RSCMU_COMMAND_SAMP, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf,"%s:SCALar:RXQuality:BER?", StrCommand[command]);

  CHECKRETMSG(RSCMU_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%lf", progressTime);
  else *progressTime = RSCMU_NAN;
  // Get the bit error rate
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%lf", ber);
  else *ber = RSCMU_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%d", CRCerrors);
  else *CRCerrors = RSCMU_NAN_VI_INT32;

  // Get the statistical results
  if (strncmp ("RUN", tab[4], 3) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_RUN;
  else if (strncmp ("EFAI", tab[4], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_EFAIL;
  else if (strncmp ("EPAS", tab[4], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_EPASS;
  else if (strncmp ("FAIL", tab[4], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_FAIL;
  else if (strncmp ("PASS", tab[4], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_PASS;
  else if (strncmp ("THIG", tab[4], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_THIGH;
  else if (strncmp ("TLOW", tab[4], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_TLOW;
  else *statisticalResult = RSCMU_NAN_VI_INT32;

  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V3_60)
  {
      // Get the number of RF Search Level Value
      if (strncmp (tab[5], "NAN", 3) != 0)
      {
        if (!sscanf (tab[5], "%lf", RFSearchLevelValue))
          CHECKRETMSG(RSCMU_getIndexFromString(instrSession, tab[5], searchLevelArr, RFSearchLevel));
        else *RFSearchLevel = RSCMU_VAL;
      }
      else
      {
          *RFSearchLevelValue = RSCMU_NAN;
          *RFSearchLevel = RSCMU_VAL;
      }
  }

  // Get the measurement status
  return RSCMU_GetSensMeasStatVal (measurementStatus, tab, 3);
}

/*===========================================================================*/
/* Function: FAST BER: Matching Tolerance
/* Purpose : This Function indicates whether and in which way the
/*           permissible error limits for the measured values of the bit
/*           error rate test have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Bbb_CalcSensLimMatc (ViSession instrSession,
                                                                            ViInt32   measurementType,
                                                                            ViPInt32  total,
                                                                            ViPInt32  Ber,
                                                                            ViPInt32  CRCErrors,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];
  ViString    StrMeasType[]= {"CONT","SSH"};
  ViString    StrRxqMeasType[] = {"BAV","BER"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER2, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00)
    sprintf(wrtBuf,"CALC:SENS:%s:LIM:MATC?",StrMeasType[measurementType]);
  else
    sprintf(wrtBuf,"CALC:RXQ:%s:LIM:MATC?",StrRxqMeasType[measurementType]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Get the measurement status
  if ((RSCMU_Status = RSCMU_GetSensMeasStatVal (total, TableOfDataValues, 0)) < 0)
  return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  // FAST for Class2 Bits
  RSCMU_Status = RSCMU_GetMatchingValue (Ber,TableOfDataValues,1);

  // Cyclic redundancy check
  RSCMU_Status = RSCMU_GetMatchingValue (CRCErrors,TableOfDataValues,2);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: FAST: measured values... with statistical results
/* Purpose : The statistical result is available only if statistical BER testing
/*           is activated via CONFigure:RXQuality:BER<nr>:CONTrol:REPetition (see p. 6.156)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Res_Confidence_Bbb  (ViSession instrSession,
                                                     ViInt32   command,
                                                     ViPReal64 progressTime,
                                                     ViPReal64 ber,
                                                     ViPInt32  CRCerrors,
                                                     ViPInt32  measurementStatus,
                                                     ViPInt32  statisticalResult,
                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_40, RSCMU_ERROR_FW_VERSION_3_40));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, command, RSCMU_COMMAND_READ, RSCMU_COMMAND_SAMP, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf,"%s:SCALar:RXQuality:BER?", StrCommand[command]);

  CHECKRETMSG(RSCMU_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%lf", progressTime);
  else *progressTime = RSCMU_NAN;
  // Get the bit error rate
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%lf", ber);
  else *ber = RSCMU_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%d", CRCerrors);
  else *CRCerrors = RSCMU_NAN_VI_INT32;

  // Get the measurement status
  return RSCMU_GetSensMeasStatVal (measurementStatus, tab, 3);
}

/*
 *-----------------------------------------------------------------------------
 *        DBLER MEASUREMENTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: DBLER: measured values...
/* Purpose : This function start a DBLER test and output the measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Dbler_ReadSens (ViSession instrSession,
                                                                       ViInt32   measurementType,
                                                                       ViPReal64 progressTime,
                                                                       ViPReal64 Ber,
                                                                       ViPReal64 Usfbler,
                                                                       ViPReal64 dbler,
                                                                       ViPInt32  CRCerrors,
                                                                       ViPInt32  measurementStatus,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  ViString    StrRxqMeasType[] = {"BAV","BER"};

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf,"READ:RXQ:%s?",StrRxqMeasType[measurementType]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Scan Results
  if ((RSCMU_Status = RSCMU_ScanSensDbler (tab, 0, progressTime, Ber, Usfbler, dbler, CRCerrors, measurementStatus)) < 0)
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: DBLER: measured values...
/* Purpose : This function outputs the measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Dbler_FetcSens (ViSession instrSession,
                                                                       ViInt32   measurementType,
                                                                       ViPReal64 progressTime,
                                                                       ViPReal64 Ber,
                                                                       ViPReal64 Usfbler,
                                                                       ViPReal64 dbler,
                                                                       ViPInt32  CRCerrors,
                                                                       ViPInt32  measurementStatus,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  ViString    StrRxqMeasType[] = {"BAV","BER"};

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf,"FETC:RXQ:%s?",StrRxqMeasType[measurementType]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Scan Results
  if ((RSCMU_Status = RSCMU_ScanSensDbler (tab, 0, progressTime, Ber, Usfbler, dbler, CRCerrors, measurementStatus)) < 0)
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: DBLER: measured values...
/* Purpose : This function output the measurement results (synchronized).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Dbler_SampSens (ViSession instrSession,
                                                                       ViInt32   measurementType,
                                                                       ViPReal64 progressTime,
                                                                       ViPReal64 Ber,
                                                                       ViPReal64 Usfbler,
                                                                       ViPReal64 dbler,
                                                                       ViPInt32  CRCerrors,
                                                                       ViPInt32  measurementStatus,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  ViString    StrRxqMeasType[] = {"BAV","BER"};

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf,"SAMP:RXQ:%s?",StrRxqMeasType[measurementType]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Scan Results
  if ((RSCMU_Status = RSCMU_ScanSensDbler (tab, 0, progressTime, Ber, Usfbler, dbler, CRCerrors, measurementStatus)) < 0)
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: DBLER: Matching Tolerance
/* Purpose : This Function indicates whether and in which way the
/*           permissible error limits for the measured values of DBLER
/*           test have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Dbler_CalcSensLimMatc (ViSession instrSession,
                                                                              ViInt32   measurementType,
                                                                              ViPInt32  total,
                                                                              ViPInt32  Ber,
                                                                              ViPInt32  Usfbler,
                                                                              ViPInt32  Bler,
                                                                              ViPInt32  CRCErrors,
                                                                              ViPInt32  FalseUSFDetection,
                                                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];
  ViString    StrRxqMeasType[] = {"BAV","BER"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf,"CALC:RXQ:%s:LIM:MATC?",StrRxqMeasType[measurementType]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Get the measurement status
  if ((RSCMU_Status = RSCMU_GetSensMeasStatVal (total, TableOfDataValues, 0)) < 0)
  return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  // FAST for Class2 Bits
  RSCMU_Status = RSCMU_GetMatchingValue (Ber,TableOfDataValues,1);

  // USF BLER
  RSCMU_Status = RSCMU_GetMatchingValue (Usfbler,TableOfDataValues,2);

  // BLER
  RSCMU_Status = RSCMU_GetMatchingValue (Bler,TableOfDataValues,3);

  // Cyclic redundancy check
  RSCMU_Status = RSCMU_GetMatchingValue (CRCErrors,TableOfDataValues,4);

  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V3_60)
    RSCMU_Status = RSCMU_GetMatchingValue (FalseUSFDetection,TableOfDataValues,5);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: DBLER: measured values... with statistical results
/* Purpose : The statistical result is available only if statistical BER testing
/*           is activated via CONFigure:RXQuality:BER<nr>:CONTrol:REPetition (see p. 6.156)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Res_Confidence_Dbler (ViSession instrSession,
                                                      ViInt32   command,
                                                      ViPReal64 progressTime,
                                                      ViPReal64 ber,
                                                      ViPReal64 usfBler,
                                                      ViPReal64 dbler,
                                                      ViPInt32  CRCerrors,
                                                      ViPInt32  measurementStatus,
                                                      ViPInt32  statisticalResult,
                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_40, RSCMU_ERROR_FW_VERSION_3_40));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, command, RSCMU_COMMAND_READ, RSCMU_COMMAND_SAMP, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf,"%s:SCALar:RXQuality:BER?", StrCommand[command]);

  CHECKRETMSG(RSCMU_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%lf", progressTime);
  else *progressTime = RSCMU_NAN;
  // Get the BER
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%lf", ber);
  else *ber = RSCMU_NAN;
  // Get the USFBLER
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%lf", usfBler);
  else *usfBler = RSCMU_NAN;
  // Get the DBLER
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%lf", dbler);
  else *dbler = RSCMU_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%d", CRCerrors);
  else *CRCerrors = RSCMU_NAN_VI_INT32;

  // Get the measurement status
  return RSCMU_GetSensMeasStatVal (measurementStatus, tab, 5);
}

/*===========================================================================*/
/* Function: DBLER: Single Shot measured values... with statistical results
/* Purpose : The statistical result is available only if statistical BER testing
/*           is activated via CONFigure:RXQuality:BER<nr>:CONTrol:REPetition (see p. 6.156)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_BER_Res_Dbler_352 (ViSession instrSession,
                                                   ViInt32   command,
                                                   ViPReal64 progressTime,
                                                   ViPReal64 ber,
                                                   ViPReal64 usfBler,
                                                   ViPReal64 dbler,
                                                   ViPInt32  CRCerrors,
                                                   ViPInt32  measurementStatus,
                                                   ViPInt32  statisticalResult,
                                                   ViPReal64 falseUsfDetection,
                                                   ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_52, RSCMU_ERROR_FW_VERSION_3_52));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, command, RSCMU_COMMAND_READ, RSCMU_COMMAND_SAMP, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf(wrtBuf,"%s:SCAL:RXQ:BER?", StrCommand[command]);

  CHECKRETMSG(RSCMU_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%lf", progressTime);
  else *progressTime = RSCMU_NAN;

  // Get the BER
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%lf", ber);
  else *ber = RSCMU_NAN;

  // Get the USFBLER
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%lf", usfBler);
  else *usfBler = RSCMU_NAN;

  // Get the DBLER
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%lf", dbler);
  else *dbler = RSCMU_NAN;

  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%d", CRCerrors);
  else *CRCerrors = RSCMU_NAN_VI_INT32;

  // Get the measurement status
  return RSCMU_GetSensMeasStatVal (measurementStatus, tab, 5);
}

/*===========================================================================*/
/* Function: DBLER: Single Shot measured values... with statistical results and RF
/* Purpose : The statistical result is available only if statistical BER testing
/*           is activated via CONFigure:RXQuality:BER<nr>:CONTrol:REPetition (see p. 6.156)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_BER_Res_Dbler (ViSession instrSession,
                                               ViInt32   command,
                                               ViReal64  *progressTime,
                                               ViReal64  *ber,
                                               ViReal64  *usfBler,
                                               ViReal64  *dbler,
                                               ViInt32   *CRCerrors,
                                               ViInt32   *measurementStatus,
                                               ViInt32   *statisticalResult,
                                               ViReal64  *falseUsfDetection,
                                               ViInt32   *RFSearchLevel,
                                               ViReal64  *RFSearchLevelValue,
                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_52, RSCMU_ERROR_FW_VERSION_3_52));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, command, RSCMU_COMMAND_READ, RSCMU_COMMAND_SAMP, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf(wrtBuf,"%s:SCAL:RXQ:BER?", StrCommand[command]);

  CHECKRETMSG(RSCMU_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%lf", progressTime);
  else *progressTime = RSCMU_NAN;

  // Get the BER
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%lf", ber);
  else *ber = RSCMU_NAN;

  // Get the USFBLER
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%lf", usfBler);
  else *usfBler = RSCMU_NAN;

  // Get the DBLER
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%lf", dbler);
  else *dbler = RSCMU_NAN;

  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%d", CRCerrors);
  else *CRCerrors = RSCMU_NAN_VI_INT32;

  // Get the statistical results
  if (strncmp ("RUN", tab[6], 3) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_RUN;
  else if (strncmp ("EFAI", tab[6], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_EFAIL;
  else if (strncmp ("EPAS", tab[6], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_EPASS;
  else if (strncmp ("FAIL", tab[6], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_FAIL;
  else if (strncmp ("PASS", tab[6], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_PASS;
  else if (strncmp ("THIG", tab[6], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_THIGH;
  else if (strncmp ("TLOW", tab[6], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_TLOW;
  else *statisticalResult = RSCMU_NAN_VI_INT32;

  // Get the false Usf Detection
  if (strncmp (tab[7], "NAN", 3) != 0)
    sscanf (tab[7], "%lf", falseUsfDetection);
  else *falseUsfDetection = RSCMU_NAN;

  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V3_60)
  {
      // Get the number of RF Search Level Value
      if (strncmp (tab[8], "NAN", 3) != 0)
      {
        if (!sscanf (tab[8], "%lf", RFSearchLevelValue))
          CHECKRETMSG(RSCMU_getIndexFromString(instrSession, tab[8], searchLevelArr, RFSearchLevel));
        else *RFSearchLevel = RSCMU_VAL;
      }
      else
      {
          *RFSearchLevelValue = RSCMU_NAN;
          *RFSearchLevel = RSCMU_VAL;
      }
  }

  // Get the measurement status
  return RSCMU_GetSensMeasStatVal (measurementStatus, tab, 5);
}

/*===========================================================================*/
/* Function: DBLER: Continuous measured values
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_BAV_Res_Dbler_352 (ViSession instrSession,
                                                   ViInt32   command,
                                                   ViPReal64 progressTime,
                                                   ViPReal64 ber,
                                                   ViPReal64 usfBler,
                                                   ViPReal64 dbler,
                                                   ViPInt32  CRCerrors,
                                                   ViPInt32  measurementStatus,
                                                   ViPReal64 falseUsfDetection,
                                                   ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_52, RSCMU_ERROR_FW_VERSION_3_52));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, command, RSCMU_COMMAND_FETC, RSCMU_COMMAND_SAMP, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf(wrtBuf,"%s:SCAL:RXQ:BAV?", StrCommand[command]);

  CHECKRETMSG(RSCMU_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%lf", progressTime);
  else *progressTime = RSCMU_NAN;

  // Get the BER
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%lf", ber);
  else *ber = RSCMU_NAN;

  // Get the USFBLER
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%lf", usfBler);
  else *usfBler = RSCMU_NAN;

  // Get the DBLER
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%lf", dbler);
  else *dbler = RSCMU_NAN;

  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%d", CRCerrors);
  else *CRCerrors = RSCMU_NAN_VI_INT32;

  // Get the measurement status
  return RSCMU_GetSensMeasStatVal (measurementStatus, tab, 5);
}

/*===========================================================================*/
/* Function: DBLER: Matching Tolerance
/* Purpose : This Function indicates whether and in which way the
/*           permissible error limits for the measured values of DBLER
/*           test have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Dbler_CalcLimMatc_352 (ViSession instrSession,
                                                       ViInt32   measurementType,
                                                       ViPInt32  total,
                                                       ViPInt32  ber,
                                                       ViPInt32  usfBler,
                                                       ViPInt32  dbler,
                                                       ViPInt32  CRCErrors,
                                                       ViPInt32  faleUsfDetection,
                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];
  ViString    StrRxqMeasType[] = {"BAV","BER"};

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_52, RSCMU_ERROR_FW_VERSION_3_52));

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) measurementType, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf,"CALCulate:RXQuality:%s:LIMit:MATChing?",StrRxqMeasType[measurementType]);

  CHECKRETMSG(RSCMU_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Get the measurement status
  if ((RSCMU_Status = RSCMU_GetSensMeasStatVal (total, TableOfDataValues, 0)) < 0)
  return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  // FAST for Class2 Bits
  RSCMU_Status = RSCMU_GetMatchingValue (ber,TableOfDataValues,1);

  // USF BLER
  RSCMU_Status = RSCMU_GetMatchingValue (usfBler,TableOfDataValues,2);

  // BLER
  RSCMU_Status = RSCMU_GetMatchingValue (dbler,TableOfDataValues,3);

  // Cyclic redundancy check
  RSCMU_Status = RSCMU_GetMatchingValue (CRCErrors,TableOfDataValues,4);

  // false USF detection
  RSCMU_Status = RSCMU_GetMatchingValue (faleUsfDetection,TableOfDataValues,5);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: AIBF: Matching Tolerances
/* Purpose : This Function indicates whether and in which way the
/*           permissibleerror limits for the measured values of the bit
/*           error rate test have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Aibf_CalcSensLimMatc (ViSession instrSession,
                                                      ViInt32 measurementType,
                                                      ViInt32 *total,
                                                      ViInt32 *frameErasureRate,
                                                      ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE] = "";
    ViChar      TableOfDataValues[100][100];
    ViString    StrRxqMeasType[] = {"BAV","BER"};
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    sprintf(wrtBuf,"CALC:RXQ:%s:LIM:MATC?", StrRxqMeasType[measurementType]);

    if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;

    // Split the multiple data values separated by a comma:
    RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

    // Get the measurement status
    if ((RSCMU_Status = RSCMU_GetSensMeasStatVal (total, TableOfDataValues, 0)) < 0)
        return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

    // Frame erasure rate
    RSCMU_Status = RSCMU_GetMatchingValue (frameErasureRate, TableOfDataValues, 1);

    return RSCMU_Status;
}

/*===========================================================================*/
/* Function: AIBF: measured values... with statistical results and RF Search
/* Purpose : The statistical result is available only if statistical BER testing
/*           is activated via CONFigure:RXQuality:BER<nr>:CONTrol:REPetition (see p. 6.156)
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Res_Aibf (ViSession instrSession,
                                          ViInt32   command,
                                          ViReal64  *progressTime,
                                          ViReal64  *frameErasureRate,
                                          ViInt32   *measurementStatus,
                                          ViInt32   *statisticalResult,
                                          ViInt32   *RFSearchLevel,
                                          ViReal64  *RFSearchLevelValue,
                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_40));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, command, RSCMU_COMMAND_READ, RSCMU_COMMAND_SAMP, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf(wrtBuf,"%s:SCALar:RXQuality:BER?", StrCommand[command]);

  CHECKRETMSG(RSCMU_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%lf", progressTime);
  else *progressTime = RSCMU_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%lf", frameErasureRate);
  else *frameErasureRate = RSCMU_NAN;

  // Get the statistical results
  if (strncmp ("RUN", tab[3], 3) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_RUN;
  else if (strncmp ("EFAI", tab[3], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_EFAIL;
  else if (strncmp ("EPAS", tab[3], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_EPASS;
  else if (strncmp ("FAIL", tab[3], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_FAIL;
  else if (strncmp ("PASS", tab[3], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_PASS;
  else if (strncmp ("THIG", tab[3], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_THIGH;
  else if (strncmp ("TLOW", tab[3], 4) == 0)
    *statisticalResult = RSCMU_CONF_STAT_RESULTS_TLOW;
  else *statisticalResult = RSCMU_NAN_VI_INT32;

 // RF Search Level - always NAN in the current firmware version (3.60)
 *RFSearchLevel = RSCMU_NAN_VI_INT32;

  // Get the measurement status
  return RSCMU_GetSensMeasStatVal (measurementStatus, tab, 2);
}

/*===========================================================================*/
/* Function: AIBF: fetch measured values...
/* Purpose : This function output the last measurement results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Aibf_FetcSens (ViSession instrSession,
                                               ViInt32   command,
                                               ViReal64  *progressTime,
                                               ViReal64  *frameErasureRate,
                                               ViInt32   *measurementStatus,
                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, command, RSCMU_COMMAND_FETC, RSCMU_COMMAND_SAMP, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf(wrtBuf,"%s:RXQ:BAV?", StrCommand[command]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the number of frames evaluated
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%lf", progressTime);
  else *progressTime = RSCMU_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%lf", frameErasureRate);
  else *frameErasureRate = RSCMU_NAN;
  // Get the number of Cyclic redundancy errors

  // Get the measurement status
  return RSCMU_GetSensMeasStatVal (measurementStatus, tab, 2);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function sets the number of statistics cycles, the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqRdContRep (ViSession instrSession,
                                                  ViInt32 Repetition,
                                                  ViInt32 StopCondition,
                                                  ViInt32 StepMode,
                                                  ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));
  
  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) Repetition, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:RXQ:RDS:CONT:REP %s,%s,%s", StrRepetition[Repetition], StrStopCondition[StopCondition], StrStepMode[StepMode]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. ( OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqRdsContDef (ViSession instrSession,
                                                   ViBoolean setDefaultValues,
                                                   ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:RXQ:RDS:CONT:DEF",
                         setDefaultValues, mode_On_Off,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Upper Limits
/* Purpose : This function defines an upper limit for the rate of repeated
/*           SACCH block requests measured by the CMU.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqRdsLimRsac (ViSession instrSession,
                                                   ViReal64 repeatedSACCHLimit,
                                                   ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setViReal64 (instrSession, "CONF:RXQ:RDS:LIM:RSAC",
                         repeatedSACCHLimit, 0.0, 100.0,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Used Timeslot
/* Purpose : This function defines the absolute level of the traffic channel 
/*           (TCH) in the used timeslot for the repeated DL SACCH application. 
/*           This level applies to the receiver quality measurement only.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqRdsContLevUtim (ViSession instrSession,
                                                       ViReal64 usedTimeslot,
                                                       ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setViReal64 (instrSession, "CONF:RXQ:RDS:CONT:LEV:UTIM",
                              usedTimeslot, -137.0, 13.0,
                              RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Unused Timeslot
/* Purpose : This function defines the relative level of the traffic channel 
/*           (TCH) in the unused timeslot for the repeated DL SACCH application. 
/*           This level applies to the receiver quality measurement only.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqRdsContLevUnt (ViSession instrSession,
                                                      ViReal64 unusedTimeslot,
                                                      ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setViReal64 (instrSession, "CONF:RXQ:RDS:CONT:LEV:UNT",
                         unusedTimeslot, -127.0, 127.0,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Invalid Result Detect Timeout
/* Purpose : This function sdefines the characteristics concerning
/*           repetitions of SACCH-messages. If it is disabled the SACCH
/*           messages are not resent. If it is enabled the SACCH message will
/*           be resent immediately to improve error correction. If the mode
/*           is set to SRR, the messages will be repeated only on request of
/*           the mobile.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqRdsContRds (ViSession instrSession,
                                                   ViInt32 repeatedDownlinkSACCH,
                                                   ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:RXQ:RDS:CONT:RDS", repeatedDownlinkSACCH, repeatedDownlinkSACCHArr,
                       RSCMU_ERROR_PARAMETER2));
}

    
/*===========================================================================*/
/* Function: Multislot Reference Level
/* Purpose : This function defines the reference value for the individual
/*           downlink (BS) TCH signal levels used for the multislot RP DL
/*           SACCH test on circuit switched channels.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqRdsContMslRlev (ViSession instrSession,
                                                       ViReal64 referenceLevel,
                                                       ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setViReal64 (instrSession, "CONF:RXQ:RDS:CONT:MSL:RLEV",
                         referenceLevel, -137.0, -24.0,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Individual Slot Reference Level
/* Purpose : This function defines the levels in all 8 timeslots of the
/*           downlink (BS) TCH signal relative to the Reference Level set via
/*           CONFigure:RXQuality:RDSacch:CONTrol[:CSWitched][:TCH]:MSLot:RLE
/*           Vel.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqRdsContMslLevInd (ViSession instrSession,
                                                         ViReal64 referenceLevel[],
                                                         ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
    ViChar*     p2buf;
    ViInt32     i = 0;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));
    
    CHECK_VI_REAL64_RANGE (instrSession, referenceLevel[0], -127.0, 127.0, RSCMU_ERROR_PARAMETER2, errorMessage);

    p2buf = wrtBuf + sprintf (wrtBuf, "CONF:RXQ:RDS:CONT:MSL:LEV:IND %f", referenceLevel[0]);
    for (i = 1; i < 8; i++)
    {
        CHECK_VI_REAL64_RANGE (instrSession, referenceLevel[i], -127.0, 127.0, RSCMU_ERROR_PARAMETER2, errorMessage);
        p2buf += sprintf (p2buf, ",%f", referenceLevel[i]);
    }

    RETMSG(RSCMU_sendCmd (instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Init
/* Purpose : This function start a new receiver quality statistics overview
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_InitRxqRds (ViSession instrSession,
                                            ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_sendCmd (instrSession, "INIT:RXQ:RDS"));
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : This function aborts running receiver quality statistics
/*           overview measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborRxqRds (ViSession instrSession,
                                            ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_sendCmd (instrSession, "ABOR:RXQ:RDS"));
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : This function stops running receiver quality statistics
/*           overview measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopRxqRds (ViSession instrSession,
                                            ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_sendCmd (instrSession, "STOP:RXQ:RDS"));
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : This function runs next receiver quality statistics overview
/*           measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContRxqRds (ViSession instrSession,
                                            ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_sendCmd (instrSession, "CONT:RXQ:RDS"));
}

/*===========================================================================*/
/* Function: Set Event Reporting Mode
/* Purpose : This function defines the events generated when the measurement
/*           is terminated or stopped
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqRdsErep (ViSession instrSession,
                                                ViInt32 Mode,
                                                ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
    ViString    StrMode[] = {"OFF","SRQ","SOPC","SRSQ"};

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf (wrtBuf, "CONF:RXQ:RDS:EREP %s", StrMode[Mode]);
    if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;

    return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Fetch Status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcRxqRdsStat (ViSession instrSession,
                                                ViInt32 *MeasurementStatus,
                                                ViInt32 *CountingNo,
                                                ViInt32 *StatisticNo,
                                                ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      Tab[100][100];

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));
  if ((RSCMU_Status = RSCMU_Query (instrSession, "FETC:RXQ:RDS:STAT?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", Tab);

  // Gets the status of the measurement:
  if ((RSCMU_Status = RSCMU_GetMeasStatVal (MeasurementStatus, Tab, 0)) < 0)
    return RSCMU_Status;

  // Gets the current value of the statistics counter (the number of the current statistics cycle):
  if ((RSCMU_Status = RSCMU_GetCountingNo (CountingNo, Tab, 1)) < 0)
    return RSCMU_Status;

  // Gets the current evaluation period within a statistics cycle:
  if ((RSCMU_Status = RSCMU_GetStatisticNo (StatisticNo, Tab, 2)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

ViStatus _VI_FUNC RSCMU_ScanRxqRds (ViChar response[],
                                    ViReal64 *repeatedSACCH,
                                    ViReal64 *repeatedSACCHPct,
                                    ViReal64 *SACCHSent, ViInt32 *status)
{
    ViChar  *p2buf;
    
    if (repeatedSACCH == NULL)
        return RSCMU_ERROR_PARAMETER2;
    if (repeatedSACCHPct == NULL)
        return RSCMU_ERROR_PARAMETER3;
    if (SACCHSent == NULL)
        return RSCMU_ERROR_PARAMETER4;
    if (status == NULL)
        return RSCMU_ERROR_PARAMETER5;

    p2buf = strtok (response, ",");
    *repeatedSACCH = RSCMU_atof (p2buf);
    
    p2buf = strtok (NULL,",");
    *repeatedSACCHPct = RSCMU_atof (p2buf);
    
    p2buf = strtok (NULL,",");
    *SACCHSent = RSCMU_atof (p2buf);
    
    p2buf = strtok (NULL,",");
    return RSCMU_getIndexFromString (NULL, p2buf, rxqRdsStatusArr, status);
}

/*===========================================================================*/
/* Function: Read
/* Purpose : This function starts a DL SACCH block-error-rate test in the
/*           single shot repetition mode and output the measurement results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadRxqRds (ViSession instrSession,
                                            ViReal64 *repeatedSACCH,
                                            ViReal64 *repeatedSACCHPct,
                                            ViReal64 *SACCHSent, ViInt32 *status,
                                            ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    CHECKRETMSG(RSCMU_getViString (instrSession,
                              "READ:RXQ:RDS?",
                              rdBuf,
                              RD_BUFFER_SIZE,
                              RSCMU_ERROR_PARAMETER1));
    RETMSG (RSCMU_ScanRxqRds (rdBuf, repeatedSACCH, repeatedSACCHPct, SACCHSent, status));
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This function reads out unsynchronized DL SACCH block-error-rate
/*           test in the single shot repetition mode and output the
/*           measurement results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcRxqRds (ViSession instrSession,
                                            ViReal64 *repeatedSACCH,
                                            ViReal64 *repeatedSACCHPct,
                                            ViReal64 *SACCHSent, ViInt32 *status,
                                            ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    CHECKRETMSG(RSCMU_getViString (instrSession,
                              "FETC:RXQ:RDS?",
                              rdBuf,
                              RD_BUFFER_SIZE,
                              RSCMU_ERROR_PARAMETER1));
    RETMSG (RSCMU_ScanRxqRds (rdBuf, repeatedSACCH, repeatedSACCHPct, SACCHSent, status));
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This function reads out synchronized DL SACCH block-error-rate
/*           test in the single shot repetition mode and output the
/*           measurement results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampRxqRds (ViSession instrSession,
                                            ViReal64 *repeatedSACCH,
                                            ViReal64 *repeatedSACCHPct,
                                            ViReal64 *SACCHSent, ViInt32 *status,
                                            ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    CHECKRETMSG(RSCMU_getViString (instrSession,
                              "SAMP:RXQ:RDS?",
                              rdBuf,
                              RD_BUFFER_SIZE,
                              RSCMU_ERROR_PARAMETER1));
    RETMSG (RSCMU_ScanRxqRds (rdBuf, repeatedSACCH, repeatedSACCHPct, SACCHSent, status));
}

/*===========================================================================*/
/* Function: Check Limits
/* Purpose : This function indicates whether and in which way the tolerances
/*           for the RP RL SACCH test have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_CalcRxqRdsLimMatc (ViSession instrSession,
                                                    ViInt32 *totalStatus,
                                                    ViInt32 *repeatedSACCH,
                                                    ViInt32 *repeatedSACCHPct,
                                                    ViInt32 *SACCHSent,
                                                    ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE] = "";
    ViChar      TableOfDataValues[100][100];

    if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V4_20, RSCMU_ERROR_FW_VERSION_4_20, errorMessage)) < 0)
        return RSCMU_Status;

    if ((RSCMU_Status = RSCMU_Query (instrSession, "CALC:RXQ:RDS:LIM:MATC?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;

    // Split the multiple data values separated by a comma:
    RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

    // Average Burst Power (Current Burst)
    CHECKRETMSG (RSCMU_getIndexFromString (instrSession, TableOfDataValues[0],rxqRdsStatusArr, totalStatus));  

    CHECKRETMSG (RSCMU_GetMatchingValue (repeatedSACCH,TableOfDataValues,1));

    CHECKRETMSG (RSCMU_GetMatchingValue (repeatedSACCHPct,TableOfDataValues,2));

    CHECKRETMSG (RSCMU_GetMatchingValue (SACCHSent,TableOfDataValues,3));

    return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function sets the number of statistics cycles, the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqFfacContRep (ViSession instrSession,
                                                    ViInt32 Repetition,
                                                    ViInt32 StopCondition,
                                                    ViInt32 StepMode,
                                                    ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));
  
  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) Repetition, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Configure  tests cycles:
  sprintf (wrtBuf, "CONF:RXQ:FFAC:CONT:REP %s,%s,%s", StrRepetition[Repetition], StrStopCondition[StopCondition], StrStepMode[StepMode]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. ( OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqFfacContDef (ViSession instrSession,
                                                    ViBoolean setDefaultValues,
                                                    ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:RXQ:FFAC:CONT:DEF",
                         setDefaultValues, mode_On_Off,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Upper Limit
/* Purpose : This function defines an upper limit for the frame error rate of 
/*           repeated FACCH block requests measured by the CMU.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqFfacLimFer (ViSession instrSession,
                                                   ViReal64 repeatedFFACCHLimit,
                                                   ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setViReal64 (instrSession, "CONF:RXQ:FFAC:LIM:FER",
                         repeatedFFACCHLimit, 0.0, 100.0,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Used Timeslot
/* Purpose : This function defines the absolute level of the traffic channel 
/*           (TCH) in the used timeslot for the repeated DL FER/FACCH application. 
/*           This level applies to the receiver quality measurement only.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqFfacContLevUtim (ViSession instrSession,
                                                        ViReal64 usedTimeslot,
                                                        ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setViReal64 (instrSession, "CONF:RXQ:FFAC:CONT:LEV:UTIM",
                              usedTimeslot, -137.0, 13.0,
                              RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Unused Timeslot
/* Purpose : This function defines the relative level of the traffic channel 
/*          (TCH) in the unused timeslot for the repeated DL FER/FACCH 
/*           application. This level applies to the receiver quality measurement only.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqFfacContLevUnt (ViSession instrSession,
                                                       ViReal64 unusedTimeslot,
                                                       ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setViReal64 (instrSession, "CONF:RXQ:FFAC:CONT:LEV:UNT",
                         unusedTimeslot, -127.0, 127.0,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Multislot Reference Level
/* Purpose : This function defines the reference value for the individual
/*           downlink (BS) TCH signal levels used for the multislot RP DL
/*           FER/FACCH test on circuit switched channels.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqFfacContMslRlev (ViSession instrSession,
                                                        ViReal64 referenceLevel,
                                                        ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setViReal64 (instrSession, "CONF:RXQ:FFAC:CONT:MSL:RLEV",
                         referenceLevel, -137.0, -24.0,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Individual Slot Reference Level
/* Purpose : This function defines the levels in all 8 timeslots of the
/*           downlink (BS) TCH signal relative to the Reference Level set via
/*           CONFigure:RXQuality:FFACch:CONTrol[:CSWitched][:TCH]:MSLot:RLE
/*           Vel.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqFfaContMslLevInd (ViSession instrSession,
                                                         ViReal64 referenceLevel[],
                                                         ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
    ViChar*     p2buf;
    ViInt32     i = 0;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));
    
    CHECK_VI_REAL64_RANGE (instrSession, referenceLevel[0], -127.0, 127.0, RSCMU_ERROR_PARAMETER2, errorMessage);

    p2buf = wrtBuf + sprintf (wrtBuf, "CONF:RXQ:FFAC:CONT:MSL:LEV:IND %f", referenceLevel[0]);
    for (i = 1; i < 8; i++)
    {
        CHECK_VI_REAL64_RANGE (instrSession, referenceLevel[i], -127.0, 127.0, RSCMU_ERROR_PARAMETER2, errorMessage);
        p2buf += sprintf (p2buf, ",%f", referenceLevel[i]);
    }

    RETMSG(RSCMU_sendCmd (instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Init
/* Purpose : This function start a new receiver quality statistics overview
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_InitRxqFfac (ViSession instrSession,
                                             ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_sendCmd (instrSession, "INIT:RXQ:FFAC"));
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : This function aborts running receiver quality statistics
/*           overview measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborRxqFfac (ViSession instrSession,
                                             ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_sendCmd (instrSession, "ABOR:RXQ:FFAC"));
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : This function stops running receiver quality statistics
/*           overview measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopRxqFfac (ViSession instrSession,
                                             ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_sendCmd (instrSession, "STOP:RXQ:FFAC"));
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : This function runs next receiver quality statistics overview
/*           measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContRxqFfac (ViSession instrSession,
                                             ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_sendCmd (instrSession, "CONT:RXQ:FFAC"));
}

/*===========================================================================*/
/* Function: Set Event Reporting Mode
/* Purpose : This function defines the events generated when the measurement
/*           is terminated or stopped
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqFfacErep (ViSession instrSession,
                                                 ViInt32 Mode,
                                                 ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
    ViString    StrMode[] = {"OFF","SRQ","SOPC","SRSQ"};

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf (wrtBuf, "CONF:RXQ:FFAC:EREP %s", StrMode[Mode]);
    if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;

    return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Fetch Status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcRxqFfacStat (ViSession instrSession,
                                                 ViInt32 *MeasurementStatus,
                                                 ViInt32 *CountingNo,
                                                 ViInt32 *StatisticNo,
                                                 ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      Tab[100][100];

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));
  if ((RSCMU_Status = RSCMU_Query (instrSession, "FETC:RXQ:FFAC:STAT?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", Tab);

  // Gets the status of the measurement:
  if ((RSCMU_Status = RSCMU_GetMeasStatVal (MeasurementStatus, Tab, 0)) < 0)
    return RSCMU_Status;

  // Gets the current value of the statistics counter (the number of the current statistics cycle):
  if ((RSCMU_Status = RSCMU_GetCountingNo (CountingNo, Tab, 1)) < 0)
    return RSCMU_Status;

  // Gets the current evaluation period within a statistics cycle:
  if ((RSCMU_Status = RSCMU_GetStatisticNo (StatisticNo, Tab, 2)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

ViStatus _VI_FUNC RSCMU_ScanRxqFfac (ViChar response[],
                                    ViReal64 *l2FramesRepeated,
                                    ViReal64 *FER,
                                    ViReal64 *framesSent, ViInt32 *status)
{
    ViChar  *p2buf;
    
    if (l2FramesRepeated == NULL)
        return RSCMU_ERROR_PARAMETER2;
    if (FER == NULL)
        return RSCMU_ERROR_PARAMETER3;
    if (framesSent == NULL)
        return RSCMU_ERROR_PARAMETER4;
    if (status == NULL)
        return RSCMU_ERROR_PARAMETER5;

    p2buf = strtok (response, ",");
    *l2FramesRepeated = RSCMU_atof (p2buf);
    
    p2buf = strtok (NULL,",");
    *FER = RSCMU_atof (p2buf);
    
    p2buf = strtok (NULL,",");
    *framesSent = RSCMU_atof (p2buf);
    
    p2buf = strtok (NULL,",");
    return RSCMU_getIndexFromString (NULL, p2buf, rxqRdsStatusArr, status);
}

/*===========================================================================*/
/* Function: Read
/* Purpose : This function starts a DL FACCH frame-error-rate test in the
/*           single shot repetition mode and output the measurement results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadRxqFfac (ViSession instrSession,
                                             ViReal64 *l2FramesRepeated,
                                             ViReal64 *FER, ViReal64 *framesSent,
                                             ViInt32 *status,
                                             ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    CHECKRETMSG(RSCMU_getViString (instrSession,
                              "READ:RXQ:FFAC?",
                              rdBuf,
                              RD_BUFFER_SIZE,
                              RSCMU_ERROR_PARAMETER1));
    RETMSG (RSCMU_ScanRxqFfac (rdBuf, l2FramesRepeated, FER, framesSent, status));
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This function reads out unsynchronized DL FACCH frame-error-rate
/*           test in the single shot repetition mode and output the
/*           measurement results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcRxqFfac (ViSession instrSession,
                                             ViReal64 *l2FramesRepeated,
                                             ViReal64 *FER, ViReal64 *framesSent,
                                             ViInt32 *status,
                                             ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    CHECKRETMSG(RSCMU_getViString (instrSession,
                              "FETC:RXQ:FFAC?",
                              rdBuf,
                              RD_BUFFER_SIZE,
                              RSCMU_ERROR_PARAMETER1));
    RETMSG (RSCMU_ScanRxqFfac (rdBuf, l2FramesRepeated, FER, framesSent, status));
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This function reads out synchronized DL FACCH frame-error-rate
/*           test in the single shot repetition mode and output the
/*           measurement results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampRxqFfac (ViSession instrSession,
                                             ViReal64 *l2FramesRepeated,
                                             ViReal64 *FER, ViReal64 *framesSent,
                                             ViInt32 *status,
                                             ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    CHECKRETMSG(RSCMU_getViString (instrSession,
                              "SAMP:RXQ:FFAC?",
                              rdBuf,
                              RD_BUFFER_SIZE,
                              RSCMU_ERROR_PARAMETER1));
    RETMSG (RSCMU_ScanRxqFfac (rdBuf, l2FramesRepeated, FER, framesSent, status));
}

/*
 * ----------------------------------------------------------------------------
 * Symbolic Status Event Register Evaluation
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Event Reporting Enable
/* Purpose : This function enables event reporting for the current GSMxxx-MS
/*           Signalling function group, i.e. it sets the corresponding
/*           bits in the STATus:OPERation:CMU:SUM<nr>:CMU<nr_event>:ENABle
/*           register (<nr>=1 | 2, <nr_event> denotes the current function
/*           group) and in all sum registers up to the status byte. The
/*           events and the corresponding symbols for the function group are
/*           listed in Chapter 5 (see section Status Registers).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_StatOperSymbEnab (ViSession instrSession,
                                                                         ViInt32   Cfm,
                                                                         ViInt32   Rfm,
                                                                         ViInt32   Slos,
                                                                         ViInt32   Lupd,
                                                                         ViInt32   Rfns,
                                                                         ViInt32   Idet,
                                                                         ViInt32   Smsr,
                                                                         ViInt32   Mrep,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) Cfm,  RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) Rfm,  RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) Slos, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) Lupd, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) Rfns, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) Idet, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) Smsr, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) Mrep, RSCMU_ERROR_PARAMETER9, errorMessage);

  strcpy(wrtBuf, "STAT:OPER:SYMB:ENAB ");

  if(Cfm)
    strcat(wrtBuf,"CFM,");
  if(Rfm)
    strcat(wrtBuf,"RFM,");
  if(Slos)
    strcat(wrtBuf,"SLOS,");
  if(Lupd)
    strcat(wrtBuf,"LUPD,");
  if(Rfns)
    strcat(wrtBuf,"RFNS,");
  if(Idet)
    strcat(wrtBuf,"IDET,");
  if(Smsr)
    strcat(wrtBuf,"SMSR,");
  if(Mrep)
    strcat(wrtBuf,"MREP,");

  if(strcmp (wrtBuf, "STAT:OPER:SYMB:ENAB ") == 0)
    strcat(wrtBuf,"NONE");
  else
    wrtBuf[strlen(wrtBuf) - 1] = 0;

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: List Of Reported Events
/* Purpose : This function lists the events reported in the current GSMxxx-MS
/*           Signalling function group and deletes these events in the
/*           STATus:OPERation:CMU:SUM<nr>:CMU<nr_event>:EVENt register as
/*           well as in all sum registers.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_StatOperSymb (ViSession instrSession,
                                                                     ViInt32   Events[],
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViInt32     Index = 0;
  ViChar      tab[100][100];

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  if ((RSCMU_Status = RSCMU_Query (instrSession, "STAT:OPER:SYMB?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  while(!strcmp (tab[Index], ""))
  {
    if (strncmp ("CFM", tab[Index], 3) == 0)
      Events[Index] = RSCMU_EVENT_CFM;
    else if (strncmp ("RFM", tab[Index], 3) == 0)
      Events[Index] = RSCMU_EVENT_RFM;
    else if (strncmp ("SLOS", tab[Index], 4) == 0)
      Events[Index] = RSCMU_EVENT_SLOS;
    else if (strncmp ("LUPD", tab[Index], 4) == 0)
      Events[Index] = RSCMU_EVENT_LUPD;
    else if (strncmp ("RFNS", tab[Index], 4) == 0)
      Events[Index] = RSCMU_EVENT_RFNS;
    else if (strncmp ("IDET", tab[Index], 4) == 0)
      Events[Index] = RSCMU_EVENT_IDET;
    else if (strncmp ("SMSR", tab[Index], 4) == 0)
      Events[Index] = RSCMU_EVENT_SMSR;
    else if (strncmp ("MREP", tab[Index], 4) == 0)
      Events[Index] = RSCMU_EVENT_MREP;
    else if (strncmp ("NONE", tab[Index], 4) == 0)
      Events[Index] = RSCMU_NONE;
    else
      Events[Index] = RSCMU_NONE;

    Index++;
  }

  return RSCMU_Status;
}

/*
 * ----------------------------------------------------------------------------
 * Close
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Close
/* Purpose : This function close the Basic Unit session and release the
/*           resources
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_Close_GSM_Sig (ViSession instrSession, ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  struct RSCMU_GSMSig_Globals *p_globalvarGSM;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarGSM)) < 0)
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  // Deallocate all system resources allocated to the GSMSig Session:
  if ((RSCMU_Status = viClose (instrSession)) < 0)
    return RSCMU_Status;

  // Deallocate the space pointed by p_globalvarGSM:
  if (p_globalvarGSM)
    free (p_globalvarGSM);

  return RSCMU_Status;
}


/*****************************************************************************/
/*****************************************************************************/
/*========== CLASS: APPLICATIONS FUNCTIONS===================================*/
/*****************************************************************************/
/*****************************************************************************/

/*****************************************************************************/
/*= GSM NON SIGNALLING ======================================================*/
/*****************************************************************************/
/*=========================================================================*/
/* Function: RSCMU_GSM_NSig_AborMeas
/* Purpose : Abort All Measurements and release resources for a GSM_NSig
/*           Session: * Abort Power measurement       ABORt:POWer
/*               * Abort Modulation Measurement  ABORt:MODulation
/*               * Abort Spectrum measurements   ABORt:SPECtrum:SWITching
/*                                               ABORt:SPECtrum:MODulation
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborMeas (ViSession instrSession,
                                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  if ((RSCMU_Status = RSCMU_GSM_NSig_AborPow (instrSession,  errorMessage)) < 0)
    return RSCMU_Status;
  if ((RSCMU_Status = RSCMU_GSM_NSig_AborMod (instrSession, errorMessage)) < 0)
    return RSCMU_Status;
  if ((RSCMU_Status = RSCMU_GSM_NSig_AborSpecSwit (instrSession, errorMessage)) < 0)
    return RSCMU_Status;
  if ((RSCMU_Status = RSCMU_GSM_NSig_AborSpecMod (instrSession, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*****************************************************************************/
/*= GSM SIGNALLING ==========================================================*/
/*****************************************************************************/
/*=========================================================================*/
/* Function: RSCMU_GSM_Sig_ConfNetwIden
/* Purpose : This function defines the identity for the mobile radio network.
/*           It corresponds to the table field 'Network identity' in the
/*           popup menu 'Network'.
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwIden (ViSession  instrSession,
                                                                     ViInt32    NetworkColorCode,
                                                                     ViInt32    MobileCountryCode,
                                                                     ViInt32    MobileNetworkCode,
                                                                     ViInt32    BTSColorCode,
                                                                     ViInt32    LocationAreaCode,
                                                                     ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  if ((RSCMU_Status = RSCMU_GSM_Sig_ConfNetwIdenNcc (instrSession, NetworkColorCode, errorMessage)) < 0)
    return RSCMU_Status;
  if ((RSCMU_Status = RSCMU_GSM_Sig_ConfNetwIdenMcc (instrSession, MobileCountryCode, errorMessage)) < 0)
    return RSCMU_Status;
  if ((RSCMU_Status = RSCMU_GSM_Sig_ConfNetwIdenMnc (instrSession, MobileNetworkCode, errorMessage)) < 0)
    return RSCMU_Status;
  if ((RSCMU_Status = RSCMU_GSM_Sig_ConfNetwIdenBcc (instrSession, BTSColorCode, errorMessage)) < 0)
    return RSCMU_Status;
  if ((RSCMU_Status = RSCMU_GSM_Sig_ConfNetwIdenLac (instrSession, LocationAreaCode, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*=========================================================================*/
/* Function: RSCMU_GSM_Sig_ConfNetwReq
/* Purpose : This Function defines the mobile signalling parameters to be
/*           requested (IMSI, IMEI, Authentification, Handover).
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwReq (ViSession  instrSession,
                                                                    ViInt32    IMSIRequest,
                                                                    ViInt32    IMEIRequest,
                                                                    ViInt32    AuthentificationRequest,
                                                                    ViInt32    HandoverRequest,
                                                                    ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  if ((RSCMU_Status = RSCMU_GSM_Sig_ConfNetwReqImsi(instrSession, IMSIRequest, errorMessage)) < 0)
    return RSCMU_Status;
  if ((RSCMU_Status = RSCMU_GSM_Sig_ConfNetwReqImei(instrSession, IMEIRequest, errorMessage)) < 0)
    return RSCMU_Status;
  if ((RSCMU_Status = RSCMU_GSM_Sig_ConfNetwReqAuth(instrSession, AuthentificationRequest, errorMessage)) < 0)
    return RSCMU_Status;
  if ((RSCMU_Status = RSCMU_GSM_Sig_ConfNetwReqHand(instrSession, HandoverRequest, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*=========================================================================*/
/* Function: RSCMU_GSM_Sig_ConfNetwTim
/* Purpose : This function defines timeouts for aborting an unused radio link
             status = RSCMU_ErrorQuery (BASEsession, &errorCode, errorM);
/*           or an unsuccessfull call to the mobile.
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwTim (ViSession instrSession,
                                                                    ViInt32   RadioLinkTimeout,
                                                                    ViInt32   TestSetTimeout,
                                                                    ViInt32   TimeTestSetONOFF,
                                                                    ViInt32   MtcTimeOut,
                                                                    ViInt32   TimeOutMtcONOFF,
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  if ((RSCMU_Status = RSCMU_GSM_Sig_ConfNetwTimRlin(instrSession, RadioLinkTimeout, errorMessage)) < 0)
    return RSCMU_Status;
  if ((RSCMU_Status = RSCMU_GSM_Sig_ConfNetwTimRlinTest(instrSession, TimeTestSetONOFF, TestSetTimeout, errorMessage)) < 0)
    return RSCMU_Status;
  if ((RSCMU_Status = RSCMU_GSM_Sig_ConfNetwTimMtc (instrSession, TimeOutMtcONOFF, MtcTimeOut, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}
/*=========================================================================*/
/* Function: RSCMU_GSM_Sig_AborMeas
/* Purpose : Abort All Measurements and release resources for a GSM_Sig
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborMeas (ViSession instrSession,
                                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Abort all measurements for the source session.
  if ((RSCMU_Status = RSCMU_GSM_Sig_AborSpow (instrSession, errorMessage)) < 0)
    return RSCMU_Status;
  if ((RSCMU_Status = RSCMU_GSM_Sig_AborPow (instrSession, errorMessage)) < 0)
    return RSCMU_Status;
  if ((RSCMU_Status = RSCMU_GSM_Sig_AborMod (instrSession,  errorMessage)) < 0)
    return RSCMU_Status;
  if ((RSCMU_Status = RSCMU_GSM_Sig_AborSens (instrSession, RSCMU_SINGLE_SHOT, errorMessage)) < 0)
    return RSCMU_Status;
  if ((RSCMU_Status = RSCMU_GSM_Sig_AborSpecSwit (instrSession, errorMessage)) < 0)
    return RSCMU_Status;
  if ((RSCMU_Status = RSCMU_GSM_Sig_AborSpecMod (instrSession, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*=========================================================================*/
/* Function: RSCMU_GSM_Sig_WaitForMsSync
/* Purpose : Waiting for mobile station synchronisation.
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_WaitForMsSync (ViSession  instrSession,
                                                                      ViInt32    Timeout,
                                                                      ViChar     errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;
  ViInt32   SignState;
  clock_t   StartTime = clock () / CLOCKS_PER_SEC;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Timeout, 0, 59, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Wait for synchronisation state:
  do
  {
    if ((clock () / CLOCKS_PER_SEC) > (StartTime + Timeout))
      return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_TIMEOUT, errorMessage);

    RSCMU_Delay (0.15);

    if ((RSCMU_Status = RSCMU_GSM_Sig_SensSignStat (instrSession, &SignState, errorMessage)) < 0)
      return RSCMU_Status;
  } while (SignState != RSCMU_STATE_SYNC);

  return RSCMU_Status;
}


/*=========================================================================*/
/* Function: RSCMU_GSM_Sig_CallFromMobile
/* Purpose : This function establishes a call to the mobile station. As soon
/*           the mobile is picked up the CMU changes to the signalling
/*           state Call Established.
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_CallFromMobile (ViSession  instrSession,
                                                                       ViInt32    Timeout,
                                                                       ViChar     errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;
  ViInt32   SignState;
  clock_t   StartTime = clock () / CLOCKS_PER_SEC;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Timeout, 0, 59, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Be sured that RSCMU is in SON or in SYNC
  if ((RSCMU_Status = RSCMU_GSM_Sig_SensSignStat (instrSession, &SignState, errorMessage)) < 0)
    return RSCMU_Status;
  if ((SignState != RSCMU_STATE_SON) && (SignState != RSCMU_STATE_SYNC))
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);

  // Ask if CMU in CEST
  do
  {
    if ((clock () / CLOCKS_PER_SEC) > (StartTime + Timeout))
      return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_CALL_FROM_MS_FAILED, errorMessage);

    if ((RSCMU_Status = RSCMU_GSM_Sig_SensSignStat (instrSession, &SignState, errorMessage)) < 0)
      return RSCMU_Status;
    RSCMU_Delay (0.1);
  } while (SignState != RSCMU_STATE_CEST);

  return RSCMU_Status;
}

/*=========================================================================*/
/* Function: RSCMU_GSM_Sig_CallToMobile
/* Purpose : This function executes a call to the mobile connected to the CMU
/*           It can be called if the CMU is in SON or in SYNC.
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_CallToMobile (ViSession  instrSession,
                                                                     ViChar     errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;
  ViInt32   SignState;
  struct RSCMU_GSM_Sig_Globals *p_globalvarGSM;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarGSM)) < 0)
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  // Call to Mobile Station:
  if ((RSCMU_Status = RSCMU_GSM_Sig_ProcSignAct (instrSession, RSCMU_MTC, errorMessage)) < 0)
    return RSCMU_Status;

  // Check the signalling state:
  if ((RSCMU_Status = RSCMU_GSM_Sig_SensSignStat (instrSession, &SignState, errorMessage)) < 0)
    return RSCMU_Status;

  // Version Manager
  if (p_globalvarGSM->RSCMU_tGlobal.RSCMU_FW_Version >= RSCMU200_V2_11)
  {
    if (p_globalvarGSM->RSCMU_SigChannelConf != RSCMU_NONE)
    {
          if (SignState != RSCMU_STATE_ALER)
            return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_CALL_TO_MS_FAILED, errorMessage);
        }

      do
      {
        if ((RSCMU_Status = RSCMU_GSM_Sig_SensSignStat (instrSession, &SignState, errorMessage)) < 0)
          return RSCMU_Status;
      if ((SignState != RSCMU_STATE_ALER) && (SignState != RSCMU_STATE_CEST))
            return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_CALL_TO_MS_FAILED, errorMessage);
        RSCMU_Delay (0.1);
      }
      while (SignState != RSCMU_STATE_CEST);
    }
    else
    {
      if (SignState != RSCMU_STATE_CEST)
        return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_CALL_TO_MS_FAILED, errorMessage);
    }

  return RSCMU_Status;
}

/*=========================================================================*/
/* Function: RSCMU_GSM_Sig_ReleaseCallFromCMU
/* Purpose : Release the call by RSCMU.
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReleaseCallFromCMU (ViSession instrSession,
                                                    ViChar    errorMessage[])
{
  ViChar      rdBuf[RD_BUFFER_SIZE]="";
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViInt32     state;

  if ((RSCMU_Status = RSCMU_GSM_Sig_SensSignStat (instrSession, &state, errorMessage)) < 0)
    return RSCMU_Status;
      // Be sured that CMU is in CEST | CED | ALER | CPEN.
  if ((state != RSCMU_STATE_CEST) && (state != RSCMU_STATE_CED) && (state != RSCMU_STATE_ALER) && (state != RSCMU_STATE_CPEN))
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
  // Release the call
  if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:ACT CREL", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  if (state == RSCMU_STATE_CED)
  {
    if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:ACT SOFF", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
      return RSCMU_Status;
  }
  return RSCMU_Status;
}

/*=========================================================================*/
/* Function: GSM_Sig_WaitForMsAttached
/* Purpose : Waiting for mobile station Attached.
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_WaitForMsAttached (ViSession  instrSession,
                                                                            ViInt32    Timeout,
                                                                            ViChar     errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;
  ViInt32   SignState;
  clock_t   StartTime = clock () / CLOCKS_PER_SEC;
  struct        RSCMU_GSM_Sig_Globals *p_globalvarGSM;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Timeout, 0, 59, RSCMU_ERROR_PARAMETER2, errorMessage);

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarGSM)) < 0)
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  if (p_globalvarGSM->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_01)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_01, errorMessage);

  // Wait for Attached state:
  do
  {
    if ((clock () / CLOCKS_PER_SEC) > (StartTime + Timeout))
      return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_TIMEOUT, errorMessage);
    RSCMU_Delay (0.15);
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensPdatStat (instrSession, &SignState, errorMessage))<0)
        return RSCMU_Status;
//      if ((l_vSignallingState != RSCMU_GPRS_STATE_AIPR) &&
//              (l_vSignallingState != RSCMU_GPRS_STATE_ATT) &&
//              (l_vSignallingState != RSCMU_GPRS_STATE_IDLE))
  } while (SignState != RSCMU_GPRS_STATE_ATT);

  return RSCMU_Status;
}

/*=========================================================================*/
/* Function: RSCMU_GSM_Sig_ConnectToMobile
/* Purpose : This function executes a TBF Established to the mobile connected to the CMU
/*           It can be called if the CMU is in SON or in ATT.
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConnectToMobile (    ViSession  instrSession,
                                                                            ViInt32    TestMode,
                                                                            ViChar     errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;
  ViInt32   SignState;
  struct RSCMU_GSM_Sig_Globals *p_globalvarGSM;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarGSM)) < 0)
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  if (p_globalvarGSM->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);


  // Check if the function is correctly used:
  if (p_globalvarGSM->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_10)
  {
    CHECK_VI_INT32_RANGE(instrSession, TestMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else
    if ((p_globalvarGSM->RSCMU_tGlobal.RSCMU_FW_Version >= RSCMU200_V3_10) && (p_globalvarGSM->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_50))
    {
    CHECK_VI_INT32_RANGE(instrSession, TestMode, RSCMU_GPRS_SERV_TMA, RSCMU_GPRS_SERV_BLER, RSCMU_ERROR_PARAMETER2, errorMessage);
    }
    else
    {
      CHECK_VI_INT32_RANGE(instrSession, TestMode, RSCMU_GPRS_SERV_TMA, RSCMU_GPRS_SERV_LBA, RSCMU_ERROR_PARAMETER2, errorMessage);
    }

    switch (TestMode) {
        case RSCMU_GPRS_SERV_TMA:
        // Connect Test Mode A
          if ((RSCMU_Status = RSCMU_GSM_Sig_ProcSignPdatAct (instrSession, RSCMU_GPRS_CONT_CTMA, errorMessage)) < 0)
            return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);
        break;
        case RSCMU_GPRS_SERV_TMB:
        // Connect Test Mode B
          if ((RSCMU_Status = RSCMU_GSM_Sig_ProcSignPdatAct (instrSession, RSCMU_GPRS_CONT_CTMB, errorMessage)) < 0)
            return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);
        break;
        case RSCMU_GPRS_SERV_RSIG:
        // Connect Test Mode Reduced Signalling Mode B
          if ((RSCMU_Status = RSCMU_GSM_Sig_ProcSignPdatAct (instrSession, RSCMU_GPRS_CONT_CRS, errorMessage)) < 0)
            return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);
        break;
        // >= V3.10
        case RSCMU_GPRS_SERV_RSA:
        // Connect Test Mode Reduced Signalling Mode A
          if ((RSCMU_Status = RSCMU_GSM_Sig_ProcSignPdatAct (instrSession, RSCMU_GPRS_CONT_CRA, errorMessage)) < 0)
            return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);
        break;
        case RSCMU_GPRS_SERV_DLON:
        // Connect Downlink only
          if ((RSCMU_Status = RSCMU_GSM_Sig_ProcSignPdatAct (instrSession, RSCMU_GPRS_CONT_CDL, errorMessage)) < 0)
            return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);
        break;
        case RSCMU_GPRS_SERV_BLER:
        // Connect Block Error Rate
          if ((RSCMU_Status = RSCMU_GSM_Sig_ProcSignPdatAct (instrSession, RSCMU_GPRS_CONT_CBL, errorMessage)) < 0)
            return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);
        break;
        // >= V3.50
        case RSCMU_GPRS_SERV_RSCS:
        // Connect Test Mode Reduced Signalling EGPRS symetrical
          if ((RSCMU_Status = RSCMU_GSM_Sig_ProcSignPdatAct (instrSession, RSCMU_GPRS_CONT_CRES, errorMessage)) < 0)
            return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);
        break;
        case RSCMU_GPRS_SERV_RSCA:
        // Connect Test Mode Reduced Signalling EGPRS asymetrical
          if ((RSCMU_Status = RSCMU_GSM_Sig_ProcSignPdatAct (instrSession, RSCMU_GPRS_CONT_CREA, errorMessage)) < 0)
            return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);
        break;
        case RSCMU_GPRS_SERV_LBS:
        // Connect Test Mode Loopback EGPRS symetrical
          if ((RSCMU_Status = RSCMU_GSM_Sig_ProcSignPdatAct (instrSession, RSCMU_GPRS_CONT_CLBS, errorMessage)) < 0)
            return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);
        break;
        case RSCMU_GPRS_SERV_LBA:
        // Connect Test Mode Loopback EGPRS asymetrical
          if ((RSCMU_Status = RSCMU_GSM_Sig_ProcSignPdatAct (instrSession, RSCMU_GPRS_CONT_CLBA, errorMessage)) < 0)
            return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);
        break;

    }

  do
  {
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensPdatStat (instrSession, &SignState, errorMessage))<0)
        return RSCMU_Status;
      if ((SignState != RSCMU_GPRS_STATE_CTBF) && (SignState != RSCMU_GPRS_STATE_TEST))
            return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_CALL_TO_MS_FAILED, errorMessage);
      RSCMU_Delay (0.1);
  }
  while (SignState != RSCMU_GPRS_STATE_TEST);

  return RSCMU_Status;
}

/*=========================================================================*/
/* Function: RSCMU_GSM_Sig_ConnectFromMobile
/* Purpose : This function waits for a TBF Established from the mobile connected to the CMU
/*           It can be called if the CMU is in IDLE or in ATT.
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConnectFromMobile (  ViSession  instrSession,
                                                                            ViInt32    Timeout,
                                                                            ViChar     errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;
  ViInt32   SignState;
  clock_t   StartTime = clock () / CLOCKS_PER_SEC;
  struct RSCMU_GSM_Sig_Globals *p_globalvarGSM;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Timeout, 0, 59, RSCMU_ERROR_PARAMETER2, errorMessage);

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarGSM)) < 0)
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_Status, errorMessage);

  if (p_globalvarGSM->RSCMU_tGlobal.RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  if ((RSCMU_Status = RSCMU_GSM_Sig_SensPdatStat (instrSession, &SignState, errorMessage))<0)
    return RSCMU_Status;

  if ((SignState != RSCMU_GPRS_STATE_CTBF) && (SignState != RSCMU_GPRS_STATE_TEST))
        return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_CALL_TO_MS_FAILED, errorMessage);

  // Ask if CMU in CEST
  do
  {
    if ((clock () / CLOCKS_PER_SEC) > (StartTime + Timeout))
      return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_CALL_FROM_MS_FAILED, errorMessage);

      if ((RSCMU_Status = RSCMU_GSM_Sig_SensPdatStat (instrSession, &SignState, errorMessage))<0)
        return RSCMU_Status;
    RSCMU_Delay (0.1);
  }
  while (SignState != RSCMU_GPRS_STATE_TEST);

  return RSCMU_Status;
}

/*=========================================================================*/
/* Function: RSCMU_GSM_Sig_DisconnectFromCMU
/* Purpose : Release the call by RSCMU.
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_DisconnectFromCMU (ViSession instrSession,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViInt32     SignState;

  // Be sured that RSCMU is in TEST
  if ((RSCMU_Status = RSCMU_GSM_Sig_SensPdatStat (instrSession, &SignState, errorMessage))<0)
    return RSCMU_Status;
  if (SignState != RSCMU_GPRS_STATE_TEST)
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);

  // Disconnect the TBF
  if ((RSCMU_Status = RSCMU_GSM_Sig_ProcSignPdatAct (instrSession, RSCMU_GPRS_CONT_DISC, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*=========================================================================*/
/* Function: Tolerances for power\t template
/* Purpose : This function permits to activate and define the power time
/*           template for normal and access bursts according to GSM
/*           specifications.
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowLim (ViSession  instrSession,
                                                                   ViReal64   AbsLevUppArea_1_8,
                                                                   ViReal64   RelLevUppArea_1_8,
                                                                   ViReal64   RelLevUppArea_2,
                                                                   ViReal64   RelLevUppArea_3,
                                                                   ViReal64   RelLevUppArea_4,
                                                                   ViReal64   RelLevUppArea_5,
                                                                   ViReal64   RelLevLowArea,
                                                                   ViReal64   RelLevUppArea_6,
                                                                   ViReal64   RelLevUppArea_7,
                                                                   ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if ((RSCMU_Status = RSCMU_GSM_Sig_ConfPowLimLineUpp (instrSession, 1,
                                                       RSCMU_ON, -1.000000E+001,
                                                       RSCMU_ON, -7.250000E+000,
                                                       RSCMU_ON, RelLevUppArea_1_8,
                                                       RSCMU_ON, RelLevUppArea_1_8,
                                                       RSCMU_ON, AbsLevUppArea_1_8,
                                                       RSCMU_ON, AbsLevUppArea_1_8,
                                                       RSCMU_ON,
                                                       errorMessage)) < 0)
    return RSCMU_Status;

  if ((RSCMU_Status = RSCMU_GSM_Sig_ConfPowLimLineUpp (instrSession, 2,
                                                       RSCMU_ON, -7.250000E+000,
                                                       RSCMU_ON, -4.500000E+000,
                                                       RSCMU_ON, RelLevUppArea_2,
                                                       RSCMU_ON, RelLevUppArea_2,
                                                       RSCMU_ON, -1.700000E+001,
                                                       RSCMU_ON, -1.700000E+001,
                                                       RSCMU_ON,
                                                       errorMessage)) < 0)
    return RSCMU_Status;

  if ((RSCMU_Status = RSCMU_GSM_Sig_ConfPowLimLineUpp (instrSession, 3,
                                                       RSCMU_ON, -4.500000E+000,
                                                       RSCMU_ON, -2.250000E+000,
                                                       RSCMU_ON, RelLevUppArea_3,
                                                       RSCMU_ON, RelLevUppArea_3,
                                                       RSCMU_OFF, 0.0,
                                                       RSCMU_OFF, 0.0,
                                                       RSCMU_ON,
                                                       errorMessage)) < 0)
    return RSCMU_Status;

  if ((RSCMU_Status = RSCMU_GSM_Sig_ConfPowLimLineUpp (instrSession, 4,
                                                       RSCMU_ON, -2.250000E+000,
                                                       RSCMU_ON, 5.000000E-001,
                                                       RSCMU_ON, RelLevUppArea_4,
                                                       RSCMU_ON, RelLevUppArea_4,
                                                       RSCMU_OFF, 0.0,
                                                       RSCMU_OFF, 0.0,
                                                       RSCMU_ON,
                                                       errorMessage)) < 0)
    return RSCMU_Status;

  if ((RSCMU_Status = RSCMU_GSM_Sig_ConfPowLimLineUpp (instrSession, 5,
                                                       RSCMU_ON, 5.000000E-001,
                                                       RSCMU_ON, 1.502500E+002,
                                                       RSCMU_ON, RelLevUppArea_5,
                                                       RSCMU_ON, RelLevUppArea_5,
                                                       RSCMU_OFF, 0.0,
                                                       RSCMU_OFF, 0.0,
                                                       RSCMU_ON,
                                                       errorMessage)) < 0)
    return RSCMU_Status;

  if ((RSCMU_Status = RSCMU_GSM_Sig_ConfPowLimLineUpp (instrSession, 6,
                                                       RSCMU_ON, 1.502500E+002,
                                                       RSCMU_ON, 1.525000E+002,
                                                       RSCMU_ON, RelLevUppArea_6,
                                                       RSCMU_ON, RelLevUppArea_6,
                                                       RSCMU_OFF, 0.0,
                                                       RSCMU_OFF, 0.0,
                                                       RSCMU_ON,
                                                       errorMessage)) < 0)
    return RSCMU_Status;

  if ((RSCMU_Status = RSCMU_GSM_Sig_ConfPowLimLineUpp (instrSession, 7,
                                                       RSCMU_ON, 1.525000E+002,
                                                       RSCMU_ON, 1.552500E+002,
                                                       RSCMU_ON, RelLevUppArea_7,
                                                       RSCMU_ON, RelLevUppArea_7,
                                                       RSCMU_ON, -1.700000E+001,
                                                       RSCMU_ON, -1.700000E+001,
                                                       RSCMU_ON,
                                                       errorMessage)) < 0)
    return RSCMU_Status;

  // Version Manager
  if (p_globalvarBase->RSCMU_FW_Version > RSCMU200_V2_11)
  {
    if ((RSCMU_Status = RSCMU_GSM_Sig_ConfPowLimLineUpp (instrSession, 8,
                                                         RSCMU_ON, 1.552500E+002,
                                                         RSCMU_ON, 1.570000E+002,
                                                         RSCMU_ON, RelLevUppArea_1_8,
                                                         RSCMU_ON, RelLevUppArea_1_8,
                                                         RSCMU_ON, -5.400000E+001,
                                                         RSCMU_ON, -5.400000E+001,
                                                         RSCMU_ON,
                                                         errorMessage)) < 0)
      return RSCMU_Status;
  }
  else
  {
    if ((RSCMU_Status = RSCMU_GSM_Sig_ConfPowLimLineUpp (instrSession, 8,
                                                         RSCMU_ON, 1.552500E+002,
                                                         RSCMU_ON, 1.567500E+002,
                                                         RSCMU_ON, RelLevUppArea_1_8,
                                                         RSCMU_ON, RelLevUppArea_1_8,
                                                         RSCMU_ON, -5.400000E+001,
                                                         RSCMU_ON, -5.400000E+001,
                                                         RSCMU_ON,
                                                         errorMessage)) < 0)
      return RSCMU_Status;

    if ((RSCMU_Status = RSCMU_GSM_Sig_ConfPowLimLineUpp (instrSession, 9,
                                                         RSCMU_ON, 1.567500E+002,
                                                         RSCMU_ON, 1.570000E+002,
                                                         RSCMU_ON, RelLevUppArea_1_8,
                                                         RSCMU_ON, RelLevUppArea_1_8,
                                                         RSCMU_ON, -5.400000E+001,
                                                         RSCMU_ON, -5.400000E+001,
                                                         RSCMU_ON,
                                                         errorMessage)) < 0)
      return RSCMU_Status;
  }

  // Version Manager
  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V2_10)
  {
    if ((RSCMU_Status = RSCMU_GSM_Sig_ConfPowLimLineLow (instrSession, 2,
                                                         RSCMU_ON, 5.000000E-001,
                                                         RSCMU_ON, 1.475000000E+002,
                                                         RSCMU_ON, RelLevLowArea,
                                                         RSCMU_ON, RelLevLowArea,
                                                         RSCMU_OFF, 0.0,
                                                         RSCMU_OFF, 0.0,
                                                         RSCMU_ON,
                                                         errorMessage)) < 0)
      return RSCMU_Status;
  }
  else
  {
    if ((RSCMU_Status = RSCMU_GSM_Sig_ConfPowLimLineLow (instrSession, 1,
                                                         RSCMU_ON, 5.000000E-001,
                                                         RSCMU_ON, 5.000000E-001,
                                                         RSCMU_ON, -1.000000E+002,
                                                         RSCMU_ON, RelLevLowArea,
                                                         RSCMU_OFF, 0.0,
                                                         RSCMU_OFF, 0.0,
                                                         RSCMU_ON,
                                                         errorMessage)) < 0)
      return RSCMU_Status;

    if ((RSCMU_Status = RSCMU_GSM_Sig_ConfPowLimLineLow (instrSession, 2,
                                                         RSCMU_ON, 1.472500E+002,
                                                         RSCMU_ON, 1.475000E+002,
                                                         RSCMU_ON, RelLevLowArea,
                                                         RSCMU_ON, -1.000000E+002,
                                                         RSCMU_OFF, 0.0,
                                                         RSCMU_OFF, 0.0,
                                                         RSCMU_ON,
                                                         errorMessage)) < 0)
      return RSCMU_Status;
  }
  return RSCMU_Status;
}

/*=========================================================================*/
/* Function: RSCMU_GSM_Sig_HandOver
/* Purpose : This function performs a handover from the Origin Network Handle
/*           Session to the Destination Network Handle Session.
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_HandOver (ViSession  SourceHandle,
                                                                 ViSession  TargetHandle,
                                                                 ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViInt32     state, prevState;
  clock_t     StartTime, EndTime;
  ViChar      wrtBuf[WR_BUFFER_SIZE]="", rdBuf[RD_BUFFER_SIZE]="",TargetName[30]="";

  struct RSCMU_GSM_Sig_Globals *p_globalvarGSM_Target ;

  // Get the 'HandOverSessionName' of the TargetSession
  if ((RSCMU_Status = viGetAttribute (TargetHandle, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarGSM_Target)) < 0)
    return RSCMU_Status;
//
  strncpy (TargetName, p_globalvarGSM_Target->RSCMU_tHandOver.HandOverSessionName,
                      strlen(p_globalvarGSM_Target->RSCMU_tHandOver.HandOverSessionName));
/*
  // Extract HandOver TargetList, compare TargetHandle with it.
  if ((RSCMU_Status = RSCMU_Query (SourceHandle, "STATUS:HANDOVER:TARGET:LIST?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  for (i=0;i<2;i++)
  {
    if (strncmp (TargetName, tab[i], strlen (tab[i])) == 0)
      Found = RSCMU_TRUE;
  }

  if (!Found)
    return RSCMU_K2G_errorMessage (SourceHandle, RSCMU_ERROR_INVALID_HANDOVER_TARGET, errorMessage);
*/
  // Be sured that RSCMU is in CEST or in CED.
  if ((RSCMU_Status = RSCMU_GSM_Sig_SensSignStat (SourceHandle, &prevState, errorMessage)) < 0)
    return RSCMU_Status;
  if ((prevState != RSCMU_STATE_CEST) && (prevState != RSCMU_STATE_CED))
    return RSCMU_K2G_errorMessage (SourceHandle, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
/*
  // Abort all measurements for the source session.
  if ((RSCMU_GSM_Sig_AborMeas (SourceHandle, errorMessage)) < 0)
    return RSCMU_Status;
*/
  // Execute the HandOver.
  sprintf (wrtBuf, "CONF:HAND:TARG %s",p_globalvarGSM_Target->RSCMU_tHandOver.HandOverSessionName);
  if ((RSCMU_Status = RSCMU_Query (SourceHandle, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  if ((RSCMU_Status = RSCMU_Query (SourceHandle, "PROC:SIGN:ACT HAND", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Wait 500 ms before query CMU state -Handover should happened
  RSCMU_Delay (0.5);

  // Be sured that RSCMU switches in CED or in CEST.
  if (prevState == RSCMU_STATE_CEST)
  {
    // JMG 030309 RSCMU_Delay (0.2);
    StartTime = clock() / CLOCKS_PER_SEC;
    do
    {
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensSignStat (TargetHandle, &state, errorMessage)) < 0)
        return RSCMU_Status;
      if (state == RSCMU_STATE_CPEN)
        // JMG 030309
        RSCMU_Delay (0.05);
      EndTime = clock() / CLOCKS_PER_SEC;
    }
    while ((state != RSCMU_STATE_CED) && ((EndTime - StartTime) < 30.0));

    if (state != RSCMU_STATE_CED)
      return RSCMU_K2G_errorMessage (TargetHandle, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
  }
  else if (prevState == RSCMU_STATE_CED)
  {
    StartTime = clock() / CLOCKS_PER_SEC;
    do
    {
      RSCMU_Delay (0.05);
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensSignStat (TargetHandle, &state, errorMessage)) < 0)
        return RSCMU_Status;
      EndTime = clock() / CLOCKS_PER_SEC;
    }
    while ((state != RSCMU_STATE_CED) && ((EndTime - StartTime) < 30.0));

    if (state != RSCMU_STATE_CED)
      return RSCMU_K2G_errorMessage (TargetHandle, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
  }

  return RSCMU_Status;
}

/*=========================================================================*/
/* Function: RSCMU_GSM_Sig_Init_Measurements
/* Purpose : This function will perform a INIT for any measurements
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_Init_Measurements (ViSession  instrSession,
                                                                          ViBoolean  Sens_Flag,
                                                                          ViBoolean  Power_Flag,
                                                                          ViBoolean  Modulation_Flag,
                                                                          ViReal64   Timeout,
                                                                          ViChar     errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;

  clock_t   StartTime;
  clock_t   CurrentTime;

  ViInt32   PowStatus = RSCMU_MEAS_OFF;
  ViInt32   PowMprStatus = RSCMU_MEAS_OFF;
  ViInt32   ModStatus = RSCMU_MEAS_OFF;
  ViInt32   SensStatus = RSCMU_MEAS_OFF;
  ViInt32   CurrentStatCycleCount;
  ViInt32   CurrentEvalPeriodCount;

  StartTime = clock() / CLOCKS_PER_SEC;

  // Start SENS measurement:
  if (Sens_Flag == RSCMU_ON)
  {
    if ((RSCMU_GSM_Sig_InitSens (instrSession, RSCMU_SINGLE_SHOT, errorMessage)) < 0)
      return RSCMU_Status;
  }

  // Start power measurement:
  if ((Power_Flag == RSCMU_ON) && (Modulation_Flag == RSCMU_OFF))
  {
    if ((RSCMU_GSM_Sig_InitPow (instrSession, errorMessage)) < 0)
      return RSCMU_Status;
  }

  // Start Modulation measurement:
  if ((Modulation_Flag == RSCMU_ON) && (Power_Flag == RSCMU_OFF))
  {
    if ((RSCMU_GSM_Sig_InitMod (instrSession, errorMessage)) < 0)
      return RSCMU_Status;
  }

  // Start Combined Power/Modulation measurement:
  if ((Modulation_Flag == RSCMU_ON) && (Power_Flag == RSCMU_ON))
  {
    if ((RSCMU_GSM_NSig_InitPowMpr (instrSession, errorMessage)) < 0)
      return RSCMU_Status;
  }

// do
// {
//   if ((PowStatus != RSCMU_MEAS_RDY) && (Power_Flag == RSCMU_ON) && (Modulation_Flag == RSCMU_OFF))
//   {
//     if ((RSCMU_Status = RSCMU_GSM_Sig_FetcPowStat (instrSession,
//                                                        &PowStatus,
//                                                        &CurrentStatCycleCount,
//                                                        &CurrentEvalPeriodCount,
//                                                        errorMessage)) < 0)
//       return RSCMU_Status;
//
//     switch (PowStatus)
//     {
//       case RSCMU_MEAS_RUN:
//       case RSCMU_MEAS_RDY:
//       break;
//       default:
//         return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_MEAS_STATUS, errorMessage);
//     }
//   }
//
//   if ((ModStatus != RSCMU_MEAS_RDY) && (Modulation_Flag == RSCMU_ON) && (Power_Flag == RSCMU_OFF))
//   {
//
//     if ((RSCMU_Status = RSCMU_GSM_Sig_FetcModStat (instrSession,
//                                                    &ModStatus,
//                                                    &CurrentStatCycleCount,
//                                                    &CurrentEvalPeriodCount,
//                                                    errorMessage)) < 0)
//       return RSCMU_Status;
//
//     switch (ModStatus)
//     {
//       case RSCMU_MEAS_RUN:
//       case RSCMU_MEAS_RDY:
//         break;
//       default:
//         return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_MEAS_STATUS, errorMessage);
//     }
//   }
//
//   if ((PowMprStatus != RSCMU_MEAS_RDY) && (Modulation_Flag == RSCMU_ON) && (Power_Flag == RSCMU_ON))
//   {
//
//     if ((RSCMU_Status = RSCMU_GSM_Sig_FetcPowMprStat (instrSession,
//                                                       &PowMprStatus,
//                                                       &CurrentStatCycleCount,
//                                                       &CurrentEvalPeriodCount,
//                                                       errorMessage)) < 0)
//       return RSCMU_Status;
//
//     switch (PowMprStatus)
//     {
//       case RSCMU_MEAS_RUN:
//       case RSCMU_MEAS_RDY:
//         break;
//       default:
//         return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_MEAS_STATUS, errorMessage);
//     }
//   }
//
//   if ((SensStatus != RSCMU_MEAS_RDY) && (Sens_Flag == RSCMU_ON))
//   {
//     if ((RSCMU_Status = RSCMU_GSM_Sig_FetcSensStat (instrSession,
//                                                    RSCMU_SINGLE_SHOT,
//                                                    &SensStatus,
//                                                    &CurrentStatCycleCount,
//                                                    &CurrentEvalPeriodCount,
//                                                    errorMessage)) < 0)
//       return RSCMU_Status;
//
//     switch (SensStatus)
//     {
//       case RSCMU_MEAS_RUN:
//       case RSCMU_MEAS_RDY:
//         break;
//       default:
//         return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_MEAS_STATUS, errorMessage);
//     }
//   }
//
//   RSCMU_Delay(0.05);
//
//   CurrentTime = clock() / CLOCKS_PER_SEC;
//
//   if ((CurrentTime - StartTime) > Timeout)
//     return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_TIMEOUT, errorMessage);
//
// } while
//  (
//   ((PowStatus != RSCMU_MEAS_RDY) && (Power_Flag == RSCMU_ON) && (Modulation_Flag == RSCMU_OFF))
//   ||
//   ((SensStatus != RSCMU_MEAS_RDY) && (Sens_Flag == RSCMU_ON))
//   ||
//   ((ModStatus != RSCMU_MEAS_RDY) && (Modulation_Flag == RSCMU_ON) && (Power_Flag == RSCMU_OFF))
//   ||
//   ((PowMprStatus != RSCMU_MEAS_RDY) && (Modulation_Flag == RSCMU_ON) && (Power_Flag == RSCMU_ON))
//  );

  for(;;)
  {
    if ((PowStatus != RSCMU_MEAS_RDY) && (Power_Flag == RSCMU_ON) && (Modulation_Flag == RSCMU_OFF))
    {
      if ((RSCMU_Status = RSCMU_GSM_Sig_FetcPowStat (instrSession,
                                                         &PowStatus,
                                                         &CurrentStatCycleCount,
                                                         &CurrentEvalPeriodCount,
                                                         errorMessage)) < 0)
        return RSCMU_Status;

      switch (PowStatus)
      {
        case RSCMU_MEAS_RUN:
        case RSCMU_MEAS_RDY:
        break;
        default:
          return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_MEAS_STATUS, errorMessage);
      }
    }

    if ((ModStatus != RSCMU_MEAS_RDY) && (Modulation_Flag == RSCMU_ON) && (Power_Flag == RSCMU_OFF))
    {

      if ((RSCMU_Status = RSCMU_GSM_Sig_FetcModStat (instrSession,
                                                     &ModStatus,
                                                     &CurrentStatCycleCount,
                                                     &CurrentEvalPeriodCount,
                                                     errorMessage)) < 0)
        return RSCMU_Status;

      switch (ModStatus)
      {
        case RSCMU_MEAS_RUN:
        case RSCMU_MEAS_RDY:
          break;
        default:
          return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_MEAS_STATUS, errorMessage);
      }
    }

    if ((PowMprStatus != RSCMU_MEAS_RDY) && (Modulation_Flag == RSCMU_ON) && (Power_Flag == RSCMU_ON))
    {

      if ((RSCMU_Status = RSCMU_GSM_Sig_FetcPowMprStat (instrSession,
                                                        &PowMprStatus,
                                                        &CurrentStatCycleCount,
                                                        &CurrentEvalPeriodCount,
                                                        errorMessage)) < 0)
        return RSCMU_Status;

      switch (PowMprStatus)
      {
        case RSCMU_MEAS_RUN:
        case RSCMU_MEAS_RDY:
          break;
        default:
          return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_MEAS_STATUS, errorMessage);
      }
    }

    if ((SensStatus != RSCMU_MEAS_RDY) && (Sens_Flag == RSCMU_ON))
    {
      if ((RSCMU_Status = RSCMU_GSM_Sig_FetcSensStat (instrSession,
                                                     RSCMU_SINGLE_SHOT,
                                                     &SensStatus,
                                                     &CurrentStatCycleCount,
                                                     &CurrentEvalPeriodCount,
                                                     errorMessage)) < 0)
        return RSCMU_Status;

      switch (SensStatus)
      {
        case RSCMU_MEAS_RUN:
        case RSCMU_MEAS_RDY:
          break;
        default:
          return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_MEAS_STATUS, errorMessage);
      }
    }

    if (
        ((PowStatus != RSCMU_MEAS_RDY) && (Power_Flag == RSCMU_ON) && (Modulation_Flag == RSCMU_OFF))
        ||
        ((SensStatus != RSCMU_MEAS_RDY) && (Sens_Flag == RSCMU_ON))
        ||
        ((ModStatus != RSCMU_MEAS_RDY) && (Modulation_Flag == RSCMU_ON) && (Power_Flag == RSCMU_OFF))
        ||
        ((PowMprStatus != RSCMU_MEAS_RDY) && (Modulation_Flag == RSCMU_ON) && (Power_Flag == RSCMU_ON))
    )
    {
        RSCMU_Delay(0.05);

        CurrentTime = clock() / CLOCKS_PER_SEC;

        if ((CurrentTime - StartTime) > Timeout)
        return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_TIMEOUT, errorMessage);
    }
    else
    {
        break;
    }
  }

  return RSCMU_Status;
}

/*=========================================================================*/
/* Function:
/* Purpose :
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowMprRfer (ViSession  instrSession,
                                                                       ViInt32    Mode,
                                                                       ViReal64   Timeout,
                                                                       ViReal64   *AvgBurstPwAvg,
                                                                       ViInt32    *BurstMatching,
                                                                       ViReal64   *PhErrPeak,
                                                                       ViReal64   *PhErrRMS,
                                                                       ViReal64   *FreqErr,
                                                                       ViReal64   *RferClassIIBits,
                                                                       ViReal64   *Fer,
                                                                       ViChar     errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;

  clock_t   StartTime;
  clock_t   CurrentTime;

  ViInt32   PowMprStatus = RSCMU_MEAS_OFF;
  ViInt32   SensStatus = RSCMU_MEAS_OFF;
  ViInt32   CurrentStatCycleCount;
  ViInt32   CurrentEvalPeriodCount;

  ViReal64  AvgBurstPwCurr;
  ViReal64  PeakBurstPwCurr;
  ViInt32   PowerControlLevel;
  ViReal64  TimingAdvError;
  ViReal64  BurstsOutOfTol;
  //ViInt32   BurstMatching;

  //ViInt32   Mode;
  //ViReal64  PhErrPeak;
  //ViReal64  PhErrRMS;
  //ViReal64  FreqErr;
  //ViReal64  AvgBurstPwAvg;

  ViReal64  ProgressTime;
  //ViReal64  RferClassIIBits;
  ViReal64  RferClassIbBits;
  //ViReal64  Fer;
  ViInt32   CRCErrors;
  ViInt32   Status;

  StartTime = clock() / CLOCKS_PER_SEC;

  // Start sensitivity measurement:
  if ((RSCMU_GSM_Sig_InitSens (instrSession, RSCMU_SINGLE_SHOT, errorMessage)) < 0)
    return RSCMU_Status;

  // Start power & modulation measurement:
  if ((RSCMU_GSM_Sig_InitPowMpr (instrSession, errorMessage)) < 0)
    return RSCMU_Status;

  do
  {
    if (PowMprStatus != RSCMU_MEAS_RDY)
    {
      if ((RSCMU_Status = RSCMU_GSM_Sig_FetcPowMprStat (instrSession,
                                                        &PowMprStatus,
                                                        &CurrentStatCycleCount,
                                                        &CurrentEvalPeriodCount,
                                                        errorMessage)) < 0)
        return RSCMU_Status;

      switch (PowMprStatus)
      {
        case RSCMU_MEAS_RUN:
          break;
        case RSCMU_MEAS_RDY:
          if ((RSCMU_Status = RSCMU_GSM_Sig_FetcPowMpr (instrSession,
                                                        Mode,
                                                        &AvgBurstPwCurr,
                                                        &PeakBurstPwCurr,
                                                        &PowerControlLevel,
                                                        &TimingAdvError,
                                                        &BurstsOutOfTol,
                                                        BurstMatching,
                                                        PhErrPeak,
                                                        PhErrRMS,
                                                        FreqErr,
                                                        AvgBurstPwAvg,
                                                        errorMessage)) < 0)
            return RSCMU_Status;

          break;
        default:
          // Abort sensitivity measurement:
          if ((RSCMU_GSM_Sig_AborSens (instrSession, RSCMU_SINGLE_SHOT, errorMessage)) < 0)
            return RSCMU_Status;

          // Abort power & modulation measurement:
          if ((RSCMU_GSM_Sig_AborPowMpr (instrSession, errorMessage)) < 0)
            return RSCMU_Status;

          return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_MEAS_STATUS, errorMessage);
      }
    }

    if (SensStatus != RSCMU_MEAS_RDY)
    {
      if ((RSCMU_Status = RSCMU_GSM_Sig_FetcSensStat (instrSession,
                                                      RSCMU_SINGLE_SHOT,
                                                      &SensStatus,
                                                      &CurrentStatCycleCount,
                                                      &CurrentEvalPeriodCount,
                                                      errorMessage)) < 0)
        return RSCMU_Status;

      switch (SensStatus)
      {
        case RSCMU_MEAS_RUN:
          break;
        case RSCMU_MEAS_RDY:
          if ((RSCMU_Status = RSCMU_GSM_Sig_Rfer_FetcSens (instrSession,
                                                           RSCMU_SINGLE_SHOT,
                                                           &ProgressTime,
                                                           RferClassIIBits,
                                                           &RferClassIbBits,
                                                           Fer,
                                                           &CRCErrors,
                                                           &Status,
                                                           errorMessage)) < 0)
            return RSCMU_Status;
          break;
        default:
          // Abort sensitivity measurement:
          if ((RSCMU_GSM_Sig_AborSens (instrSession, RSCMU_SINGLE_SHOT, errorMessage)) < 0)
            return RSCMU_Status;

          // Abort power & modulation measurement:
          if ((RSCMU_GSM_Sig_AborPowMpr (instrSession, errorMessage)) < 0)
            return RSCMU_Status;

          return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_MEAS_STATUS, errorMessage);
      }
    }

    CurrentTime = clock() / CLOCKS_PER_SEC;

    if ((CurrentTime - StartTime) > Timeout)
    {
      // Abort sensitivity measurement:
      if ((RSCMU_GSM_Sig_AborSens (instrSession, RSCMU_SINGLE_SHOT, errorMessage)) < 0)
        return RSCMU_Status;

      // Abort power & modulation measurement:
      if ((RSCMU_GSM_Sig_AborPowMpr (instrSession, errorMessage)) < 0)
        return RSCMU_Status;

      return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_TIMEOUT, errorMessage);
    }

  } while ((PowMprStatus != RSCMU_MEAS_RDY) || (SensStatus != RSCMU_MEAS_RDY));

  // Abort sensitivity measurement:
  if ((RSCMU_GSM_Sig_AborSens (instrSession, RSCMU_SINGLE_SHOT, errorMessage)) < 0)
    return RSCMU_Status;

  // Abort power & modulation measurement:
  if ((RSCMU_GSM_Sig_AborPowMpr (instrSession, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*=========================================================================*/
/* Function:
/* Purpose :
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowMprBbb (ViSession  instrSession,
                                                                      ViInt32    Mode,
                                                                      ViReal64   Timeout,
                                                                      ViReal64   *AvgBurstPwAvg,
                                                                      ViInt32    *BurstMatching,
                                                                      ViReal64   *PhErrPeak,
                                                                      ViReal64   *PhErrRMS,
                                                                      ViReal64   *FreqErr,
                                                                      ViReal64   *BbbClassIIBits,
                                                                      ViChar     errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;

  clock_t   StartTime;
  clock_t   CurrentTime;

  ViInt32   PowMprStatus = RSCMU_MEAS_OFF;
  ViInt32   SensStatus = RSCMU_MEAS_OFF;
  ViInt32   CurrentStatCycleCount;
  ViInt32   CurrentEvalPeriodCount;

  ViReal64  AvgBurstPwCurr;
  ViReal64  PeakBurstPwCurr;
  ViInt32   PowerControlLevel;
  ViReal64  TimingAdvError;
  ViReal64  BurstsOutOfTol;
  //ViInt32   BurstMatching;

  //ViInt32   Mode;
  //ViReal64  PhErrPeak;
  //ViReal64  PhErrRMS;
  //ViReal64  FreqErr;
  //ViReal64  AvgBurstPwAvg;

  ViReal64  ProgressTime;
  //ViReal64  BbbClassIIBits;
  ViInt32   CRCErrors;
  ViInt32   Status;

  StartTime = clock() / CLOCKS_PER_SEC;

  // Start sensitivity measurement:
  if ((RSCMU_GSM_Sig_InitSens (instrSession, RSCMU_SINGLE_SHOT, errorMessage)) < 0)
    return RSCMU_Status;

  // Start power & modulation measurement:
  if ((RSCMU_GSM_Sig_InitPowMpr (instrSession, errorMessage)) < 0)
    return RSCMU_Status;

  do
  {
    if (PowMprStatus != RSCMU_MEAS_RDY)
    {
      if ((RSCMU_Status = RSCMU_GSM_Sig_FetcPowMprStat (instrSession,
                                                        &PowMprStatus,
                                                        &CurrentStatCycleCount,
                                                        &CurrentEvalPeriodCount,
                                                        errorMessage)) < 0)
        return RSCMU_Status;

      switch (PowMprStatus)
      {
        case RSCMU_MEAS_RUN:
          break;
        case RSCMU_MEAS_RDY:
          if ((RSCMU_Status = RSCMU_GSM_Sig_FetcPowMpr (instrSession,
                                                        Mode,
                                                        &AvgBurstPwCurr,
                                                        &PeakBurstPwCurr,
                                                        &PowerControlLevel,
                                                        &TimingAdvError,
                                                        &BurstsOutOfTol,
                                                        BurstMatching,
                                                        PhErrPeak,
                                                        PhErrRMS,
                                                        FreqErr,
                                                        AvgBurstPwAvg,
                                                        errorMessage)) < 0)
            return RSCMU_Status;
          break;
        default:

          // Abort sensitivity measurement:
          if ((RSCMU_GSM_Sig_AborSens (instrSession, RSCMU_SINGLE_SHOT, errorMessage)) < 0)
            return RSCMU_Status;

          // Abort power & modulation measurement:
          if ((RSCMU_GSM_Sig_AborPowMpr (instrSession, errorMessage)) < 0)
            return RSCMU_Status;

          return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_MEAS_STATUS, errorMessage);
      }
    }

    if (SensStatus != RSCMU_MEAS_RDY)
    {
      if ((RSCMU_Status = RSCMU_GSM_Sig_FetcSensStat (instrSession,
                                                      RSCMU_SINGLE_SHOT,
                                                      &SensStatus,
                                                      &CurrentStatCycleCount,
                                                      &CurrentEvalPeriodCount,
                                                      errorMessage)) < 0)
        return RSCMU_Status;

      switch (SensStatus)
      {
        case RSCMU_MEAS_RUN:
          break;
        case RSCMU_MEAS_RDY:
          if ((RSCMU_Status = RSCMU_GSM_Sig_Bbb_FetcSens (instrSession,
                                                          RSCMU_SINGLE_SHOT,
                                                          &ProgressTime,
                                                          BbbClassIIBits,
                                                          &CRCErrors,
                                                          &Status,
                                                          errorMessage)) < 0)
            return RSCMU_Status;
          break;
        default:
          // Abort sensitivity measurement:
          if ((RSCMU_GSM_Sig_AborSens (instrSession, RSCMU_SINGLE_SHOT, errorMessage)) < 0)
            return RSCMU_Status;

          // Abort power & modulation measurement:
          if ((RSCMU_GSM_Sig_AborPowMpr (instrSession, errorMessage)) < 0)
            return RSCMU_Status;

          return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_MEAS_STATUS, errorMessage);
      }
    }

    CurrentTime = clock() / CLOCKS_PER_SEC;

    if ((CurrentTime - StartTime) > Timeout)
    {
      // Abort sensitivity measurement:
      if ((RSCMU_GSM_Sig_AborSens (instrSession, RSCMU_SINGLE_SHOT, errorMessage)) < 0)
        return RSCMU_Status;

      // Abort power & modulation measurement:
      if ((RSCMU_GSM_Sig_AborPowMpr (instrSession, errorMessage)) < 0)
        return RSCMU_Status;

      return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_TIMEOUT, errorMessage);
    }

  } while ((PowMprStatus != RSCMU_MEAS_RDY) || (SensStatus != RSCMU_MEAS_RDY));

  // Abort sensitivity measurement:
  if ((RSCMU_GSM_Sig_AborSens (instrSession, RSCMU_SINGLE_SHOT, errorMessage)) < 0)
    return RSCMU_Status;

  // Abort power & modulation measurement:
  if ((RSCMU_GSM_Sig_AborPowMpr (instrSession, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*=========================================================================*/
/* Function:
/* Purpose :
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowMprDbler (ViSession  instrSession,
                                                                       ViInt32    Mode,
                                                                       ViReal64   Timeout,
                                                                       ViReal64   *AvgBurstPwAvg,
                                                                       ViInt32    *BurstMatching,
                                                                       ViReal64   *PhErrPeak,
                                                                       ViReal64   *PhErrRMS,
                                                                       ViReal64   *FreqErr,
                                                                       ViReal64   *Ber,
                                                                       ViReal64   *Usfbler,
                                                                       ViReal64   *dbler,
                                                                       ViChar     errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;

  clock_t   StartTime;
  clock_t   CurrentTime;

  ViInt32   PowMprStatus = RSCMU_MEAS_OFF;
  ViInt32   SensStatus = RSCMU_MEAS_OFF;
  ViInt32   CurrentStatCycleCount;
  ViInt32   CurrentEvalPeriodCount;

  ViReal64  AvgBurstPwCurr;
  ViReal64  PeakBurstPwCurr;
  ViInt32   PowerControlLevel;
  ViReal64  TimingAdvError;
  ViReal64  BurstsOutOfTol;
  //ViInt32   BurstMatching;

  //ViInt32   Mode;
  //ViReal64  PhErrPeak;
  //ViReal64  PhErrRMS;
  //ViReal64  FreqErr;
  //ViReal64  AvgBurstPwAvg;

  ViReal64  ProgressTime;
  //ViReal64  RferClassIIBits;
  //ViReal64  Fer;
  ViInt32   CRCErrors;
  ViInt32   Status;

  StartTime = clock() / CLOCKS_PER_SEC;

  // Start sensitivity measurement:
  if ((RSCMU_GSM_Sig_InitSens (instrSession, RSCMU_SINGLE_SHOT, errorMessage)) < 0)
    return RSCMU_Status;

  // Start power & modulation measurement:
  if ((RSCMU_GSM_Sig_InitPowMpr (instrSession, errorMessage)) < 0)
    return RSCMU_Status;

  do
  {
    if (PowMprStatus != RSCMU_MEAS_RDY)
    {
      if ((RSCMU_Status = RSCMU_GSM_Sig_FetcPowMprStat (instrSession,
                                                        &PowMprStatus,
                                                        &CurrentStatCycleCount,
                                                        &CurrentEvalPeriodCount,
                                                        errorMessage)) < 0)
        return RSCMU_Status;

      switch (PowMprStatus)
      {
        case RSCMU_MEAS_RUN:
          break;
        case RSCMU_MEAS_RDY:
          if ((RSCMU_Status = RSCMU_GSM_Sig_FetcPowMpr (instrSession,
                                                        Mode,
                                                        &AvgBurstPwCurr,
                                                        &PeakBurstPwCurr,
                                                        &PowerControlLevel,
                                                        &TimingAdvError,
                                                        &BurstsOutOfTol,
                                                        BurstMatching,
                                                        PhErrPeak,
                                                        PhErrRMS,
                                                        FreqErr,
                                                        AvgBurstPwAvg,
                                                        errorMessage)) < 0)
            return RSCMU_Status;

          break;
        default:
          // Abort sensitivity measurement:
          if ((RSCMU_GSM_Sig_AborSens (instrSession, RSCMU_SINGLE_SHOT, errorMessage)) < 0)
            return RSCMU_Status;

          // Abort power & modulation measurement:
          if ((RSCMU_GSM_Sig_AborPowMpr (instrSession, errorMessage)) < 0)
            return RSCMU_Status;

          return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_MEAS_STATUS, errorMessage);
      }
    }

    if (SensStatus != RSCMU_MEAS_RDY)
    {
      if ((RSCMU_Status = RSCMU_GSM_Sig_FetcSensStat (instrSession,
                                                      RSCMU_SINGLE_SHOT,
                                                      &SensStatus,
                                                      &CurrentStatCycleCount,
                                                      &CurrentEvalPeriodCount,
                                                      errorMessage)) < 0)
        return RSCMU_Status;

      switch (SensStatus)
      {
        case RSCMU_MEAS_RUN:
          break;
        case RSCMU_MEAS_RDY:
          if ((RSCMU_Status = RSCMU_GSM_Sig_Dbler_FetcSens (instrSession,
                                                                                                                        RSCMU_SINGLE_SHOT,
                                                                                                                        &ProgressTime,
                                                                                                                        Ber,
                                                                                                                        Usfbler,
                                                                                                                        dbler,
                                                                                                                        &CRCErrors,
                                                                                                                        &Status,
                                                                                                                        errorMessage)) < 0)
            return RSCMU_Status;
          break;
        default:
          // Abort sensitivity measurement:
          if ((RSCMU_GSM_Sig_AborSens (instrSession, RSCMU_SINGLE_SHOT, errorMessage)) < 0)
            return RSCMU_Status;

          // Abort power & modulation measurement:
          if ((RSCMU_GSM_Sig_AborPowMpr (instrSession, errorMessage)) < 0)
            return RSCMU_Status;

          return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_MEAS_STATUS, errorMessage);
      }
    }

    CurrentTime = clock() / CLOCKS_PER_SEC;

    if ((CurrentTime - StartTime) > Timeout)
    {
      // Abort sensitivity measurement:
      if ((RSCMU_GSM_Sig_AborSens (instrSession, RSCMU_SINGLE_SHOT, errorMessage)) < 0)
        return RSCMU_Status;

      // Abort power & modulation measurement:
      if ((RSCMU_GSM_Sig_AborPowMpr (instrSession, errorMessage)) < 0)
        return RSCMU_Status;

      return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_TIMEOUT, errorMessage);
    }

  } while ((PowMprStatus != RSCMU_MEAS_RDY) || (SensStatus != RSCMU_MEAS_RDY));

  // Abort sensitivity measurement:
  if ((RSCMU_GSM_Sig_AborSens (instrSession, RSCMU_SINGLE_SHOT, errorMessage)) < 0)
    return RSCMU_Status;

  // Abort power & modulation measurement:
  if ((RSCMU_GSM_Sig_AborPowMpr (instrSession, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*****************************************************************************/
/*****************************************************************************/
/*========== CLASS: EDGE MEASUREMENT (K41) ==================================*/
/*****************************************************************************/
/*****************************************************************************/

/*****************************************************************************/
/*= EDGE NON SIGNALLING =====================================================*/
/*****************************************************************************/

/* -----------------------------------------------------------------------------
 *        POSITIONNING BURST IN TIME
 * -----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set offset time
/* Purpose : This function defines an offset time by which the burst is shifted
/*           relative to the time axis and the tolerance template
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowTimeBoff (ViSession instrSession,
                                                                          ViReal64  offset,
                                                                          ViChar    errorMessage[])
{
  return RSCMU_ConfPowTimeBoff(instrSession, RSCMU_EPSK, offset, errorMessage);
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowContRep (ViSession instrSession,
                                                                         ViInt32   repetition,
                                                                         ViInt32   stopCondition,
                                                                         ViInt32   stepMode,
                                                                         ViChar    errorMessage[])
{
  return RSCMU_ConfControlRep (instrSession, RSCMU_POW, RSCMU_EPSK, repetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Filter
/* Purpose : This function selects the measurement filter for the P/t
/*           measurement. The default filter setting differs for the two
/*           modulation schemes.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowFilt (ViSession instrSession,
                                                                      ViInt32   Filter,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_ConfFilt(instrSession, RSCMU_POW, RSCMU_EPSK, Filter, errorMessage);
}

/*===========================================================================*/
/* Function: Reference Power Mode
/* Purpose : This function determines how the reference power (0-dB line in
/*           the P/t Norm. 8PSK test diagram) for 8PSK-modulated signals is
/*           calculated.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowRPMode (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViString    StrRPMode[] = {"CURR","AVER","DCOM"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Sets the reference power mode
  sprintf (wrtBuf, "CONF:POW:EPSK:CONT:RPM %s", StrRPMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;

}

/*===========================================================================*/
/* Function: Set Grid (ON/OFF)
/* Purpose : This function switches the grid lines in the test diagrams
/*           on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_DispPowContGrid (ViSession instrSession,
                                                                          ViInt32   gridLines,
                                                                          ViChar    errorMessage[])
{
  return RSCMU_DisplayGrid (instrSession, RSCMU_POW, RSCMU_GMSK, gridLines, errorMessage);
}

/*===========================================================================*/
/* Function: Set Default limit Lines (ON/OFF)
/* Purpose : This function switches the default limit lines on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowLimLineDef (ViSession instrSession,
                                                                            ViInt32   defaultLimitLines,
                                                                            ViChar    errorMessage[])
{
  return RSCMU_ConfLimLineDef (instrSession, RSCMU_POW, RSCMU_EPSK, defaultLimitLines, errorMessage);
}

/*===========================================================================*/
/* Function: Upper limit Line
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowLimLineUpp (ViSession instrSession,
                                                                            ViInt32   area,
                                                                            ViInt32   StartTimeOnOff,
                                                                            ViReal64  StartTime,
                                                                            ViInt32   EndTimeOnOff,
                                                                            ViReal64  EndTime,
                                                                            ViInt32   StartRelLevOnOff,
                                                                            ViReal64  StartRelLev,
                                                                            ViInt32   EndRelLevOnOff,
                                                                            ViReal64  EndRelLev,
                                                                            ViInt32   StartAbsLevOnOff,
                                                                            ViReal64  StartAbsLev,
                                                                            ViInt32   EndAbsLevOnOff,
                                                                            ViReal64  EndAbsLev,
                                                                            ViInt32   Visibility,
                                                                            ViChar    errorMessage[])
{
  return RSCMU_ConfPowLimLineUpp (instrSession, RSCMU_EPSK, area, StartTimeOnOff, StartTime, EndTimeOnOff, EndTime,
    StartRelLevOnOff, StartRelLev, EndRelLevOnOff, EndRelLev, StartAbsLevOnOff, StartAbsLev, EndAbsLevOnOff, EndAbsLev, Visibility, errorMessage);
}

/*===========================================================================*/
/* Function: Lower limit Line
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowLimLineLow (ViSession instrSession,
                                                                            ViInt32   area,
                                                                            ViInt32   StartTimeOnOff,
                                                                            ViReal64  StartTime,
                                                                            ViInt32   EndTimeOnOff,
                                                                            ViReal64  EndTime,
                                                                            ViInt32   StartRelLevOnOff,
                                                                            ViReal64  StartRelLev,
                                                                            ViInt32   EndRelLevOnOff,
                                                                            ViReal64  EndRelLev,
                                                                            ViInt32   StartAbsLevOnOff,
                                                                            ViReal64  StartAbsLev,
                                                                            ViInt32   EndAbsLevOnOff,
                                                                            ViReal64  EndAbsLev,
                                                                            ViInt32   Visibility,
                                                                            ViChar    errorMessage[])
{
  return RSCMU_ConfPowLimLineLow (instrSession, RSCMU_EPSK, area, StartTimeOnOff, StartTime, EndTimeOnOff, EndTime,
    StartRelLevOnOff, StartRelLev, EndRelLevOnOff, EndRelLev, StartAbsLevOnOff, StartAbsLev, EndAbsLevOnOff, EndAbsLev, Visibility, errorMessage);
}

/*===========================================================================*/
/* Function: Dynamic Correction of Upper limit Line
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowLimLineUppDyn (ViSession instrSession,
                                                                               ViInt32   Area,
                                                                               ViInt32   TPCLRange,
                                                                               ViInt32   FromTPCLOnOff,
                                                                               ViInt32   FromTPCL,
                                                                               ViInt32   ToTPCLOnOff,
                                                                               ViInt32   ToTPCL,
                                                                               ViInt32   CorrectionOnOff,
                                                                               ViReal64  Correction,
                                                                               ViInt32   Enable,
                                                                               ViChar    errorMessage[])
{
  return RSCMU_ConfPowLimLineUppDyn (instrSession, RSCMU_EPSK, Area, TPCLRange, FromTPCLOnOff, FromTPCL, ToTPCLOnOff,
                                       ToTPCL, CorrectionOnOff, Correction, Enable, errorMessage);
}

/*===========================================================================*/
/* Function: Dynamic Correction of Lower limit Line
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowLimLineLowDyn (ViSession instrSession,
                                                                               ViInt32   Area,
                                                                               ViInt32   TPCLRange,
                                                                               ViInt32   FromTPCLOnOff,
                                                                               ViInt32   FromTPCL,
                                                                               ViInt32   ToTPCLOnOff,
                                                                               ViInt32   ToTPCL,
                                                                               ViInt32   CorrectionOnOff,
                                                                               ViReal64  Correction,
                                                                               ViInt32   Enable,
                                                                               ViChar    errorMessage[])
{
  return RSCMU_ConfPowLimLineLowDyn (instrSession, RSCMU_EPSK, Area, TPCLRange, FromTPCLOnOff, FromTPCL, ToTPCLOnOff,
                                       ToTPCL, CorrectionOnOff, Correction, Enable, errorMessage);
}

/*===========================================================================*/
/* Function: Dynamic Correction of Upper limit Line On/Off
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowLimUppDynMod (ViSession instrSession,
                                                                              ViInt32   area,
                                                                              ViInt32   enable,
                                                                              ViChar    errorMessage[])
{
  return RSCMU_ConfPowLimUppDynMod (instrSession, RSCMU_EPSK, area, enable, errorMessage);
}

/*===========================================================================*/
/* Function: Dynamic Correction of Lower limit Line On/Off
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowLimLowDynMod (ViSession instrSession,
                                                                              ViInt32   area,
                                                                              ViInt32   enable,
                                                                              ViChar    errorMessage[])
{
  return RSCMU_ConfPowLimLowDynMod (instrSession, RSCMU_EPSK, area, enable, errorMessage);
}

/*===========================================================================*/
/* Function: Set Scope of Measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowCont (ViSession instrSession,
                                                                      ViInt32 measuredValuesType,
                                                                      ViInt32 NbBurst,
                                                                      ViChar errorMessage[])
{
  return RSCMU_ConfControl (instrSession, RSCMU_POW, RSCMU_EPSK, measuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowContRepStat (ViSession instrSession,
                                                                             ViInt32   multipleMeasNbRepetition,
                                                                             ViInt32   stopCondition,
                                                                             ViInt32   stepMode,
                                                                             ViChar    errorMessage[])
{
  return RSCMU_ConfPowContRepStat(instrSession, RSCMU_EPSK, multipleMeasNbRepetition, stopCondition, stepMode, errorMessage );
}

/*===========================================================================*/
/* Function: Burst power measured values
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfArrPowRang (ViSession instrSession,
                                                                         ViReal64  initialTime_sec,
                                                                         ViInt32   testPointsNumber,
                                                                         ViChar    errorMessage[])
{
  ViStatus RSCMU_Status = VI_SUCCESS;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set power subranges
/* Purpose : This function configures the read, fetch and sample commands.
/*           It restricts the measurement to up to 32 subranges where either
/*           all measurement results or a single statistical value is returned
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSubPowRang (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  startTime,
                                                                         ViInt32   NbSamples,
                                                                         ViChar    errorMessage[])
{
  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, startTime, -10.0, 156.75, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbSamples, 0, 668, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSubarrays (instrSession, RSCMU_POW, RSCMU_EPSK, Mode, startTime, NbSamples, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_InitPow
/* Purpose : This function starts the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_InitPow (ViSession instrSession,
                                                                  ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_POW, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_AborPow
/* Purpose : This function stopss the power measurement, setting it to
/*           the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_AborPow (ViSession instrSession,
                                                                  ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_POW, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_StopPow
/* Purpose : This function stops the power measurement, setting it to
/*           the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_StopPow (ViSession instrSession,
                                                                  ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_POW, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_ContPow
/* Purpose : This function continue the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ContPow (ViSession instrSession,
                                                                  ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_POW, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_FetcPowStat
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcPowStat (ViSession instrSession,
                                                                      ViInt32  *measurementStatus,
                                                                      ViInt32  *CountingNo,
                                                                      ViInt32  *StatisticNo,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_FetcStatus (instrSession, RSCMU_POW, RSCMU_EPSK, measurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_ConfPowErep
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowErep (ViSession instrSession,
                                                                      ViInt32   Report,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_ConfReporting (instrSession, RSCMU_POW, RSCMU_EPSK, Report, errorMessage);
}

/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function starts a single shot measurement and output all
/*           scalar measurement results. These are:
/*             Average power of current burst
/*             Peak power of current burst
/*             Bursts out of tolerance
/*             Burst template matching
/*             Average power of averaged trace
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadPow (ViSession instrSession,
                                                                  ViReal64  *AvgBurstPwCurr,
                                                                  ViReal64  *PeakBurstPwCurr,
                                                                  ViReal64  *BurstsOutOfTol,
                                                                  ViInt32   *BurstMatching,
                                                                  ViReal64  *AvgBurstPwAvg,
                                                                  ViChar    errorMessage[])
{
  return RSCMU_MeasScalarPowerBurst (instrSession, RSCMU_COMMAND_READ, RSCMU_EPSK, AvgBurstPwCurr, PeakBurstPwCurr, BurstsOutOfTol, BurstMatching, AvgBurstPwAvg, errorMessage);
}

/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function reads out measurement and output all scalar
/*             measurement results (unsynchronized). These are:
/*             Average power of current burst
/*             Peak power of current burst
/*             Burst out of tolerance
/*             Burst template matching
/*             Average power of averaged trace
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcPow (ViSession instrSession,
                                                                  ViReal64  *AvgBurstPwCurr,
                                                                  ViReal64  *PeakBurstPwCurr,
                                                                  ViReal64  *BurstsOutOfTol,
                                                                  ViInt32   *BurstMatching,
                                                                  ViReal64  *AvgBurstPwAvg,
                                                                  ViChar    errorMessage[])
{
  return RSCMU_MeasScalarPowerBurst (instrSession, RSCMU_COMMAND_FETC, RSCMU_EPSK, AvgBurstPwCurr, PeakBurstPwCurr, BurstsOutOfTol, BurstMatching, AvgBurstPwAvg, errorMessage);
}

/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function reads out measurement and output all scalar
/*             measurement results (synchronized). These are:
/*             Average power of current burst
/*             Peak power of current burst
/*             Burst out of tolerance
/*             Burst template matching
/*             Average power of averaged trace
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampPow (ViSession instrSession,
                                                                  ViReal64 *AvgBurstPwCurr,
                                                                  ViReal64 *PeakBurstPwCurr,
                                                                  ViReal64 *BurstsOutOfTol,
                                                                  ViInt32  *BurstMatching,
                                                                  ViReal64 *AvgBurstPwAvg,
                                                                  ViChar errorMessage[])
{
  return RSCMU_MeasScalarPowerBurst (instrSession, RSCMU_COMMAND_SAMP, RSCMU_EPSK, AvgBurstPwCurr, PeakBurstPwCurr, BurstsOutOfTol, BurstMatching, AvgBurstPwAvg, errorMessage);
}

/*===========================================================================*/
/* Function: Power/t Limit Check
/* Purpose : This function indicates whether and in which way the per-
/*           missible tolerances for the scalar measured values  have
/*           been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_CalcPowLimMatc (ViSession instrSession,
                                                                         ViInt32  *avgBurstPowerCurrent,
                                                                         ViInt32  *peakBurstPowerCurrent,
                                                                         ViInt32  *burstTemplateMatching,
                                                                         ViInt32  *averageBurstPowerAverage,
                                                                         ViChar    errorMessage[])
{
  return RSCMU_CalcScalPowLimMatc(instrSession, RSCMU_EPSK, avgBurstPowerCurrent, peakBurstPowerCurrent, burstTemplateMatching, averageBurstPowerAverage, errorMessage);
}

/*===========================================================================*/
/* Function: Burst power measured values
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadArrPowBurs (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    errorMessage[])
{
  return RSCMU_MeasArrayPowerBurst (instrSession, RSCMU_COMMAND_READ, RSCMU_EPSK, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetc Burst Power...
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcArrPowBurs (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64 BurstPower[],
                                                                         ViChar errorMessage[])
{
  return RSCMU_MeasArrayPowerBurst (instrSession, RSCMU_COMMAND_FETC, RSCMU_EPSK, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Burst Power...
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampArrPowBurs (ViSession instrSession,
                                                                         ViInt32 Mode,
                                                                         ViReal64 BurstPower[],
                                                                         ViChar errorMessage[])
{
  return RSCMU_MeasArrayPowerBurst (instrSession, RSCMU_COMMAND_SAMP, RSCMU_EPSK, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Power/t Limit Check
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_CalcPowBursLimMatc (ViSession instrSession,
                                                                             ViInt32 StatisticsMode,
                                                                             ViInt32 *burstMatching,
                                                                             ViChar errorMessage[])
{
  return RSCMU_CalcArrPowLimMatc(instrSession, RSCMU_EPSK, StatisticsMode, burstMatching, errorMessage);
}

/*===========================================================================*/
/* Function: Range Violation
/* Purpose : This command is always query. ANy set bit of the two returned
/*           fiels indicates the violation of the corresponding section
/*           of the limit times
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_CalcPowResAreaLimMatc (ViSession instrSession,
                                                                                ViInt32 StatisticsMode,
                                                                                ViInt32 *UpperLimit,
                                                                                ViInt32 *LowerLimit,
                                                                                ViChar errorMessage[])
{
  return RSCMU_CalcPowAreaLimMatc(instrSession, RSCMU_EPSK, StatisticsMode, UpperLimit, LowerLimit, errorMessage);
}

/*===========================================================================*/
/* Function: Burst power measured values (SubArray)
/* Purpose : This function outputs the burst power versus time in a fixed
/*           -bit pattern and in subranges defined ny means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadSubArrPowBurs (ViSession instrSession,
                                                                            ViInt32 Mode,
                                                                            ViReal64 BurstPower[],
                                                                            ViChar errorMessage[])
{
  return RSCMU_MeasSubarraysPowerBurst (instrSession, RSCMU_COMMAND_READ, RSCMU_EPSK, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetc Burst Power (SubArray)...
/* Purpose : This function outputs the burst power versus time in a fixed
/*           -bit pattern and in subranges defined ny means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcSubArrPowBurs (ViSession instrSession,
                                                                            ViInt32   Mode,
                                                                            ViReal64  BurstPower[],
                                                                            ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPowerBurst (instrSession, RSCMU_COMMAND_FETC, RSCMU_EPSK, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Burst Power (SubArray)...
/* Purpose : This function outputs the burst power versus time in a fixed
/*           -bit pattern and in subranges defined ny means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampSubArrPowBurs (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                            ViReal64  BurstPower[],
                                                                            ViChar    errorMessage[])
{
  return RSCMU_MeasSubarraysPowerBurst (instrSession, RSCMU_COMMAND_SAMP, RSCMU_EPSK, Mode, BurstPower, errorMessage);
}


/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT MODULATION OVERview
 *    The subsystem MODulation:OVERview measures general scalar modulation
 *    parameters in 8PSK modulation. The subsystem corresponds to the measurement
 *    menu Modulation, application Overview 8PSK, and the associated popup menu
 *    Modulation Error Config
 * ----------------------------------------------------------------------------
 *      CONFIGURATION
 *          CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModOverContRep (ViSession instrSession,
                                                                             ViInt32   repetition,
                                                                             ViInt32   stopCondition,
                                                                             ViInt32   stepMode,
                                                                             ViChar    errorMessage[])
{
  return RSCMU_ConfControlRep(instrSession, RSCMU_MODOVER, RSCMU_EPSK, repetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModOverContDef (ViSession instrSession,
                                                                             ViInt32   defaultValues,
                                                                             ViChar    errorMessage[])
{
  return RSCMU_ConfContDef(instrSession, RSCMU_MODOVER, RSCMU_EPSK, defaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Reference Power Mode
/* Purpose : This function determines how the reference power (0-dB line in
/*           the Modulation 8PSK test diagram) for 8PSK-modulated signals is
/*           calculated.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModOempRPMode (ViSession instrSession,
                                                     ViInt32   RFPower,
                                                     ViChar    errorMessage[])
{
  ViString    StrRPMode[] = {"CURR","AVER","DCOM", VI_NULL};

  RETMSG(RSCMU_setEnum(instrSession, "CONFigure:MODulation:OEMP:EPSK:CONTrol:RPMode",
                       RFPower, StrRPMode,
                       RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: AM PM Timing Offset
/* Purpose : This function  determines the time delay of the amplitude vs.
/*           time trajectory of the baseband modulation vector
/*           relative to the phase vs time trajectory that is needed to
/*           minimize the modulation errors (EVM).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModOempAptoffs (ViSession instrSession,
                                               ViBoolean  AMPMTimingOffset,
                                               ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:MOD:OEMP:EPSK:CONT:APT", AMPMTimingOffset, mode_On_Off,
                       RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Reference Power Mode Signalling
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModOempRPMode (ViSession instrSession,
                                                    ViInt32   RFPower,
                                                    ViChar    errorMessage[])
{
  return RSCMU_EDGE_NSig_ConfModOempRPMode (instrSession, RFPower, errorMessage);
}


/*===========================================================================*/
/* Function: AM PM Timing Offset
/* Purpose : This function  determines the time delay of the amplitude vs.
/*           time trajectory of the baseband modulation vector
/*           relative to the phase vs time trajectory that is needed to
/*           minimize the modulation errors (EVM).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModOempAptoffs (ViSession instrSession,
                                               ViBoolean  AMPMTimingOffset,
                                               ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:MOD:OEMP:EPSK:CONT:APT", AMPMTimingOffset, mode_On_Off,
                       RSCMU_ERROR_PARAMETER2));
}


/*
 * ----------------------------------------------------------------------------
 *      LIMIT LINES
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Default limit Lines (ON/OFF)
/* Purpose : This function switches the default limit lines on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModOverLimLineDef (ViSession instrSession,
                                                                                ViBoolean defaultLimitLines,
                                                                                ViChar    errorMessage[])
{
    return RSCMU_ConfModOempLimLineDef (instrSession, defaultLimitLines, errorMessage);
}

/*===========================================================================*/
/* Function: Upper Limit Lines
/* Purpose : This function defines upper limits for the Current, Max./Min and
/*           Average traces and for the scalar modulation parameters derived
/*           from them.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModOverLimLineUpp (ViSession instrSession,
                                                                                ViInt32   Limits,
                                                                                ViReal64  EVMErrorPeak,
                                                                                ViReal64  EVMErrorRMS,
                                                                                ViReal64  magnErrorPeak,
                                                                                ViReal64  magnErrorRMS,
                                                                                ViReal64  phaseErrorPeak,
                                                                                ViReal64  phaseErrorRMS,
                                                                                ViReal64  originOffset,
                                                                                ViReal64  IQImBalance,
                                                                                ViInt32   frequencyError,
                                                                                ViChar    errorMessage[])
{
    return RSCMU_ConfModOempLimLineUpp (instrSession, Limits, EVMErrorPeak, EVMErrorRMS, magnErrorPeak, magnErrorRMS,
                                        phaseErrorPeak, phaseErrorRMS, originOffset, IQImBalance, frequencyError, errorMessage);
}

/*===========================================================================*/
/* Function: 95% Upper Limits
/* Purpose : This function defines upper limits for the 95 th percentile of
/*           the three quantities error vector magnitude, modulation error,
/*           and phase error. The 95 th percentile is the limit below which
/*           95% of the measured errors are located.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModOverLimLine95 (ViSession instrSession,
                                                                               ViReal64  EVM95,
                                                                               ViReal64  modulationError95,
                                                                               ViReal64  phaseError95,
                                                                               ViChar    errorMessage[])
{
    return RSCMU_ConfModOempLimLine95 (instrSession, EVM95, modulationError95, phaseError95, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModOverCont (ViSession instrSession,
                                                                          ViInt32   measuredValuesType,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    errorMessage[])
{
  return RSCMU_ConfControl (instrSession, RSCMU_MODOVER, RSCMU_EPSK, measuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModOverContRepSta (ViSession instrSession,
                                                                                ViInt32   NbRepetition,
                                                                                ViInt32   stopCondition,
                                                                                ViInt32   stepMode,
                                                                                ViChar    errorMessage[])
{
  return RSCMU_ConfContRepStat(instrSession, RSCMU_MODOVER, RSCMU_EPSK, NbRepetition, stopCondition, stepMode, errorMessage);
}

/* ----------------------------------------------------------------------------
 *      CONTROL OF MODULATION MEAS
 *      It contains the functions for general control of the modulation
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_InitModOver
/* Purpose : This function starts the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_InitModOver (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_MODOVER, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_AborModOver
/* Purpose : This function stopss the power measurement, setting it to
/*           the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_AborModOver (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_MODOVER, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_StopModOver
/* Purpose : This function stops the power measurement, setting it to
/*           the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_StopModOver (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_MODOVER, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_ContModOver
/* Purpose : This function continue the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ContModOver (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_MODOVER, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_ConfModOverErep
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModOverErep (ViSession instrSession,
                                                                          ViInt32   Report,
                                                                          ViChar    errorMessage[])
{
  return RSCMU_ConfReporting (instrSession, RSCMU_MODOVER, RSCMU_EPSK, Report, errorMessage);
}

/*===========================================================================*/
/* Function: Modulation Measurement Status
/* Purpose : This function returns the status of the current Modulation
/*           Overview measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcModOverStat (ViSession instrSession,
                                                                          ViInt32  *measurementStatus,
                                                                          ViInt32  *CountingNo,
                                                                          ViInt32  *StatisticNo,
                                                                          ViChar    errorMessage[])
{
  return RSCMU_FetcStatus (instrSession, RSCMU_MODOVER, RSCMU_EPSK, measurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      Subsystem MODulation[:OVERview]:EPSK[:TCH][:RESult]
 *      The subsystem MODulation:OVERview:EPSK[:RESULT] measures and returns
 *      the modulation parameters and compares them with the tolerance values.
 *      The subsystem corresponds to the various output elements in the
 *      measurement menu MODulation, application Overview 8PSK.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all
/*           scalar measurement results (see chapter 4). The calculation of
/*           results in an average or peak measurement is described in chapter
/*           3 (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadModOver (ViSession instrSession,
                                                                      ViInt32   StatisticsMode,
                                                                      ViPReal64 EVM95,
                                                                      ViPReal64 MagErr95,
                                                                      ViPReal64 PhaseErr95,
                                                                      ViPReal64 EVMPeak,
                                                                      ViPReal64 EVMRMS,
                                                                      ViPReal64 magnErrorPeak,
                                                                      ViPReal64 magnErrorRMS,
                                                                      ViPReal64 phaseErrorPeak,
                                                                      ViPReal64 phaseErrorRMS,
                                                                      ViPReal64 originOffset,
                                                                      ViPReal64 IQIm_balance,
                                                                      ViPReal64 frequencyError,
                                                                      ViPReal64 avgBurstPowerCurr,
                                                                      ViPReal64 burstOutOfTol,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_MeasModOver (instrSession, RSCMU_COMMAND_READ, StatisticsMode, EVM95, MagErr95, PhaseErr95, EVMPeak, EVMRMS,
                            magnErrorPeak, magnErrorRMS, phaseErrorPeak, phaseErrorRMS, originOffset, IQIm_balance,
                            frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}



/*===========================================================================*/
/* Function: Measurement Results
/* Purpose : This function starts a modulation measurement and output all
/*           scalar measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ModOverRes (ViSession instrSession,
                                                  ViInt32 command,
                                                  ViReal64 measurementResults[],
                                                  ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
    ViChar     *StrValue;
    ViInt16     Index = 0;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_50,RSCMU_ERROR_FW_VERSION_4_50));


    sprintf(wrtBuf,"%s:MOD:OVER:EPSK?", StrCommand[command]);

    if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;

    StrValue = strtok (rdBuf, ",");

     while (StrValue) {
        if (strcmp (StrValue, "NAN") != 0)
            sscanf (StrValue, "%lf", &measurementResults[Index]);
        else measurementResults[Index] = RSCMU_NAN;

        StrValue = strtok (NULL, ",");

        Index++;
    }

    return RSCMU_Status;
}
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function outputs all scalar measurement results (see chapter
/*           4). The calculation of results in an average or peak measurement
/*           is described in chapter 3 (see calculation of statistical
/*           quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcModOver (ViSession instrSession,
                                                                      ViInt32   StatisticsMode,
                                                                      ViPReal64 EVM95,
                                                                      ViPReal64 MagErr95,
                                                                      ViPReal64 PhaseErr95,
                                                                      ViPReal64 EVMPeak,
                                                                      ViPReal64 EVMRMS,
                                                                      ViPReal64 magnErrorPeak,
                                                                      ViPReal64 magnErrorRMS,
                                                                      ViPReal64 phaseErrorPeak,
                                                                      ViPReal64 phaseErrorRMS,
                                                                      ViPReal64 originOffset,
                                                                      ViPReal64 IQIm_balance,
                                                                      ViPReal64 frequencyError,
                                                                      ViPReal64 avgBurstPowerCurr,
                                                                      ViPReal64 burstOutOfTol,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_MeasModOver (instrSession, RSCMU_COMMAND_FETC, StatisticsMode, EVM95, MagErr95, PhaseErr95, EVMPeak, EVMRMS,
                            magnErrorPeak, magnErrorRMS, phaseErrorPeak, phaseErrorRMS, originOffset, IQIm_balance,
                            frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all
/*           scalar measurement results (see chapter 4). The calculation of
/*           results in an average or peak measurement is described in chapter
/*           3 (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampModOver (ViSession instrSession,
                                                                      ViInt32   StatisticsMode,
                                                                      ViPReal64 EVM95,
                                                                      ViPReal64 MagErr95,
                                                                      ViPReal64 PhaseErr95,
                                                                      ViPReal64 EVMPeak,
                                                                      ViPReal64 EVMRMS,
                                                                      ViPReal64 magnErrorPeak,
                                                                      ViPReal64 magnErrorRMS,
                                                                      ViPReal64 phaseErrorPeak,
                                                                      ViPReal64 phaseErrorRMS,
                                                                      ViPReal64 originOffset,
                                                                      ViPReal64 IQIm_balance,
                                                                      ViPReal64 frequencyError,
                                                                      ViPReal64 avgBurstPowerCurr,
                                                                      ViPReal64 burstOutOfTol,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_MeasModOver (instrSession, RSCMU_COMMAND_SAMP, StatisticsMode, EVM95, MagErr95, PhaseErr95, EVMPeak, EVMRMS,
                            magnErrorPeak, magnErrorRMS, phaseErrorPeak, phaseErrorRMS, originOffset, IQIm_balance,
                            frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_CalcModOverLimMatc (ViSession instrSession,
                                                                             ViInt32   StatisticsMode,
                                                                             ViInt32  *EVM95,
                                                                             ViInt32  *MagErr95,
                                                                             ViInt32  *PhaseErr95,
                                                                             ViInt32  *EVMPeak,
                                                                             ViInt32  *EVMRMS,
                                                                             ViInt32  *magnErrorPeak,
                                                                             ViInt32  *magnErrorRMS,
                                                                             ViInt32  *phaseErrorPeak,
                                                                             ViInt32  *phaseErrorRMS,
                                                                             ViInt32  *originOffset,
                                                                             ViInt32  *IQIm_balance,
                                                                             ViInt32  *frequencyError,
                                                                             ViInt32  *avgBurstPowerCurr,
                                                                             ViChar   errorMessage[])
{
  return RSCMU_CalcModOverLimMatc (instrSession, StatisticsMode, EVM95, MagErr95, PhaseErr95, EVMPeak, EVMRMS, magnErrorPeak,
                                   magnErrorRMS, phaseErrorPeak, phaseErrorRMS, originOffset, IQIm_balance, frequencyError,
                                   avgBurstPowerCurr, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT MODULATION EVMagnitude
 *    The subsystem MODulation:EVMagnitude measures the error vector magnitude
 *    as well as general scalar modulation parameters. The subsystem corresponds
 *    to the measurement menu Modulation, application EVM 8PSK, and the associated
 *    popup menu Modulation Error Config.
 * ----------------------------------------------------------------------------
 *      CONFIGURATION
 *          CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModEvmContRep (ViSession instrSession,
                                                                            ViInt32   repetition,
                                                                            ViInt32   stopCondition,
                                                                            ViInt32   stepMode,
                                                                            ViChar    errorMessage[])
{
  return RSCMU_ConfControlRep(instrSession, RSCMU_MODEVM, RSCMU_EPSK, repetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModEvmContDef (ViSession instrSession,
                                                                            ViInt32   defaultValues,
                                                                            ViChar    errorMessage[])
{
  return RSCMU_ConfContDef(instrSession, RSCMU_MODEVM, RSCMU_EPSK, defaultValues, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      LIMIT LINES
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Default limit Lines (ON/OFF)
/* Purpose : This function switches the default limit lines on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModEvmLimLineDef (ViSession instrSession,
                                                                               ViBoolean defaultLimitLines,
                                                                               ViChar    errorMessage[])
{
    return RSCMU_ConfModOempLimLineDef (instrSession, defaultLimitLines, errorMessage);
}

/*===========================================================================*/
/* Function: Upper Limit Lines
/* Purpose : This function defines upper limits for the Current, Max./Min and
/*           Average traces and for the scalar modulation parameters derived
/*           from them.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModEvmLimLineUpp (ViSession instrSession,
                                                                               ViInt32   Limits,
                                                                               ViReal64  EVMErrorPeak,
                                                                               ViReal64  EVMErrorRMS,
                                                                               ViReal64  magnErrorPeak,
                                                                               ViReal64  magnErrorRMS,
                                                                               ViReal64  phaseErrorPeak,
                                                                               ViReal64  phaseErrorRMS,
                                                                               ViReal64  originOffset,
                                                                               ViReal64  IQImBalance,
                                                                               ViInt32   frequencyError,
                                                                               ViChar    errorMessage[])
{
    return RSCMU_ConfModOempLimLineUpp (instrSession, Limits, EVMErrorPeak, EVMErrorRMS, magnErrorPeak, magnErrorRMS,
                                        phaseErrorPeak, phaseErrorRMS, originOffset, IQImBalance, frequencyError, errorMessage);
}

/*===========================================================================*/
/* Function: 95% Upper Limits
/* Purpose : This function defines upper limits for the 95 th percentile of
/*           the three quantities error vector magnitude, modulation error,
/*           and phase error. The 95 th percentile is the limit below which
/*           95% of the measured errors are located.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModEvmLimLine95 (ViSession instrSession,
                                                                              ViReal64  EVM95,
                                                                              ViReal64  modulationError95,
                                                                              ViReal64  phaseError95,
                                                                              ViChar    errorMessage[])
{
    return RSCMU_ConfModOempLimLine95 (instrSession, EVM95, modulationError95, phaseError95, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModEvmCont (ViSession instrSession,
                                                                         ViInt32   measuredValuesType,
                                                                         ViInt32   NbBurst,
                                                                         ViChar    errorMessage[])
{
  return RSCMU_ConfControl (instrSession, RSCMU_MODEVM, RSCMU_EPSK, measuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModEvmContRepSta (ViSession instrSession,
                                                                               ViInt32   NbRepetition,
                                                                               ViInt32   stopCondition,
                                                                               ViInt32   stepMode,
                                                                               ViChar    errorMessage[])
{
  return RSCMU_ConfContRepStat(instrSession, RSCMU_MODEVM, RSCMU_EPSK, NbRepetition, stopCondition, stepMode, errorMessage);
}

/* ----------------------------------------------------------------------------
 *      MEASUREMENT
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set power subranges
/* Purpose : This function configures the read, fetch and sample commands.
/*           It restricts the measurement to up to 32 subranges where either
/*           all measurement results or a single statistical value is returned
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSubModEvmRang (ViSession instrSession,
                                                                            ViInt32   Mode,
                                                                            ViReal64  startTime,
                                                                            ViInt32   NbSamples,
                                                                            ViChar    errorMessage[])
{
  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, startTime, 0, 146.75, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbSamples, 0, 588, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSubarrays (instrSession, RSCMU_MODEVM, RSCMU_EPSK, Mode, startTime, NbSamples, errorMessage);
}

/* ----------------------------------------------------------------------------
 *      CONTROL OF MODULATION MEAS
 *      It contains the functions for general control of the modulation
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_InitModEvm
/* Purpose : This function starts the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_InitModEvm (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_MODEVM, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_AborModEvm
/* Purpose : This function stopss the power measurement, setting it to
/*           the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_AborModEvm (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_MODEVM, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_StopModEvm
/* Purpose : This function stops the power measurement, setting it to
/*           the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_StopModEvm (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_MODEVM, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_ContModEvm
/* Purpose : This function continue the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ContModEvm (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_MODEVM, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_ConfModEvmErep
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModEvmErep (ViSession instrSession,
                                                                         ViInt32   Report,
                                                                         ViChar    errorMessage[])
{
  return RSCMU_ConfReporting (instrSession, RSCMU_MODEVM, RSCMU_EPSK, Report, errorMessage);
}

/*===========================================================================*/
/* Function: Modulation Measurement Status
/* Purpose : This function returns the status of the current Modulation
/*           Overview measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcModEvmStat (ViSession instrSession,
                                                                         ViInt32  *measurementStatus,
                                                                         ViInt32  *CountingNo,
                                                                         ViInt32  *StatisticNo,
                                                                         ViChar    errorMessage[])
{
  return RSCMU_FetcStatus (instrSession, RSCMU_MODEVM, RSCMU_EPSK, measurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      Subsystem MODulation[:EVMagnitude]:EPSK[:RESult]
 *
 *      The subsystem MODulation:EVMagnitude:EPSK[:RESULT] measures and returns
 *      the modulation parameters and compares them with the tolerance values.
 *      The subsystem corresponds to the various output elements in the
 *      measurement menu MODulation, application EVM 8PSK.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4). The calculation of results in
/*           an average or peak measurement is described in chapter 3 (see
/*           calculation of statistical quantities). The symbol (x3) behind a
/*           value indicates that the list contains three results corresponding
/*           to the Current, the Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadModEvm (ViSession instrSession,
                                                                     ViInt32   StatisticsMode,
                                                                     ViReal64 *EVM95,
                                                                     ViReal64 *EVMPeak,
                                                                     ViReal64 *EVMRMS,
                                                                     ViReal64 *originOffset,
                                                                     ViReal64 *IQImBalance,
                                                                     ViReal64 *frequencyError,
                                                                     ViReal64 *avgBurstPowerCurr,
                                                                     ViReal64 *burstOutOfTol,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_MeasModEvm (instrSession, RSCMU_COMMAND_READ, StatisticsMode, EVM95, EVMPeak, EVMRMS, originOffset, IQImBalance,
                           frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function outputs all scalar measurement results (see chapter
 *           4). The calculation of results in an average or peak measurement
 *           is described in chapter 3 (see calculation of statistical
 *           quantities). The symbol (x3) behind a value indicates that the
 *           list contains three results corresponding to the Current, the
 *           Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcModEvm (ViSession instrSession,
                                                                     ViInt32   StatisticsMode,
                                                                     ViReal64 *EVM95,
                                                                     ViReal64 *EVMPeak,
                                                                     ViReal64 *EVMRMS,
                                                                     ViReal64 *originOffset,
                                                                     ViReal64 *IQImBalance,
                                                                     ViReal64 *frequencyError,
                                                                     ViReal64 *avgBurstPowerCurr,
                                                                     ViReal64 *burstOutOfTol,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_MeasModEvm (instrSession, RSCMU_COMMAND_FETC, StatisticsMode, EVM95, EVMPeak, EVMRMS, originOffset, IQImBalance,
                           frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
 *           measurement results (see chapter 4). The calculation of results in
 *           an average or peak measurement is described in chapter 3 (see
 *           calculation of statistical quantities). The symbol (x3) behind a
 *           value indicates that the list contains three results corresponding
 *           to the Current, the Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampModEvm (ViSession instrSession,
                                                                     ViInt32   StatisticsMode,
                                                                     ViReal64 *EVM95,
                                                                     ViReal64 *EVMPeak,
                                                                     ViReal64 *EVMRMS,
                                                                     ViReal64 *originOffset,
                                                                     ViReal64 *IQImBalance,
                                                                     ViReal64 *frequencyError,
                                                                     ViReal64 *avgBurstPowerCurr,
                                                                     ViReal64 *burstOutOfTol,
                                                                     ViChar    errorMessage[])
{
  return RSCMU_MeasModEvm (instrSession, RSCMU_COMMAND_SAMP, StatisticsMode, EVM95, EVMPeak, EVMRMS, originOffset, IQImBalance,
                           frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_CalcModEvmLimMatc (ViSession instrSession,
                                                                            ViInt32   StatisticsMode,
                                                                            ViInt32  *EVM95,
                                                                            ViInt32  *phaseErrorPeak,
                                                                            ViInt32  *phaseErrorRMS,
                                                                            ViInt32  *originOffset,
                                                                            ViInt32  *IQImBalance,
                                                                            ViInt32  *frequencyError,
                                                                            ViChar    errorMessage[])
{
  return RSCMU_CalcModEvmLimMatc (instrSession, StatisticsMode, EVM95, phaseErrorPeak, phaseErrorRMS, originOffset,
                                  IQImBalance, frequencyError, errorMessage);
}

/*===========================================================================*/
/* Function: Read Phase Error in Burst...
/* Purpose : This function returns the error vector magnitude vs. time at fixed,
/*           equidistant test points. The number of measured values is 588,
/*           corresponding to a time range of 0 Bit to 146  Bit.
/*           The calculation of current, average, and mmax (Min./Max.) results
/*           is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadArrModEvm (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  EVMValues[],
                                                                        ViChar    errorMessage[])
{
  return RSCMU_MeasArrModEvm (instrSession, RSCMU_COMMAND_READ, Mode, EVMValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Phase Error in Burst...
/* Purpose : This function returns the error vector magnitude vs. time at fixed,
/*           equidistant test points. The number of measured values is 588,
/*           corresponding to a time range of 0 Bit to 146  Bit.
/*           The calculation of current, average, and mmax (Min./Max.) results
/*           is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcArrModEvm (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  EVMValues[],
                                                                        ViChar    errorMessage[])
{
  return RSCMU_MeasArrModEvm (instrSession, RSCMU_COMMAND_FETC, Mode, EVMValues, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Phase Error in Burst...
/* Purpose : This function returns the error vector magnitude vs. time at fixed,
/*           equidistant test points. The number of measured values is 588,
/*           corresponding to a time range of 0 Bit to 146  Bit.
/*           The calculation of current, average, and mmax (Min./Max.) results
/*           is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampArrModEvm (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  EVMValues[],
                                                                        ViChar    errorMessage[])
{
  return RSCMU_MeasArrModEvm (instrSession, RSCMU_COMMAND_SAMP, Mode, EVMValues, errorMessage);
}

/*===========================================================================*/
/* Function: Read Subarray
/* Purpose : this function measures and returns the error vector magnitude
/*           versus time in the subranges defined by means of the CONFigure:
/*           SUBarrays:MODulation:EVMagnitude:EPSK[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadSubArrModEvm (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViReal64  EVMValues[],
                                                                           ViChar    errorMessage[])
{
  return RSCMU_MeasSubArrModEvm (instrSession, RSCMU_COMMAND_READ, Mode, EVMValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Subarray
/* Purpose : this function measures and returns the error vector magnitude
/*           versus time in the subranges defined by means of the CONFigure:
/*           SUBarrays:MODulation:EVMagnitude:EPSK[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcSubArrModEvm (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViReal64  EVMValues[],
                                                                           ViChar    errorMessage[])
{
  return RSCMU_MeasSubArrModEvm (instrSession, RSCMU_COMMAND_FETC, Mode, EVMValues, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Subarray
/* Purpose : this function measures and returns the error vector magnitude
/*           versus time in the subranges defined by means of the CONFigure:
/*           SUBarrays:MODulation:EVMagnitude:EPSK[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampSubArrModEvm (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViReal64  EVMValues[],
                                                                           ViChar    errorMessage[])
{
  return RSCMU_MeasSubArrModEvm (instrSession, RSCMU_COMMAND_SAMP, Mode, EVMValues, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT MODULATION PERRor
 *    The subsystem MODulation:PERRor measures the phase error as well as
 *    general scalar modulation parameters. The subsystem corresponds to the
 *    measurement menu Modulation, application Phase Error 8PSK, and the
 *    associated popup menu Modulation Error Config.
 * ----------------------------------------------------------------------------
 *      CONFIGURATION
 *          CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModPerrContRep (ViSession instrSession,
                                                                             ViInt32   repetition,
                                                                             ViInt32   stopCondition,
                                                                             ViInt32   stepMode,
                                                                             ViChar    errorMessage[])
{
  return RSCMU_ConfControlRep(instrSession, RSCMU_MODPERR, RSCMU_EPSK, repetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModPerrContDef (ViSession instrSession,
                                                                             ViInt32   defaultValues,
                                                                             ViChar    errorMessage[])
{
  return RSCMU_ConfContDef(instrSession, RSCMU_MODPERR, RSCMU_EPSK, defaultValues, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      LIMIT LINES
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Default limit Lines (ON/OFF)
/* Purpose : This function switches the default limit lines on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModPerrLimLineDef (ViSession instrSession,
                                                                                ViBoolean defaultLimitLines,
                                                                                ViChar    errorMessage[])
{
    return RSCMU_ConfModOempLimLineDef (instrSession, defaultLimitLines, errorMessage);
}

/*===========================================================================*/
/* Function: Upper Limit Lines
/* Purpose : This function defines upper limits for the Current, Max./Min and
/*           Average traces and for the scalar modulation parameters derived
/*           from them.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModPerrLimLineUpp (ViSession instrSession,
                                                                                ViInt32   Limits,
                                                                                ViReal64  EVMErrorPeak,
                                                                                ViReal64  EVMErrorRMS,
                                                                                ViReal64  magnErrorPeak,
                                                                                ViReal64  magnErrorRMS,
                                                                                ViReal64  phaseErrorPeak,
                                                                                ViReal64  phaseErrorRMS,
                                                                                ViReal64  originOffset,
                                                                                ViReal64  IQImBalance,
                                                                                ViInt32   frequencyError,
                                                                                ViChar    errorMessage[])
{
    return RSCMU_ConfModOempLimLineUpp (instrSession, Limits, EVMErrorPeak, EVMErrorRMS, magnErrorPeak, magnErrorRMS,
                                        phaseErrorPeak, phaseErrorRMS, originOffset, IQImBalance, frequencyError, errorMessage);
}

/*===========================================================================*/
/* Function: 95% Upper Limits
/* Purpose : This function defines upper limits for the 95 th percentile of
/*           the three quantities error vector magnitude, modulation error,
/*           and phase error. The 95 th percentile is the limit below which
/*           95% of the measured errors are located.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModPerrLimLine95 (ViSession instrSession,
                                                                               ViReal64  EVM95,
                                                                               ViReal64  modulationError95,
                                                                               ViReal64  phaseError95,
                                                                               ViChar    errorMessage[])
{
    return RSCMU_ConfModOempLimLine95 (instrSession, EVM95, modulationError95, phaseError95, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModPerrCont (ViSession instrSession,
                                                                          ViInt32   measuredValuesType,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    errorMessage[])
{
  return RSCMU_ConfControl (instrSession, RSCMU_MODPERR, RSCMU_EPSK, measuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModPerrContRepSta (ViSession instrSession,
                                                                                ViInt32   NbRepetition,
                                                                                ViInt32   stopCondition,
                                                                                ViInt32   stepMode,
                                                                                ViChar    errorMessage[])
{
  return RSCMU_ConfContRepStat(instrSession, RSCMU_MODPERR, RSCMU_EPSK, NbRepetition, stopCondition, stepMode, errorMessage);
}

/* ----------------------------------------------------------------------------
 *      MEASUREMENT
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set power subranges
/* Purpose : This function configures the read, fetch and sample commands.
/*           It restricts the measurement to up to 32 subranges where either
/*           all measurement results or a single statistical value is returned
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSubModPerrRang (ViSession instrSession,
                                                                             ViInt32   Mode,
                                                                             ViReal64  startTime,
                                                                             ViInt32   NbSamples,
                                                                             ViChar    errorMessage[])
{
  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, startTime, 0, 146.75, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbSamples, 0, 588, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSubarrays (instrSession, RSCMU_MODPERR, RSCMU_EPSK, Mode, startTime, NbSamples, errorMessage);
}

/* ----------------------------------------------------------------------------
 *      CONTROL OF MODULATION MEAS
 *      It contains the functions for general control of the modulation
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_InitModMerr
/* Purpose : This function starts the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_InitModPerr (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_MODPERR, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_AborModMerr
/* Purpose : This function stopss the power measurement, setting it to
/*           the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_AborModPerr (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_MODPERR, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_StopModMerr
/* Purpose : This function stops the power measurement, setting it to
/*           the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_StopModPerr (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_MODPERR, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_ContModMerr
/* Purpose : This function continue the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ContModPerr (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_MODPERR, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_ConfModMerrErep
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModPerrErep (ViSession instrSession,
                                                                          ViInt32   Report,
                                                                          ViChar    errorMessage[])
{
  return RSCMU_ConfReporting (instrSession, RSCMU_MODPERR, RSCMU_EPSK, Report, errorMessage);
}

/*===========================================================================*/
/* Function: Modulation Measurement Status
/* Purpose : This function returns the status of the current Modulation
/*           Overview measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcModPerrStat (ViSession instrSession,
                                                                          ViInt32  *measurementStatus,
                                                                          ViInt32  *CountingNo,
                                                                          ViInt32  *StatisticNo,
                                                                          ViChar    errorMessage[])
{
  return RSCMU_FetcStatus (instrSession, RSCMU_MODPERR, RSCMU_EPSK, measurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      Subsystem MODulation:PERRor:EPSK[:RESult]
 *
 *      The subsystem MODulation:PERRor:EPSK[:RESULT] measures and returns
 *      the modulation parameters and compares them with the tolerance values.
 *      The subsystem corresponds to the various output elements in the
 *      measurement menu MODulation, application Phase Error 8PSK.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadModPerr (ViSession instrSession,
                                                                      ViInt32   StatisticsMode,
                                                                      ViReal64 *PhaseError95,
                                                                      ViReal64 *phaseErrorPeak,
                                                                      ViReal64 *phaseErrorRMS,
                                                                      ViReal64 *originOffset,
                                                                      ViReal64 *IQImBalance,
                                                                      ViReal64 *frequencyError,
                                                                      ViReal64 *avgBurstPowerCurr,
                                                                      ViReal64 *burstOutOfTol,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_EDGE_MeasModPerr (instrSession, RSCMU_COMMAND_READ, StatisticsMode, PhaseError95, phaseErrorPeak, phaseErrorRMS,
                                 originOffset, IQImBalance, frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcModPerr (ViSession instrSession,
                                                                      ViInt32   StatisticsMode,
                                                                      ViReal64 *PhaseError95,
                                                                      ViReal64 *phaseErrorPeak,
                                                                      ViReal64 *phaseErrorRMS,
                                                                      ViReal64 *originOffset,
                                                                      ViReal64 *IQImBalance,
                                                                      ViReal64 *frequencyError,
                                                                      ViReal64 *avgBurstPowerCurr,
                                                                      ViReal64 *burstOutOfTol,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_EDGE_MeasModPerr (instrSession, RSCMU_COMMAND_FETC, StatisticsMode, PhaseError95, phaseErrorPeak, phaseErrorRMS,
                                 originOffset, IQImBalance, frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampModPerr (ViSession instrSession,
                                                                      ViInt32   StatisticsMode,
                                                                      ViReal64 *PhaseError95,
                                                                      ViReal64 *phaseErrorPeak,
                                                                      ViReal64 *phaseErrorRMS,
                                                                      ViReal64 *originOffset,
                                                                      ViReal64 *IQImBalance,
                                                                      ViReal64 *frequencyError,
                                                                      ViReal64 *avgBurstPowerCurr,
                                                                      ViReal64 *burstOutOfTol,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_EDGE_MeasModPerr (instrSession, RSCMU_COMMAND_SAMP, StatisticsMode, PhaseError95, phaseErrorPeak, phaseErrorRMS,
                                 originOffset, IQImBalance, frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_CalcModPerrLimMatc (ViSession instrSession,
                                                                             ViInt32   StatisticsMode,
                                                                             ViInt32  *PhaseError95,
                                                                             ViInt32  *phaseErrorPeak,
                                                                             ViInt32  *phaseErrorRMS,
                                                                             ViInt32  *originOffset,
                                                                             ViInt32  *IQImBalance,
                                                                             ViInt32  *frequencyError,
                                                                             ViChar    errorMessage[])
{
  return RSCMU_EDGE_CalcModPerrLimMatc (instrSession, StatisticsMode, PhaseError95, phaseErrorPeak, phaseErrorRMS,
                                        originOffset, IQImBalance, frequencyError, errorMessage);
}

/*===========================================================================*/
/* Function: Read Phase Error in Burst...
/* Purpose : This function returns the the phase error vs. time at fixed,
/*           equidistant test points. The number of measured values is 588,
/*           corresponding to a time range of 0 Bit to 146  Bit.
/*           The calculation of current, average, and mmax (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadArrModPerr (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  phaseErrorValues[],
                                                                         ViChar    errorMessage[])
{
  return RSCMU_EDGE_MeasArrModPerr (instrSession, RSCMU_COMMAND_READ, Mode, phaseErrorValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Phase Error in Burst...
/* Purpose : This function returns the the phase error vs. time at fixed,
/*           equidistant test points. The number of measured values is 588,
/*           corresponding to a time range of 0 Bit to 146  Bit.
/*           The calculation of current, average, and mmax (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcArrModPerr (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  phaseErrorValues[],
                                                                         ViChar    errorMessage[])
{
  return RSCMU_EDGE_MeasArrModPerr (instrSession, RSCMU_COMMAND_FETC, Mode, phaseErrorValues, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Phase Error in Burst...
/* Purpose : This function returns the the phase error vs. time at fixed,
/*           equidistant test points. The number of measured values is 588,
/*           corresponding to a time range of 0 Bit to 146  Bit.
/*           The calculation of current, average, and mmax (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampArrModPerr (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  phaseErrorValues[],
                                                                         ViChar    errorMessage[])
{
  return RSCMU_EDGE_MeasArrModPerr (instrSession, RSCMU_COMMAND_SAMP, Mode, phaseErrorValues, errorMessage);
}

/*===========================================================================*/
/* Function: Read Subarray
/* Purpose : this function measures and returns the phase error versus time in
/*           the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:PERRor:EPSK command. V2.15
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadSubArrModPerr (ViSession instrSession,
                                                                            ViInt32   Mode,
                                                                            ViReal64  PhaseErrorValues[],
                                                                            ViChar    errorMessage[])
{
  return RSCMU_EDGE_MeasSubArrModPerr (instrSession, RSCMU_COMMAND_READ, Mode, PhaseErrorValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Subarray
/* Purpose : this function measures and returns the phase error versus time in
/*           the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:PERRor:EPSK command. V2.15
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcSubArrModPerr (ViSession instrSession,
                                                                            ViInt32   Mode,
                                                                            ViReal64  PhaseErrorValues[],
                                                                            ViChar    errorMessage[])
{
  return RSCMU_EDGE_MeasSubArrModPerr (instrSession, RSCMU_COMMAND_FETC, Mode, PhaseErrorValues, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Subarray
/* Purpose : this function measures and returns the phase error versus time in
/*           the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:PERRor:EPSK command. V2.15
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampSubArrModPerr (ViSession instrSession,
                                                                            ViInt32   Mode,
                                                                            ViReal64  PhaseErrorValues[],
                                                                            ViChar    errorMessage[])
{
  return RSCMU_EDGE_MeasSubArrModPerr (instrSession, RSCMU_COMMAND_SAMP, Mode, PhaseErrorValues, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT MODULATION MERRor
 *    The subsystem MODulation:MERRor measures the magnitude error as well as
 *    general scalar modulation parameters. The subsystem corresponds to the
 *    measurement menu Modulation, application Magn. Error 8PSK, and the
 *    associated popup menu Modulation Error Config.
 * ----------------------------------------------------------------------------
 *      CONFIGURATION
 *          CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModMerrContRep (ViSession instrSession,
                                                                             ViInt32   repetition,
                                                                             ViInt32   stopCondition,
                                                                             ViInt32   stepMode,
                                                                             ViChar    errorMessage[])
{
  return RSCMU_ConfControlRep(instrSession, RSCMU_MODMERR, RSCMU_EPSK, repetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModMerrContDef (ViSession instrSession,
                                                                             ViInt32   defaultValues,
                                                                             ViChar    errorMessage[])
{
  return RSCMU_ConfContDef(instrSession, RSCMU_MODMERR, RSCMU_EPSK, defaultValues, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      LIMIT LINES
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Default limit Lines (ON/OFF)
/* Purpose : This function switches the default limit lines on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModMerrLimLineDef (ViSession instrSession,
                                                                                ViBoolean defaultLimitLines,
                                                                                ViChar    errorMessage[])
{
    return RSCMU_ConfModOempLimLineDef (instrSession, defaultLimitLines, errorMessage);
}

/*===========================================================================*/
/* Function: Upper Limit Lines
/* Purpose : This function defines upper limits for the Current, Max./Min and
/*           Average traces and for the scalar modulation parameters derived
/*           from them.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModMerrLimLineUpp (ViSession instrSession,
                                                                                ViInt32   Limits,
                                                                                ViReal64  EVMErrorPeak,
                                                                                ViReal64  EVMErrorRMS,
                                                                                ViReal64  magnErrorPeak,
                                                                                ViReal64  magnErrorRMS,
                                                                                ViReal64  phaseErrorPeak,
                                                                                ViReal64  phaseErrorRMS,
                                                                                ViReal64  originOffset,
                                                                                ViReal64  IQImBalance,
                                                                                ViInt32   frequencyError,
                                                                                ViChar    errorMessage[])
{
    return RSCMU_ConfModOempLimLineUpp (instrSession, Limits, EVMErrorPeak, EVMErrorRMS, magnErrorPeak, magnErrorRMS,
                                        phaseErrorPeak, phaseErrorRMS, originOffset, IQImBalance, frequencyError, errorMessage);
}

/*===========================================================================*/
/* Function: 95% Upper Limits
/* Purpose : This function defines upper limits for the 95 th percentile of
/*           the three quantities error vector magnitude, modulation error,
/*           and phase error. The 95 th percentile is the limit below which
/*           95% of the measured errors are located.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModMerrLimLine95 (ViSession instrSession,
                                                                               ViReal64  EVM95,
                                                                               ViReal64  modulationError95,
                                                                               ViReal64  phaseError95,
                                                                               ViChar    errorMessage[])
{
    return RSCMU_ConfModOempLimLine95 (instrSession, EVM95, modulationError95, phaseError95, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModMerrCont (ViSession instrSession,
                                                                          ViInt32   measuredValuesType,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    errorMessage[])
{
  return RSCMU_ConfControl (instrSession, RSCMU_MODMERR, RSCMU_EPSK, measuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModMerrContRepSta (ViSession instrSession,
                                                                                ViInt32   NbRepetition,
                                                                                ViInt32   stopCondition,
                                                                                ViInt32   stepMode,
                                                                                ViChar    errorMessage[])
{
  return RSCMU_ConfContRepStat(instrSession, RSCMU_MODMERR, RSCMU_EPSK, NbRepetition, stopCondition, stepMode, errorMessage);
}

/* ----------------------------------------------------------------------------
 *      MEASUREMENT
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set power subranges
/* Purpose : This function configures the read, fetch and sample commands.
/*           It restricts the measurement to up to 32 subranges where either
/*           all measurement results or a single statistical value is returned
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSubModMerrRang (ViSession instrSession,
                                                                             ViInt32   Mode,
                                                                             ViReal64  startTime,
                                                                             ViInt32   NbSamples,
                                                                             ViChar    errorMessage[])
{
  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, startTime, 0, 146.75, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbSamples, 0, 588, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSubarrays (instrSession, RSCMU_MODMERR, RSCMU_EPSK, Mode, startTime, NbSamples, errorMessage);
}

/* ----------------------------------------------------------------------------
 *      CONTROL OF MODULATION MEAS
 *      It contains the functions for general control of the modulation
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_InitModMerr
/* Purpose : This function starts the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_InitModMerr (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_MODMERR, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_AborModMerr
/* Purpose : This function stopss the power measurement, setting it to
/*           the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_AborModMerr (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_MODMERR, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_StopModMerr
/* Purpose : This function stops the power measurement, setting it to
/*           the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_StopModMerr (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_MODMERR, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_ContModMerr
/* Purpose : This function continue the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ContModMerr (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_MODMERR, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_ConfModMerrErep
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModMerrErep (ViSession instrSession,
                                                                          ViInt32   Report,
                                                                          ViChar    errorMessage[])
{
  return RSCMU_ConfReporting (instrSession, RSCMU_MODMERR, RSCMU_EPSK, Report, errorMessage);
}

/*===========================================================================*/
/* Function: Modulation Measurement Status
/* Purpose : This function returns the status of the current Modulation
/*           Overview measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcModMerrStat (ViSession instrSession,
                                                                          ViInt32  *measurementStatus,
                                                                          ViInt32  *CountingNo,
                                                                          ViInt32  *StatisticNo,
                                                                          ViChar    errorMessage[])
{
  return RSCMU_FetcStatus (instrSession, RSCMU_MODMERR, RSCMU_EPSK, measurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      Subsystem MODulation:MERRor:EPSK[:RESult]
 *
 *      The subsystem MODulation:MERRor:EPSK[:RESULT] measures and returns the
 *      modulation parameters and compares them with the tolerance values.
 *      The subsystem corresponds to the various output elements in the
 *      measurement menu MODulation, application Magn. Error 8PSK.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadModMerr (ViSession instrSession,
                                                                      ViInt32   StatisticsMode,
                                                                      ViReal64 *MagnError95,
                                                                      ViReal64 *MagnErrorPeak,
                                                                      ViReal64 *MagnErrorRMS,
                                                                      ViReal64 *originOffset,
                                                                      ViReal64 *IQImBalance,
                                                                      ViReal64 *frequencyError,
                                                                      ViReal64 *avgBurstPowerCurr,
                                                                      ViReal64 *burstOutOfTol,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_MeasModMerr (instrSession, RSCMU_COMMAND_READ, StatisticsMode, MagnError95, MagnErrorPeak, MagnErrorRMS,
                            originOffset, IQImBalance, frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcModMerr (ViSession instrSession,
                                                                      ViInt32   StatisticsMode,
                                                                      ViReal64 *MagnError95,
                                                                      ViReal64 *MagnErrorPeak,
                                                                      ViReal64 *MagnErrorRMS,
                                                                      ViReal64 *originOffset,
                                                                      ViReal64 *IQImBalance,
                                                                      ViReal64 *frequencyError,
                                                                      ViReal64 *avgBurstPowerCurr,
                                                                      ViReal64 *burstOutOfTol,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_MeasModMerr (instrSession, RSCMU_COMMAND_FETC, StatisticsMode, MagnError95, MagnErrorPeak, MagnErrorRMS,
                            originOffset, IQImBalance, frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampModMerr (ViSession instrSession,
                                                                      ViInt32   StatisticsMode,
                                                                      ViReal64 *MagnError95,
                                                                      ViReal64 *MagnErrorPeak,
                                                                      ViReal64 *MagnErrorRMS,
                                                                      ViReal64 *originOffset,
                                                                      ViReal64 *IQImBalance,
                                                                      ViReal64 *frequencyError,
                                                                      ViReal64 *avgBurstPowerCurr,
                                                                      ViReal64 *burstOutOfTol,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_MeasModMerr (instrSession, RSCMU_COMMAND_SAMP, StatisticsMode, MagnError95, MagnErrorPeak, MagnErrorRMS,
                            originOffset, IQImBalance, frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_CalcModMerrLimMatc (ViSession instrSession,
                                                                             ViInt32   StatisticsMode,
                                                                             ViInt32  *MagnError95,
                                                                             ViInt32  *MagnErrorPeak,
                                                                             ViInt32  *MagnErrorRMS,
                                                                             ViInt32  *originOffset,
                                                                             ViInt32  *IQImBalance,
                                                                             ViInt32  *frequencyError,
                                                                             ViChar    errorMessage[])
{
  return RSCMU_CalcModMerrLimMatc (instrSession, StatisticsMode, MagnError95, MagnErrorPeak, MagnErrorRMS, originOffset,
                                   IQImBalance, frequencyError, errorMessage);
}

/*===========================================================================*/
/* Function: Read Phase Error in Burst...
/* Purpose : This function returns the the phase error vs. time at fixed,
/*           equidistant test points. The number of measured values is 588,
/*           corresponding to a time range of 0 Bit to 146  Bit.
/*           The calculation of current, average, and mmax (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadArrModMerr (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  MagnErrorValues[],
                                                                         ViChar    errorMessage[])
{
  return RSCMU_MeasArrModMerr (instrSession, RSCMU_COMMAND_READ, Mode, MagnErrorValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Phase Error in Burst...
/* Purpose : This function returns the the phase error vs. time at fixed,
/*           equidistant test points. The number of measured values is 588,
/*           corresponding to a time range of 0 Bit to 146  Bit.
/*           The calculation of current, average, and mmax (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcArrModMerr (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  MagnErrorValues[],
                                                                         ViChar    errorMessage[])
{
  return RSCMU_MeasArrModMerr (instrSession, RSCMU_COMMAND_FETC, Mode, MagnErrorValues, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Phase Error in Burst...
/* Purpose : This function returns the the phase error vs. time at fixed,
/*           equidistant test points. The number of measured values is 588,
/*           corresponding to a time range of 0 Bit to 146  Bit.
/*           The calculation of current, average, and mmax (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampArrModMerr (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  MagnErrorValues[],
                                                                         ViChar    errorMessage[])
{
  return RSCMU_MeasArrModMerr (instrSession, RSCMU_COMMAND_SAMP, Mode, MagnErrorValues, errorMessage);
}

/*===========================================================================*/
/* Function: Read Subarray
/* Purpose : this function measures and returns the phase error versus time in
/*           the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:MERRor:EPSK command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadSubArrModMerr (ViSession instrSession,
                                                                            ViInt32   Mode,
                                                                            ViReal64  MagnErrorValues[],
                                                                            ViChar    errorMessage[])
{
  return RSCMU_MeasSubArrModMerr (instrSession, RSCMU_COMMAND_READ, Mode, MagnErrorValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Subarray
/* Purpose : this function measures and returns the phase error versus time in
/*           the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:MERRor:EPSK command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcSubArrModMerr (ViSession instrSession,
                                                                            ViInt32   Mode,
                                                                            ViReal64  MagnErrorValues[],
                                                                            ViChar    errorMessage[])
{
  return RSCMU_MeasSubArrModMerr (instrSession, RSCMU_COMMAND_FETC, Mode, MagnErrorValues, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Subarray
/* Purpose : this function measures and returns the phase error versus time in
/*           the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:MERRor:EPSK command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampSubArrModMerr (ViSession instrSession,
                                                                            ViInt32   Mode,
                                                                            ViReal64  MagnErrorValues[],
                                                                            ViChar    errorMessage[])
{
  return RSCMU_MeasSubArrModMerr (instrSession, RSCMU_COMMAND_SAMP, Mode, MagnErrorValues, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT SPECTRUM/SWITCHING
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecSwitContDef (ViSession instrSession,
                                                                              ViInt32   DefaultValues,
                                                                              ViChar    errorMessage[])
{
  return RSCMU_ConfContDef(instrSession, RSCMU_SPECSWIT, RSCMU_EPSK, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecSwitContRep (ViSession  instrSession,
                                                                               ViInt32    Repetition,
                                                                               ViInt32    StopCondition,
                                                                               ViInt32    StepMode,
                                                                               ViChar     errorMessage[])
{
  return RSCMU_ConfControlRep(instrSession, RSCMU_SPECSWIT, RSCMU_EPSK, Repetition, StopCondition, StepMode, errorMessage);
}


/*===========================================================================*/
/* Function: continuous statistical mode
/* Purpose : This function defines the continuous statistical mode for the
/*           Spectrum due to Switching measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SpecSwitContStatMod (ViSession instrSession,
                                                       ViInt32 continuousStatisticalMode,
                                                       ViChar errorMessage[])
{
    return RSCMU_ConfSpecSwitContStatMod (instrSession, RSCMU_EPSK, continuousStatisticalMode, errorMessage);
}

/*===========================================================================*/
/* Function: Slot Count
/* Purpose : This function defines whether a single timeslot or all timeslots
/*           are considered for the Spectrum due to Switching measurement..
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SpecSwitSlotCount (ViSession instrSession,
                                                     ViInt32 slotCount,
                                                     ViChar errorMessage[])
{
    return RSCMU_ConfSpecSwitSlotCount (instrSession, RSCMU_EPSK, slotCount, errorMessage);
}

/*===========================================================================*/
/* Function: Set Grid (ON/OFF)
/* Purpose : This function switches the grid lines in the test diagrams on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_DispSpecSwitContGrid (ViSession instrSession,
                                                                               ViInt32   gridLines,
                                                                               ViChar    errorMessage[])
{
  return RSCMU_DisplayGrid (instrSession, RSCMU_SPECSWIT, RSCMU_EPSK, gridLines, errorMessage);
}

/*===========================================================================*/
/* Function: Default Limit Lines
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecSwitLimLinDef (ViSession instrSession,
                                                                                 ViInt32   DefaultValues,
                                                                                 ViChar    errorMessage[])
{
  return RSCMU_ConfLimLineDef (instrSession, RSCMU_SPECSWIT, RSCMU_EPSK, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines
/* Purpose : These commands activate and define limit lines for the spectrum
/*           due to switching measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecSwitLimLine (ViSession instrSession,
                                                                               ViInt32   PowerLevel,
                                                                               ViReal64  power,
                                                                               ViInt32   enable,
                                                                               ViReal64  value1,
                                                                               ViReal64  value2,
                                                                               ViReal64  value3,
                                                                               ViReal64  value4,
                                                                               ViChar    errorMessage[])
{
  return RSCMU_ConfSpecSwitLimLine (instrSession, RSCMU_EPSK, PowerLevel, power, enable, value1, value2, value3, value4, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines On/Off
/* Purpose : This function switches the limit checking for all measurepoints.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecSwitLimLinMod (ViSession instrSession,
                                                                                 ViInt32   limitLines,
                                                                                 ViChar    errorMessage[])
{
  return RSCMU_ConfSpecSwitLimLineMod(instrSession, RSCMU_EPSK, limitLines, errorMessage);
}

/*===========================================================================*/
/* Function: Statistic Count
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecSwitCont (ViSession instrSession,
                                                                            ViInt32   MeasuredValuesType,
                                                                            ViInt32   NbBurst,
                                                                            ViChar    errorMessage[])
{
  return RSCMU_ConfControl (instrSession, RSCMU_SPECSWIT, RSCMU_EPSK, MeasuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecSwitContRepSt (ViSession  instrSession,
                                                                                 ViInt32    NbRepetition,
                                                                                 ViInt32    StopCondition,
                                                                                 ViInt32    StepMode,
                                                                                 ViChar     errorMessage[])
{
  return RSCMU_ConfContRepStat(instrSession, RSCMU_SPECSWIT, RSCMU_EPSK, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Measure Points
/* Purpose : This function permits to select which frequencies a spectrum
/*           switching measurement is performed. A reduction of the
/*           measurement points enhances the measurement speed.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecSwitContMpo (ViSession  instrSession,
                                                                               ViInt32    MeasurePoint,
                                                                               ViInt32    Enable,
                                                                               ViChar     errorMessage[])
{
  return RSCMU_ConfSpecSwitContMpo (instrSession, RSCMU_EPSK, MeasurePoint, Enable, errorMessage);
}

/*===========================================================================*/
/* Function: Burst Power SubRanges
/* Purpose : This function configurates the READ..., FETCh... and
/*           SAMPle:SUBarray:SPECtrum:SWITching commands.
/*           If the requested number of results exceeds the measurement
/*           range, the count parameter will be corrected by the system.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSubSpecSwit (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViReal64  FirstMeasurementFreq,
                                                                          ViInt32   MeasureResultsNumber,
                                                                          ViChar    errorMessage[])
{
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, FirstMeasurementFreq, -1.8, 1.8, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, MeasureResultsNumber, 1, 9, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSubarrays (instrSession, RSCMU_SPECSWIT, RSCMU_EPSK, Mode, FirstMeasurementFreq, MeasureResultsNumber, errorMessage);
}

/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_InitSpecSwit (ViSession instrSession,
                                                                       ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_SPECSWIT, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : Abort measurement and switch off => OFF
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_AborSpecSwit (ViSession instrSession,
                                                                       ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_SPECSWIT, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : Stop measurement => STOP
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_StopSpecSwit (ViSession instrSession,
                                                                       ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_SPECSWIT, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : Next measurement step (only counting mode) => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ContSpecSwit (ViSession instrSession,
                                                                       ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_SPECSWIT, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: Spectrum Switching Measurement Status
/* Purpose : This function returns the status of the current Spectrum Switching
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcSpecSwitStat (ViSession  instrSession,
                                                                           ViInt32   *MeasurementStatus,
                                                                           ViInt32   *CountingNo,
                                                                           ViInt32   *StatisticNo,
                                                                           ViChar     errorMessage[])
{
  return RSCMU_FetcStatus (instrSession, RSCMU_SPECSWIT, RSCMU_EPSK, MeasurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*===========================================================================*/
/* Function: Event Reporting Mode
/* Purpose : This function defines the events to be reported during the
/*           measurement (event reporting, see chapter 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecSwitErep (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViChar    errorMessage[])
{
  return RSCMU_ConfReporting (instrSession, RSCMU_SPECSWIT, RSCMU_EPSK, Mode, errorMessage);
}

/*===========================================================================*/
/* Function: Read
/* Purpose : This function starts the measurement and outputs some results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadSpecSwit (ViSession  instrSession,
                                                                       ViReal64  *referencePower,
                                                                       ViInt32   *matching,
                                                                       ViChar     errorMessage[])
{
  return RSCMU_MeasSpecSwit (instrSession, RSCMU_COMMAND_READ, RSCMU_EPSK, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This function only outputs the results without any care of the
/*           measurement state.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcSpecSwit (ViSession  instrSession,
                                                                       ViReal64  *referencePower,
                                                                       ViInt32   *matching,
                                                                       ViChar     errorMessage[])
{
  return RSCMU_MeasSpecSwit (instrSession, RSCMU_COMMAND_FETC, RSCMU_EPSK, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This function waits until the results are valid for the first
/*           time (depending on the chosen statistic count) and then outputs
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampSpecSwit (ViSession  instrSession,
                                                                       ViReal64  *referencePower,
                                                                       ViInt32   *matching,
                                                                       ViChar     errorMessage[])
{
  return RSCMU_MeasSpecSwit (instrSession, RSCMU_COMMAND_SAMP, RSCMU_EPSK, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Read
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadArrSpecSwit (ViSession instrSession,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    errorMessage[])
{
  return RSCMU_MeasArrSpecSwit (instrSession, RSCMU_COMMAND_READ, RSCMU_EPSK, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcArrSpecSwit (ViSession instrSession,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    errorMessage[])
{
  return RSCMU_MeasArrSpecSwit (instrSession, RSCMU_COMMAND_FETC, RSCMU_EPSK, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampArrSpecSwit (ViSession instrSession,
                                                                          ViReal64  BurstPower[],
                                                                          ViChar    errorMessage[])
{
  return RSCMU_MeasArrSpecSwit (instrSession, RSCMU_COMMAND_SAMP, RSCMU_EPSK, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Read (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadSubArrSpecSwit (ViSession instrSession,
                                                                             ViReal64  BurstPower[],
                                                                             ViChar    errorMessage[])
{
  return RSCMU_MeasSubArrSpecSwit (instrSession, RSCMU_COMMAND_READ, RSCMU_EPSK, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcSubArrSpecSwit (ViSession instrSession,
                                                                             ViReal64  BurstPower[],
                                                                             ViChar    errorMessage[])
{
  return RSCMU_MeasSubArrSpecSwit (instrSession, RSCMU_COMMAND_FETC, RSCMU_EPSK, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampSubArrSpecSwit (ViSession instrSession,
                                                                             ViReal64  BurstPower[],
                                                                             ViChar    errorMessage[])
{
  return RSCMU_MeasSubArrSpecSwit (instrSession, RSCMU_COMMAND_SAMP, RSCMU_EPSK, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Configure Additional Measurepoints
/* Purpose : This function permits to configure the frequencies for two
/*           additional Measurepoints for spectrum switching measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecSwitConfAMP (ViSession instrSession,
                                                       ViInt32   enableMP1,
                                                       ViReal64  frequencyMP1,
                                                       ViInt32   enableMP2,
                                                       ViReal64  frequencyMP2,
                                                       ViChar    errorMessage[])
{
  return RSCMU_ConfSpecSwitAddMeaPoints (instrSession, RSCMU_EPSK, enableMP1, frequencyMP1, enableMP2, frequencyMP2, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch scalar results for Additional Measurepoints
/* Purpose : This function output the off-carrier power due to switching
/*           in the additional Measurepoints.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcSpecSwitAMP (ViSession instrSession,
                                                   ViReal64  *valueMP1Neg,
                                                   ViReal64  *valueMP1Pos,
                                                   ViReal64  *valueMP2Neg,
                                                   ViReal64  *valueMP2Pos,
                                                   ViChar    errorMessage[])
{
  return RSCMU_FetcSpecSwitAddMeaPoints (instrSession, RSCMU_EPSK, valueMP1Neg, valueMP1Pos, valueMP2Neg, valueMP2Pos, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT SPECTRUM/MODULATION
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecModContDef (ViSession instrSession,
                                                                             ViInt32   DefaultValues,
                                                                             ViChar    errorMessage[])
{
  return RSCMU_ConfContDef(instrSession, RSCMU_SPECMOD, RSCMU_EPSK, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecModContRep (ViSession  instrSession,
                                                                             ViInt32    Repetition,
                                                                             ViInt32    StopCondition,
                                                                             ViInt32    StepMode,
                                                                             ViChar     errorMessage[])
{
  return RSCMU_ConfControlRep(instrSession, RSCMU_SPECMOD, RSCMU_EPSK, Repetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Grid On/Off
/* Purpose : This function switches the grid lines in the test diagrams on or
/*           off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_DispSpecModContGrid (ViSession instrSession,
                                                                              ViInt32   gridLines,
                                                                              ViChar    errorMessage[])
{
  return RSCMU_DisplayGrid (instrSession, RSCMU_SPECMOD, RSCMU_EPSK, gridLines, errorMessage);
}

/*===========================================================================*/
/* Function: Default limit Lines
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecModLimLineDef (ViSession instrSession,
                                                                                ViInt32   DefaultValues,
                                                                                ViChar    errorMessage[])
{
  return RSCMU_ConfLimLineDef (instrSession, RSCMU_SPECMOD, RSCMU_EPSK, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Reference Power
/* Purpose : This function defines the MS carrier output power domain where
/*           the limit lines are to be determined by linear interpolation
/*           (see Table 1). Below Min. Power, the lower limit line applies,
/*           above Max. Power, the upper limit line applies.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecModLimLinRefp (ViSession instrSession,
                                                                                ViReal64  minPower,
                                                                                ViReal64  maxPower,
                                                                                ViChar    errorMessage[])
{
  return RSCMU_ConfSpecModLimLineRefp (instrSession, RSCMU_EPSK, minPower, maxPower, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines
/* Purpose : These commands activate and define limit lines for the spectrum
/*           due to modulation measurement.
/*           The limit lines for the spectrum due to modulation as specified
/*           in standard GSM 05.05 depend on the GSM band, the frequency, and
/*           (for frequencies that differ from the carrier frequency by more
/*           than 400 kHz) on the output power of the mobile station.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecModLimLine (ViSession instrSession,
                                                                             ViInt32   measurePoint,
                                                                             ViInt32   enable,
                                                                             ViReal64  minPower,
                                                                             ViReal64  maxPower,
                                                                             ViReal64  AbsLevel,
                                                                             ViChar    errorMessage[])
{
  return RSCMU_ConfSpecModLimLine (instrSession, RSCMU_EPSK, measurePoint, enable, minPower, maxPower, AbsLevel, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines On/Off
/* Purpose : This function switches the limit checking for all measurepoints.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecModLimLineMod (ViSession instrSession,
                                                                                ViInt32   limitLines,
                                                                                ViChar    errorMessage[])
{
  return RSCMU_ConfSpecModLimLineMod (instrSession, RSCMU_EPSK, limitLines, errorMessage);
}

/*===========================================================================*/
/* Function: Statistic Count
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecModCont (ViSession instrSession,
                                                                          ViInt32   MeasuredValuesType,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    errorMessage[])
{
  return RSCMU_ConfControl (instrSession, RSCMU_SPECMOD, RSCMU_EPSK, MeasuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecModContRepSta (ViSession  instrSession,
                                                                                ViInt32    NbRepetition,
                                                                                ViInt32    StopCondition,
                                                                                ViInt32    StepMode,
                                                                                ViChar     errorMessage[])
{
  return RSCMU_ConfContRepStat(instrSession, RSCMU_SPECMOD, RSCMU_EPSK, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Measure Points
/* Purpose : This function permits to select which frequencies a spectrum
/*           modulation measurement is performed. A reduction of the
/*           measurement points enhances the measurement speed.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecModContMpo (ViSession  instrSession,
                                                                             ViInt32    MeasurePoint,
                                                                             ViInt32    Enable,
                                                                             ViChar     errorMessage[])
{
  return RSCMU_ConfSpecModContMpo (instrSession, RSCMU_EPSK, MeasurePoint, Enable, errorMessage);
}

/*===========================================================================*/
/* Function: Burst Power SubRanges
/* Purpose : This function configurates the READ..., FETCh... and
/*           SAMPle:SUBArrays:MODulation:SWITching commands.
/*           If the requested number of results exceeds the measurement
/*           range, the count parameter will be corrected by the system.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSubSpecMod (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  FirstMeasurementFreq,
                                                                         ViInt32   MeasureResultsNumber,
                                                                         ViChar    errorMessage[])
{
  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, FirstMeasurementFreq, -1.8, 1.8, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, MeasureResultsNumber, 1, 23, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSubarrays (instrSession, RSCMU_SPECMOD, RSCMU_EPSK, Mode, FirstMeasurementFreq, MeasureResultsNumber, errorMessage);
}

/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_InitSpecMod (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_SPECMOD, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : Abort measurement and switch off => OFF
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_AborSpecMod (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_SPECMOD, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : Stop measurement => STOP
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_StopSpecMod (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_SPECMOD, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : Next measurement step (only counting mode) => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ContSpecMod (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_SPECMOD, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: Spectrum Modulation Measurement Status
/* Purpose : This function returns the status of the current Spectrum
/*           Modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcSpecModStat (ViSession  instrSession,
                                                                          ViInt32   *MeasurementStatus,
                                                                          ViInt32   *CountingNo,
                                                                          ViInt32   *StatisticNo,
                                                                          ViChar     errorMessage[])
{
  return RSCMU_FetcStatus (instrSession, RSCMU_SPECMOD, RSCMU_EPSK, MeasurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*===========================================================================*/
/* Function: Event Reporting Mode
/* Purpose : This function defines the events to be reported during the
/*           measurement (event reporting, see chapter 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecModErep (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViChar    errorMessage[])
{
  return RSCMU_ConfReporting (instrSession, RSCMU_SPECMOD, RSCMU_EPSK, Mode, errorMessage);
}

/*===========================================================================*/
/* Function: Start single shot measurement and return results
/* Purpose : This function starts a single shot measurement and returns the
/*           results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadSpecMod (ViSession  instrSession,
                                                                      ViReal64  *ReferencePower,
                                                                      ViInt32   *Matching,
                                                                      ViChar     errorMessage[])
{
  return RSCMU_MeasSpecMod (instrSession, RSCMU_COMMAND_READ, RSCMU_EPSK, ReferencePower, Matching, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This function only outputs the results without any care of the
/*           measurement state.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcSpecMod (ViSession  instrSession,
                                                                      ViReal64  *ReferencePower,
                                                                      ViInt32   *Matching,
                                                                      ViChar     errorMessage[])
{
  return RSCMU_MeasSpecMod (instrSession, RSCMU_COMMAND_FETC, RSCMU_EPSK, ReferencePower, Matching, errorMessage);
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This function waits until the results are valid for the first
/*           time (depending on the chosen statistic count) and then outputs
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampSpecMod (ViSession  instrSession,
                                                                      ViReal64  *ReferencePower,
                                                                      ViInt32   *Matching,
                                                                      ViChar     errorMessage[])
{
  return RSCMU_MeasSpecMod (instrSession, RSCMU_COMMAND_SAMP, RSCMU_EPSK, ReferencePower, Matching, errorMessage);
}


/*===========================================================================*/
/* Function: Read
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadArrSpecMod (ViSession instrSession,
                                                  ViReal64  BurstPower[],
                                                  ViChar    errorMessage[])
{
  RETMSG(RSCMU_MeasArray( instrSession, "READ:ARRay:SPECtrum:MODulation:EPSK"
                                     ,BurstPower, errorMessage));
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcArrSpecMod (ViSession instrSession,
                                                  ViReal64  BurstPower[],
                                                  ViChar    errorMessage[])
{
  RETMSG(RSCMU_MeasArray( instrSession, "FETCh:ARRay:SPECtrum:MODulation:EPSK"
                                     ,BurstPower, errorMessage));
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampArrSpecMod (ViSession instrSession,
                                                  ViReal64  BurstPower[],
                                                  ViChar    errorMessage[])
{
  RETMSG(RSCMU_MeasArray( instrSession, "SAMPle:ARRay:SPECtrum:MODulation:EPSK"
                                     ,BurstPower, errorMessage));
}


/*===========================================================================*/
/* Function: Read (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadSubArrSpecMod (ViSession instrSession,
                                                     ViReal64  BurstPower[],
                                                     ViChar    errorMessage[])
{
  RETMSG(RSCMU_MeasArray( instrSession, "READ:SUBarrays:SPECtrum:MODulation:EPSK"
                                        ,BurstPower, errorMessage));
}


/*===========================================================================*/
/* Function: Fetch (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcSubArrSpecMod (ViSession instrSession,
                                                     ViReal64  BurstPower[],
                                                     ViChar    errorMessage[])
{
  RETMSG(RSCMU_MeasArray( instrSession, "FETCh:SUBarrays:SPECtrum:MODulation:EPSK"
                                        ,BurstPower, errorMessage));
}

/*===========================================================================*/
/* Function: Sample (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampSubArrSpecMod (ViSession instrSession,
                                                     ViReal64  BurstPower[],
                                                     ViChar    errorMessage[])
{
  RETMSG(RSCMU_MeasArray( instrSession, "SAMPle:SUBarrays:SPECtrum:MODulation:EPSK"
                                        ,BurstPower, errorMessage));
}


/*****************************************************************************/
/*= EDGE SIGNALLING =========================================================*/
/*****************************************************************************/
/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT POWER/T
 *    This subsystem POWer contains the functions for measurement of
 *    the signal power.
 *    It corresponds to the measurement menu Power versus Time and the
 *    associated popup menu Power vs Time Configuration.
 * ----------------------------------------------------------------------------
 *      CONTROL OF POWER MEASUREMENT
 *      This subsystem contains the functions for general control of the
 *      power measurement.
 *-----------------------------------------------------------------------------
 */

/*===========================================================================*/
/* Function: StartMeasurements
/* Purpose : This function start measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_InitPow (ViSession instrSession,
                                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_POW, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: StartMeasurements
/* Purpose : This function start measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_AborPow (ViSession instrSession,
                                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_POW, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: StartMeasurements
/* Purpose : This function start measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_StopPow (ViSession instrSession,
                                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_POW, RSCMU_EPSK, errorMessage);
}
/*===========================================================================*/
/* Function: StartMeasurements
/* Purpose : This function start measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ContPow (ViSession instrSession,
                                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_POW, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowErep (ViSession  instrSession,
                                                                     ViInt32    Report,
                                                                     ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfReporting (instrSession, RSCMU_POW, RSCMU_EPSK, Report, errorMessage);
}

/*===========================================================================*/
/* Function: Power/t Measurement Status
/* Purpose : This function returns the status of the current Power/t
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcPowStat (ViSession  instrSession,
                                                                     ViInt32    *MeasurementStatus,
                                                                     ViInt32    *CountingNo,
                                                                     ViInt32    *StatisticNo,
                                                                     ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_FetcStatus (instrSession, RSCMU_POW, RSCMU_EPSK, MeasurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of Measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowCont (ViSession instrSession,
                                                                     ViInt32   MeasuredValuesType,
                                                                     ViInt32   NbBurst,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfControl (instrSession, RSCMU_POW, RSCMU_EPSK, MeasuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowContRep (ViSession  instrSession,
                                                                        ViInt32    Repetition,
                                                                        ViInt32    StopCondition,
                                                                        ViInt32    StepMode,
                                                                        ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfControlRep (instrSession, RSCMU_POW, RSCMU_EPSK, Repetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Reference Power Mode
/* Purpose : This function determines how the reference power (0-dB line in
/*           the P/t Norm. 8PSK test diagram) for 8PSK-modulated signals is
/*           calculated.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowRPMode (ViSession instrSession,
                                                                       ViInt32   Mode,
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_EDGE_NSig_ConfPowRPMode (instrSession, Mode, errorMessage);
}

/*===========================================================================*/
/* Function: Set Grid (ON/OFF)
/* Purpose : This function switches the grid lines in the test diagrams
/*           on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_DispPowContGrid (ViSession instrSession,
                                                                         ViInt32   gridLines,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) gridLines, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "DISP:POW:EPSK:CONT:GRID %s", mode_On_Off[gridLines]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set offset time
/* Purpose : This function defines an offset time by which the burst is shifted
/*           relative to the time axis and the tolerance template
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowTimeBoff (ViSession instrSession,
                                                                         ViReal64  Offset,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfPowTimeBoff(instrSession, RSCMU_EPSK, Offset, errorMessage);
}

/*===========================================================================*/
/* Function: Filter
/* Purpose : This function selects the measurement filter for the P/t
/*           measurement. The default filter setting differs for the two
/*           modulation schemes.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowFilt (ViSession instrSession,
                                                                     ViInt32   Filter,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfFilt(instrSession, RSCMU_POW, RSCMU_EPSK, Filter, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Statistics Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowContRepStat (ViSession  instrSession,
                                                                            ViInt32    NbRepetition,
                                                                            ViInt32    StopCondition,
                                                                            ViInt32    StepMode,
                                                                            ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfPowContRepStat(instrSession, RSCMU_EPSK, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      STATISTICS
 *      The functions of the following subsystems define the parameters
 *      of the signal power measurement. GSM signals are transferred in
 *      the form of bursts, which are divided up into different
 *      tolerance ranges according to the standard.
 *-----------------------------------------------------------------------------
 *        LIMIT LINES
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Default limit Lines (ON/OFF)
/* Purpose : This function switches the default limit lines on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowLimLineDef (ViSession  instrSession,
                                                                           ViInt32    DefaultLimitLines,
                                                                           ViChar     errorMessage[])
{

  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, DefaultLimitLines, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:POW:EPSK:LIM:LINE:DEF %s", mode_On_Off[DefaultLimitLines]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Upper limit Line
/* Purpose : This function activates and defines upper limit lines for normal
/*           bursts. The limit lines are defined section by section.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowLimLineUpp (ViSession instrSession,
                                                                           ViInt32   Area,
                                                                           ViInt32   StartTimeOnOff,
                                                                           ViReal64  StartTime,
                                                                           ViInt32   EndTimeOnOff,
                                                                           ViReal64  EndTime,
                                                                           ViInt32   StartRelLevOnOff,
                                                                           ViReal64  StartRelLev,
                                                                           ViInt32   EndRelLevOnOff,
                                                                           ViReal64  EndRelLev,
                                                                           ViInt32   StartAbsLevOnOff,
                                                                           ViReal64  StartAbsLev,
                                                                           ViInt32   EndAbsLevOnOff,
                                                                           ViReal64  EndAbsLev,
                                                                           ViInt32   Visibility,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_EDGE_NSig_ConfPowLimLineUpp (instrSession, Area, StartTimeOnOff, StartTime, EndTimeOnOff, EndTime,
    StartRelLevOnOff, StartRelLev, EndRelLevOnOff, EndRelLev, StartAbsLevOnOff, StartAbsLev, EndAbsLevOnOff, EndAbsLev, Visibility, errorMessage);
}

/*===========================================================================*/
/* Function: Upper limit Line
/* Purpose : This function activates and defines lower limit lines for normal
/*           bursts. The limit lines are defined section by section.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowLimLineLow (ViSession instrSession,
                                                                           ViInt32   Area,
                                                                           ViInt32   StartTimeOnOff,
                                                                           ViReal64  StartTime,
                                                                           ViInt32   EndTimeOnOff,
                                                                           ViReal64  EndTime,
                                                                           ViInt32   StartRelLevOnOff,
                                                                           ViReal64  StartRelLev,
                                                                           ViInt32   EndRelLevOnOff,
                                                                           ViReal64  EndRelLev,
                                                                           ViInt32   StartAbsLevOnOff,
                                                                           ViReal64  StartAbsLev,
                                                                           ViInt32   EndAbsLevOnOff,
                                                                           ViReal64  EndAbsLev,
                                                                           ViInt32   Visibility,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_EDGE_NSig_ConfPowLimLineLow (instrSession, Area, StartTimeOnOff, StartTime, EndTimeOnOff, EndTime,
    StartRelLevOnOff, StartRelLev, EndRelLevOnOff, EndRelLev, StartAbsLevOnOff, StartAbsLev, EndAbsLevOnOff, EndAbsLev, Visibility, errorMessage);
}

/*===========================================================================*/
/* Function: Dynamic Correction of Upper limit Line
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowLimLineUppDyn (ViSession instrSession,
                                                                              ViInt32   Area,
                                                                              ViInt32   TPCLRange,
                                                                              ViInt32   FromTPCLOnOff,
                                                                              ViInt32   FromTPCL,
                                                                              ViInt32   ToTPCLOnOff,
                                                                              ViInt32   ToTPCL,
                                                                              ViInt32   CorrectionOnOff,
                                                                              ViReal64  Correction,
                                                                              ViInt32   Enable,
                                                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfPowLimLineUppDyn (instrSession, RSCMU_EPSK, Area, TPCLRange, FromTPCLOnOff, FromTPCL, ToTPCLOnOff,
                                       ToTPCL, CorrectionOnOff, Correction, Enable, errorMessage);
}

/*===========================================================================*/
/* Function: Dynamic Correction of Lower limit Line
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowLimLineLowDyn (ViSession instrSession,
                                                                              ViInt32   Area,
                                                                              ViInt32   TPCLRange,
                                                                              ViInt32   FromTPCLOnOff,
                                                                              ViInt32   FromTPCL,
                                                                              ViInt32   ToTPCLOnOff,
                                                                              ViInt32   ToTPCL,
                                                                              ViInt32   CorrectionOnOff,
                                                                              ViReal64  Correction,
                                                                              ViInt32   Enable,
                                                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfPowLimLineLowDyn (instrSession, RSCMU_EPSK, Area, TPCLRange, FromTPCLOnOff, FromTPCL, ToTPCLOnOff,
                                       ToTPCL, CorrectionOnOff, Correction, Enable, errorMessage);
}

/*===========================================================================*/
/* Function: Dynamic Correction of Upper limit Line On/Off
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowLimUppDynMod (ViSession instrSession,
                                                                             ViInt32   area,
                                                                             ViInt32   enable,
                                                                             ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfPowLimUppDynMod (instrSession, RSCMU_EPSK, area, enable, errorMessage);
}

/*===========================================================================*/
/* Function: Dynamic Correction of Lower limit Line On/Off
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowLimLowDynMod (ViSession instrSession,
                                                                             ViInt32   area,
                                                                             ViInt32   enable,
                                                                             ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfPowLimLowDynMod (instrSession, RSCMU_EPSK, area, enable, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      MEASURED VALUES
 *      The functions of the following subsystems determine and output
 *      the results of the signal power measurement.
 *-----------------------------------------------------------------------------
 *        MEASUREMENT AND BURST POWER
 *        It contains the commands for measurement and output of the
 *        burst power and its comparison with tolerance values.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function starts a single shot power vs. time measurement
/*           and output all scalar measurement results. These are:
/*             Average power of current burst
/*             Peak power of current burst
/*             Power control level
/*             Timing advance error
/*             Bursts out of tolerance
/*             Burst template matching
/*             Average power of averaged trace
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadPow (ViSession  instrSession,
                                                                 ViReal64  *AvgBurstPwCurr,
                                                                 ViReal64  *PeakBurstPwCurr,
                                                                 ViInt32   *PowerControlLevel,
                                                                 ViReal64  *TimingAdvError,
                                                                 ViReal64  *BurstOutOfTol,
                                                                 ViInt32   *BurstMatching,
                                                                 ViReal64  *AvgBurstPwAvg,
                                                                 ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  if ((RSCMU_Status = RSCMU_Query (instrSession, "READ:POW:EPSK?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Scan the results of power:
  RSCMU_Status = RSCMU_Sig_ScanPow (TableOfDataValues, AvgBurstPwCurr, PeakBurstPwCurr, PowerControlLevel,
    TimingAdvError, BurstOutOfTol, BurstMatching, AvgBurstPwAvg);

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function starts a power vs. time measurement and output all
/*           scalar measurement results (unsynchronized). These are:
/*             Average power of current burst
/*             Peak power of current burst
/*             Power control level
/*             Timing advance error
/*             Bursts out of tolerance
/*             Burst template matching
/*             Average power of averaged trace
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcPow (ViSession  instrSession,
                                                                 ViReal64  *AvgBurstPwCurr,
                                                                 ViReal64  *PeakBurstPwCurr,
                                                                 ViInt32   *PowerControlLevel,
                                                                 ViReal64  *TimingAdvError,
                                                                 ViReal64  *BurstOutOfTol,
                                                                 ViInt32   *BurstMatching,
                                                                 ViReal64  *AvgBurstPwAvg,
                                                                 ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  if ((RSCMU_Status = RSCMU_Query (instrSession, "FETC:POW:EPSK?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Scan the results of power:
  RSCMU_Status = RSCMU_Sig_ScanPow (TableOfDataValues, AvgBurstPwCurr, PeakBurstPwCurr, PowerControlLevel,
    TimingAdvError, BurstOutOfTol, BurstMatching, AvgBurstPwAvg);

  return RSCMU_Status;

}
/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function starts a power vs. time measurement and output all
/*           scalar measurement results (synchronized). These are:
/*             Average power of current burst
/*             Peak power of current burst
/*             Power control level
/*             Timing advance error
/*             Bursts out of tolerance
/*             Burst template matching
/*             Average power of averaged trace
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampPow (ViSession  instrSession,
                                                                 ViReal64  *AvgBurstPwCurr,
                                                                 ViReal64  *PeakBurstPwCurr,
                                                                 ViInt32   *PowerControlLevel,
                                                                 ViReal64  *TimingAdvError,
                                                                 ViReal64  *BurstOutOfTol,
                                                                 ViInt32   *BurstMatching,
                                                                 ViReal64  *AvgBurstPwAvg,
                                                                 ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  if ((RSCMU_Status = RSCMU_Query (instrSession, "SAMP:POW:EPSK?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Scan the results of power:
  RSCMU_Status = RSCMU_Sig_ScanPow (TableOfDataValues, AvgBurstPwCurr, PeakBurstPwCurr, PowerControlLevel,
    TimingAdvError, BurstOutOfTol, BurstMatching, AvgBurstPwAvg);

  return RSCMU_Status;
}
/*===========================================================================*/
/* Function: Request Tolerance On Values
/* Purpose : This function indicates whether and in which way the per-
/*           missible tolerances for the scalar measured values  have
/*           been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_CalcPowLimMatc (ViSession instrSession,
                                                                        ViInt32  *AvgBurstPowCurr,
                                                                        ViInt32  *PeakBurstPowCurr,
                                                                        ViInt32  *TimingAdvanceErr,
                                                                        ViInt32  *BurstMatching,
                                                                        ViInt32  *AvgBurstPowAvg,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  if ((RSCMU_Status = RSCMU_Query (instrSession, "CALC:POW:EPSK:LIM:MATC?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Average Burst Power (Current Burst)
  RSCMU_Status = RSCMU_GetMatchingValue (AvgBurstPowCurr,TableOfDataValues,0);

  //Peak Burst Power (CurrentBurst)
  RSCMU_Status = RSCMU_GetMatchingValue (PeakBurstPowCurr,TableOfDataValues,1);

  // Timing Advance Error
  RSCMU_Status = RSCMU_GetMatchingValue (TimingAdvanceErr,TableOfDataValues,2);

  // Burst Template Matching
  RSCMU_Status = RSCMU_GetMatchingValue (BurstMatching,TableOfDataValues,3);

  // Average Burst Power of average trace
  RSCMU_Status = RSCMU_GetMatchingValue (AvgBurstPowAvg,TableOfDataValues,4);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Read Burst Power...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadArrPowBurs (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  BurstPower[],
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return  RSCMU_EDGE_NSig_ReadArrPowBurs (instrSession, Mode, BurstPower, errorMessage);
}
/*===========================================================================*/
/* Function: Fetch Burst Power...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcArrPowBurs (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  BurstPower[],
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return  RSCMU_EDGE_NSig_FetcArrPowBurs (instrSession, Mode, BurstPower, errorMessage);
}
/*===========================================================================*/
/* Function: Sample Burst Power...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampArrPowBurs (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  BurstPower[],
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return  RSCMU_EDGE_NSig_SampArrPowBurs (instrSession, Mode, BurstPower, errorMessage);
}
/*===========================================================================*/
/* Function: Read Burst Power...(SubArray)
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadSubArrPowBurs (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViReal64  BurstPower[],
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return  RSCMU_EDGE_NSig_ReadSubArrPowBurs (instrSession, Mode, BurstPower, errorMessage);
}
/*===========================================================================*/
/* Function: Fetch Burst Power.  (SubArray)
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcSubArrPowBurs (ViSession  instrSession,
                                                                           ViInt32    Mode,
                                                                           ViReal64   BurstPower[],
                                                                           ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return  RSCMU_EDGE_NSig_FetcSubArrPowBurs (instrSession, Mode, BurstPower, errorMessage);
}
/*===========================================================================*/
/* Function: Sample Burst Power...(SubArray)
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampSubArrPowBurs (ViSession  instrSession,
                                                                           ViInt32    Mode,
                                                                           ViReal64   BurstPower[],
                                                                           ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return  RSCMU_EDGE_NSig_SampSubArrPowBurs (instrSession, Mode, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Set power subranges
/* Purpose : This function configures the read, fetch and sample commands.
/*           It restricts the measurement to up to 32 subranges where either
/*           all measurement results or a single statistical value is returned
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSubPowRang (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  startTime,
                                                                        ViInt32   Nbofsamples,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, startTime, -10.0, 156.75, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Nbofsamples, 0, 668, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSubarrays (instrSession, RSCMU_POW, RSCMU_EPSK, Mode, startTime, Nbofsamples, errorMessage);
}

/*===========================================================================*/
/* Function: ToleranceError of Power Meas...
/* Purpose : This function indicates whether and in which way
/*           permissible tolerances for the burst power have been
/*           exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_CalcPowBursLimMatc (ViSession instrSession,
                                                                            ViInt32   StatisticsMode,
                                                                            ViInt32  *ToleranceError,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_EDGE_NSig_CalcPowBursLimMatc (instrSession, StatisticsMode, ToleranceError, errorMessage);
}
/*===========================================================================*/
/* Function: Range Violation
/* Purpose : This command is always query. ANy set bit of the two returned
/*           fiels indicates the violation of the corresponding section
/*           of the limit times
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_CalcPowResAreaLimMatc (ViSession   instrSession,
                                                                               ViInt32     StatisticsMode,
                                                                               ViInt32    *UpperLimitMatching,
                                                                               ViInt32    *LowerLimitMatching,
                                                                               ViChar      errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_EDGE_NSig_CalcPowResAreaLimMatc (instrSession, StatisticsMode, UpperLimitMatching,LowerLimitMatching, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT MODULATION OVERview
 *    The subsystem MODulation:OVERview measures general scalar modulation
 *    parameters in 8PSK modulation. The subsystem corresponds to the measurement
 *    menu Modulation, application Overview 8PSK, and the associated popup menu
 *    Modulation Error Config
 * ----------------------------------------------------------------------------
 *      CONFIGURATION
 *          CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModOverContRep (ViSession instrSession,
                                                                            ViInt32   repetition,
                                                                            ViInt32   stopCondition,
                                                                            ViInt32   stepMode,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfControlRep(instrSession, RSCMU_MODOVER, RSCMU_EPSK, repetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModOverContDef (ViSession instrSession,
                                                                            ViInt32   defaultValues,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfContDef(instrSession, RSCMU_MODOVER, RSCMU_EPSK, defaultValues, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      LIMIT LINES
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Default limit Lines (ON/OFF)
/* Purpose : This function switches the default limit lines on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModOverLimLineDef (ViSession instrSession,
                                                                               ViBoolean defaultLimitLines,
                                                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfModOempLimLineDef (instrSession, defaultLimitLines, errorMessage);
}

/*===========================================================================*/
/* Function: Upper Limit Lines
/* Purpose : This function defines upper limits for the Current, Max./Min and
/*           Average traces and for the scalar modulation parameters derived
/*           from them.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModOverLimLineUpp (ViSession instrSession,
                                                                               ViInt32   Limits,
                                                                               ViReal64  EVMErrorPeak,
                                                                               ViReal64  EVMErrorRMS,
                                                                               ViReal64  magnErrorPeak,
                                                                               ViReal64  magnErrorRMS,
                                                                               ViReal64  phaseErrorPeak,
                                                                               ViReal64  phaseErrorRMS,
                                                                               ViReal64  originOffset,
                                                                               ViReal64  IQImBalance,
                                                                               ViInt32   frequencyError,
                                                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfModOempLimLineUpp (instrSession, Limits, EVMErrorPeak, EVMErrorRMS, magnErrorPeak, magnErrorRMS,
                                        phaseErrorPeak, phaseErrorRMS, originOffset, IQImBalance, frequencyError, errorMessage);
}

/*===========================================================================*/
/* Function: 95% Upper Limits
/* Purpose : This function defines upper limits for the 95 th percentile of
/*           the three quantities error vector magnitude, modulation error,
/*           and phase error. The 95 th percentile is the limit below which
/*           95% of the measured errors are located.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModOverLimLine95 (ViSession instrSession,
                                                                              ViReal64  EVM95,
                                                                              ViReal64  modulationError95,
                                                                              ViReal64  phaseError95,
                                                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfModOempLimLine95 (instrSession, EVM95, modulationError95, phaseError95, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModOverCont (ViSession instrSession,
                                                                         ViInt32   measuredValuesType,
                                                                         ViInt32   NbBurst,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfControl (instrSession, RSCMU_MODOVER, RSCMU_EPSK, measuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModOverContRepSta (ViSession instrSession,
                                                                               ViInt32   NbRepetition,
                                                                               ViInt32   stopCondition,
                                                                               ViInt32   stepMode,
                                                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfContRepStat(instrSession, RSCMU_MODOVER, RSCMU_EPSK, NbRepetition, stopCondition, stepMode, errorMessage);
}

/* ----------------------------------------------------------------------------
 *      CONTROL OF MODULATION MEAS
 *      It contains the functions for general control of the modulation
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: RSCMU_EDGE_Sig_InitModOver
/* Purpose : This function starts the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_InitModOver (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_MODOVER, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_Sig_AborModOver
/* Purpose : This function stopss the power measurement, setting it to
/*           the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_AborModOver (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_MODOVER, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_Sig_StopModOver
/* Purpose : This function stops the power measurement, setting it to
/*           the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_StopModOver (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_MODOVER, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_Sig_ContModOver
/* Purpose : This function continue the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ContModOver (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_MODOVER, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_Sig_ConfModOverErep
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModOverErep (ViSession instrSession,
                                                                         ViInt32   Report,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfReporting (instrSession, RSCMU_MODOVER, RSCMU_EPSK, Report, errorMessage);
}

/*===========================================================================*/
/* Function: Modulation Measurement Status
/* Purpose : This function returns the status of the current Modulation
/*           Overview measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcModOverStat (ViSession instrSession,
                                                                         ViInt32  *measurementStatus,
                                                                         ViInt32  *CountingNo,
                                                                         ViInt32  *StatisticNo,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_FetcStatus (instrSession, RSCMU_MODOVER, RSCMU_EPSK, measurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      Subsystem MODulation[:OVERview]:EPSK[:TCH][:RESult]
 *      The subsystem MODulation:OVERview:EPSK[:RESULT] measures and returns
 *      the modulation parameters and compares them with the tolerance values.
 *      The subsystem corresponds to the various output elements in the
 *      measurement menu MODulation, application Overview 8PSK.
 *-----------------------------------------------------------------------------
 */


/*===========================================================================*/
/* Function: Measurement Results
/* Purpose : This function starts a modulation measurement and output all
/*           scalar measurement results
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ModOverRes (ViSession instrSession,
                                                  ViInt32 command,
                                                  ViReal64 measurementResults[],
                                                  ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
    ViChar     *StrValue;
    ViInt16     Index = 0;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_50,RSCMU_ERROR_FW_VERSION_4_50));


    sprintf(wrtBuf,"%s:MOD:OVER:EPSK?", StrCommand[command]);

    if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;

    StrValue = strtok (rdBuf, ",");

     while (StrValue) {
        if (strcmp (StrValue, "NAN") != 0)
            sscanf (StrValue, "%lf", &measurementResults[Index]);
        else measurementResults[Index] = RSCMU_NAN;

        StrValue = strtok (NULL, ",");

        Index++;
    }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all
/*           scalar measurement results (see chapter 4). The calculation of
/*           results in an average or peak measurement is described in chapter
/*           3 (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadModOver (ViSession instrSession,
                                                                     ViInt32   StatisticsMode,
                                                                     ViPReal64 EVM95,
                                                                     ViPReal64 MagErr95,
                                                                     ViPReal64 PhaseErr95,
                                                                     ViPReal64 EVMPeak,
                                                                     ViPReal64 EVMRMS,
                                                                     ViPReal64 magnErrorPeak,
                                                                     ViPReal64 magnErrorRMS,
                                                                     ViPReal64 phaseErrorPeak,
                                                                     ViPReal64 phaseErrorRMS,
                                                                     ViPReal64 originOffset,
                                                                     ViPReal64 IQIm_balance,
                                                                     ViPReal64 frequencyError,
                                                                     ViPReal64 avgBurstPowerCurr,
                                                                     ViPReal64 burstOutOfTol,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasModOver (instrSession, RSCMU_COMMAND_READ, StatisticsMode, EVM95, MagErr95, PhaseErr95, EVMPeak, EVMRMS,
                            magnErrorPeak, magnErrorRMS, phaseErrorPeak, phaseErrorRMS, originOffset, IQIm_balance,
                            frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function outputs all scalar measurement results (see chapter
/*           4). The calculation of results in an average or peak measurement
/*           is described in chapter 3 (see calculation of statistical
/*           quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcModOver (ViSession instrSession,
                                                                     ViInt32   StatisticsMode,
                                                                     ViPReal64 EVM95,
                                                                     ViPReal64 MagErr95,
                                                                     ViPReal64 PhaseErr95,
                                                                     ViPReal64 EVMPeak,
                                                                     ViPReal64 EVMRMS,
                                                                     ViPReal64 magnErrorPeak,
                                                                     ViPReal64 magnErrorRMS,
                                                                     ViPReal64 phaseErrorPeak,
                                                                     ViPReal64 phaseErrorRMS,
                                                                     ViPReal64 originOffset,
                                                                     ViPReal64 IQIm_balance,
                                                                     ViPReal64 frequencyError,
                                                                     ViPReal64 avgBurstPowerCurr,
                                                                     ViPReal64 burstOutOfTol,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasModOver (instrSession, RSCMU_COMMAND_FETC, StatisticsMode, EVM95, MagErr95, PhaseErr95, EVMPeak, EVMRMS,
                            magnErrorPeak, magnErrorRMS, phaseErrorPeak, phaseErrorRMS, originOffset, IQIm_balance,
                            frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all
/*           scalar measurement results (see chapter 4). The calculation of
/*           results in an average or peak measurement is described in chapter
/*           3 (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampModOver (ViSession instrSession,
                                                                     ViInt32   StatisticsMode,
                                                                     ViPReal64 EVM95,
                                                                     ViPReal64 MagErr95,
                                                                     ViPReal64 PhaseErr95,
                                                                     ViPReal64 EVMPeak,
                                                                     ViPReal64 EVMRMS,
                                                                     ViPReal64 magnErrorPeak,
                                                                     ViPReal64 magnErrorRMS,
                                                                     ViPReal64 phaseErrorPeak,
                                                                     ViPReal64 phaseErrorRMS,
                                                                     ViPReal64 originOffset,
                                                                     ViPReal64 IQIm_balance,
                                                                     ViPReal64 frequencyError,
                                                                     ViPReal64 avgBurstPowerCurr,
                                                                     ViPReal64 burstOutOfTol,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasModOver (instrSession, RSCMU_COMMAND_SAMP, StatisticsMode, EVM95, MagErr95, PhaseErr95, EVMPeak, EVMRMS,
                            magnErrorPeak, magnErrorRMS, phaseErrorPeak, phaseErrorRMS, originOffset, IQIm_balance,
                            frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_CalcModOverLimMatc (ViSession instrSession,
                                                                            ViInt32   StatisticsMode,
                                                                            ViInt32  *EVM95,
                                                                            ViInt32  *MagErr95,
                                                                            ViInt32  *PhaseErr95,
                                                                            ViInt32  *EVMPeak,
                                                                            ViInt32  *EVMRMS,
                                                                            ViInt32  *magnErrorPeak,
                                                                            ViInt32  *magnErrorRMS,
                                                                            ViInt32  *phaseErrorPeak,
                                                                            ViInt32  *phaseErrorRMS,
                                                                            ViInt32  *originOffset,
                                                                            ViInt32  *IQIm_balance,
                                                                            ViInt32  *frequencyError,
                                                                            ViInt32  *avgBurstPowerCurr,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_CalcModOverLimMatc (instrSession, StatisticsMode, EVM95, MagErr95, PhaseErr95, EVMPeak, EVMRMS, magnErrorPeak,
                                   magnErrorRMS, phaseErrorPeak, phaseErrorRMS, originOffset, IQIm_balance, frequencyError,
                                   avgBurstPowerCurr, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT MODULATION EVMagnitude
 *    The subsystem MODulation:EVMagnitude measures the error vector magnitude
 *    as well as general scalar modulation parameters. The subsystem corresponds
 *    to the measurement menu Modulation, application EVM 8PSK, and the associated
 *    popup menu Modulation Error Config.
 * ----------------------------------------------------------------------------
 *      CONFIGURATION
 *          CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModEvmContRep (ViSession instrSession,
                                                                           ViInt32   repetition,
                                                                           ViInt32   stopCondition,
                                                                           ViInt32   stepMode,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfControlRep(instrSession, RSCMU_MODEVM, RSCMU_EPSK, repetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModEvmContDef (ViSession instrSession,
                                                                           ViInt32   defaultValues,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfContDef(instrSession, RSCMU_MODEVM, RSCMU_EPSK, defaultValues, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      LIMIT LINES
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Default limit Lines (ON/OFF)
/* Purpose : This function switches the default limit lines on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModEvmLimLineDef (ViSession instrSession,
                                                                              ViBoolean defaultLimitLines,
                                                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfModOempLimLineDef (instrSession, defaultLimitLines, errorMessage);
}

/*===========================================================================*/
/* Function: Upper Limit Lines
/* Purpose : This function defines upper limits for the Current, Max./Min and
/*           Average traces and for the scalar modulation parameters derived
/*           from them.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModEvmLimLineUpp (ViSession instrSession,
                                                                              ViInt32   Limits,
                                                                              ViReal64  EVMErrorPeak,
                                                                              ViReal64  EVMErrorRMS,
                                                                              ViReal64  magnErrorPeak,
                                                                              ViReal64  magnErrorRMS,
                                                                              ViReal64  phaseErrorPeak,
                                                                              ViReal64  phaseErrorRMS,
                                                                              ViReal64  originOffset,
                                                                              ViReal64  IQImBalance,
                                                                              ViInt32   frequencyError,
                                                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfModOempLimLineUpp (instrSession, Limits, EVMErrorPeak, EVMErrorRMS, magnErrorPeak, magnErrorRMS,
                                        phaseErrorPeak, phaseErrorRMS, originOffset, IQImBalance, frequencyError, errorMessage);
}

/*===========================================================================*/
/* Function: 95% Upper Limits
/* Purpose : This function defines upper limits for the 95 th percentile of
/*           the three quantities error vector magnitude, modulation error,
/*           and phase error. The 95 th percentile is the limit below which
/*           95% of the measured errors are located.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModEvmLimLine95 (ViSession instrSession,
                                                                             ViReal64  EVM95,
                                                                             ViReal64  modulationError95,
                                                                             ViReal64  phaseError95,
                                                                             ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfModOempLimLine95 (instrSession, EVM95, modulationError95, phaseError95, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModEvmCont (ViSession instrSession,
                                                                        ViInt32   measuredValuesType,
                                                                        ViInt32   NbBurst,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfControl (instrSession, RSCMU_MODEVM, RSCMU_EPSK, measuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModEvmContRepSta (ViSession instrSession,
                                                                              ViInt32   NbRepetition,
                                                                              ViInt32   stopCondition,
                                                                              ViInt32   stepMode,
                                                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfContRepStat(instrSession, RSCMU_MODEVM, RSCMU_EPSK, NbRepetition, stopCondition, stepMode, errorMessage);
}

/* ----------------------------------------------------------------------------
 *      MEASUREMENT
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set power subranges
/* Purpose : This function configures the read, fetch and sample commands.
/*           It restricts the measurement to up to 32 subranges where either
/*           all measurement results or a single statistical value is returned
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSubModEvmRang (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViReal64  startTime,
                                                                           ViInt32   NbSamples,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, startTime, 0, 146.75, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbSamples, 0, 588, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSubarrays (instrSession, RSCMU_MODEVM, RSCMU_EPSK, Mode, startTime, NbSamples, errorMessage);
}

/* ----------------------------------------------------------------------------
 *      CONTROL OF MODULATION MEAS
 *      It contains the functions for general control of the modulation
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_InitModEvm
/* Purpose : This function starts the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_InitModEvm (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_MODEVM, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_AborModEvm
/* Purpose : This function stopss the power measurement, setting it to
/*           the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_AborModEvm (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_MODEVM, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_StopModEvm
/* Purpose : This function stops the power measurement, setting it to
/*           the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_StopModEvm (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_MODEVM, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_ContModEvm
/* Purpose : This function continue the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ContModEvm (ViSession instrSession,
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_MODEVM, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_ConfModEvmErep
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModEvmErep (ViSession instrSession,
                                                                        ViInt32   Report,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfReporting (instrSession, RSCMU_MODEVM, RSCMU_EPSK, Report, errorMessage);
}

/*===========================================================================*/
/* Function: Modulation Measurement Status
/* Purpose : This function returns the status of the current Modulation
/*           Overview measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcModEvmStat (ViSession instrSession,
                                                                        ViInt32  *measurementStatus,
                                                                        ViInt32  *CountingNo,
                                                                        ViInt32  *StatisticNo,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_FetcStatus (instrSession, RSCMU_MODEVM, RSCMU_EPSK, measurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      Subsystem MODulation[:EVMagnitude]:EPSK[:RESult]
 *
 *      The subsystem MODulation:EVMagnitude:EPSK[:RESULT] measures and returns
 *      the modulation parameters and compares them with the tolerance values.
 *      The subsystem corresponds to the various output elements in the
 *      measurement menu MODulation, application EVM 8PSK.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4). The calculation of results in
/*           an average or peak measurement is described in chapter 3 (see
/*           calculation of statistical quantities). The symbol (x3) behind a
/*           value indicates that the list contains three results corresponding
/*           to the Current, the Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadModEvm (ViSession instrSession,
                                                                    ViInt32   StatisticsMode,
                                                                    ViReal64 *EVM95,
                                                                    ViReal64 *EVMPeak,
                                                                    ViReal64 *EVMRMS,
                                                                    ViReal64 *originOffset,
                                                                    ViReal64 *IQImBalance,
                                                                    ViReal64 *frequencyError,
                                                                    ViReal64 *avgBurstPowerCurr,
                                                                    ViReal64 *burstOutOfTol,
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasModEvm (instrSession, RSCMU_COMMAND_READ, StatisticsMode, EVM95, EVMPeak, EVMRMS, originOffset, IQImBalance,
                           frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function outputs all scalar measurement results (see chapter
 *           4). The calculation of results in an average or peak measurement
 *           is described in chapter 3 (see calculation of statistical
 *           quantities). The symbol (x3) behind a value indicates that the
 *           list contains three results corresponding to the Current, the
 *           Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcModEvm (ViSession instrSession,
                                                                    ViInt32   StatisticsMode,
                                                                    ViReal64 *EVM95,
                                                                    ViReal64 *EVMPeak,
                                                                    ViReal64 *EVMRMS,
                                                                    ViReal64 *originOffset,
                                                                    ViReal64 *IQImBalance,
                                                                    ViReal64 *frequencyError,
                                                                    ViReal64 *avgBurstPowerCurr,
                                                                    ViReal64 *burstOutOfTol,
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasModEvm (instrSession, RSCMU_COMMAND_FETC, StatisticsMode, EVM95, EVMPeak, EVMRMS, originOffset, IQImBalance,
                           frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
 *           measurement results (see chapter 4). The calculation of results in
 *           an average or peak measurement is described in chapter 3 (see
 *           calculation of statistical quantities). The symbol (x3) behind a
 *           value indicates that the list contains three results corresponding
 *           to the Current, the Average, and the MMax value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampModEvm (ViSession instrSession,
                                                                    ViInt32   StatisticsMode,
                                                                    ViReal64 *EVM95,
                                                                    ViReal64 *EVMPeak,
                                                                    ViReal64 *EVMRMS,
                                                                    ViReal64 *originOffset,
                                                                    ViReal64 *IQImBalance,
                                                                    ViReal64 *frequencyError,
                                                                    ViReal64 *avgBurstPowerCurr,
                                                                    ViReal64 *burstOutOfTol,
                                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasModEvm (instrSession, RSCMU_COMMAND_SAMP, StatisticsMode, EVM95, EVMPeak, EVMRMS, originOffset, IQImBalance,
                           frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_CalcModEvmLimMatc (ViSession instrSession,
                                                                           ViInt32   StatisticsMode,
                                                                           ViInt32  *EVM95,
                                                                           ViInt32  *phaseErrorPeak,
                                                                           ViInt32  *phaseErrorRMS,
                                                                           ViInt32  *originOffset,
                                                                           ViInt32  *IQImBalance,
                                                                           ViInt32  *frequencyError,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_CalcModEvmLimMatc (instrSession, StatisticsMode, EVM95, phaseErrorPeak, phaseErrorRMS, originOffset,
                                  IQImBalance, frequencyError, errorMessage);
}

/*===========================================================================*/
/* Function: Read Phase Error in Burst...
/* Purpose : This function returns the error vector magnitude vs. time at fixed,
/*           equidistant test points. The number of measured values is 588,
/*           corresponding to a time range of 0 Bit to 146  Bit.
/*           The calculation of current, average, and mmax (Min./Max.) results
/*           is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadArrModEvm (ViSession instrSession,
                                                                       ViInt32   Mode,
                                                                       ViReal64  EVMValues[],
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasArrModEvm (instrSession, RSCMU_COMMAND_READ, Mode, EVMValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Phase Error in Burst...
/* Purpose : This function returns the error vector magnitude vs. time at fixed,
/*           equidistant test points. The number of measured values is 588,
/*           corresponding to a time range of 0 Bit to 146  Bit.
/*           The calculation of current, average, and mmax (Min./Max.) results
/*           is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcArrModEvm (ViSession instrSession,
                                                                       ViInt32   Mode,
                                                                       ViReal64  EVMValues[],
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasArrModEvm (instrSession, RSCMU_COMMAND_FETC, Mode, EVMValues, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Phase Error in Burst...
/* Purpose : This function returns the error vector magnitude vs. time at fixed,
/*           equidistant test points. The number of measured values is 588,
/*           corresponding to a time range of 0 Bit to 146  Bit.
/*           The calculation of current, average, and mmax (Min./Max.) results
/*           is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampArrModEvm (ViSession instrSession,
                                                                       ViInt32   Mode,
                                                                       ViReal64  EVMValues[],
                                                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasArrModEvm (instrSession, RSCMU_COMMAND_SAMP, Mode, EVMValues, errorMessage);
}

/*===========================================================================*/
/* Function: Read Subarray
/* Purpose : this function measures and returns the error vector magnitude
/*           versus time in the subranges defined by means of the CONFigure:
/*           SUBarrays:MODulation:EVMagnitude:EPSK[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadSubArrModEvm (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViReal64  EVMValues[],
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasSubArrModEvm (instrSession, RSCMU_COMMAND_READ, Mode, EVMValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Subarray
/* Purpose : this function measures and returns the error vector magnitude
/*           versus time in the subranges defined by means of the CONFigure:
/*           SUBarrays:MODulation:EVMagnitude:EPSK[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcSubArrModEvm (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViReal64  EVMValues[],
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasSubArrModEvm (instrSession, RSCMU_COMMAND_FETC, Mode, EVMValues, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Subarray
/* Purpose : this function measures and returns the error vector magnitude
/*           versus time in the subranges defined by means of the CONFigure:
/*           SUBarrays:MODulation:EVMagnitude:EPSK[:TCH] command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampSubArrModEvm (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViReal64  EVMValues[],
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasSubArrModEvm (instrSession, RSCMU_COMMAND_SAMP, Mode, EVMValues, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT MODULATION PERRor
 *    The subsystem MODulation:PERRor measures the phase error as well as
 *    general scalar modulation parameters. The subsystem corresponds to the
 *    measurement menu Modulation, application Phase Error 8PSK, and the
 *    associated popup menu Modulation Error Config.
 * ----------------------------------------------------------------------------
 *      CONFIGURATION
 *          CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModPerrContRep (ViSession instrSession,
                                                                            ViInt32   repetition,
                                                                            ViInt32   stopCondition,
                                                                            ViInt32   stepMode,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfControlRep(instrSession, RSCMU_MODPERR, RSCMU_EPSK, repetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModPerrContDef (ViSession instrSession,
                                                                            ViInt32   defaultValues,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfContDef(instrSession, RSCMU_MODPERR, RSCMU_EPSK, defaultValues, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      LIMIT LINES
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Default limit Lines (ON/OFF)
/* Purpose : This function switches the default limit lines on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModPerrLimLineDef (ViSession instrSession,
                                                                               ViBoolean defaultLimitLines,
                                                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfModOempLimLineDef (instrSession, defaultLimitLines, errorMessage);
}

/*===========================================================================*/
/* Function: Upper Limit Lines
/* Purpose : This function defines upper limits for the Current, Max./Min and
/*           Average traces and for the scalar modulation parameters derived
/*           from them.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModPerrLimLineUpp (ViSession instrSession,
                                                                               ViInt32   Limits,
                                                                               ViReal64  EVMErrorPeak,
                                                                               ViReal64  EVMErrorRMS,
                                                                               ViReal64  magnErrorPeak,
                                                                               ViReal64  magnErrorRMS,
                                                                               ViReal64  phaseErrorPeak,
                                                                               ViReal64  phaseErrorRMS,
                                                                               ViReal64  originOffset,
                                                                               ViReal64  IQImBalance,
                                                                               ViInt32   frequencyError,
                                                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfModOempLimLineUpp (instrSession, Limits, EVMErrorPeak, EVMErrorRMS, magnErrorPeak, magnErrorRMS,
                                        phaseErrorPeak, phaseErrorRMS, originOffset, IQImBalance, frequencyError, errorMessage);
}

/*===========================================================================*/
/* Function: 95% Upper Limits
/* Purpose : This function defines upper limits for the 95 th percentile of
/*           the three quantities error vector magnitude, modulation error,
/*           and phase error. The 95 th percentile is the limit below which
/*           95% of the measured errors are located.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModPerrLimLine95 (ViSession instrSession,
                                                                              ViReal64  EVM95,
                                                                              ViReal64  modulationError95,
                                                                              ViReal64  phaseError95,
                                                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfModOempLimLine95 (instrSession, EVM95, modulationError95, phaseError95, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModPerrCont (ViSession instrSession,
                                                                         ViInt32   measuredValuesType,
                                                                         ViInt32   NbBurst,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfControl (instrSession, RSCMU_MODPERR, RSCMU_EPSK, measuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModPerrContRepSta (ViSession instrSession,
                                                                               ViInt32   NbRepetition,
                                                                               ViInt32   stopCondition,
                                                                               ViInt32   stepMode,
                                                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfContRepStat(instrSession, RSCMU_MODPERR, RSCMU_EPSK, NbRepetition, stopCondition, stepMode, errorMessage);
}

/* ----------------------------------------------------------------------------
 *      MEASUREMENT
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set power subranges
/* Purpose : This function configures the read, fetch and sample commands.
/*           It restricts the measurement to up to 32 subranges where either
/*           all measurement results or a single statistical value is returned
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSubModPerrRang (ViSession instrSession,
                                                                            ViInt32   Mode,
                                                                            ViReal64  startTime,
                                                                            ViInt32   NbSamples,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, startTime, 0, 146.75, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbSamples, 0, 588, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSubarrays (instrSession, RSCMU_MODPERR, RSCMU_EPSK, Mode, startTime, NbSamples, errorMessage);
}

/* ----------------------------------------------------------------------------
 *      CONTROL OF MODULATION MEAS
 *      It contains the functions for general control of the modulation
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: RSCMU_EDGE_Sig_InitModMerr
/* Purpose : This function starts the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_InitModPerr (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_MODPERR, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_Sig_AborModMerr
/* Purpose : This function stopss the power measurement, setting it to
/*           the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_AborModPerr (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_MODPERR, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_Sig_StopModMerr
/* Purpose : This function stops the power measurement, setting it to
/*           the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_StopModPerr (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_MODPERR, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_Sig_ContModMerr
/* Purpose : This function continue the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ContModPerr (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_MODPERR, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_Sig_ConfModMerrErep
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModPerrErep (ViSession instrSession,
                                                                         ViInt32   Report,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfReporting (instrSession, RSCMU_MODPERR, RSCMU_EPSK, Report, errorMessage);
}

/*===========================================================================*/
/* Function: Modulation Measurement Status
/* Purpose : This function returns the status of the current Modulation
/*           Overview measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcModPerrStat (ViSession instrSession,
                                                                         ViInt32  *measurementStatus,
                                                                         ViInt32  *CountingNo,
                                                                         ViInt32  *StatisticNo,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_FetcStatus (instrSession, RSCMU_MODPERR, RSCMU_EPSK, measurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      Subsystem MODulation:PERRor:EPSK[:RESult]
 *
 *      The subsystem MODulation:PERRor:EPSK[:RESULT] measures and returns
 *      the modulation parameters and compares them with the tolerance values.
 *      The subsystem corresponds to the various output elements in the
 *      measurement menu MODulation, application Phase Error 8PSK.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadModPerr (ViSession instrSession,
                                                                     ViInt32   StatisticsMode,
                                                                     ViReal64 *PhaseError95,
                                                                     ViReal64 *phaseErrorPeak,
                                                                     ViReal64 *phaseErrorRMS,
                                                                     ViReal64 *originOffset,
                                                                     ViReal64 *IQImBalance,
                                                                     ViReal64 *frequencyError,
                                                                     ViReal64 *avgBurstPowerCurr,
                                                                     ViReal64 *burstOutOfTol,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_EDGE_MeasModPerr (instrSession, RSCMU_COMMAND_READ, StatisticsMode, PhaseError95, phaseErrorPeak, phaseErrorRMS,
                                 originOffset, IQImBalance, frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcModPerr (ViSession instrSession,
                                                                     ViInt32   StatisticsMode,
                                                                     ViReal64 *PhaseError95,
                                                                     ViReal64 *phaseErrorPeak,
                                                                     ViReal64 *phaseErrorRMS,
                                                                     ViReal64 *originOffset,
                                                                     ViReal64 *IQImBalance,
                                                                     ViReal64 *frequencyError,
                                                                     ViReal64 *avgBurstPowerCurr,
                                                                     ViReal64 *burstOutOfTol,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_EDGE_MeasModPerr (instrSession, RSCMU_COMMAND_FETC, StatisticsMode, PhaseError95, phaseErrorPeak, phaseErrorRMS,
                                 originOffset, IQImBalance, frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampModPerr (ViSession instrSession,
                                                                     ViInt32   StatisticsMode,
                                                                     ViReal64 *PhaseError95,
                                                                     ViReal64 *phaseErrorPeak,
                                                                     ViReal64 *phaseErrorRMS,
                                                                     ViReal64 *originOffset,
                                                                     ViReal64 *IQImBalance,
                                                                     ViReal64 *frequencyError,
                                                                     ViReal64 *avgBurstPowerCurr,
                                                                     ViReal64 *burstOutOfTol,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_EDGE_MeasModPerr (instrSession, RSCMU_COMMAND_SAMP, StatisticsMode, PhaseError95, phaseErrorPeak, phaseErrorRMS,
                                 originOffset, IQImBalance, frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_CalcModPerrLimMatc (ViSession instrSession,
                                                                            ViInt32   StatisticsMode,
                                                                            ViInt32  *PhaseError95,
                                                                            ViInt32  *phaseErrorPeak,
                                                                            ViInt32  *phaseErrorRMS,
                                                                            ViInt32  *originOffset,
                                                                            ViInt32  *IQImBalance,
                                                                            ViInt32  *frequencyError,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_EDGE_CalcModPerrLimMatc (instrSession, StatisticsMode, PhaseError95, phaseErrorPeak, phaseErrorRMS,
                                        originOffset, IQImBalance, frequencyError, errorMessage);
}

/*===========================================================================*/
/* Function: Read Phase Error in Burst...
/* Purpose : This function returns the the phase error vs. time at fixed,
/*           equidistant test points. The number of measured values is 588,
/*           corresponding to a time range of 0 Bit to 146  Bit.
/*           The calculation of current, average, and mmax (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadArrModPerr (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  phaseErrorValues[],
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_EDGE_MeasArrModPerr (instrSession, RSCMU_COMMAND_READ, Mode, phaseErrorValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Phase Error in Burst...
/* Purpose : This function returns the the phase error vs. time at fixed,
/*           equidistant test points. The number of measured values is 588,
/*           corresponding to a time range of 0 Bit to 146  Bit.
/*           The calculation of current, average, and mmax (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcArrModPerr (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  phaseErrorValues[],
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_EDGE_MeasArrModPerr (instrSession, RSCMU_COMMAND_FETC, Mode, phaseErrorValues, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Phase Error in Burst...
/* Purpose : This function returns the the phase error vs. time at fixed,
/*           equidistant test points. The number of measured values is 588,
/*           corresponding to a time range of 0 Bit to 146  Bit.
/*           The calculation of current, average, and mmax (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampArrModPerr (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  phaseErrorValues[],
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_EDGE_MeasArrModPerr (instrSession, RSCMU_COMMAND_SAMP, Mode, phaseErrorValues, errorMessage);
}

/*===========================================================================*/
/* Function: Read Subarray
/* Purpose : this function measures and returns the phase error versus time in
/*           the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:PERRor:EPSK command. V2.15
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadSubArrModPerr (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViReal64  PhaseErrorValues[],
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_EDGE_MeasSubArrModPerr (instrSession, RSCMU_COMMAND_READ, Mode, PhaseErrorValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Subarray
/* Purpose : this function measures and returns the phase error versus time in
/*           the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:PERRor:EPSK command. V2.15
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcSubArrModPerr (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViReal64  PhaseErrorValues[],
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_EDGE_MeasSubArrModPerr (instrSession, RSCMU_COMMAND_FETC, Mode, PhaseErrorValues, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Subarray
/* Purpose : this function measures and returns the phase error versus time in
/*           the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:PERRor:EPSK command. V2.15
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampSubArrModPerr (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViReal64  PhaseErrorValues[],
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_EDGE_MeasSubArrModPerr (instrSession, RSCMU_COMMAND_SAMP, Mode, PhaseErrorValues, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT MODULATION MERRor
 *    The subsystem MODulation:MERRor measures the magnitude error as well as
 *    general scalar modulation parameters. The subsystem corresponds to the
 *    measurement menu Modulation, application Magn. Error 8PSK, and the
 *    associated popup menu Modulation Error Config.
 * ----------------------------------------------------------------------------
 *      CONFIGURATION
 *          CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModMerrContRep (ViSession instrSession,
                                                                            ViInt32   repetition,
                                                                            ViInt32   stopCondition,
                                                                            ViInt32   stepMode,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfControlRep(instrSession, RSCMU_MODMERR, RSCMU_EPSK, repetition, stopCondition, stepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModMerrContDef (ViSession instrSession,
                                                                            ViInt32   defaultValues,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfContDef(instrSession, RSCMU_MODMERR, RSCMU_EPSK, defaultValues, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      LIMIT LINES
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Default limit Lines (ON/OFF)
/* Purpose : This function switches the default limit lines on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModMerrLimLineDef (ViSession instrSession,
                                                                               ViBoolean defaultLimitLines,
                                                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfModOempLimLineDef (instrSession, defaultLimitLines, errorMessage);
}

/*===========================================================================*/
/* Function: Upper Limit Lines
/* Purpose : This function defines upper limits for the Current, Max./Min and
/*           Average traces and for the scalar modulation parameters derived
/*           from them.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModMerrLimLineUpp (ViSession instrSession,
                                                                               ViInt32   Limits,
                                                                               ViReal64  EVMErrorPeak,
                                                                               ViReal64  EVMErrorRMS,
                                                                               ViReal64  magnErrorPeak,
                                                                               ViReal64  magnErrorRMS,
                                                                               ViReal64  phaseErrorPeak,
                                                                               ViReal64  phaseErrorRMS,
                                                                               ViReal64  originOffset,
                                                                               ViReal64  IQImBalance,
                                                                               ViInt32   frequencyError,
                                                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfModOempLimLineUpp (instrSession, Limits, EVMErrorPeak, EVMErrorRMS, magnErrorPeak, magnErrorRMS,
                                        phaseErrorPeak, phaseErrorRMS, originOffset, IQImBalance, frequencyError, errorMessage);
}

/*===========================================================================*/
/* Function: 95% Upper Limits
/* Purpose : This function defines upper limits for the 95 th percentile of
/*           the three quantities error vector magnitude, modulation error,
/*           and phase error. The 95 th percentile is the limit below which
/*           95% of the measured errors are located.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModMerrLimLine95 (ViSession instrSession,
                                                                              ViReal64  EVM95,
                                                                              ViReal64  modulationError95,
                                                                              ViReal64  phaseError95,
                                                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfModOempLimLine95 (instrSession, EVM95, modulationError95, phaseError95, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Scope of measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModMerrCont (ViSession instrSession,
                                                                         ViInt32   measuredValuesType,
                                                                         ViInt32   NbBurst,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfControl (instrSession, RSCMU_MODMERR, RSCMU_EPSK, measuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModMerrContRepSta (ViSession instrSession,
                                                                               ViInt32   NbRepetition,
                                                                               ViInt32   stopCondition,
                                                                               ViInt32   stepMode,
                                                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfContRepStat(instrSession, RSCMU_MODMERR, RSCMU_EPSK, NbRepetition, stopCondition, stepMode, errorMessage);
}

/* ----------------------------------------------------------------------------
 *      MEASUREMENT
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set power subranges
/* Purpose : This function configures the read, fetch and sample commands.
/*           It restricts the measurement to up to 32 subranges where either
/*           all measurement results or a single statistical value is returned
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSubModMerrRang (ViSession instrSession,
                                                                            ViInt32   Mode,
                                                                            ViReal64  startTime,
                                                                            ViInt32   NbSamples,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, startTime, 0, 146.75, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, NbSamples, 0, 588, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSubarrays (instrSession, RSCMU_MODMERR, RSCMU_EPSK, Mode, startTime, NbSamples, errorMessage);
}

/* ----------------------------------------------------------------------------
 *      CONTROL OF MODULATION MEAS
 *      It contains the functions for general control of the modulation
 *      measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_InitModMerr
/* Purpose : This function starts the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_InitModMerr (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_MODMERR, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_AborModMerr
/* Purpose : This function stopss the power measurement, setting it to
/*           the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_AborModMerr (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_MODMERR, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_StopModMerr
/* Purpose : This function stops the power measurement, setting it to
/*           the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_StopModMerr (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_MODMERR, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_ContModMerr
/* Purpose : This function continue the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ContModMerr (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_MODMERR, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_NSig_ConfModMerrErep
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModMerrErep (ViSession instrSession,
                                                                         ViInt32   Report,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfReporting (instrSession, RSCMU_MODMERR, RSCMU_EPSK, Report, errorMessage);
}

/*===========================================================================*/
/* Function: Modulation Measurement Status
/* Purpose : This function returns the status of the current Modulation
/*           Overview measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcModMerrStat (ViSession instrSession,
                                                                         ViInt32  *measurementStatus,
                                                                         ViInt32  *CountingNo,
                                                                         ViInt32  *StatisticNo,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_FetcStatus (instrSession, RSCMU_MODMERR, RSCMU_EPSK, measurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      Subsystem MODulation:MERRor:EPSK[:RESult]
 *
 *      The subsystem MODulation:MERRor:EPSK[:RESULT] measures and returns the
 *      modulation parameters and compares them with the tolerance values.
 *      The subsystem corresponds to the various output elements in the
 *      measurement menu MODulation, application Magn. Error 8PSK.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadModMerr (ViSession instrSession,
                                                                     ViInt32   StatisticsMode,
                                                                     ViReal64 *MagnError95,
                                                                     ViReal64 *MagnErrorPeak,
                                                                     ViReal64 *MagnErrorRMS,
                                                                     ViReal64 *originOffset,
                                                                     ViReal64 *IQImBalance,
                                                                     ViReal64 *frequencyError,
                                                                     ViReal64 *avgBurstPowerCurr,
                                                                     ViReal64 *burstOutOfTol,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasModMerr (instrSession, RSCMU_COMMAND_READ, StatisticsMode, MagnError95, MagnErrorPeak, MagnErrorRMS,
                            originOffset, IQImBalance, frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcModMerr (ViSession instrSession,
                                                                     ViInt32   StatisticsMode,
                                                                     ViReal64 *MagnError95,
                                                                     ViReal64 *MagnErrorPeak,
                                                                     ViReal64 *MagnErrorRMS,
                                                                     ViReal64 *originOffset,
                                                                     ViReal64 *IQImBalance,
                                                                     ViReal64 *frequencyError,
                                                                     ViReal64 *avgBurstPowerCurr,
                                                                     ViReal64 *burstOutOfTol,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasModMerr (instrSession, RSCMU_COMMAND_FETC, StatisticsMode, MagnError95, MagnErrorPeak, MagnErrorRMS,
                            originOffset, IQImBalance, frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampModMerr (ViSession instrSession,
                                                                     ViInt32   StatisticsMode,
                                                                     ViReal64 *MagnError95,
                                                                     ViReal64 *MagnErrorPeak,
                                                                     ViReal64 *MagnErrorRMS,
                                                                     ViReal64 *originOffset,
                                                                     ViReal64 *IQImBalance,
                                                                     ViReal64 *frequencyError,
                                                                     ViReal64 *avgBurstPowerCurr,
                                                                     ViReal64 *burstOutOfTol,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasModMerr (instrSession, RSCMU_COMMAND_SAMP, StatisticsMode, MagnError95, MagnErrorPeak, MagnErrorRMS,
                            originOffset, IQImBalance, frequencyError, avgBurstPowerCurr, burstOutOfTol, errorMessage);
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_CalcModMerrLimMatc (ViSession instrSession,
                                                                            ViInt32   StatisticsMode,
                                                                            ViInt32  *MagnError95,
                                                                            ViInt32  *MagnErrorPeak,
                                                                            ViInt32  *MagnErrorRMS,
                                                                            ViInt32  *originOffset,
                                                                            ViInt32  *IQImBalance,
                                                                            ViInt32  *frequencyError,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_CalcModMerrLimMatc (instrSession, StatisticsMode, MagnError95, MagnErrorPeak, MagnErrorRMS, originOffset,
                                   IQImBalance, frequencyError, errorMessage);
}

/*===========================================================================*/
/* Function: Read Phase Error in Burst...
/* Purpose : This function returns the the phase error vs. time at fixed,
/*           equidistant test points. The number of measured values is 588,
/*           corresponding to a time range of 0 Bit to 146  Bit.
/*           The calculation of current, average, and mmax (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadArrModMerr (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  MagnErrorValues[],
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasArrModMerr (instrSession, RSCMU_COMMAND_READ, Mode, MagnErrorValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Phase Error in Burst...
/* Purpose : This function returns the the phase error vs. time at fixed,
/*           equidistant test points. The number of measured values is 588,
/*           corresponding to a time range of 0 Bit to 146  Bit.
/*           The calculation of current, average, and mmax (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcArrModMerr (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  MagnErrorValues[],
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasArrModMerr (instrSession, RSCMU_COMMAND_FETC, Mode, MagnErrorValues, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Phase Error in Burst...
/* Purpose : This function returns the the phase error vs. time at fixed,
/*           equidistant test points. The number of measured values is 588,
/*           corresponding to a time range of 0 Bit to 146  Bit.
/*           The calculation of current, average, and mmax (Min./Max.)
/*           results is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampArrModMerr (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  MagnErrorValues[],
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasArrModMerr (instrSession, RSCMU_COMMAND_SAMP, Mode, MagnErrorValues, errorMessage);
}

/*===========================================================================*/
/* Function: Read Subarray
/* Purpose : this function measures and returns the phase error versus time in
/*           the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:MERRor:EPSK command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadSubArrModMerr (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViReal64  MagnErrorValues[],
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasSubArrModMerr (instrSession, RSCMU_COMMAND_READ, Mode, MagnErrorValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Subarray
/* Purpose : this function measures and returns the phase error versus time in
/*           the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:MERRor:EPSK command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcSubArrModMerr (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViReal64  MagnErrorValues[],
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasSubArrModMerr (instrSession, RSCMU_COMMAND_FETC, Mode, MagnErrorValues, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Subarray
/* Purpose : this function measures and returns the phase error versus time in
/*           the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:MERRor:EPSK command.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampSubArrModMerr (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViReal64  MagnErrorValues[],
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasSubArrModMerr (instrSession, RSCMU_COMMAND_SAMP, Mode, MagnErrorValues, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT SPECTRUM/SWITCHING
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecSwitContDef (ViSession instrSession,
                                                                             ViInt32   DefaultValues,
                                                                             ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfContDef(instrSession, RSCMU_SPECSWIT, RSCMU_EPSK, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecSwitContRep (ViSession  instrSession,
                                                                             ViInt32    Repetition,
                                                                             ViInt32    StopCondition,
                                                                             ViInt32    StepMode,
                                                                             ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfControlRep(instrSession, RSCMU_SPECSWIT, RSCMU_EPSK, Repetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: continuous statistical mode
/* Purpose : This function defines the continuous statistical mode for the
/*           Spectrum due to Switching measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SpecSwitContStatMod (ViSession instrSession,
                                                      ViInt32 continuousStatisticalMode,
                                                      ViChar errorMessage[])
{
    return RSCMU_ConfSpecSwitContStatMod (instrSession, RSCMU_EPSK, continuousStatisticalMode, errorMessage);
}

/*===========================================================================*/
/* Function: Slot Count
/* Purpose : This function defines whether a single timeslot or all timeslots
/*           are considered for the Spectrum due to Switching measurement..
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SpecSwitSlotCount (ViSession instrSession,
                                                    ViInt32 slotCount,
                                                    ViChar errorMessage[])
{
    return RSCMU_ConfSpecSwitSlotCount (instrSession, RSCMU_EPSK, slotCount, errorMessage);
}

/*===========================================================================*/
/* Function: Set Grid (ON/OFF)
/* Purpose : This function switches the grid lines in the test diagrams on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_DispSpecSwitContGrid (ViSession instrSession,
                                                                              ViInt32   gridLines,
                                                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_DisplayGrid (instrSession, RSCMU_SPECSWIT, RSCMU_EPSK, gridLines, errorMessage);
}

/*===========================================================================*/
/* Function: Default Limit Lines
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecSwitLimLinDef (ViSession instrSession,
                                                                               ViInt32   DefaultValues,
                                                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfLimLineDef (instrSession, RSCMU_SPECSWIT, RSCMU_EPSK, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines
/* Purpose : These commands activate and define limit lines for the spectrum
/*           due to switching measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecSwitLimLine (ViSession instrSession,
                                                                             ViInt32   PowerLevel,
                                                                             ViReal64  power,
                                                                             ViInt32   enable,
                                                                             ViReal64  value1,
                                                                             ViReal64  value2,
                                                                             ViReal64  value3,
                                                                             ViReal64  value4,
                                                                             ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfSpecSwitLimLine (instrSession, RSCMU_EPSK, PowerLevel, power, enable, value1, value2, value3, value4, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines On/Off
/* Purpose : This function switches the limit checking for all measurepoints.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecSwitLimLinMod (ViSession instrSession,
                                                                               ViInt32   limitLines,
                                                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfSpecSwitLimLineMod(instrSession, RSCMU_EPSK, limitLines, errorMessage);
}

/*===========================================================================*/
/* Function: Statistic Count
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecSwitCont (ViSession instrSession,
                                                                          ViInt32   MeasuredValuesType,
                                                                          ViInt32   NbBurst,
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfControl (instrSession, RSCMU_SPECSWIT, RSCMU_EPSK, MeasuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecSwitContRepSt (ViSession  instrSession,
                                                                               ViInt32    NbRepetition,
                                                                               ViInt32    StopCondition,
                                                                               ViInt32    StepMode,
                                                                               ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfContRepStat(instrSession, RSCMU_SPECSWIT, RSCMU_EPSK, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Measure Points
/* Purpose : This function permits to select which frequencies a spectrum
/*           switching measurement is performed. A reduction of the
/*           measurement points enhances the measurement speed.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecSwitContMpo (ViSession  instrSession,
                                                                             ViInt32    MeasurePoint,
                                                                             ViInt32    Enable,
                                                                             ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfSpecSwitContMpo (instrSession, RSCMU_EPSK, MeasurePoint, Enable, errorMessage);
}

/*===========================================================================*/
/* Function: Burst Power SubRanges
/* Purpose : This function configurates the READ..., FETCh... and
/*           SAMPle:SUBarray:SPECtrum:SWITching commands.
/*           If the requested number of results exceeds the measurement
/*           range, the count parameter will be corrected by the system.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSubSpecSwit (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViReal64  FirstMeasurementFreq,
                                                                         ViInt32   MeasureResultsNumber,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, FirstMeasurementFreq, -1.8, 1.8, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, MeasureResultsNumber, 1, 9, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSubarrays (instrSession, RSCMU_SPECSWIT, RSCMU_EPSK, Mode, FirstMeasurementFreq, MeasureResultsNumber, errorMessage);
}

/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_InitSpecSwit (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_SPECSWIT, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : Abort measurement and switch off => OFF
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_AborSpecSwit (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_SPECSWIT, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : Stop measurement => STOP
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_StopSpecSwit (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_SPECSWIT, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : Next measurement step (only counting mode) => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ContSpecSwit (ViSession instrSession,
                                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_SPECSWIT, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: Spectrum Switching Measurement Status
/* Purpose : This function returns the status of the current Spectrum Switching
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcSpecSwitStat (ViSession  instrSession,
                                                                          ViInt32   *MeasurementStatus,
                                                                          ViInt32   *CountingNo,
                                                                          ViInt32   *StatisticNo,
                                                                          ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_FetcStatus (instrSession, RSCMU_SPECSWIT, RSCMU_EPSK, MeasurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*===========================================================================*/
/* Function: Event Reporting Mode
/* Purpose : This function defines the events to be reported during the
/*           measurement (event reporting, see chapter 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecSwitErep (ViSession instrSession,
                                                                          ViInt32   Mode,
                                                                          ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfReporting (instrSession, RSCMU_SPECSWIT, RSCMU_EPSK, Mode, errorMessage);
}

/*===========================================================================*/
/* Function: Read
/* Purpose : This function starts the measurement and outputs some results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadSpecSwit (ViSession  instrSession,
                                                                      ViReal64  *referencePower,
                                                                      ViInt32   *matching,
                                                                      ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasSpecSwit (instrSession, RSCMU_COMMAND_READ, RSCMU_EPSK, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This function only outputs the results without any care of the
/*           measurement state.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcSpecSwit (ViSession  instrSession,
                                                                      ViReal64  *referencePower,
                                                                      ViInt32   *matching,
                                                                      ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasSpecSwit (instrSession, RSCMU_COMMAND_FETC, RSCMU_EPSK, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This function waits until the results are valid for the first
/*           time (depending on the chosen statistic count) and then outputs
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampSpecSwit (ViSession  instrSession,
                                                                      ViReal64  *referencePower,
                                                                      ViInt32   *matching,
                                                                      ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasSpecSwit (instrSession, RSCMU_COMMAND_SAMP, RSCMU_EPSK, referencePower, matching, errorMessage);
}

/*===========================================================================*/
/* Function: Read
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadArrSpecSwit (ViSession instrSession,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasArrSpecSwit (instrSession, RSCMU_COMMAND_READ, RSCMU_EPSK, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcArrSpecSwit (ViSession instrSession,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasArrSpecSwit (instrSession, RSCMU_COMMAND_FETC, RSCMU_EPSK, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampArrSpecSwit (ViSession instrSession,
                                                                         ViReal64  BurstPower[],
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasArrSpecSwit (instrSession, RSCMU_COMMAND_SAMP, RSCMU_EPSK, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Read (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadSubArrSpecSwit (ViSession instrSession,
                                                                            ViReal64  BurstPower[],
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasSubArrSpecSwit (instrSession, RSCMU_COMMAND_READ, RSCMU_EPSK, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcSubArrSpecSwit (ViSession instrSession,
                                                                            ViReal64  BurstPower[],
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasSubArrSpecSwit (instrSession, RSCMU_COMMAND_FETC, RSCMU_EPSK, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampSubArrSpecSwit (ViSession instrSession,
                                                                            ViReal64  BurstPower[],
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasSubArrSpecSwit (instrSession, RSCMU_COMMAND_SAMP, RSCMU_EPSK, BurstPower, errorMessage);
}

/*===========================================================================*/
/* Function: Configure Additional Measurepoints
/* Purpose : This function permits to configure the frequencies for two
/*           additional Measurepoints for spectrum switching measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecSwitConfAMP (ViSession instrSession,
                                                      ViInt32   enableMP1,
                                                      ViReal64  frequencyMP1,
                                                      ViInt32   enableMP2,
                                                      ViReal64  frequencyMP2,
                                                      ViChar    errorMessage[])
{
  return RSCMU_ConfSpecSwitAddMeaPoints (instrSession, RSCMU_EPSK, enableMP1, frequencyMP1, enableMP2, frequencyMP2, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch scalar results for Additional Measurepoints
/* Purpose : This function output the off-carrier power due to switching
/*           in the additional Measurepoints.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcSpecSwitAMP (ViSession instrSession,
                                                  ViReal64  *valueMP1Neg,
                                                  ViReal64  *valueMP1Pos,
                                                  ViReal64  *valueMP2Neg,
                                                  ViReal64  *valueMP2Pos,
                                                  ViChar    errorMessage[])
{
  return RSCMU_FetcSpecSwitAddMeaPoints (instrSession, RSCMU_EPSK, valueMP1Neg, valueMP1Pos, valueMP2Neg, valueMP2Pos, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    TEST OBJECT SPECTRUM/MODULATION
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecModContDef (ViSession instrSession,
                                                                            ViInt32   DefaultValues,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfContDef(instrSession, RSCMU_SPECMOD, RSCMU_EPSK, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecModContRep (ViSession  instrSession,
                                                                            ViInt32    Repetition,
                                                                            ViInt32    StopCondition,
                                                                            ViInt32    StepMode,
                                                                            ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfControlRep(instrSession, RSCMU_SPECMOD, RSCMU_EPSK, Repetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Grid On/Off
/* Purpose : This function switches the grid lines in the test diagrams on or
/*           off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_DispSpecModContGrid (ViSession instrSession,
                                                                             ViInt32   gridLines,
                                                                             ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_DisplayGrid (instrSession, RSCMU_SPECMOD, RSCMU_EPSK, gridLines, errorMessage);
}

/*===========================================================================*/
/* Function: Default limit Lines
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecModLimLineDef (ViSession instrSession,
                                                                               ViInt32   DefaultValues,
                                                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfLimLineDef (instrSession, RSCMU_SPECMOD, RSCMU_EPSK, DefaultValues, errorMessage);
}

/*===========================================================================*/
/* Function: Reference Power
/* Purpose : This function defines the MS carrier output power domain where
/*           the limit lines are to be determined by linear interpolation
/*           (see Table 1). Below Min. Power, the lower limit line applies,
/*           above Max. Power, the upper limit line applies.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecModLimLinRefp (ViSession instrSession,
                                                                               ViReal64  minPower,
                                                                               ViReal64  maxPower,
                                                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfSpecModLimLineRefp (instrSession, RSCMU_EPSK, minPower, maxPower, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines
/* Purpose : These commands activate and define limit lines for the spectrum
/*           due to modulation measurement.
/*           The limit lines for the spectrum due to modulation as specified
/*           in standard GSM 05.05 depend on the GSM band, the frequency, and
/*           (for frequencies that differ from the carrier frequency by more
/*           than 400 kHz) on the output power of the mobile station.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecModLimLine (ViSession instrSession,
                                                                            ViInt32   measurePoint,
                                                                            ViInt32   enable,
                                                                            ViReal64  minPower,
                                                                            ViReal64  maxPower,
                                                                            ViReal64  AbsLevel,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfSpecModLimLine (instrSession, RSCMU_EPSK, measurePoint, enable, minPower, maxPower, AbsLevel, errorMessage);
}

/*===========================================================================*/
/* Function: Limit Lines On/Off
/* Purpose : This function switches the limit checking for all measurepoints.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecModLimLineMod (ViSession instrSession,
                                                                               ViInt32   limitLines,
                                                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfSpecModLimLineMod (instrSession, RSCMU_EPSK, limitLines, errorMessage);
}

/*===========================================================================*/
/* Function: Statistic Count
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecModCont (ViSession instrSession,
                                                                         ViInt32   MeasuredValuesType,
                                                                         ViInt32   NbBurst,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfControl (instrSession, RSCMU_SPECMOD, RSCMU_EPSK, MeasuredValuesType,  NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecModContRepSta (ViSession  instrSession,
                                                                               ViInt32    NbRepetition,
                                                                               ViInt32    StopCondition,
                                                                               ViInt32    StepMode,
                                                                               ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfContRepStat(instrSession, RSCMU_SPECMOD, RSCMU_EPSK, NbRepetition, StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Measure Points
/* Purpose : This function permits to select which frequencies a spectrum
/*           modulation measurement is performed. A reduction of the
/*           measurement points enhances the measurement speed.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecModContMpo (ViSession  instrSession,
                                                                            ViInt32    MeasurePoint,
                                                                            ViInt32    Enable,
                                                                            ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfSpecModContMpo (instrSession, RSCMU_EPSK, MeasurePoint, Enable, errorMessage);
}

/*===========================================================================*/
/* Function: Burst Power SubRanges
/* Purpose : This function configurates the READ..., FETCh... and
/*           SAMPle:SUBArrays:MODulation:SWITching commands.
/*           If the requested number of results exceeds the measurement
/*           range, the count parameter will be corrected by the system.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSubSpecMod (ViSession instrSession,
                                                                        ViInt32   Mode,
                                                                        ViReal64  FirstMeasurementFreq,
                                                                        ViInt32   MeasureResultsNumber,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, FirstMeasurementFreq, -1.8, 1.8, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, MeasureResultsNumber, 1, 23, RSCMU_ERROR_PARAMETER4, errorMessage);

  return RSCMU_ConfSubarrays (instrSession, RSCMU_SPECMOD, RSCMU_EPSK, Mode, FirstMeasurementFreq, MeasureResultsNumber, errorMessage);
}

/*===========================================================================*/
/* Function: Init
/* Purpose : Start measurement without waiting => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_InitSpecMod (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_INIT, RSCMU_SPECMOD, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : Abort measurement and switch off => OFF
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_AborSpecMod (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_ABOR, RSCMU_SPECMOD, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : Stop measurement => STOP
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_StopSpecMod (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_STOP, RSCMU_SPECMOD, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : Next measurement step (only counting mode) => RUN
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ContSpecMod (ViSession instrSession,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_SendControlCommand (instrSession, RSCMU_COMMAND_CONT, RSCMU_SPECMOD, RSCMU_EPSK, errorMessage);
}

/*===========================================================================*/
/* Function: Spectrum Modulation Measurement Status
/* Purpose : This function returns the status of the current Spectrum
/*           Modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcSpecModStat (ViSession  instrSession,
                                                                         ViInt32   *MeasurementStatus,
                                                                         ViInt32   *CountingNo,
                                                                         ViInt32   *StatisticNo,
                                                                         ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_FetcStatus (instrSession, RSCMU_SPECMOD, RSCMU_EPSK, MeasurementStatus, CountingNo, StatisticNo, errorMessage);
}

/*===========================================================================*/
/* Function: Event Reporting Mode
/* Purpose : This function defines the events to be reported during the
/*           measurement (event reporting, see chapter 5).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecModErep (ViSession instrSession,
                                                                         ViInt32   Mode,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_ConfReporting (instrSession, RSCMU_SPECMOD, RSCMU_EPSK, Mode, errorMessage);
}

/*===========================================================================*/
/* Function: Start single shot measurement and return results
/* Purpose : This function starts a single shot measurement and returns the
/*           results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadSpecMod (ViSession  instrSession,
                                                                     ViReal64  *ReferencePower,
                                                                     ViInt32   *Matching,
                                                                     ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasSpecMod (instrSession, RSCMU_COMMAND_READ, RSCMU_EPSK, ReferencePower, Matching, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This function only outputs the results without any care of the
/*           measurement state.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcSpecMod (ViSession  instrSession,
                                                                     ViReal64  *ReferencePower,
                                                                     ViInt32   *Matching,
                                                                     ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasSpecMod (instrSession, RSCMU_COMMAND_FETC, RSCMU_EPSK, ReferencePower, Matching, errorMessage);
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This function waits until the results are valid for the first
/*           time (depending on the chosen statistic count) and then outputs
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampSpecMod (ViSession  instrSession,
                                                                     ViReal64  *ReferencePower,
                                                                     ViInt32   *Matching,
                                                                     ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status;

  if((RSCMU_Status = RSCMU_CheckMinFwVersion (instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_MeasSpecMod (instrSession, RSCMU_COMMAND_SAMP, RSCMU_EPSK, ReferencePower, Matching, errorMessage);
}

/*===========================================================================*/
/* Function: Read
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadArrSpecMod (ViSession instrSession,
                                                  ViReal64  BurstPower[],
                                                  ViChar    errorMessage[])
{
  RETMSG(RSCMU_MeasArray( instrSession, "READ:ARRay:SPECtrum:MODulation:EPSK"
                                     ,BurstPower, errorMessage));
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcArrSpecMod (ViSession instrSession,
                                                  ViReal64  BurstPower[],
                                                  ViChar    errorMessage[])
{
  RETMSG(RSCMU_MeasArray( instrSession, "FETCh:ARRay:SPECtrum:MODulation:EPSK"
                                     ,BurstPower, errorMessage));
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampArrSpecMod (ViSession instrSession,
                                                  ViReal64  BurstPower[],
                                                  ViChar    errorMessage[])
{
  RETMSG(RSCMU_MeasArray( instrSession, "SAMPle:ARRay:SPECtrum:MODulation:EPSK"
                                     ,BurstPower, errorMessage));
}

/*===========================================================================*/
/* Function: Read (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadSubArrSpecMod (ViSession instrSession,
                                                    ViReal64  BurstPower[],
                                                    ViChar    errorMessage[])
{
  RETMSG(RSCMU_MeasArray( instrSession, "READ:SUBarrays:SPECtrum:MODulation:EPSK"
                                        ,BurstPower, errorMessage));
}

/*===========================================================================*/
/* Function: Fetch (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcSubArrSpecMod (ViSession instrSession,
                                                    ViReal64  BurstPower[],
                                                    ViChar    errorMessage[])
{
  RETMSG(RSCMU_MeasArray( instrSession, "FETCh:SUBarrays:SPECtrum:MODulation:EPSK"
                                        ,BurstPower, errorMessage));
}

/*===========================================================================*/
/* Function: Sample (SubArray...)
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampSubArrSpecMod (ViSession instrSession,
                                                    ViReal64  BurstPower[],
                                                    ViChar    errorMessage[])
{
  RETMSG(RSCMU_MeasArray( instrSession, "SAMPle:SUBarrays:SPECtrum:MODulation:EPSK"
                                        ,BurstPower, errorMessage));
}



/*****************************************************************************/
/*****************************************************************************/
/*========== CLASS: (E)GPRS MEASUREMENT (K42, K43) ==========================*/
/*****************************************************************************/
/*****************************************************************************/


/*****************************************************************************/
/*= (E)GPRS SIGNALLING ======================================================*/
/*****************************************************************************/
/*============================================================================
/*  CONNECTION CONTROL
/*===========================================================================*/
/*===========================================================================*/
/* Function: Controlling the Signalling
/* Purpose : This function changes between the different packet data
/*           signalling states of the CMU.
/*
/*           Available values:
/*           SOFF : Switch off BCCH signal (signal off)
/*           SON  : Switch on BCCH signal (signal on)
/*           CTMA : Connect Test Mode A
/*           CTMB : Connect Test Mode B
/*           CRA  : Connect Reduced Signalling Mode A
/*           CRS  : Connect Reduced Signalling Mode B
/*           CDL  : Connect Downlink only
/*           CBL  : Connect Block ErrorRate (BLER)
/*           CRES : Connect Reduced Signalling Mode Symmetrical  (EGPRS)
/*           CREA : Connect Reduced Signalling Mode Asymmetrical (EGPRS)
/*           CLBS : Connect Loopback Symmetrical  (EGPRS)
/*           CLBA : Connect Loopback Asymmetrical (EGPRS)
/*           DISC : Disconnect
/*           HAND : Handover
 *
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignPdatAct (ViSession instrSession,
                                                                        ViInt32   signallingState,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViInt32     prevState;
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the function is correctly used:
  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_21)
  {
    CHECK_VI_INT32_RANGE(instrSession, signallingState, 0, 8, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else
    if ((p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V3_21) && (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_50))
    {
      CHECK_VI_INT32_RANGE(instrSession, signallingState, 0, 11, RSCMU_ERROR_PARAMETER2, errorMessage);
    }
    else
    if ((p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V3_50) && (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V4_10))    
    {
      CHECK_VI_INT32_RANGE(instrSession, signallingState, RSCMU_GPRS_CONT_SOFF, RSCMU_GPRS_CONT_CLBA, RSCMU_ERROR_PARAMETER2, errorMessage);
    }
    else
    {
      CHECK_VI_INT32_RANGE(instrSession, signallingState, RSCMU_GPRS_CONT_SOFF, RSCMU_GPRS_CONT_CBUL, RSCMU_ERROR_PARAMETER2, errorMessage);
    }
        

  switch (signallingState)
  {
    case RSCMU_GPRS_CONT_SOFF:
      if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:PDAT:ACT SOFF", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;
    break;

    case RSCMU_GPRS_CONT_SON:
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensPdatStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU_Status;
      // Be sure that CMU transmits no control channel signal
      if (prevState != RSCMU_GPRS_STATE_OFF)
      {
        // neant
      }
      else
      {
        if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:PDAT:ACT SON", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
          return RSCMU_Status;
      }
    break;

    case RSCMU_GPRS_CONT_CTMA:
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensPdatStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU_Status;
      // Be sure that GPRS-attach has succeeded or connecting is in progress or in Idle
      if ((prevState != RSCMU_GPRS_STATE_ATT) && (prevState != RSCMU_GPRS_STATE_CTBF) && (prevState != RSCMU_GPRS_STATE_IDLE))
        return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
      if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:PDAT:ACT CTMA", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;
    break;

    case RSCMU_GPRS_CONT_CTMB:
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensPdatStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU_Status;
      // Be sure that GPRS-attach has succeeded or connecting is in progress or in Idle
      if ((prevState != RSCMU_GPRS_STATE_ATT) && (prevState != RSCMU_GPRS_STATE_CTBF) && (prevState != RSCMU_GPRS_STATE_IDLE))
        return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
      if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:PDAT:ACT CTMB", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;
    break;

    case RSCMU_GPRS_CONT_DISC:
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensPdatStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU_Status;
      // Be sure that SignallingState is TBF Established or TBFEstablishedDualBand
      if ((prevState != RSCMU_GPRS_STATE_TEST) && (prevState != RSCMU_GPRS_STATE_TED))
        return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
      if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:PDAT:ACT DISC", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;
    break;

    case RSCMU_GPRS_CONT_CRS:
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensPdatStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU_Status;
      // Be sure that GPRS-attach has succeeded or connecting is in progress or in Idle
      if ((prevState != RSCMU_GPRS_STATE_ATT) && (prevState != RSCMU_GPRS_STATE_CTBF) && (prevState != RSCMU_GPRS_STATE_IDLE))
        return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
      if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:PDAT:ACT CRS", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;
    break;

    case RSCMU_GPRS_CONT_CBL:
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensPdatStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU_Status;
      // Be sure that GPRS-attach has succeeded or connecting is in progress or in Idle
      if ((prevState != RSCMU_GPRS_STATE_ATT) && (prevState != RSCMU_GPRS_STATE_CTBF) && (prevState != RSCMU_GPRS_STATE_IDLE))
        return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
      if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:PDAT:ACT CBL", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;
    break;

    case RSCMU_GPRS_CONT_CDL:
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensPdatStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU_Status;
      // Be sure that GPRS-attach has succeeded or connecting is in progress or in Idle
      if ((prevState != RSCMU_GPRS_STATE_ATT) && (prevState != RSCMU_GPRS_STATE_CTBF) && (prevState != RSCMU_GPRS_STATE_IDLE))
        return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
      if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:PDAT:ACT CDL", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;
    break;

    case RSCMU_GPRS_CONT_CRA:
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensPdatStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU_Status;
      // Be sure that GPRS-attach has succeeded or connecting is in progress or in Idle
      if ((prevState != RSCMU_GPRS_STATE_ATT) && (prevState != RSCMU_GPRS_STATE_CTBF) && (prevState != RSCMU_GPRS_STATE_IDLE))
        return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
      if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:PDAT:ACT CRA", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;
    break;

    case RSCMU_GPRS_CONT_CRES:
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensPdatStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU_Status;
      // Be sure that GPRS-attach has succeeded or connecting is in progress or in Idle
      if ((prevState != RSCMU_GPRS_STATE_ATT) && (prevState != RSCMU_GPRS_STATE_CTBF) && (prevState != RSCMU_GPRS_STATE_IDLE))
        return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
      if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:PDAT:ACT CRES", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;
    break;

    case RSCMU_GPRS_CONT_CREA:
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensPdatStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU_Status;
      // Be sure that GPRS-attach has succeeded or connecting is in progress or in Idle
      if ((prevState != RSCMU_GPRS_STATE_ATT) && (prevState != RSCMU_GPRS_STATE_CTBF) && (prevState != RSCMU_GPRS_STATE_IDLE))
        return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
      if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:PDAT:ACT CREA", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;
    break;

    case RSCMU_GPRS_CONT_HAND:
        //Handover
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensPdatStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU_Status;
      // Be sure that SignallingState is TBF Established or TBF Established DualBand
      if ((prevState != RSCMU_GPRS_STATE_TEST) && (prevState != RSCMU_GPRS_STATE_TED))
        return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
      if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:PDAT:ACT HAND", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;
    break;

    case RSCMU_GPRS_CONT_CLBS:
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensPdatStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU_Status;
      // Be sure that GPRS-attach has succeeded or connecting is in progress or in Idle
      if ((prevState != RSCMU_GPRS_STATE_ATT) && (prevState != RSCMU_GPRS_STATE_CTBF) && (prevState != RSCMU_GPRS_STATE_IDLE))
        return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
      if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:PDAT:ACT CLBS", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;
    break;

    case RSCMU_GPRS_CONT_CLBA:
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensPdatStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU_Status;
      // Be sure that GPRS-attach has succeeded or connecting is in progress or in Idle
      if ((prevState != RSCMU_GPRS_STATE_ATT) && (prevState != RSCMU_GPRS_STATE_CTBF) && (prevState != RSCMU_GPRS_STATE_IDLE))
        return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
      if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:PDAT:ACT CLBA", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;
    break;
    case RSCMU_GPRS_CONT_CBUL:
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensPdatStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU_Status;
      // Be sure that GPRS-attach has succeeded or connecting is in progress or in Idle
      if ((prevState != RSCMU_GPRS_STATE_ATT) && (prevState != RSCMU_GPRS_STATE_CBUL) && (prevState != RSCMU_GPRS_STATE_IDLE))
        return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
      if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:PDAT:ACT CBUL", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;
    break;

    case RSCMU_GPRS_CONT_SAT:
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensPdatStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU_Status;
      // Be sure that GPRS-attach has succeeded or connecting is in progress or in Idle
      if ((prevState != RSCMU_GPRS_STATE_ATT) && (prevState != RSCMU_GPRS_STATE_CTBF) && (prevState != RSCMU_GPRS_STATE_IDLE))
        return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
      if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:PDAT:ACT SAT", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;
    break;
    case RSCMU_GPRS_CONT_CRUD:
      if ((RSCMU_Status = RSCMU_GSM_Sig_SensPdatStat (instrSession, &prevState, errorMessage))<0)
        return RSCMU_Status;
      // Be sure that GPRS-attach has succeeded or connecting is in progress or in Idle
      if ((prevState != RSCMU_GPRS_STATE_ATT) && (prevState != RSCMU_GPRS_STATE_CTBF) && (prevState != RSCMU_GPRS_STATE_IDLE))
        return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_SIGN_STAT, errorMessage);
      if ((RSCMU_Status = RSCMU_Query (instrSession, "PROC:SIGN:PDAT:ACT CRUD", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;
    break;
  }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Sense
/* Purpose : This command returns the current GPRS service state. It is
/*           available with option CMU-K42, GPRS software Extension, only.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensPdatStat (ViSession  instrSession,
                                                                     ViInt32   *ServiceState,
                                                                     ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_01)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_01, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU_Status = RSCMU_Query (instrSession, "SENS:SIGN:PDAT:STAT?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Extract the CMU response:
  // FW >= 3.01
  if (strncmp ("IDLE", rdBuf, 4) == 0)
    *ServiceState = RSCMU_GPRS_STATE_IDLE;
  else if (strncmp ("ATT", rdBuf, 3) == 0)
    *ServiceState = RSCMU_GPRS_STATE_ATT;
  else if (strncmp ("RAUP", rdBuf, 4) == 0)
    *ServiceState = RSCMU_GPRS_STATE_RAUP;
  else if (strncmp ("AIPR", rdBuf, 4) == 0)
    *ServiceState = RSCMU_GPRS_STATE_AIPR;
  else if (strncmp ("DIPR", rdBuf, 4) == 0)
    *ServiceState = RSCMU_GPRS_STATE_DIPR;
  // FW >= 3.05
  else if (strncmp ("SOFF", rdBuf, 4) == 0)
    *ServiceState = RSCMU_GPRS_STATE_OFF;
  else if (strncmp ("CTBF", rdBuf, 4) == 0)
    *ServiceState = RSCMU_GPRS_STATE_CTBF;
  else if (strncmp ("TEST", rdBuf, 4) == 0)
    *ServiceState = RSCMU_GPRS_STATE_TEST;
  else if (strncmp ("TED", rdBuf, 3) == 0)
    *ServiceState = RSCMU_GPRS_STATE_TED;
  // FW >= 4.11
  else if (strncmp ("BULT", rdBuf, 4) == 0)
    *ServiceState = RSCMU_GPRS_STATE_CBUL;
  else
  {
    *ServiceState = RSCMU_UNKNOWN_STATE;
    return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_GPRS_STAT, errorMessage);
  }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Sense GPRS Service
/* Purpose : This function returns the current GPRS service. The
/*           different test modes are accessed via PROCedure:SIGNalling:
/*           PDATa:ACTion (see p. 6.188).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensSignPdatServ (ViSession  instrSession,
                                                                         ViInt32   *Service,
                                                                         ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Sense the current signalling state of the CMU
  if ((RSCMU_Status = RSCMU_Query (instrSession, "SENS:SIGN:PDAT:SERV?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Extract the CMU response:
  if (strncmp ("TMA", rdBuf, 3) == 0)
    *Service = RSCMU_GPRS_SERV_TMA;
  if (strncmp ("TMB", rdBuf, 3) == 0)
    *Service = RSCMU_GPRS_SERV_TMB;
  if (strncmp ("RSIG", rdBuf, 4) == 0)
    *Service = RSCMU_GPRS_SERV_RSIG;
  if (strncmp ("RSA", rdBuf, 3) == 0)
    *Service = RSCMU_GPRS_SERV_RSA;
  if (strncmp ("RSCS", rdBuf, 4) == 0)
    *Service = RSCMU_GPRS_SERV_RSCS;
  if (strncmp ("RSCA", rdBuf, 4) == 0)
    *Service = RSCMU_GPRS_SERV_RSCA;
  if (strncmp ("DLON", rdBuf, 4) == 0)
    *Service = RSCMU_GPRS_SERV_DLON;
  if (strncmp ("BLER", rdBuf, 4) == 0)
    *Service = RSCMU_GPRS_SERV_BLER;
  if (strncmp ("LBS", rdBuf, 3) == 0)
    *Service = RSCMU_GPRS_SERV_LBS;
  if (strncmp ("LBA", rdBuf, 3) == 0)
    *Service = RSCMU_GPRS_SERV_LBA;
  if (strncmp ("ATES", rdBuf, 4) == 0)
    *Service = RSCMU_GPRS_SERV_ATES;
  if (strncmp ("BULT", rdBuf, 4) == 0)
    *Service = RSCMU_GPRS_SERV_BULT;
  if (strncmp ("RUDL", rdBuf, 4) == 0)
    *Service = RSCMU_GPRS_SERV_RUDL;

  return RSCMU_Status;
}

/*-----------------------------------------------------------------------------
 * Multi Slot
 *-----------------------------------------------------------------------------
 */

/*===========================================================================*/
/* Function: RF Channel
/* Purpose : This function changes the RF channel that the CMU uses for data
/*           transfer while it is in test mode (current parameter).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignPdatMslChan (ViSession instrSession,
                                                                            ViInt32   TchNumber,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarSession;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  if (p_globalvarSession->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Get the Globals
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  // Which Current Fonction Group?
  if (strncmp ("\"GSM400MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    if ((RSCMU_invalidViInt32Range (TchNumber, 259, 293)) && (RSCMU_invalidViInt32Range (TchNumber, 306, 340)))
      return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM850MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, TchNumber, 128, 251, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    if ((RSCMU_invalidViInt32Range (TchNumber, 0, 124)) && (RSCMU_invalidViInt32Range (TchNumber, 955, 1023)))
      return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1800MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, TchNumber, 512, 885, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, TchNumber, 512, 810, RSCMU_ERROR_PARAMETER2, errorMessage);
  }

  sprintf (wrtBuf, "PROC:SIGN:PDAT:MSL:CHAN %d",TchNumber);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}


/*===========================================================================*/
/* Function: Automatic Slot Configuration
/* Purpose : This function enables or disables automatically activation of
/*           an appropriate number of slots that is suitable for a particular
/*           measurement and supported by the connected MS.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignPdatAutSconf (ViSession instrSession,
                                                      ViInt32   enable,
                                                      ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_50, RSCMU_ERROR_FW_VERSION_3_50));

    RETMSG(RSCMU_setEnum(instrSession, "CONFigure:SIGNalling:PDATa:ASConfig:ENABle", enable, mode_On_Off,
                       RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Pdata Slot Configuration
/* Purpose : This function changes the slot configuration and the RF levels
/*           that the CMU uses in test mode (current parameters). All levels
/*           are relative to the reference level defined via RSCMU_GSM_Sig_
/*           BssPdatMslRlev.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignPdatMslSconf (ViSession instrSession, ViInt32   MainTS,
                                                      ViInt32   DL0Enable,ViInt32   DL1Enable,ViInt32   DL2Enable,ViInt32   DL3Enable,ViInt32   DL4Enable,ViInt32   DL5Enable,ViInt32   DL6Enable,ViInt32   DL7Enable,
                                                      ViReal64  DL0Level,ViReal64  DL1Level,ViReal64  DL2Level,ViReal64  DL3Level,ViReal64  DL4Level,ViReal64  DL5Level,ViReal64  DL6Level,ViReal64  DL7Level,
                                                      ViInt32   UL0Enable,ViInt32   UL1Enable,ViInt32   UL2Enable,ViInt32   UL3Enable,ViInt32   UL4Enable,ViInt32   UL5Enable,ViInt32   UL6Enable,ViInt32   UL7Enable,
                                                      ViInt32   UL0Gamma,ViInt32   UL1Gamma,ViInt32   UL2Gamma,ViInt32   UL3Gamma,ViInt32   UL4Gamma,ViInt32   UL5Gamma,ViInt32   UL6Gamma,ViInt32   UL7Gamma,
                                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

   // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE (instrSession, MainTS, 0, 7, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) DL0Enable, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) DL1Enable, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) DL2Enable, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) DL3Enable, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) DL4Enable, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) DL5Enable, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) DL6Enable, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) DL7Enable, RSCMU_ERROR_PARAMETER10, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL0Level, -127, 127, RSCMU_ERROR_PARAMETER11, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL1Level, -127, 127, RSCMU_ERROR_PARAMETER12, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL2Level, -127, 127, RSCMU_ERROR_PARAMETER13, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL3Level, -127, 127, RSCMU_ERROR_PARAMETER14, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL4Level, -127, 127, RSCMU_ERROR_PARAMETER15, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL5Level, -127, 127, RSCMU_ERROR_PARAMETER16, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL6Level, -127, 127, RSCMU_ERROR_PARAMETER17, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL7Level, -127, 127, RSCMU_ERROR_PARAMETER18, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) UL0Enable, RSCMU_ERROR_PARAMETER19, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) UL1Enable, RSCMU_ERROR_PARAMETER20, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) UL2Enable, RSCMU_ERROR_PARAMETER21, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) UL3Enable, RSCMU_ERROR_PARAMETER22, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) UL4Enable, RSCMU_ERROR_PARAMETER23, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) UL5Enable, RSCMU_ERROR_PARAMETER24, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) UL6Enable, RSCMU_ERROR_PARAMETER25, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) UL7Enable, RSCMU_ERROR_PARAMETER26, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL0Gamma, 0, 31, RSCMU_ERROR_PARAMETER27, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL1Gamma, 0, 31, RSCMU_ERROR_PARAMETER28, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL2Gamma, 0, 31, RSCMU_ERROR_PARAMETER29, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL3Gamma, 0, 31, RSCMU_ERROR_PARAMETER30, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL4Gamma, 0, 31, RSCMU_ERROR_PARAMETER31, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL5Gamma, 0, 31, RSCMU_ERROR_PARAMETER32, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL6Gamma, 0, 31, RSCMU_ERROR_PARAMETER33, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL7Gamma, 0, 31, RSCMU_ERROR_PARAMETER34, errorMessage);


  sprintf (wrtBuf, "PROC:SIGN:PDAT:MSL:SCON %d,%s,%s,%s,%s,%s,%s,%s,%s,%lf,%lf,%lf,%lf,%lf,%lf,%lf,%lf,%s,%s,%s,%s,%s,%s,%s,%s,%d,%d,%d,%d,%d,%d,%d,%d"
       ,MainTS
       ,mode_On_Off[DL0Enable], mode_On_Off[DL1Enable], mode_On_Off[DL2Enable], mode_On_Off[DL3Enable], mode_On_Off[DL4Enable], mode_On_Off[DL5Enable], mode_On_Off[DL6Enable], mode_On_Off[DL7Enable]
       ,DL0Level, DL1Level, DL2Level, DL3Level, DL4Level, DL5Level, DL6Level, DL7Level
       ,mode_On_Off[UL0Enable], mode_On_Off[UL1Enable], mode_On_Off[UL2Enable], mode_On_Off[UL3Enable], mode_On_Off[UL4Enable], mode_On_Off[UL5Enable], mode_On_Off[UL6Enable], mode_On_Off[UL7Enable]
       ,UL0Gamma, UL1Gamma, UL2Gamma, UL3Gamma, UL4Gamma, UL5Gamma, UL6Gamma, UL7Gamma);


    RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Pdata Gamma Settings
/* Purpose : This function changes the the channel-specific power control
/*           parameters Gamma CH that the MS uses in TBFEst mode (current parameters).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignPdatMslGamma (ViSession instrSession,
                                                      ViInt32 TS0Gamma,
                                                      ViInt32 TS1Gamma,
                                                      ViInt32 TS2Gamma,
                                                      ViInt32 TS3Gamma,
                                                      ViInt32 TS4Gamma,
                                                      ViInt32 TS5Gamma,
                                                      ViInt32 TS6Gamma,
                                                      ViInt32 TS7Gamma,
                                                      ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_21, RSCMU_ERROR_FW_VERSION_3_21));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE  (instrSession, TS0Gamma, 0, 31, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS1Gamma, 0, 31, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS2Gamma, 0, 31, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS3Gamma, 0, 31, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS4Gamma, 0, 31, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS5Gamma, 0, 31, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS6Gamma, 0, 31, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS7Gamma, 0, 31, RSCMU_ERROR_PARAMETER9, errorMessage);

  sprintf (wrtBuf, "PROCedure:SIGNalling:PDATa:TCH:MSLot:MS:SCONfig:GAMMa %d,%d,%d,%d,%d,%d,%d,%d", TS0Gamma, TS1Gamma, TS2Gamma, TS3Gamma
                                                                                                  , TS4Gamma, TS5Gamma, TS6Gamma, TS7Gamma);

  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}



/*===========================================================================*/
/* !Only for compatibility!
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignPdatMslMtim (ViSession instrSession,
                                                                            ViInt32   MainTimeSlot,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, MainTimeSlot, 0, 7, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "PROC:SIGN:PDAT:MSL:MTIM %d", MainTimeSlot);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* !Only for compatibility!
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignPdatMslBsSconf (ViSession instrSession,
                                                                               ViInt32   TS0Enable,
                                                                               ViReal64  TS0Level,
                                                                               ViInt32   TS1Enable,
                                                                               ViReal64  TS1Level,
                                                                               ViInt32   TS2Enable,
                                                                               ViReal64  TS2Level,
                                                                               ViInt32   TS3Enable,
                                                                               ViReal64  TS3Level,
                                                                               ViInt32   TS4Enable,
                                                                               ViReal64  TS4Level,
                                                                               ViInt32   TS5Enable,
                                                                               ViReal64  TS5Level,
                                                                               ViInt32   TS6Enable,
                                                                               ViReal64  TS6Level,
                                                                               ViInt32   TS7Enable,
                                                                               ViReal64  TS7Level,
                                                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS0Enable, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS0Level, -127, 127, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS1Enable, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS1Level, -127, 127, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS2Enable, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS2Level, -127, 127, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS3Enable, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS3Level, -127, 127, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS4Enable, RSCMU_ERROR_PARAMETER10, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS4Level, -127, 127, RSCMU_ERROR_PARAMETER11, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS5Enable, RSCMU_ERROR_PARAMETER12, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS5Level, -127, 127, RSCMU_ERROR_PARAMETER13, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS6Enable, RSCMU_ERROR_PARAMETER14, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS6Level, -127, 127, RSCMU_ERROR_PARAMETER15, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS7Enable, RSCMU_ERROR_PARAMETER16, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS7Level, -127, 127, RSCMU_ERROR_PARAMETER17, errorMessage);

  sprintf (wrtBuf, "PROC:SIGN:PDAT:MSL:BS:SCON %s,%s,%s,%s,%s,%s,%s,%s,%lf,%lf,%lf,%lf,%lf,%lf,%lf,%lf", mode_On_Off[TS0Enable]
                                                                                                       , mode_On_Off[TS1Enable]
                                                                                                       , mode_On_Off[TS2Enable]
                                                                                                       , mode_On_Off[TS3Enable]
                                                                                                       , mode_On_Off[TS4Enable]
                                                                                                       , mode_On_Off[TS5Enable]
                                                                                                       , mode_On_Off[TS6Enable]
                                                                                                       , mode_On_Off[TS7Enable]
                                                                                                       , TS0Level
                                                                                                       , TS1Level
                                                                                                       , TS2Level
                                                                                                       , TS3Level
                                                                                                       , TS4Level
                                                                                                       , TS5Level
                                                                                                       , TS6Level
                                                                                                       , TS7Level);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* !Only for compatibility!
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignPdatMslMsSconf (ViSession instrSession,
                                                                               ViInt32   TS0Enable,
                                                                               ViInt32   TS0Gamma,
                                                                               ViInt32   TS1Enable,
                                                                               ViInt32   TS1Gamma,
                                                                               ViInt32   TS2Enable,
                                                                               ViInt32   TS2Gamma,
                                                                               ViInt32   TS3Enable,
                                                                               ViInt32   TS3Gamma,
                                                                               ViInt32   TS4Enable,
                                                                               ViInt32   TS4Gamma,
                                                                               ViInt32   TS5Enable,
                                                                               ViInt32   TS5Gamma,
                                                                               ViInt32   TS6Enable,
                                                                               ViInt32   TS6Gamma,
                                                                               ViInt32   TS7Enable,
                                                                               ViInt32   TS7Gamma,
                                                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_10)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS0Enable, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS0Gamma, 0, 31, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS1Enable, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS1Gamma, 0, 31, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS2Enable, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS2Gamma, 0, 31, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS3Enable, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS3Gamma, 0, 31, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS4Enable, RSCMU_ERROR_PARAMETER10, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS4Gamma, 0, 31, RSCMU_ERROR_PARAMETER11, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS5Enable, RSCMU_ERROR_PARAMETER12, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS5Gamma, 0, 31, RSCMU_ERROR_PARAMETER13, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS6Enable, RSCMU_ERROR_PARAMETER14, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS6Gamma, 0, 31, RSCMU_ERROR_PARAMETER15, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS7Enable, RSCMU_ERROR_PARAMETER16, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS7Gamma, 0, 31, RSCMU_ERROR_PARAMETER17, errorMessage);

  sprintf (wrtBuf, "PROC:SIGN:PDAT:MSL:MS:SCON %s,%s,%s,%s,%s,%s,%s,%s,%d,%d,%d,%d,%d,%d,%d,%d", mode_On_Off[TS0Enable]
                                                                                               , mode_On_Off[TS1Enable]
                                                                                               , mode_On_Off[TS2Enable]
                                                                                               , mode_On_Off[TS3Enable]
                                                                                               , mode_On_Off[TS4Enable]
                                                                                               , mode_On_Off[TS5Enable]
                                                                                               , mode_On_Off[TS6Enable]
                                                                                               , mode_On_Off[TS7Enable]
                                                                                               , TS0Gamma
                                                                                               , TS1Gamma
                                                                                               , TS2Gamma
                                                                                               , TS3Gamma
                                                                                               , TS4Gamma
                                                                                               , TS5Gamma
                                                                                               , TS6Gamma
                                                                                               , TS7Gamma);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}


/*
 *-----------------------------------------------------------------------------
 *    MS SIGNAL
 * ----------------------------------------------------------------------------
 */

/*===========================================================================*/
/* Function: Uplink Slot Configuration
/* Purpose : This function changes the slot configuration and the channel-
/*           specific power control parameters that the MS is to use in test
/*           mode (default parameters).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfMssPdatMslSconf (ViSession instrSession,
                                                                            ViInt32   TS0Enable,
                                                                            ViInt32   TS0Gamma,
                                                                            ViInt32   TS1Enable,
                                                                            ViInt32   TS1Gamma,
                                                                            ViInt32   TS2Enable,
                                                                            ViInt32   TS2Gamma,
                                                                            ViInt32   TS3Enable,
                                                                            ViInt32   TS3Gamma,
                                                                            ViInt32   TS4Enable,
                                                                            ViInt32   TS4Gamma,
                                                                            ViInt32   TS5Enable,
                                                                            ViInt32   TS5Gamma,
                                                                            ViInt32   TS6Enable,
                                                                            ViInt32   TS6Gamma,
                                                                            ViInt32   TS7Enable,
                                                                            ViInt32   TS7Gamma,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS0Enable, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS0Gamma, 0, 31, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS1Enable, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS1Gamma, 0, 31, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS2Enable, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS2Gamma, 0, 31, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS3Enable, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS3Gamma, 0, 31, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS4Enable, RSCMU_ERROR_PARAMETER10, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS4Gamma, 0, 31, RSCMU_ERROR_PARAMETER11, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS5Enable, RSCMU_ERROR_PARAMETER12, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS5Gamma, 0, 31, RSCMU_ERROR_PARAMETER13, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS6Enable, RSCMU_ERROR_PARAMETER14, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS6Gamma, 0, 31, RSCMU_ERROR_PARAMETER15, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS7Enable, RSCMU_ERROR_PARAMETER16, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS7Gamma, 0, 31, RSCMU_ERROR_PARAMETER17, errorMessage);

  sprintf (wrtBuf, "CONF:MSS:PDAT:MSL:SCON %s,%s,%s,%s,%s,%s,%s,%s,%d,%d,%d,%d,%d,%d,%d,%d", mode_On_Off [TS0Enable]
                                                                                           , mode_On_Off [TS1Enable]
                                                                                           , mode_On_Off [TS2Enable]
                                                                                           , mode_On_Off [TS3Enable]
                                                                                           , mode_On_Off [TS4Enable]
                                                                                           , mode_On_Off [TS5Enable]
                                                                                           , mode_On_Off [TS6Enable]
                                                                                           , mode_On_Off [TS7Enable]
                                                                                           , TS0Gamma
                                                                                           , TS1Gamma
                                                                                           , TS2Gamma
                                                                                           , TS3Gamma
                                                                                           , TS4Gamma
                                                                                           , TS5Gamma
                                                                                           , TS6Gamma
                                                                                           , TS7Gamma);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set PCL Value
/* Purpose : This function defines the power control level that the MS shall
/*           use in circuit-switched mode and the power control parameter
/*           PMAX that holds for packet-data mode. Both parameters are always
/*           equal. An overview of power control levels (PCL) in GSM is given
/*           in chapter 4 (see table or index).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfMssPdatCchPcl (ViSession instrSession,
                                                                          ViInt32   MobilePhonePCL,
                                                                          ViChar    errorMessage[])
{
  // Remote control is the same as in GSM Signalling:MS Signal configuration
  return RSCMU_GSM_Sig_ConfMssCchPcl (instrSession, MobilePhonePCL, errorMessage);
}

/* ----------------------------------------------------------------------------
 *   BS Signal Configuration
 *
 *   The subsystem BSSignal:PDATa configures the RF signal that the CMU
 *   transmits in packet data transfer mode. It corresponds to the Packet
 *   Data section in the BS Signal tab of the popup menu Connect. Control.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: P0 value
/* Purpose : This function defines the downlink power control parameter P0.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssPdatMslP0 (ViSession  instrSession,
                                                                         ViReal64   P0_Value,
                                                                         ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the function is correctly used
  CHECK_VI_REAL64_RANGE(instrSession, P0_Value, 0, 31, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set absolute level in used timeslot
  sprintf (wrtBuf, "CONF:BSS:PDAT:MSL:PZER %lf", P0_Value);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: RF Channel
/* Purpose : This function changes the RF channel that the CMU shall use for
/*           data transfer once it is in test mode (default parameter).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssPdatMslChan (ViSession instrSession,
                                                                           ViInt32   TrafficChannelNb,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarSession;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  if (p_globalvarSession->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Get the Globals
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  // Which Current Fonction Group?
  if (strncmp ("\"GSM400MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    if ((RSCMU_invalidViInt32Range (TrafficChannelNb, 259, 293)) && (RSCMU_invalidViInt32Range (TrafficChannelNb, 306, 340)))
      return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM850MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, TrafficChannelNb, 128, 251, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    if ((RSCMU_invalidViInt32Range (TrafficChannelNb, 0, 124)) && (RSCMU_invalidViInt32Range (TrafficChannelNb, 955, 1023)))
      return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1800MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, TrafficChannelNb, 512, 885, RSCMU_ERROR_PARAMETER2, errorMessage);
  }
  else if (strncmp ("\"GSM1900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, TrafficChannelNb, 512, 810, RSCMU_ERROR_PARAMETER2, errorMessage);
  }

  sprintf (wrtBuf, "CONF:BSS:PDAT:MSL:CHAN %d",TrafficChannelNb);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Reference Level
/* Purpose : This function changes the RF channel that the CMU shall use for
/*           data transfer once it is in test mode (default parameter).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensBssPdatMslRlev (ViSession  instrSession,
                                                                           ViInt32   *RefLevel,
                                                                           ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViReal64    RefLevelTmp;
  struct      RSCMU_SESSION_Globals  *p_globalvarSession;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  if (p_globalvarSession->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Get the reference level
  if ((RSCMU_Status = RSCMU_Query (instrSession, "BSS:PDAT:MSL:RLEV?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  if (strcmp (rdBuf, "NAN") != 0)
  {
    sscanf (rdBuf, "%lf", &RefLevelTmp);
    RefLevelTmp += 0.001; // To avoid a problem due to the fraction part
    *RefLevel = (ViInt32) RefLevelTmp;
  }
  else
  {
    *RefLevel = RSCMU_NAN_VI_INT32;
  }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Main Timeslot
/* Purpose : This function changes the main timeslot that the CMU and the MS
/*           shall use for data transfer during test mode (default parameter).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssPdatMslMtim (ViSession instrSession,
                                                                           ViInt32   MainTimeSlot,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, MainTimeSlot, 0, 7, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:BSS:PDAT:MSL:MTIM %d", MainTimeSlot);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Downlink Slot Configuration
/* Purpose : This function changes the slot configuration and the RF levels
/*           that the CMU shall use in test mode (default parameters). All
/*           levels are relative to the reference level defined via
/*           RSCMU_GSM_Sig_SensBssPdatMslRlev.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssPdatMslSconf (ViSession instrSession,
                                                                            ViInt32   TS0Enable,
                                                                            ViReal64  TS0Level,
                                                                            ViInt32   TS1Enable,
                                                                            ViReal64  TS1Level,
                                                                            ViInt32   TS2Enable,
                                                                            ViReal64  TS2Level,
                                                                            ViInt32   TS3Enable,
                                                                            ViReal64  TS3Level,
                                                                            ViInt32   TS4Enable,
                                                                            ViReal64  TS4Level,
                                                                            ViInt32   TS5Enable,
                                                                            ViReal64  TS5Level,
                                                                            ViInt32   TS6Enable,
                                                                            ViReal64  TS6Level,
                                                                            ViInt32   TS7Enable,
                                                                            ViReal64  TS7Level,
                                                                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS0Enable, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS0Level, -127, 127, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS1Enable, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS1Level, -127, 127, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS2Enable, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS2Level, -127, 127, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS3Enable, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS3Level, -127, 127, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS4Enable, RSCMU_ERROR_PARAMETER10, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS4Level, -127, 127, RSCMU_ERROR_PARAMETER11, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS5Enable, RSCMU_ERROR_PARAMETER12, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS5Level, -127, 127, RSCMU_ERROR_PARAMETER13, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS6Enable, RSCMU_ERROR_PARAMETER14, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS6Level, -127, 127, RSCMU_ERROR_PARAMETER15, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS7Enable, RSCMU_ERROR_PARAMETER16, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS7Level, -127, 127, RSCMU_ERROR_PARAMETER17, errorMessage);

  sprintf (wrtBuf, "CONF:BSS:PDAT:MSL:SCON %s,%s,%s,%s,%s,%s,%s,%s,%lf,%lf,%lf,%lf,%lf,%lf,%lf,%lf", mode_On_Off [TS0Enable]
                                                                                                   , mode_On_Off [TS1Enable]
                                                                                                   , mode_On_Off [TS2Enable]
                                                                                                   , mode_On_Off [TS3Enable]
                                                                                                   , mode_On_Off [TS4Enable]
                                                                                                   , mode_On_Off [TS5Enable]
                                                                                                   , mode_On_Off [TS6Enable]
                                                                                                   , mode_On_Off [TS7Enable]
                                                                                                   , TS0Level
                                                                                                   , TS1Level
                                                                                                   , TS2Level
                                                                                                   , TS3Level
                                                                                                   , TS4Level
                                                                                                   , TS5Level
                                                                                                   , TS6Level
                                                                                                   , TS7Level);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}



/*===========================================================================*/
/* Function: Edit Frequency Hopping Channel Sequence
/* Purpose : This function defines a hopping sequence containing up to 7 channel
/*           numbers. Off is used to shorten the hopping sequence. .
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssPdatFhopChan (ViSession instrSession,
                                                     ViChar channels[],
                                                     ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      *StrChan;
  ViChar      *DataValue;
  ViInt32     iChannel;
  ViUInt32     i;
  struct      RSCMU_SESSION_Globals  *p_globalvarSession;

  // Get the Globals
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  // Version manager
  if (p_globalvarSession->RSCMU_FW_Version < RSCMU200_V3_40)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_40, errorMessage);


  // Translates characters to uppercase:
  for (i=0; i<strlen (channels); i++)
    channels[i] = toupper(channels[i]);

  StrChan = (char *) malloc(sizeof(char)*strlen(channels)+1);
  strcpy(StrChan, channels);
  DataValue = strtok (channels, ",");

  if (strncmp ("\"GSM400MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    while (DataValue)
    {
      //Compares each channel with the GSM400 channel range
      if(!strstr((DataValue), "OFF"))
      {
        iChannel = atoi(DataValue);
        if((iChannel < 259) || (iChannel > 340))
        {
          free(StrChan);
          return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_CHANNEL_NUMBER, errorMessage);
        }
      }
      DataValue = strtok (NULL, ",");
    }
  }
  else if (strncmp ("\"GSM850MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    while (DataValue)
    {
      //Compares each channel with the GSM850 channel range
      if(!strstr((DataValue), "OFF"))
      {
        iChannel = atoi(DataValue);
        if((iChannel < 128) || (iChannel > 251))
        {
          free(StrChan);
          return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_CHANNEL_NUMBER, errorMessage);
        }
      }
      DataValue = strtok (NULL, ",");
    }
  }
  // Which Current Fonction Group?
  else if (strncmp ("\"GSM900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    while (DataValue)
    {
      //Compares each channel with the GSM900 channel range
      if(!strstr((DataValue), "OFF"))
      {
        iChannel = atoi(DataValue);
        if(((iChannel > 124) && (iChannel < 955)) || (iChannel > 1024))
        {
          free (StrChan);
          return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_CHANNEL_NUMBER, errorMessage);
        }
      }
      DataValue = strtok (NULL, ",");
    }
  }

  else if (strncmp ("\"GSM1800MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    while (DataValue)
    {
      //Compares each channel with the GSM1800 channel range
      if(!strstr((DataValue), "OFF"))
      {
        iChannel = atoi(DataValue);
        if((iChannel < 512) || (iChannel > 885))
        {
          free(StrChan);
          return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_CHANNEL_NUMBER, errorMessage);
        }
      }
      DataValue = strtok (NULL, ",");
    }
  }

  else if (strncmp ("\"GSM1900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    while (DataValue)
    {
      //Compares each channel with the GSM1900 channel range
      if(!strstr((DataValue), "OFF"))
      {
        iChannel = atoi(DataValue);
        if((iChannel < 512) || (iChannel > 810))
        {
          free(StrChan);
          return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_CHANNEL_NUMBER, errorMessage);
        }
      }
      DataValue = strtok (NULL, ",");
    }
  }

  // Configue the Hopping Sequence
  sprintf(wrtBuf, "CONFigure:BSSignal:PDATa:TCH:MSLot:FHOPping:SEQuence %s", StrChan);
  free(StrChan);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;

}

/*===========================================================================*/
/* Function: Frequency Hopping Enable
/* Purpose : This function enables or disables frequency hopping in the
/*           downlink traffic channel.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcBssPdatFhopEnable (ViSession instrSession,
                                                       ViInt32 enable,
                                                       ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_40, RSCMU_ERROR_FW_VERSION_3_40));

  RETMSG(RSCMU_setEnum(instrSession, "PROCedure:SIGNalling:PDATa:TCH:MSLot:FHOPping:ENABle",
                       enable, mode_On_Off,
                       RSCMU_ERROR_PARAMETER2));
}

/* ----------------------------------------------------------------------------
 *   NETWORK CONFIGURATION
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Network Support
/* Purpose : This function defines whether or not the CMU supports GPRS-attach.
/*           It is available with option CMU-K42, GPRS Software Extension, only.
/*           The GGPR setting comes into effect only if the MS under test
/*           supports GPRS.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwNSup (ViSession instrSession,
                                                                     ViInt32   setting,
                                                                     ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrSetting[]={"GGPR","GSM","GEGP",VI_NULL};

  // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_01,RSCMU_ERROR_FW_VERSION_3_01));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, setting, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:NSUP %s", StrSetting[setting]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set Routing Area Code (RAC)
/* Purpose : This function defines the routing area code for GPRS services.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwIdenRac (ViSession  instrSession,
                                                                        ViInt32    RoutingAreaCode,
                                                                        ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, RoutingAreaCode, RSCMU_RAC_MIN, RSCMU_RAC_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:IDEN:RAC %d", RoutingAreaCode);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}


/*===========================================================================*/
/* Main Service
/* This function switches between application test and test mode (circuit 
/* switched or packet data) connections. The two parameters CSWitched and 
/* PDATa are equivalent and close an application test session.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwMainServ (ViSession instrSession,
                                                  ViInt32 mainService,
                                                  ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[] = {"CSW", "PDAT", "ATES", VI_NULL};

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V5_00, RSCMU_ERROR_FW_VERSION_5_00));

    RETMSG(RSCMU_setEnum(instrSession, "CONFigure:NETWork:MSERvice",
                         mainService, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Main Service Query
/* This function returns whether the MS under test operates in GSM
/* or (E)GPRS mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensNetwMainServ (ViSession instrSession,
                                                  ViInt32 *mainService,
                                                  ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[] = {"CSW", "PDAT", "ATES", "NAN", VI_NULL};

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_05, RSCMU_ERROR_FW_VERSION_3_05));

    RETMSG(RSCMU_getEnum(instrSession, "NETW:MSER?",
                            mainService,
                            list,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: B52 Mode
/* Purpose : This function defines if the Speech codec is reserved for
/*           audio tests or supports BLER measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwB52Mode (ViSession instrSession,
                                                 ViInt32   Mode,
                                                 ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[] = {"SCOD", "MSUP", VI_NULL};

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_10, RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:NETW:B52M",
                         Mode, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Uplink State Flag
/* Purpose : This function defines the Uplink State Flag (USF) in the blocks
/*           transmitted to the MS while the CMU is in GPRS test mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatUsf (ViSession instrSession,
                                                                        ViInt32   flag,
                                                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, flag, 0, 7, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:PDAT:USF %d", flag);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}



/*===========================================================================*/
/* Function: Set the USF Duty Cycle
/* Purpose : This function...
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwPdatUSFDutyCycle (ViSession instrSession,
                                                      ViInt32 USFDutyCycle,
                                                      ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[] = {"A100","A000","A012", VI_NULL};

  // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_40, RSCMU_ERROR_FW_VERSION_3_40));

    RETMSG(RSCMU_setEnum(instrSession, "PROCedure:NETWork:PDATa:UDCYcle",
                         USFDutyCycle, list,
                         RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Set the Dynamic Allocation
/* Purpose : This command enables or disables extended dynamic allocation
/* of the mobile.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatEda (ViSession  instrSession,
                                                                        ViInt32    Enable,
                                                                        ViChar     errorMessage[])
{
  ViString    Str[] = {"OFF", "ON", "AUTO", VI_NULL};

  RETMSG(RSCMU_setEnum(instrSession, "CONFigure:NETWork:PDATa:EDAllocation",
                         Enable, Str,
                         RSCMU_ERROR_PARAMETER2));
}


/*===========================================================================*/
/* Function: Number of PDUs
/* Purpose : This function defines the number of Protocol Data Units (PDUs)
/*           that the MS is to transmit in the uplink during GPRS test mode A.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatNopdu (ViSession instrSession,
                                                   ViInt32   NumberOfPdus,
                                                   ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_05,RSCMU_ERROR_FW_VERSION_3_05));
  RETMSG(RSCMU_setViInt32(instrSession,
                          "CONF:NETW:PDAT:NOPD",
                          NumberOfPdus,
                          0, 4095,
                          RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Slot Offset
/* Purpose : This function defines the timeslot to be taken as the first
/*           downlink timeslot when the MS is in multi-slot operation.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatSoff (ViSession instrSession,
                                                                         ViInt32   SlotOffset,
                                                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, SlotOffset, 0, 7, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:NETW:PDAT:SOFF %d", SlotOffset);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Conf. Bit Stream
/* Purpose : This command defines the pseudo random bit sequence that the CMU
/*           transmits to the MS in GPRS test mode.
/*
/*           The CONFigure... command is available in the signalling states
/*           SOFF, IDLE, and ATT. It defines the bit stream before the GPRS
/*           test mode is established.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatBitStr (ViSession instrSession,
                                                                           ViInt32   Mode,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    Mode_Bit_Stream[] = {"","","PR9","PR11","PR15","PR16","FA0","FA1","FA01"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, RSCMU_SPEECH_PR9, RSCMU_SPEECH_FA01, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set the bit stream
  if (Mode < RSCMU_SPEECH_FA0)
    sprintf(wrtBuf, "CONF:NETW:PDAT:BITS %s",Mode_Bit_Stream[Mode]);
  else
    sprintf(wrtBuf, "CONF:NETW:PDAT:BITS %s",Mode_Bit_Stream[Mode-5]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*==================================================================================================*/
/* Function: Conf. Test Mode with ACK
/* Purpose : This command enables or disables the operating mode where the mobile
/* periodically transmits a PACKET_UPLINK_ACK_NACK message (GSM 04.60) while it is in test mode B.
/* SOFF, IDLE
/*
/*           The CONFigure... command is available in the signalling states
/*           SOFF, IDLE, and ATT. It defines the bit stream before the GPRS
/*           test mode is established.
/*==================================================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatTwack (ViSession instrSession,
                                                                           ViInt32   Enable,
                                                                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Enable, RSCMU_OFF, RSCMU_ON, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set the bit stream
  sprintf(wrtBuf, "CONF:NETW:PDAT:TWAC %s", mode_On_Off[Enable]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Proc. Bit Stream
/* Purpose : This command defines the pseudo random bit sequence that the CMU
/*           transmits to the MS in GPRS test mode.
/*
/*           The PROCedure... command is available in the signalling state TEST.
/*           It changes the bit stream during test mode, resets the device
/*           hardware to the new bit stream and continues the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcNetwPdatBitStr (ViSession instrSession,
                                                   ViInt32   Mode,
                                                   ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    Mode_Bit_Stream[] = {"","","PR9","PR11","PR15","PR16","FA0","FA1","FA01"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, RSCMU_SPEECH_PR9, RSCMU_SPEECH_FA01, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set the bit stream
  if (Mode < RSCMU_SPEECH_FA0)
    sprintf(wrtBuf, "PROC:NETW:PDAT:BITS %s",Mode_Bit_Stream[Mode]);
  else
    sprintf(wrtBuf, "PROC:NETW:PDAT:BITS %s",Mode_Bit_Stream[Mode-5]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: T avg_t
/* Purpose : This function specifies the signal level filter period for power
/*           control in packet transfer mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_PdatTavgt (ViSession instrSession,
                                           ViInt32 tAVG_T, ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    CHECK_VI_INT32_RANGE(instrSession, tAVG_T, 0, 31, RSCMU_ERROR_PARAMETER2, errorMessage);

    RETMSG(RSCMU_setViInt32(instrSession, "CONF:NETW:PDAT:TAVG",
                            tAVG_T,
                            0,31,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* BEP Period
/* This function specifies the BEP Period in packet transfer mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_PdatBepPeriod (ViSession instrSession,
                                               ViInt32 BEPPeriod,
                                               ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

  RETMSG(RSCMU_setViInt32(instrSession,
                          "CONFigure:NETWork:PDATa:BPERiod",
                          BEPPeriod,
                          0, 15,
                          RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: TRFL
/* Purpose : This function senables or disables the transfer of the packet
/*           data receiver reports in the uplink signal.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_PdatTrfl (ViSession instrSession,
                                          ViInt32 TRFL, ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    RETMSG(RSCMU_setViString(instrSession, "CONF:NETW:PDAT:TRFL",
                            mode_On_Off[TRFL],
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Single Measurement Report
/* Purpose : This function starts a DL SACCH block-error-rate test in the
/*           single shot repetition mode and output the measurement results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_PdatAct (ViSession instrSession,
                                         ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG (RSCMU_sendCmd (instrSession, "PROC:RREP:PDAT:ACT"));
}

/*===========================================================================*/
/* Function: Control Ack Type
/* Purpose : This function selects the format of the PACKET CONTROL ACKNOWLEDGMENT message
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_PdatCtrlAckType (ViSession instrSession,
                                                 ViInt32   independentValue,
                                                 ViInt32   controlAckType,
                                                 ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[] = {"NBUR","ABUR", VI_NULL};
    GET_WRT_BUF(instrSession);

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_52, RSCMU_ERROR_FW_VERSION_3_52));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, independentValue, RSCMU_DEF, RSCMU_CUR, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, controlAckType, RSCMU_NORMAL_BURST, RSCMU_ACCESS_BURST, RSCMU_ERROR_PARAMETER3, errorMessage);

    sprintf (wrtBuf, "%s:NETWork:PDATa:CATYpe", confProcArr[independentValue]);

    RETMSG(RSCMU_setEnum(instrSession,wrtBuf, controlAckType, list, RSCMU_ERROR_PARAMETER3));
}

/*===========================================================================*/
/* Function: Conf. Coding Scheme GPRS
/* Purpose : This function selects the GPRS coding scheme for packet data
/*           channels.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatGprsCsch (ViSession instrSession,
                                                                             ViInt32   Coding_Scheme,
                                                                             ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Coding_Scheme, RSCMU_CS1, RSCMU_CS4, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Set the bit stream
  sprintf(wrtBuf, "CONF:NETW:PDAT:GPRS:CSCH CS%d", Coding_Scheme);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Proc. Coding Scheme GPRS
/* Purpose : This function selects the GPRS coding scheme for packet data
/*           channels.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcNetwPdatGprsCsch (ViSession instrSession,
                                                      ViInt32   Coding_Scheme,
                                                      ViChar    errorMessage[])
{

    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[] = {"", "CS1", "CS2", "CS3", "CS4", VI_NULL};
    GET_WRT_BUF(instrSession);

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_10, RSCMU_ERROR_FW_VERSION_3_10));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, Coding_Scheme, RSCMU_CS1, RSCMU_CS4, RSCMU_ERROR_PARAMETER2, errorMessage);

    RETMSG(RSCMU_setEnum(instrSession, "PROC:NETW:PDAT:GPRS:CSCH", Coding_Scheme, list,
                       RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: BLER Polling Interval
/* Purpose : This function defines the BLER Polling Interval for GPRS. After
/*           the given number of radio frames the mobile sends an ACK/NACK
/*           message back to the R&S CMU. The polling rate can
/*           be increased by decreasing the BLER Polling Interval.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatBpinGprs
             (ViSession instrSession, ViInt32 BLERPollingInterval,
              ViChar _VI_FAR errorMessage[])

{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setViInt32(instrSession, "CONF:NETW:PDAT:BPIN:GPRS",
                            BLERPollingInterval, 1, 24,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Coding Scheme EGPRS
/* Purpose : This function selects the EGPRS coding scheme for packet data
/*           channels.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwPdatEgprsCsch (ViSession instrSession,
                                                     ViInt32 IndependentValue,
                                                     ViInt32 Coding_Scheme,
                                                      ViChar errorMessage[])
{

    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[] = {"","MCS1","MCS2","MCS3","MCS4","MCS5","MCS6","MCS7","MCS8","MCS9", VI_NULL};
    GET_WRT_BUF(instrSession);

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_10, RSCMU_ERROR_FW_VERSION_3_10));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, IndependentValue, RSCMU_DEF, RSCMU_CUR, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, Coding_Scheme, RSCMU_MCS1, RSCMU_MCS9, RSCMU_ERROR_PARAMETER3, errorMessage);

    sprintf (wrtBuf, "%s:NETW:PDAT:CSCH", confProcArr[IndependentValue]);

    RETMSG(RSCMU_setEnum(instrSession,wrtBuf, Coding_Scheme, list, RSCMU_ERROR_PARAMETER3));

}


/*===========================================================================*/
/* Function: Configure Punctering Scheme EGPRS
/* Purpose : This function selects the punctering schemes for EGPRS Coding Schemes
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwPdatPunctScheme (ViSession instrSession,
                                                       ViInt32 IndependentValue,
                                                       ViInt32 MCS1,
                                                       ViInt32 MCS2,
                                                       ViInt32 MCS3,
                                                       ViInt32 MCS4,
                                                       ViInt32 MCS5,
                                                       ViInt32 MCS6,
                                                       ViInt32 MCS71st,
                                                       ViInt32 MCS72nd,
                                                       ViInt32 MCS81st,
                                                       ViInt32 MCS82nd,
                                                       ViInt32 MCS91st,
                                                       ViInt32 MCS92nd,
                                                       ViChar  errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[] = {"P1","P2","P3", VI_NULL};
    GET_WRT_BUF(instrSession);

  // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_10, RSCMU_ERROR_FW_VERSION_3_10));

  // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, IndependentValue, RSCMU_DEF, RSCMU_CUR, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, MCS1, RSCMU_P1, RSCMU_P2, RSCMU_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, MCS2, RSCMU_P1, RSCMU_P2, RSCMU_ERROR_PARAMETER4, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, MCS3, RSCMU_P1, RSCMU_P3, RSCMU_ERROR_PARAMETER5, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, MCS4, RSCMU_P1, RSCMU_P3, RSCMU_ERROR_PARAMETER6, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, MCS5, RSCMU_P1, RSCMU_P2, RSCMU_ERROR_PARAMETER7, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, MCS6, RSCMU_P1, RSCMU_P2, RSCMU_ERROR_PARAMETER8, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, MCS71st, RSCMU_P1, RSCMU_P3, RSCMU_ERROR_PARAMETER9, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, MCS72nd, RSCMU_P1, RSCMU_P3, RSCMU_ERROR_PARAMETER10, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, MCS81st, RSCMU_P1, RSCMU_P3, RSCMU_ERROR_PARAMETER11, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, MCS82nd, RSCMU_P1, RSCMU_P3, RSCMU_ERROR_PARAMETER12, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, MCS91st, RSCMU_P1, RSCMU_P3, RSCMU_ERROR_PARAMETER13, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, MCS92nd, RSCMU_P1, RSCMU_P3, RSCMU_ERROR_PARAMETER14, errorMessage);

  if (pvar_base_globals->RSCMU_FW_Version < RSCMU200_V3_20)
  {
    sprintf (wrtBuf, "%s:NETW:PDAT:PSCH %s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s"  , confProcArr[IndependentValue]                                                                             
                                                                              , list[MCS1]
                                                                              , list[MCS2]
                                                                              , list[MCS3]
                                                                              , list[MCS4]
                                                                              , list[MCS5]
                                                                              , list[MCS6]
                                                                              , list[MCS71st]
                                                                              , list[MCS72nd]
                                                                              , list[MCS81st]
                                                                              , list[MCS82nd]
                                                                              , list[MCS91st]
                                                                              , list[MCS92nd]);
  }
  else
  {
    sprintf (wrtBuf, "%s:NETWork:PDATa:EGPRS:PSCHeme %s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s" , confProcArr[IndependentValue]                                                                             
                                                                                          , list[MCS1]
                                                                                          , list[MCS2]
                                                                                          , list[MCS3]
                                                                                          , list[MCS4]
                                                                                          , list[MCS5]
                                                                                          , list[MCS6]
                                                                                          , list[MCS71st]
                                                                                          , list[MCS72nd]
                                                                                          , list[MCS81st]
                                                                                          , list[MCS82nd]
                                                                                          , list[MCS91st]
                                                                                          , list[MCS92nd]);
  }

    RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}


/*===========================================================================*/
/* Function: Configure EGPRS Incremental Redundancy
/* Purpose : This function Enable or disable the Incremental Redundancy Flag.
/*===========================================================================*/

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatIncRed (ViSession instrSession,
                                                    ViInt32   enable,
                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_21, RSCMU_ERROR_FW_VERSION_3_21));

  RETMSG(RSCMU_setEnum(instrSession, "CONFigure:NETWork:PDATa:EGPRs:PSCHeme:IREDundancy",
                       enable, mode_On_Off,
                       RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: BLER Polling Interval
/* Purpose : This function defines the BLER Polling Interval for EGPRS. After
/*           the given number of radio frames the mobile sends an ACK/NACK
/*           message back to the R&S CMU. The polling rate can
/*           be increased by decreasing the BLER Polling Interval.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatBpinEgprs
             (ViSession instrSession, ViInt32 BLERPollingInterval,
              ViChar _VI_FAR errorMessage[])

{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setViInt32(instrSession, "CONF:NETW:PDAT:BPIN:EGPR",
                            BLERPollingInterval, 1, 32,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Conf. PC Measurement Channel
/* Purpose : This function defines the channel type that the mobile uses to
/*           determine the received signal strength and quality.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_PdatPCMeasChan (ViSession instrSession,
                                                ViInt32   Type,
                                                ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[] = {"BCCH", "PDCH", VI_NULL};

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_10, RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:NETW:PDAT:PCMC",
                         Type, list,
                         RSCMU_ERROR_PARAMETER2));
}


/*===========================================================================*/
/* Function: Conf.RLC Mode
/* Purpose : This function defines the channel type that the mobile uses to
/*           determine the received signal strength and quality.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_PdatRLCMode (ViSession instrSession,
                                             ViInt32   Mode,
                                             ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[] = {"UNAC", "ACKN", VI_NULL};

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_10, RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:NETW:PDAT:RLCM",
                         Mode, list,
                         RSCMU_ERROR_PARAMETER2));
}


/*===========================================================================*/
/* Function: PDP Context Activation
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_PdatPDPContextActiv (ViSession instrSession,
                                                     ViInt32 Activation,
                                                     ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViString    list[] = {"REJ", "ACC", VI_NULL};

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_42, RSCMU_ERROR_FW_VERSION_3_42));

    RETMSG(RSCMU_setEnum(instrSession, "CONFigure:NETWork:PDATa:PDPContext",
                         Activation, list,
                         RSCMU_ERROR_PARAMETER2));
}



/*===========================================================================*/
/* Function: DL Resources in Use
/* Purpose : This function selects the percentage of DL RLC blocks assigned
/*           to the MS under test and used for the BLER calculation.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerDLResUse (ViSession instrSession,
                                              ViInt32   dlResinUse,
                                              ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    GET_WRT_BUF(instrSession);

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, dlResinUse,1,12, RSCMU_ERROR_PARAMETER2, errorMessage);

    // Configure  tests cycles:
    sprintf (wrtBuf, "CONFigure:RXQuality:BLER:CONTrol:DLDCycle RB%d", dlResinUse);

    RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT BLER
 *    The subsystem RXQuality:BLER contains the commands for the Block Error Ratio (BLER)
 *    measurement. The subsystem corresponds to the main menu Receiver Quality, application BLER and
 *    the corresponding parts of the associated popup menu Receiver Quality Configuration.
 * ----------------------------------------------------------------------------
 *    MEASUREMENT CONTROL
 *    This subsystem contains the functions for general control of theBLER measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start new measurement
/* Purpose : This function starts the BLER measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerInit (ViSession instrSession,
                                          ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_sendCmd(instrSession, "INIT:RXQ:BLER"));
}


/*===========================================================================*/
/* Function: Abort running measurement and switch off
/* Purpose : This function stops the BLER measurement, setting it
/*           to the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerAbort (ViSession instrSession,
                                           ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_sendCmd(instrSession, "ABOR:RXQ:BLER"));
}



/*===========================================================================*/
/* Function: stop measurement after current statistic cycle
/* Purpose : This function stops the BLER measurement, setting it
/*           to the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerStop (ViSession instrSession,
                                          ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_sendCmd(instrSession, "STOP:RXQ:BLER"));
}



/*===========================================================================*/
/* Function: Next Measurement Step
/* Purpose : This function continues the BLER measurement, setting
/*           it to the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerContinue (ViSession instrSession,
                                              ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_sendCmd(instrSession, "CONT:RXQ:BLER"));
}



/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the measurement
/*           is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerErep (ViSession instrSession,
                                          ViInt32 measErep,
                                          ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:RXQ:BLER:EREP",
                         measErep, StrEventReporting,
                         RSCMU_ERROR_PARAMETER2));
}



/*===========================================================================*/
/* Function: BLER Measurement Status
/* Purpose : This function returns the status of the BLER measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerFetcStat (ViSession instrSession,
                                              ViInt32 *measStatus,
                                              ViInt32 *countingNo,
                                              ViChar errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;
  ViChar    rdBuf[RD_BUFFER_SIZE] = "";
  ViChar    TableOfDataValues[100][100];

  // Fetch the status of the wideband power measurement:
  if ((RSCMU_Status = RSCMU_Query (instrSession, "FETC:RXQ:BLER:STAT?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Get the status of the measurement:
  if ((RSCMU_Status = RSCMU_GetMeasStatVal (measStatus, TableOfDataValues, 0)) < 0)
    return RSCMU_Status;

  // Get the current value of the statistics counter (the number of the current statistics cycle):
  if ((RSCMU_Status = RSCMU_GetCountingNo (countingNo, TableOfDataValues, 1)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}


/*
 * ----------------------------------------------------------------------------
 *      CONTROL
 *-----------------------------------------------------------------------------
 */

/*===========================================================================*/
/* Function: BLER Repetition
/* Purpose : This function determines the number of statistics cycles,
/*           the stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBlerRep (ViSession instrSession,
                                             ViInt32   repetition,
                                             ViInt32   stopCondition,
                                             ViInt32   stepMode,
                                             ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    GET_WRT_BUF(instrSession);

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, repetition,0,1, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, stopCondition,0,1, RSCMU_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, stepMode,0,1, RSCMU_ERROR_PARAMETER4, errorMessage);

    // Configure  tests cycles:
    sprintf (wrtBuf, "CONF:RXQ:BLER:CONT:REP %s,%s,%s", StrRepetition[repetition], StrStopCondition[stopCondition], StrStepMode[stepMode]);

    RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}


/*===========================================================================*/
/* Function: RLC Block Count
/* Purpose : This function sets the number of RLC blocks to be sent and
/* evaluated in a single shot BLER measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBlerRLCBlockCount (ViSession instrSession,
                                                       ViInt32 RLCBlocks,
                                                       ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_setViInt32(instrSession, "CONF:RXQ:BLER:CONT:RLBC",
                            RLCBlocks, 100, 10000000,
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Reference Level
/* Purpose : This function defines the reference value for the individual downlink
/*           (BS) TCH signal levels used for the multislot BLER test on packet data channels.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBlerRefLev (ViSession instrSession,
                                                ViReal64 refLevel,
                                                ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

    RETMSG(RSCMU_setViReal64(instrSession, "CONF:RXQ:BLER:CONT:PDAT:MSL:RLEV",
                             refLevel, -137.0,13.0,
                             RSCMU_ERROR_PARAMETER2));

}

/*===========================================================================*/
/* Function: Individual Level
/* Purpose : Individual Level rel. to RSCMU_GSM_Sig_ConfBlerRefLev
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBlerLevInd (ViSession instrSession,
                                                ViReal64 indlevel0,
                                                ViReal64 indlevel1,
                                                ViReal64 indlevel2,
                                                ViReal64 indlevel3,
                                                ViReal64 indlevel4,
                                                ViReal64 indlevel5,
                                                ViReal64 indlevel6,
                                                ViReal64 indlevel7,
                                                ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    GET_WRT_BUF(instrSession);

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));


  // Check if the function is correctly used:
    CHECK_VI_REAL64_RANGE(instrSession, indlevel0, -127.0, 127.0, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_REAL64_RANGE(instrSession, indlevel1, -127.0, 127.0, RSCMU_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_REAL64_RANGE(instrSession, indlevel2, -127.0, 127.0, RSCMU_ERROR_PARAMETER4, errorMessage);
    CHECK_VI_REAL64_RANGE(instrSession, indlevel3, -127.0, 127.0, RSCMU_ERROR_PARAMETER5, errorMessage);
    CHECK_VI_REAL64_RANGE(instrSession, indlevel4, -127.0, 127.0, RSCMU_ERROR_PARAMETER6, errorMessage);
    CHECK_VI_REAL64_RANGE(instrSession, indlevel5, -127.0, 127.0, RSCMU_ERROR_PARAMETER7, errorMessage);
    CHECK_VI_REAL64_RANGE(instrSession, indlevel6, -127.0, 127.0, RSCMU_ERROR_PARAMETER8, errorMessage);
    CHECK_VI_REAL64_RANGE(instrSession, indlevel7, -127.0, 127.0, RSCMU_ERROR_PARAMETER9, errorMessage);

    sprintf ( wrtBuf, "CONF:RXQ:BLER:CONT:PDAT:MSL:LEV:IND %lf,%lf,%lf,%lf,%lf,%lf,%lf,%lf", indlevel0,
                                                                                             indlevel1,
                                                                                             indlevel2,
                                                                                             indlevel3,
                                                                                             indlevel4,
                                                                                             indlevel5,
                                                                                             indlevel6,
                                                                                             indlevel7);
    RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}


/*
 * ----------------------------------------------------------------------------
 *      RESULTS
 *-----------------------------------------------------------------------------
 */

/*===========================================================================*/
/* Function: Read Scalar
/* Purpose : This function starts the Bler measurement and returns the
/*           results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerRead350 (ViSession   instrSession,
                                               ViReal64 *progressTime,
                                               ViReal64 *BLEROverall,
                                               ViReal64 *RLCBlocksOverall,
                                               ViReal64  BLER[],
                                               ViReal64  RLCBlocks[],
                                               ViReal64 *dataRateOverall,
                                               ViReal64  dataRate[],
                                               ViReal64 *longThermThroughput,
                                               ViReal64 *longThermThroughputSlot,
                                               ViChar    errorMessage[])
{
  return RSCMU_MeasBler (instrSession, RSCMU_COMMAND_READ,
                                          progressTime,
                                          BLEROverall,
                                          RLCBlocksOverall,
                                          BLER,
                                          RLCBlocks,
                                          dataRateOverall,
                                          dataRate,
                                          longThermThroughput,
                                          longThermThroughputSlot,
                                          errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Scalar
/* Purpose : This function reads out measurements (unsynchronized) and returns
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerFetch350 (ViSession  instrSession,
                                               ViReal64 *progressTime,
                                               ViReal64 *BLEROverall,
                                               ViReal64 *RLCBlocksOverall,
                                               ViReal64  BLER[],
                                               ViReal64  RLCBlocks[],
                                               ViReal64 *dataRateOverall,
                                               ViReal64  dataRate[],
                                               ViReal64 *longThermThroughput,
                                               ViReal64 *longThermThroughputSlot,
                                               ViChar    errorMessage[])
{
  return RSCMU_MeasBler (instrSession, RSCMU_COMMAND_FETC,
                                          progressTime,
                                          BLEROverall,
                                          RLCBlocksOverall,
                                          BLER,
                                          RLCBlocks,
                                          dataRateOverall,
                                          dataRate,
                                          longThermThroughput,
                                          longThermThroughputSlot,
                                          errorMessage);
}

/*===========================================================================*/
/* Function: Sample Scalar
/* Purpose : This function reads out measurements (synchronized) and returns
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerSample350 (ViSession instrSession,
                                               ViReal64 *progressTime,
                                               ViReal64 *BLEROverall,
                                               ViReal64 *RLCBlocksOverall,
                                               ViReal64  BLER[],
                                               ViReal64  RLCBlocks[],
                                               ViReal64 *dataRateOverall,
                                               ViReal64  dataRate[],
                                               ViReal64 *longThermThroughput,
                                               ViReal64 *longThermThroughputSlot,
                                               ViChar    errorMessage[])
{
  return RSCMU_MeasBler (instrSession, RSCMU_COMMAND_SAMP,
                                          progressTime,
                                          BLEROverall,
                                          RLCBlocksOverall,
                                          BLER,
                                          RLCBlocks,
                                          dataRateOverall,
                                          dataRate,
                                          longThermThroughput,
                                          longThermThroughputSlot,
                                          errorMessage);
}

/*===========================================================================*/
/* Function: Read Scalar (< V3.50)
/* Purpose : Old function without longThermThroughput
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerRead (ViSession instrSession,
                                           ViReal64 *progressTime,
                                           ViReal64 *BLEROverall,
                                           ViReal64 *RLCBlocksOverall,
                                           ViReal64 BLER[],
                                           ViReal64 RLCBlocks[],
                                           ViReal64 *dataRateOverall,
                                           ViReal64 dataRate[],
                                           ViChar errorMessage[])
{
  ViReal64  longThermThroughput;
  ViReal64  longThermThroughputSlot;

  return RSCMU_MeasBler (instrSession, RSCMU_COMMAND_READ,
                                          progressTime,
                                          BLEROverall,
                                          RLCBlocksOverall,
                                          BLER,
                                          RLCBlocks,
                                          dataRateOverall,
                                          dataRate,
                                          &longThermThroughput,
                                          &longThermThroughputSlot,
                                          errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Scalar (< V3.50)
/* Purpose : Old function without longThermThroughput
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerFetch (ViSession instrSession,
                                           ViReal64 *progressTime,
                                           ViReal64 *BLEROverall,
                                           ViReal64 *RLCBlocksOverall,
                                           ViReal64 BLER[],
                                           ViReal64 RLCBlocks[],
                                           ViReal64 *dataRateOverall,
                                           ViReal64 dataRate[],
                                           ViChar errorMessage[])
{
  ViReal64  longThermThroughput;
  ViReal64  longThermThroughputSlot;

  return RSCMU_MeasBler (instrSession, RSCMU_COMMAND_FETC,
                                          progressTime,
                                          BLEROverall,
                                          RLCBlocksOverall,
                                          BLER,
                                          RLCBlocks,
                                          dataRateOverall,
                                          dataRate,
                                          &longThermThroughput,
                                          &longThermThroughputSlot,
                                          errorMessage);
}

/*===========================================================================*/
/* Function: Sample Scalar (< V3.50)
/* Purpose : Old function without longThermThroughput
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerSample (ViSession instrSession,
                                            ViReal64 *progressTime,
                                            ViReal64 *BLEROverall,
                                            ViReal64 *RLCBlocksOverall,
                                            ViReal64 BLER[],
                                            ViReal64 RLCBlocks[],
                                            ViReal64 *dataRateOverall,
                                            ViReal64 dataRate[],
                                            ViChar errorMessage[])
{
  ViReal64  longThermThroughput;
  ViReal64  longThermThroughputSlot;

  return RSCMU_MeasBler (instrSession, RSCMU_COMMAND_SAMP,
                                          progressTime,
                                          BLEROverall,
                                          RLCBlocksOverall,
                                          BLER,
                                          RLCBlocks,
                                          dataRateOverall,
                                          dataRate,
                                          &longThermThroughput,
                                          &longThermThroughputSlot,
                                          errorMessage);
}



/*===========================================================================*/
/* Function: Conf. Coding Scheme
/* Purpose : This function returns the multislot class of the mobile while it
/*           operates in packet data mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMsclPdat (ViSession  instrSession,
                                                                     ViInt32   *Class,
                                                                     ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarSession;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  if (p_globalvarSession->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Get the reference level
  if ((RSCMU_Status = RSCMU_Query (instrSession, "MSS:MSCL:PDAT?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf, "%d", &Class);
  else
    *Class = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}


/*===========================================================================*/
/* Circuit Switched Timeslot
/* This function defines the timeslot allocated for the CS services while the
/* mobile operates in DTM. The DTM CS timeslot must not coincide with the main timeslot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssDTMCswTS (ViSession instrSession,
                                                 ViInt32 CSwTimeslot,
                                                 ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_80,RSCMU_ERROR_FW_VERSION_3_80));

  RETMSG(RSCMU_setViInt32(instrSession,
                          "CONFigure:BSSignal:DTMode:CSTimeslot",
                          CSwTimeslot,
                          0, 7,
                          RSCMU_ERROR_PARAMETER2));
}


/*===========================================================================*/
/* DTM Downlink Slot Configuration
/* This command configures the downlink slot configuration and the RF levels
/* that the CMU uses in DTM test mode (default parameters).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssDTMMslSconf (ViSession instrSession,
                                                    ViInt32   TS0Enable,
                                                    ViReal64  TS0Level,
                                                    ViInt32   TS1Enable,
                                                    ViReal64  TS1Level,
                                                    ViInt32   TS2Enable,
                                                    ViReal64  TS2Level,
                                                    ViInt32   TS3Enable,
                                                    ViReal64  TS3Level,
                                                    ViInt32   TS4Enable,
                                                    ViReal64  TS4Level,
                                                    ViInt32   TS5Enable,
                                                    ViReal64  TS5Level,
                                                    ViInt32   TS6Enable,
                                                    ViReal64  TS6Level,
                                                    ViInt32   TS7Enable,
                                                    ViReal64  TS7Level,
                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_80)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_80, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS0Enable, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS0Level, -127, 127, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS1Enable, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS1Level, -127, 127, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS2Enable, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS2Level, -127, 127, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS3Enable, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS3Level, -127, 127, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS4Enable, RSCMU_ERROR_PARAMETER10, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS4Level, -127, 127, RSCMU_ERROR_PARAMETER11, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS5Enable, RSCMU_ERROR_PARAMETER12, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS5Level, -127, 127, RSCMU_ERROR_PARAMETER13, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS6Enable, RSCMU_ERROR_PARAMETER14, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS6Level, -127, 127, RSCMU_ERROR_PARAMETER15, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS7Enable, RSCMU_ERROR_PARAMETER16, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS7Level, -127, 127, RSCMU_ERROR_PARAMETER17, errorMessage);

  sprintf (wrtBuf, "CONFigure:BSSignal:DTMode:TCH:MSLot:SCONfig %s,%s,%s,%s,%s,%s,%s,%s,%lf,%lf,%lf,%lf,%lf,%lf,%lf,%lf",
                                                                                                     mode_On_Off [TS0Enable]
                                                                                                   , mode_On_Off [TS1Enable]
                                                                                                   , mode_On_Off [TS2Enable]
                                                                                                   , mode_On_Off [TS3Enable]
                                                                                                   , mode_On_Off [TS4Enable]
                                                                                                   , mode_On_Off [TS5Enable]
                                                                                                   , mode_On_Off [TS6Enable]
                                                                                                   , mode_On_Off [TS7Enable]
                                                                                                   , TS0Level
                                                                                                   , TS1Level
                                                                                                   , TS2Level
                                                                                                   , TS3Level
                                                                                                   , TS4Level
                                                                                                   , TS5Level
                                                                                                   , TS6Level
                                                                                                   , TS7Level);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* DTM Uplink Slot Configuration
/* This function defines the slot configuration and the channel-specific power
/* control parameters that the MS is to use for DTM tests (default parameters).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfMssDTMMslSconf (ViSession instrSession,
                                                    ViInt32 TS0Enable,
                                                    ViInt32 TS0Gamma,
                                                    ViInt32 TS1Enable,
                                                    ViInt32 TS1Gamma,
                                                    ViInt32 TS2Enable,
                                                    ViInt32 TS2Gamma,
                                                    ViInt32 TS3Enable,
                                                    ViInt32 TS3Gamma,
                                                    ViInt32 TS4Enable,
                                                    ViInt32 TS4Gamma,
                                                    ViInt32 TS5Enable,
                                                    ViInt32 TS5Gamma,
                                                    ViInt32 TS6Enable,
                                                    ViInt32 TS6Gamma,
                                                    ViInt32 TS7Enable,
                                                    ViInt32 TS7Gamma,
                                                    ViInt32 CSwSlotNr,
                                                    ViInt32 CSwPCL,
                                                    ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarSession;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  if (p_globalvarSession->RSCMU_FW_Version < RSCMU200_V3_80)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_80, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS0Enable, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS0Gamma, 0, 31, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS1Enable, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS1Gamma, 0, 31, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS2Enable, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS2Gamma, 0, 31, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS3Enable, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS3Gamma, 0, 31, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS4Enable, RSCMU_ERROR_PARAMETER10, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS4Gamma, 0, 31, RSCMU_ERROR_PARAMETER11, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS5Enable, RSCMU_ERROR_PARAMETER12, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS5Gamma, 0, 31, RSCMU_ERROR_PARAMETER13, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS6Enable, RSCMU_ERROR_PARAMETER14, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS6Gamma, 0, 31, RSCMU_ERROR_PARAMETER15, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) TS7Enable, RSCMU_ERROR_PARAMETER16, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS7Gamma, 0, 31, RSCMU_ERROR_PARAMETER17, errorMessage);
  CHECK_VI_INT32_RANGE  (instrSession, TS7Gamma, 0, 7, RSCMU_ERROR_PARAMETER18, errorMessage);
  if (strncmp ("\"GSM400MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, CSwPCL, 0, 19, RSCMU_ERROR_PARAMETER19, errorMessage);
  }
  else if (strncmp ("\"GSM850MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, CSwPCL, 0, 19, RSCMU_ERROR_PARAMETER19, errorMessage);
  }
  else if (strncmp ("\"GSM900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, CSwPCL, 0, 19, RSCMU_ERROR_PARAMETER19, errorMessage);
  }
  else if (strncmp ("\"GSM1800MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, CSwPCL, 0, 31, RSCMU_ERROR_PARAMETER19, errorMessage);
  }
  else if (strncmp ("\"GSM1900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, CSwPCL, 0, 31, RSCMU_ERROR_PARAMETER19, errorMessage);
  }

  sprintf (wrtBuf, "CONFigure:MSSignal:DTMode:TCH:MSLot:SCONfig %s,%s,%s,%s,%s,%s,%s,%s,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d"
                                                                                           , mode_On_Off [TS0Enable]
                                                                                           , mode_On_Off [TS1Enable]
                                                                                           , mode_On_Off [TS2Enable]
                                                                                           , mode_On_Off [TS3Enable]
                                                                                           , mode_On_Off [TS4Enable]
                                                                                           , mode_On_Off [TS5Enable]
                                                                                           , mode_On_Off [TS6Enable]
                                                                                           , mode_On_Off [TS7Enable]
                                                                                           , TS0Gamma
                                                                                           , TS1Gamma
                                                                                           , TS2Gamma
                                                                                           , TS3Gamma
                                                                                           , TS4Gamma
                                                                                           , TS5Gamma
                                                                                           , TS6Gamma
                                                                                           , TS7Gamma
                                                                                           , CSwSlotNr
                                                                                           , CSwPCL);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* DTM Call: Complete Slot Configuration
/* This command changes the main timeslot, the levels in all active and inactive
/* timeslots of the BS signal, and the channel-specific power control parameters
/* for the MS (current values, see Slot Configuration Editor in manual control)
/* while a DTM connection is active.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignDTMMslSconf (ViSession instrSession, ViInt32   MainTS,
                                                      ViInt32   DL0Enable,ViInt32   DL1Enable,ViInt32   DL2Enable,ViInt32   DL3Enable,ViInt32   DL4Enable,ViInt32   DL5Enable,ViInt32   DL6Enable,ViInt32   DL7Enable,
                                                      ViReal64  DL0Level,ViReal64  DL1Level,ViReal64  DL2Level,ViReal64  DL3Level,ViReal64  DL4Level,ViReal64  DL5Level,ViReal64  DL6Level,ViReal64  DL7Level,
                                                      ViInt32   UL0Enable,ViInt32   UL1Enable,ViInt32   UL2Enable,ViInt32   UL3Enable,ViInt32   UL4Enable,ViInt32   UL5Enable,ViInt32   UL6Enable,ViInt32   UL7Enable,
                                                      ViInt32   UL0Gamma,ViInt32   UL1Gamma,ViInt32   UL2Gamma,ViInt32   UL3Gamma,ViInt32   UL4Gamma,ViInt32   UL5Gamma,ViInt32   UL6Gamma,ViInt32   UL7Gamma,
                                                      ViInt32 CSwSlotNr, ViInt32 CSwPCL,ViChar errorMessage[])

{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  struct      RSCMU_SESSION_Globals  *p_globalvarSession;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarSession)) < 0)
    return RSCMU_Status;

  if (p_globalvarSession->RSCMU_FW_Version < RSCMU200_V3_80)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_80, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE (instrSession, MainTS, 0, 7, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) DL0Enable, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) DL1Enable, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) DL2Enable, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) DL3Enable, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) DL4Enable, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) DL5Enable, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) DL6Enable, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) DL7Enable, RSCMU_ERROR_PARAMETER10, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL0Level, -127, 127, RSCMU_ERROR_PARAMETER11, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL1Level, -127, 127, RSCMU_ERROR_PARAMETER12, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL2Level, -127, 127, RSCMU_ERROR_PARAMETER13, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL3Level, -127, 127, RSCMU_ERROR_PARAMETER14, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL4Level, -127, 127, RSCMU_ERROR_PARAMETER15, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL5Level, -127, 127, RSCMU_ERROR_PARAMETER16, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL6Level, -127, 127, RSCMU_ERROR_PARAMETER17, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, DL7Level, -127, 127, RSCMU_ERROR_PARAMETER18, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) UL0Enable, RSCMU_ERROR_PARAMETER19, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) UL1Enable, RSCMU_ERROR_PARAMETER20, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) UL2Enable, RSCMU_ERROR_PARAMETER21, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) UL3Enable, RSCMU_ERROR_PARAMETER22, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) UL4Enable, RSCMU_ERROR_PARAMETER23, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) UL5Enable, RSCMU_ERROR_PARAMETER24, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) UL6Enable, RSCMU_ERROR_PARAMETER25, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) UL7Enable, RSCMU_ERROR_PARAMETER26, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL0Gamma, 0, 31, RSCMU_ERROR_PARAMETER27, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL1Gamma, 0, 31, RSCMU_ERROR_PARAMETER28, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL2Gamma, 0, 31, RSCMU_ERROR_PARAMETER29, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL3Gamma, 0, 31, RSCMU_ERROR_PARAMETER30, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL4Gamma, 0, 31, RSCMU_ERROR_PARAMETER31, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL5Gamma, 0, 31, RSCMU_ERROR_PARAMETER32, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL6Gamma, 0, 31, RSCMU_ERROR_PARAMETER33, errorMessage);
  CHECK_VI_INT32_RANGE (instrSession, UL7Gamma, 0, 31, RSCMU_ERROR_PARAMETER34, errorMessage);
  if (strncmp ("\"GSM400MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, CSwPCL, 0, 19, RSCMU_ERROR_PARAMETER19, errorMessage);
  }
  else if (strncmp ("\"GSM850MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, CSwPCL, 0, 19, RSCMU_ERROR_PARAMETER19, errorMessage);
  }
  else if (strncmp ("\"GSM900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, CSwPCL, 0, 19, RSCMU_ERROR_PARAMETER19, errorMessage);
  }
  else if (strncmp ("\"GSM1800MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, CSwPCL, 0, 31, RSCMU_ERROR_PARAMETER19, errorMessage);
  }
  else if (strncmp ("\"GSM1900MS_Sig\"", p_globalvarSession->FGrp_Name, strlen(p_globalvarSession->FGrp_Name)) == 0)
  {
    CHECK_VI_INT32_RANGE(instrSession, CSwPCL, 0, 31, RSCMU_ERROR_PARAMETER19, errorMessage);
  }

  sprintf (wrtBuf, "PROCedure:SIGNalling:DTMode:TCH:MSLot:SCONfig %d,%s,%s,%s,%s,%s,%s,%s,%s,%lf,%lf,%lf,%lf,%lf,%lf,%lf,%lf,%s,%s,%s,%s,%s,%s,%s,%s,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d"
       ,MainTS
       ,mode_On_Off[DL0Enable], mode_On_Off[DL1Enable], mode_On_Off[DL2Enable], mode_On_Off[DL3Enable], mode_On_Off[DL4Enable], mode_On_Off[DL5Enable], mode_On_Off[DL6Enable], mode_On_Off[DL7Enable]
       ,DL0Level, DL1Level, DL2Level, DL3Level, DL4Level, DL5Level, DL6Level, DL7Level
       ,mode_On_Off[UL0Enable], mode_On_Off[UL1Enable], mode_On_Off[UL2Enable], mode_On_Off[UL3Enable], mode_On_Off[UL4Enable], mode_On_Off[UL5Enable], mode_On_Off[UL6Enable], mode_On_Off[UL7Enable]
       ,UL0Gamma, UL1Gamma, UL2Gamma, UL3Gamma, UL4Gamma, UL5Gamma, UL6Gamma, UL7Gamma
       ,CSwSlotNr, CSwPCL);


    RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* DTM Call: Downlink Power Slot Configuration
/* This function changes the levels in all active and inactive timeslots slots of the BS signal.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcBssDTMSconfPower (ViSession instrSession,
                                                    ViReal64  TS0Level,
                                                    ViReal64  TS1Level,
                                                    ViReal64  TS2Level,
                                                    ViReal64  TS3Level,
                                                    ViReal64  TS4Level,
                                                    ViReal64  TS5Level,
                                                    ViReal64  TS6Level,
                                                    ViReal64  TS7Level,
                                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_80)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_80, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE (instrSession, TS0Level, -127, 127, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS1Level, -127, 127, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS2Level, -127, 127, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS3Level, -127, 127, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS4Level, -127, 127, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS5Level, -127, 127, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS6Level, -127, 127, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_REAL64_RANGE (instrSession, TS7Level, -127, 127, RSCMU_ERROR_PARAMETER9, errorMessage);

  sprintf (wrtBuf, "PROCedure:SIGNalling:DTMode:TCH:MSLot:BS:SCONfig:POWer %lf,%lf,%lf,%lf,%lf,%lf,%lf,%lf"
                                                                                       , TS0Level
                                                                                       , TS1Level
                                                                                       , TS2Level
                                                                                       , TS3Level
                                                                                       , TS4Level
                                                                                       , TS5Level
                                                                                       , TS6Level
                                                                                       , TS7Level);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: AMR Noise Suppression
/* Purpose : This function sets the noise suppression control Bit for AMR.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrNsbc (ViSession instrSession,
                                             ViInt32 nsbc,
                                             ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  struct   RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_20)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_20, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_40)
  {
  RETMSG(RSCMU_setEnum(instrSession, "CONFigure:NETWork:CSWitched:AMR:NSBC",
                       nsbc, mode_On_Off,
                       RSCMU_ERROR_PARAMETER2));
  }
  else
  {
  RETMSG(RSCMU_setEnum(instrSession, "CONFigure:NETWork:CSWitched:AMR:NSUPpression",
                       nsbc, mode_On_Off,
                       RSCMU_ERROR_PARAMETER2));
  }
}


/*===========================================================================*/
/* Function: CMI Phase
/* Purpose : This function sets the Codec Mode Indication Phase to odd or
/*           even. If set to ODD, the Codec Mode Command will be sent in odd
/*           frames, the Codec Mode Indication in even frames. For EVEN it
/*           is the other way round.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrCmip (ViSession instrSession,
                                             ViInt32 CMIPhase,
                                             ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setEnum(instrSession, "PROC:NETW:CSW:AMR:CMIP", CMIPhase, netwCMIPhaseArr,
                       RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: CMI Phase
/* Purpose : This function sets the Rate Set Reconfiguration to RATSCCH
/*           (Robust AMR Traffic Synchronized Control Channel) or CMM
/*           (Channel Mode Modify).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrRsr (ViSession instrSession,
                                            ViInt32 rateSetReconfigure,
                                            ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:NETW:CSW:AMR:RSR", rateSetReconfigure, netwRateReconfigArr,
                       RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: AMR Half Rate Codec Mode Downlink
/* Purpose : This function sets the codec mode that the CMU uses to generate
/*           the speech data transmitted to the MS under test.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrHrCModeDL (ViSession instrSession,
                                                  ViInt32 independentValue,
                                                  ViInt32 mode,
                                                  ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_20,RSCMU_ERROR_FW_VERSION_3_20));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, independentValue, RSCMU_DEF, RSCMU_CUR, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, mode,1,4, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "%s:NETWork:CSWitched:AMR:HRATe:DLCMode %s" , confProcArr[independentValue],codecModeList[mode]);
  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: AMR Half Rate Codec Mode Uplink
/* Purpose : This command sets the codec mode that the mobile under test
/*           shall use in uplink direction.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrHrCModeUL (ViSession instrSession,
                                                  ViInt32 independentValue,
                                                  ViInt32 mode,
                                                  ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_20,RSCMU_ERROR_FW_VERSION_3_20));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, independentValue, RSCMU_DEF, RSCMU_CUR, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, mode,1,4, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "%s:NETWork:CSWitched:AMR:HRATe:ULCMode %s" , confProcArr[independentValue],codecModeList[mode]);
  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: AMR Half Rate Rate set setting
/* Purpose : These function select four codec modes and define the decision
/* thresholds for changing the codec mode. The settings are valid for Half Rate
/* AMR speech coder tests. The instrument rejects the settings (SCPI error -221,
/* Settings conflict) unless the values meet all of the following conditions:
/* - The rates must be in descending order so that <CM4> is the
/*   largest bit rate.
/* - Up to 3 codec modes can be switched off. OFF must be the
/*   first values of the parameter list, preceding the used
/*   codec modes.
/* - Thresholds must be in descending order so that
/*   <ThrDown2> =<ThrDown3> =<ThrDown4> and
/*   <ThrUp1> =<ThrUp2> =<ThrUp3>.
/* - The hysteresis must be positive so that Up (j) =Down (j + 1)
/*   for j= 1 to 3
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrHrRSet (ViSession instrSession,
                                               ViInt32 independentValue,
                                               ViInt32 codec4,
                                               ViInt32 codec3,
                                               ViInt32 codec2,
                                               ViInt32 codec1,
                                               ViReal64 down4,
                                               ViReal64 up3,
                                               ViReal64 down3,
                                               ViReal64 up2,
                                               ViReal64 down2,
                                               ViReal64 up1,
                                               ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViString    list[] = {"OFF","C0475","C0515","C0590","C0670","C0740","C0795","C1020","C1220",  VI_NULL};
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_20,RSCMU_ERROR_FW_VERSION_3_20));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, independentValue, RSCMU_DEF, RSCMU_CUR, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codec4,RSCMU_OFF,RSCMU_AMR_CODMODE_12_2, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codec3,RSCMU_OFF,RSCMU_AMR_CODMODE_12_2, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codec2,RSCMU_OFF,RSCMU_AMR_CODMODE_12_2, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codec1,RSCMU_OFF,RSCMU_AMR_CODMODE_12_2, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, down4, 0.0, 31.5, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, up3, 0.0, 31.5, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, down3, 0.0, 31.5, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, up2, 0.0, 31.5, RSCMU_ERROR_PARAMETER10, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, down2, 0.0, 31.5, RSCMU_ERROR_PARAMETER11, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, up1, 0.0, 31.5, RSCMU_ERROR_PARAMETER12, errorMessage);

  sprintf (wrtBuf, "%s:NETWork:CSWitched:AMR:HRATe:RSETting %s, %s, %s, %s, %lf, %lf, %lf, %lf, %lf, %lf" ,
                        confProcArr[independentValue],list[codec4],list[codec3],list[codec2],list[codec1],down4, up3, down3, up2, down2, up1);
  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}


/*===========================================================================*/
/* Function: CMC Stress
/* Purpose : This function sets CMC Stress ON or OFF.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrHrUlcmCstr (ViSession instrSession,
                                                   ViBoolean CMCStress,
                                                   ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V4_50, RSCMU_ERROR_FW_VERSION_4_50));

    RETMSG(RSCMU_setEnum(instrSession, "CONF:NETW:CSW:AMR:HRAT:ULCM:CSTR", CMCStress, mode_On_Off,
                       RSCMU_ERROR_PARAMETER2));
}


/*===========================================================================*/
/* Function: AMR Full Rate Codec Mode Downlink
/* Purpose : This function sets the codec mode that the CMU uses to generate
/*           the speech data transmitted to the MS under test.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrFrCModeDL (ViSession instrSession,
                                                  ViInt32 independentValue,
                                                  ViInt32 mode,
                                                  ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_20,RSCMU_ERROR_FW_VERSION_3_20));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, independentValue, RSCMU_DEF, RSCMU_CUR, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, mode,1,4, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "%s:NETWork:CSWitched:AMR:FRATe:DLCMode %s" , confProcArr[independentValue],codecModeList[mode]);
  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}


/*===========================================================================*/
/* Function: AMR WB Full Rate Codec Mode Downlink
/* Purpose : This command sets the codec mode that the mobile under test
/*           shall use in downlink direction.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbFrCModeDL (ViSession instrSession,
                                                    ViInt32 independentValue,
                                                    ViInt32 mode,
                                                    ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_23,RSCMU_ERROR_FW_VERSION_4_23));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, independentValue, RSCMU_DEF, RSCMU_CUR, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, mode,1,3, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "%s:NETW:AMR:WB:FRAT:DLCM %s" , confProcArr[independentValue], codecModeList[mode]);
  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: AMR Full Rate Codec Mode Uplink
/* Purpose : This command sets the codec mode that the mobile under test
/*           shall use in uplink direction.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrFrCModeUL (ViSession instrSession,
                                                  ViInt32 independentValue,
                                                  ViInt32 mode,
                                                  ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_20,RSCMU_ERROR_FW_VERSION_3_20));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, independentValue, RSCMU_DEF, RSCMU_CUR, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, mode,1,4, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "%s:NETWork:CSWitched:AMR:FRATe:ULCMode %s" , confProcArr[independentValue], codecModeList[mode]);
  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: AMR WB Full Rate Codec Mode Uplink
/* Purpose : This command sets the codec mode that the mobile under test
/*           shall use in uplink direction.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbFrCModeUL (ViSession instrSession,
                                                    ViInt32 independentValue,
                                                    ViInt32 mode,
                                                    ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_23,RSCMU_ERROR_FW_VERSION_4_23));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, independentValue, RSCMU_DEF, RSCMU_CUR, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, mode,1,3, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "%s:NETW:AMR:WB:FRAT:ULCM %s" , confProcArr[independentValue], codecModeList[mode]);
  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: AMR Full Rate Rate set setting
/* Purpose : These function select four codec modes and define the decision
/* thresholds for changing the codec mode. The settings are valid for Full Rate
/* AMR speech coder tests. The instrument rejects the settings (SCPI error -221,
/* Settings conflict) unless the values meet all of the following conditions:
/* - The rates must be in descending order so that <CM4> is the
/*   largest bit rate.
/* - Up to 3 codec modes can be switched off. OFF must be the
/*   first values of the parameter list, preceding the used
/*   codec modes.
/* - Thresholds must be in descending order so that
/*   <ThrDown2> =<ThrDown3> =<ThrDown4> and
/*   <ThrUp1> =<ThrUp2> =<ThrUp3>.
/* - The hysteresis must be positive so that Up (j) =Down (j + 1)
/*   for j= 1 to 3
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrFrRSet (ViSession instrSession,
                                               ViInt32 independentValue,
                                               ViInt32 codec4,
                                               ViInt32 codec3,
                                               ViInt32 codec2,
                                               ViInt32 codec1,
                                               ViReal64 down4,
                                               ViReal64 up3,
                                               ViReal64 down3,
                                               ViReal64 up2,
                                               ViReal64 down2,
                                               ViReal64 up1,
                                               ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViString    list[] = {"OFF","C0475","C0515","C0590","C0670","C0740","C0795","C1020","C1220", VI_NULL};
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_20,RSCMU_ERROR_FW_VERSION_3_20));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, independentValue, RSCMU_DEF, RSCMU_CUR, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codec4,RSCMU_OFF,RSCMU_AMR_CODMODE_12_2, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codec3,RSCMU_OFF,RSCMU_AMR_CODMODE_12_2, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codec2,RSCMU_OFF,RSCMU_AMR_CODMODE_12_2, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, codec1,RSCMU_OFF,RSCMU_AMR_CODMODE_12_2, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, down4, 0.0, 31.5, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, up3, 0.0, 31.5, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, down3, 0.0, 31.5, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, up2, 0.0, 31.5, RSCMU_ERROR_PARAMETER10, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, down2, 0.0, 31.5, RSCMU_ERROR_PARAMETER11, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, up1, 0.0, 31.5, RSCMU_ERROR_PARAMETER12, errorMessage);

  sprintf (wrtBuf, "%s:NETWork:CSWitched:AMR:FRATe:RSETting %s, %s, %s, %s, %lf, %lf, %lf, %lf, %lf, %lf" ,
                        confProcArr[independentValue],list[codec4],list[codec3],list[codec2],list[codec1],down4, up3, down3, up2, down2, up1);
  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/*
/*                            K47 (TX / RX)
/*
/*===========================================================================*/

/*===========================================================================*/
/*
/*                            TX Calibration
/*
/*===========================================================================*/

/*===========================================================================*/
/* Function: CodecMode DL (requested by MS)
/* Purpose : This function is always a query and returns the codec mode that
/*           the MS requests according to the AMR Rate Set settings.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrEHrDl (ViSession instrSession,
                                                ViInt32 *codecMode,
                                                ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    CHECKRETMSG(RSCMU_getViString (instrSession,
                              "SENS:MSS:AMR:HRAT:EPSK:DLCM?",
                              rdBuf,
                              RD_BUFFER_SIZE,
                              RSCMU_ERROR_PARAMETER1));
    sscanf (rdBuf, "CM%ld", codecMode);
    RETMSG (RSCMU_Status);
}

/*===========================================================================*/
/* Function: CodecMode WB DL (used by MS)
/* Purpose : This function is always a query and returns the actual DL codec
/*           mode used by the MS, irrespective of the commanded codec mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrWbEHrDl (ViSession instrSession,
                                                   ViInt32 *codecMode,
                                                   ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    GET_RD_BUF(instrSession);

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_23,RSCMU_ERROR_FW_VERSION_4_23));

    // Get the Codec Mode
    CHECKRETMSG(RSCMU_getViString(instrSession,"SENS:MSS:AMR:WB:HRAT:EPSK:DLCM?",rdBuf,RD_BUFFER_SIZE,0));

    if      (strncmp (rdBuf,"CM1", 3) == 0)
    *codecMode = 1;
    else if (strncmp (rdBuf,"CM2", 3) == 0)
    *codecMode = 2;
    else if (strncmp (rdBuf,"CM3", 3) == 0)
    *codecMode = 3;
    else if (strncmp (rdBuf,"CM4", 3) == 0)
    *codecMode = 4;
    else if (strncmp (rdBuf, "NAN",3) == 0)
    *codecMode = RSCMU_NAN_VI_INT32;
    
    RETMSG (RSCMU_Status);
}

/*===========================================================================*/
/* Function: CodecMode WB UL (used by MS)
/* Purpose : This function is always a query and returns the actual UL codec
/*           mode used by the MS, irrespective of the commanded codec mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrWbEHrUl (ViSession instrSession,
                                                   ViInt32 *codecMode,
                                                   ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    GET_RD_BUF(instrSession);

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_23,RSCMU_ERROR_FW_VERSION_4_23));

    // Get the Codec Mode
    CHECKRETMSG(RSCMU_getViString(instrSession,"SENS:MSS:AMR:WB:HRAT:EPSK:ULCM?",rdBuf,RD_BUFFER_SIZE,0));

    if      (strncmp (rdBuf,"CM1", 3) == 0)
    *codecMode = 1;
    else if (strncmp (rdBuf,"CM2", 3) == 0)
    *codecMode = 2;
    else if (strncmp (rdBuf,"CM3", 3) == 0)
    *codecMode = 3;
    else if (strncmp (rdBuf,"CM4", 3) == 0)
    *codecMode = 4;
    else if (strncmp (rdBuf, "NAN",3) == 0)
    *codecMode = RSCMU_NAN_VI_INT32;
    
    RETMSG (RSCMU_Status);
}

/*===========================================================================*/
/* Function: CodecMode UL (used by MS)
/* Purpose : This function is always a query and returns the actual UL codec
/*           mode used by the MS, irrespective of the commanded codec mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrEHrUl (ViSession instrSession,
                                                ViInt32 *codecMode,
                                                ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    CHECKRETMSG(RSCMU_getViString (instrSession,
                              "SENS:MSS:AMR:HRAT:EPSK:ULCM?",
                              rdBuf,
                              RD_BUFFER_SIZE,
                              RSCMU_ERROR_PARAMETER1));
    sscanf (rdBuf, "CM%ld", codecMode);
    RETMSG (RSCMU_Status);
}

/*===========================================================================*/
/* Function: CodecMode WB DL (used by MS)
/* Purpose : This function is always a query and returns the actual UL codec
/*           mode used by the MS, irrespective of the commanded codec mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrWbEFrDl (ViSession instrSession,
                                                   ViInt32 *codecMode,
                                                   ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    GET_RD_BUF(instrSession);

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_23,RSCMU_ERROR_FW_VERSION_4_23));

    // Get the Codec Mode
    CHECKRETMSG(RSCMU_getViString(instrSession,"SENS:MSS:AMR:WB:FRAT:EPSK:DLCM?",rdBuf,RD_BUFFER_SIZE,0));

    if      (strncmp (rdBuf,"CM1", 3) == 0)
    *codecMode = 1;
    else if (strncmp (rdBuf,"CM2", 3) == 0)
    *codecMode = 2;
    else if (strncmp (rdBuf,"CM3", 3) == 0)
    *codecMode = 3;
    else if (strncmp (rdBuf,"CM4", 3) == 0)
    *codecMode = 4;
    else if (strncmp (rdBuf, "NAN",3) == 0)
    *codecMode = RSCMU_NAN_VI_INT32;
    
    RETMSG (RSCMU_Status);
}

/*===========================================================================*/
/* Function: CodecMode WB UL (used by MS)
/* Purpose : This function is always a query and returns the actual UL codec
/*           mode used by the MS, irrespective of the commanded codec mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrWbEFrUl (ViSession instrSession,
                                                   ViInt32 *codecMode,
                                                   ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    GET_RD_BUF(instrSession);

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_23,RSCMU_ERROR_FW_VERSION_4_23));

    // Get the Codec Mode
    CHECKRETMSG(RSCMU_getViString(instrSession,"SENS:MSS:AMR:WB:FRAT:EPSK:ULCM?",rdBuf,RD_BUFFER_SIZE,0));

    if      (strncmp (rdBuf,"CM1", 3) == 0)
    *codecMode = 1;
    else if (strncmp (rdBuf,"CM2", 3) == 0)
    *codecMode = 2;
    else if (strncmp (rdBuf,"CM3", 3) == 0)
    *codecMode = 3;
    else if (strncmp (rdBuf,"CM4", 3) == 0)
    *codecMode = 4;
    else if (strncmp (rdBuf, "NAN",3) == 0)
    *codecMode = RSCMU_NAN_VI_INT32;
    
    RETMSG (RSCMU_Status);
}

/*===========================================================================*/
/* Function: Target Level
/* Purpose : This function defines the target of the traffic channel (TCH) in
/*           the used timeslot for the single shot CMR performance
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqCmrpContTlev (ViSession instrSession,
                                                     ViReal64 targetLevel,
                                                     ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_setViReal64 (instrSession, "CONF:RXQ:CMRP:CONT:TLEV",
                              targetLevel, -137.0, -24.0, RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Init
/* Purpose : This function start a new receiver quality statistics overview
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_InitRxqCmrp (ViSession instrSession,
                                             ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_sendCmd (instrSession, "INIT:RXQ:CMRP"));
}

/*===========================================================================*/
/* Function: Abort
/* Purpose : This function aborts running receiver quality statistics
/*           overview measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborRxqCmrp (ViSession instrSession,
                                             ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_sendCmd (instrSession, "ABOR:RXQ:CMRP"));
}

/*===========================================================================*/
/* Function: Stop
/* Purpose : This function stops running receiver quality statistics
/*           overview measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopRxqCmrp (ViSession instrSession,
                                             ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_sendCmd (instrSession, "STOP:RXQ:CMRP"));
}

/*===========================================================================*/
/* Function: Continue
/* Purpose : This function runs next receiver quality statistics overview
/*           measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContRxqCmrp (ViSession instrSession,
                                             ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    RETMSG(RSCMU_sendCmd (instrSession, "CONT:RXQ:CMRP"));
}

/*===========================================================================*/
/* Function: Set Event Reporting Mode
/* Purpose : This function defines the events generated when the measurement
/*           is terminated or stopped
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqCmrpErep (ViSession instrSession,
                                                 ViInt32 Mode,
                                                 ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
    ViString    StrMode[] = {"OFF","SRQ","SOPC","SRSQ"};

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf (wrtBuf, "CONF:RXQ:CMRP:EREP %s", StrMode[Mode]);
    if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;

    return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Fetch Status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcRxqCmrpStat (ViSession instrSession,
                                                ViInt32 *MeasurementStatus,
                                                ViInt32 *CountingNo,
                                                ViInt32 *StatisticNo,
                                                ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      Tab[100][100];

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));
  if ((RSCMU_Status = RSCMU_Query (instrSession, "FETC:RXQ:CMRP:STAT?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", Tab);

  // Gets the status of the measurement:
  if ((RSCMU_Status = RSCMU_GetMeasStatVal (MeasurementStatus, Tab, 0)) < 0)
    return RSCMU_Status;

  // Gets the current value of the statistics counter (the number of the current statistics cycle):
  if ((RSCMU_Status = RSCMU_GetCountingNo (CountingNo, Tab, 1)) < 0)
    return RSCMU_Status;

  // Gets the current evaluation period within a statistics cycle:
  if ((RSCMU_Status = RSCMU_GetStatisticNo (StatisticNo, Tab, 2)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

ViStatus _VI_FUNC RSCMU_ScanRxqCmrp (ViString response,
                                             ViInt32 results[])
{
    ViChar  *p2buf = NULL;
    ViInt32 i = 0;
    
    p2buf = strtok (response, ",");
    results[0] = atol (p2buf);
    
    for (i = 1; i < 9; i++)
    {
        p2buf = strtok (NULL,",");
        results[i] = atol (p2buf);
    }
    if (i == 9)
        return VI_SUCCESS;
    else
        return RSCMU_ERROR_INTERPRETING_RESPONSE;
}

/*===========================================================================*/
/* Function: Read
/* Purpose : This function starts single shot CMR performance test and
/*           outputs the measurement results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadRxqCmrp (ViSession instrSession,
                                             ViInt32 results[],
                                             ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    CHECKRETMSG(RSCMU_getViString (instrSession,
                              "READ:RXQ:CMRP?",
                              rdBuf,
                              RD_BUFFER_SIZE,
                              RSCMU_ERROR_PARAMETER1));
    RETMSG (RSCMU_ScanRxqCmrp (rdBuf, results));
}

/*===========================================================================*/
/* Function: Fetch
/* Purpose : This function reads out unsynchronized CMR performance test
/*           measurement results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcRxqCmrp (ViSession instrSession,
                                             ViInt32 results[],
                                             ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    CHECKRETMSG(RSCMU_getViString (instrSession,
                              "FETC:RXQ:CMRP?",
                              rdBuf,
                              RD_BUFFER_SIZE,
                              RSCMU_ERROR_PARAMETER1));
    RETMSG (RSCMU_ScanRxqCmrp (rdBuf, results));
}

/*===========================================================================*/
/* Function: Sample
/* Purpose : This function reads out synchronized CMR performance test
/*           measurement results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampRxqCmrp (ViSession instrSession,
                                             ViInt32 results[],
                                             ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      rdBuf[RD_BUFFER_SIZE] = "";

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V4_20,RSCMU_ERROR_FW_VERSION_4_20));

    CHECKRETMSG(RSCMU_getViString (instrSession,
                              "SAMP:RXQ:CMRP?",
                              rdBuf,
                              RD_BUFFER_SIZE,
                              RSCMU_ERROR_PARAMETER1));
    RETMSG (RSCMU_ScanRxqCmrp (rdBuf, results));
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function select four codec modes and define the decision
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowTxcContRep (ViSession instrSession,
                                                    ViInt32 repetition,
                                                    ViInt32 multipleMeasurement,
                                                    ViInt32 stopCondition,
                                                    ViInt32 stepMode,
                                                    ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    ViChar      wrBuf[WR_BUFFER_SIZE]= "";
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    if (repetition != RSCMU_MULT)
    {
        sprintf(wrBuf, "CONF:POW:TXC:CONT:REP %s,%s,%s",
                                            repetitionArr[repetition],
                                            stopConditionArr[stopCondition],
                                            stepModeArr[stepMode]);
    }
    else
    {
        sprintf(wrBuf, "CONF:POW:TXC:CONT:REP %d,%s,%s",
                                            multipleMeasurement,
                                            stopConditionArr[stopCondition],
                                            stepModeArr[stepMode]);
    }

    RETMSG(RSCMU_sendCmd(instrSession, wrBuf));
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function select four codec modes and define the decision
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowTxcContDef (ViSession instrSession,
                                                    ViInt32 setDefaultValues,
                                                    ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    RETMSG(RSCMU_setViString(instrSession, "CONF:POW:TXC:CONT:DEF",
                            mode_On_Off[setDefaultValues],
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Frequency List
/* Purpose : This function specifies all measured frequencies.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowTxcFreqAll (ViSession instrSession,
                                                    ViBoolean state[],
                                                    ViReal64 frequencyValue[],
                                                    ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViInt32     i;
    ViChar*     p2buf;
    ViChar      command [2048];

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));

    p2buf = command + sprintf (command, "CONF:POW:TXC:FREQ:ALL ");

    for (i = 0; i <100; i++)
    {
        if (state[i])
            p2buf += sprintf (p2buf,"%f,", frequencyValue[i]);
        else
            p2buf += sprintf (p2buf, "OFF,");
    }

    *--p2buf = '\n';

    RETMSG (viWrite (instrSession, (ViBuf) command, strlen(command), NULL));
}

/*===========================================================================*/
/* Function: Frequency List
/* Purpose : This function specifies a single measured frequency numbered by
/*           the numeric suffix.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowTxcFreq (ViSession instrSession,
                                                 ViInt32   frequencyNumber,
                                                 ViReal64  frequency,
                                                 ViChar    errorMessage[])
{
    ViStatus    RSCMU_Status;
    ViChar      wrBuf[WR_BUFFER_SIZE]= "";
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, frequencyNumber, 1, 100, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrBuf, "CONF:POW:TXC:FREQ%d %lf", frequencyNumber, frequency);

    RETMSG(RSCMU_sendCmd(instrSession, wrBuf));
}

/*===========================================================================*/
/* Function: Configure Subranges...
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubPowTxc (ViSession instrSession,
                                                ViInt32 statisticsMode,
                                                ViReal64 startTime_bit,
                                                ViInt32 number_of_samples,
                                                ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, statisticsMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);
    CHECK_VI_REAL64_RANGE(instrSession, startTime_bit, 0, 349, RSCMU_ERROR_PARAMETER3, errorMessage);
    CHECK_VI_INT32_RANGE(instrSession, number_of_samples, 1, 350, RSCMU_ERROR_PARAMETER4, errorMessage);

    sprintf (wrtBuf, "CONF:SUB:POW:TXC %s,%lf,%d", StrStatistics[statisticsMode],
                                                   startTime_bit*1E-6,
                                                   number_of_samples);

    if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;

    return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Init, Abort, Stop and Continue Measurement
/* Purpose : This function controls the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ControlPowTxc (ViSession instrSession,
                                                ViInt32 commandNr,
                                                ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    sprintf (wrtBuf, "%s:POW:TXC", StrCommand[commandNr]);

    return RSCMU_sendCmd (instrSession, wrtBuf);
}

/*===========================================================================*/
/* Function: Start Modulation Measurements
/* Purpose : This function start the modulation measurement,
/*           setting it to the status beyond.
/*           RUN        Start measurement without waiting
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_InitPowTxc (ViSession instrSession,
                                             ViChar errorMessage[])
{
    return RSCMU_GSM_NSig_ControlPowTxc (instrSession, 1, errorMessage);
}

/*===========================================================================*/
/* Function: Abort Modulation Measurements
/* Purpose : This function abort the running modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborPowTxc (ViSession instrSession,
                                             ViChar errorMessage[])
{
    return RSCMU_GSM_NSig_ControlPowTxc (instrSession, 2, errorMessage);
}

/*===========================================================================*/
/* Function: Stop Modulation Measurements
/* Purpose : This function stop measurement after current statistic cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopPowTxc (ViSession instrSession,
                                             ViChar errorMessage[])
{
    return RSCMU_GSM_NSig_ControlPowTxc (instrSession, 3, errorMessage);
}

/*===========================================================================*/
/* Function: Run next measurement step
/* Purpose : This function runs next modulation measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContPowTxc (ViSession instrSession,
                                             ViChar errorMessage[])
{
    return RSCMU_GSM_NSig_ControlPowTxc (instrSession, 4, errorMessage);
}

/*===========================================================================*/
/* Function: Set Event Reporting Mode
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowTxcErep (ViSession instrSession,
                                                 ViInt32 measurementEventReporting,
                                                 ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    return RSCMU_setEnum (instrSession, "CONF:POW:TXC:EREP",
                          measurementEventReporting,
                          StrEventReporting,
                          RSCMU_ERROR_PARAMETER2);
}

/*===========================================================================*/
/* Function: Modulation Measurement Status
/* Purpose : This function returns the status of the current measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcScalPowTxcStat (ViSession instrSession,
                                                     ViInt32 *measurementStatus,
                                                     ViInt32 *countingNo,
                                                     ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;
    ViChar      rdBuf[RD_BUFFER_SIZE], wrtBuf[WR_BUFFER_SIZE];
    ViChar*     str;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    sprintf(wrtBuf,"FETC:POW:TXC:STAT?");

    CHECKRETMSG(RSCMU_getViString(instrSession, wrtBuf, rdBuf, RD_BUFFER_SIZE,0));

    if (!(str = strtok(rdBuf,",")))
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_INTERPRETING_RESPONSE, errorMessage);

    // Get the status of the measurement:
    CHECKRET(RSCMU_getIndexFromString(instrSession, rdBuf, measurementStatusArr, measurementStatus));

    if (!(str = strtok(NULL,",")))
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_INTERPRETING_RESPONSE, errorMessage);

    if(!sscanf(str,"%ld",countingNo))
        *countingNo = RSCMU_NONE;

    return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Read Scalar Results
/* Purpose : This function is always a query. It starts the measurement and/or
/*           returns the average power in a particular timeslot (1 to 350).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadScalPowTxc (ViSession instrSession,
                                                 ViInt32 timeslotNumber,
                                                 ViReal64 *averagePower,
                                                 ViChar errorMessage[])
{
    return RSCMU_GSM_NSig_TxScalar(instrSession, 5, timeslotNumber, averagePower, errorMessage);
}

/*===========================================================================*/
/* Function: Read, Fetch, Sample Scalar Results
/* Purpose : This function is always a query. It starts the measurement and/or
/*           returns the average power in a particular timeslot (1 to 350).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_TxScalar (ViSession instrSession,
                                                 ViInt32 commandNr,
                                                 ViInt32 timeslotNumber,
                                                 ViReal64 *averagePower,
                                                 ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;
    ViChar      wrtBuf[WR_BUFFER_SIZE];


    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    CHECK_VI_INT32_RANGE(instrSession, timeslotNumber, 1, 350, RSCMU_ERROR_PARAMETER3, errorMessage);

    sprintf(wrtBuf,"%s:POW:TXC:POW%d?",  StrCommand[commandNr],timeslotNumber);

    CHECKRETMSG(RSCMU_getViReal64(instrSession, wrtBuf, averagePower, RSCMU_ERROR_PARAMETER4));

    return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Fetch Scalar Results
/* Purpose : This function is always a query. It starts the measurement and/or
/*           returns the average power in a particular timeslot (1 to 350).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcScalPowTxcPow (ViSession instrSession,
                                                    ViInt32 timeslotNumber,
                                                    ViReal64 *averagePower,
                                                    ViChar errorMessage[])
{
    return RSCMU_GSM_NSig_TxScalar(instrSession, 6, timeslotNumber, averagePower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Scalar Results
/* Purpose : This function is always a query. It starts the measurement and/or
/*           returns the average power in a particular timeslot (1 to 350).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampScalPowTxcPow (ViSession instrSession,
                                                    ViInt32 timeslotNumber,
                                                    ViReal64 *averagePower,
                                                    ViChar errorMessage[])
{
    return RSCMU_GSM_NSig_TxScalar(instrSession, 7, timeslotNumber, averagePower, errorMessage);
}

/*===========================================================================*/
/* Function: Read Array Results
/* Purpose : This function is always a query. It returns a list containing
/*           the average burst power in 350 timeslots.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrPowTxc (ViSession instrSession,
                                                ViReal64 averagePower[],
                                                ViChar errorMessage[])
{
    return RSCMU_GMS_NSig_TxArray (instrSession, 5, averagePower, errorMessage);
}

/*===========================================================================*/
/* Function: Read, Fetch and Sample Array Results
/* Purpose : This function is always a query. It returns a list containing
/*           the average burst power in 350 timeslots.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GMS_NSig_TxArray (ViSession instrSession,
                                                ViInt32 commandNr,
                                                ViReal64 averagePower[],
                                                ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
    ViInt32     NbOfMeasValues;
    ViChar      BurstPowerTmp[669][20];

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    sprintf (wrtBuf, "%s:ARR:POW:TXC?", StrCommand[commandNr]);
    if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;

    // Find all burst power values by breaking the read buffer:
    NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

    RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, averagePower);

    return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Read Array Results
/* Purpose : This function is always a query. It returns a list containing
/*           the average burst power in 350 timeslots.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrPowTxc (ViSession instrSession,
                                                ViReal64 averagePower[],
                                                ViChar errorMessage[])
{
    return RSCMU_GMS_NSig_TxArray (instrSession, 6, averagePower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Array Results
/* Purpose : This function is always a query. It returns a list containing
/*           the average burst power in 350 timeslots.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrPowTxc (ViSession instrSession,
                                                ViReal64 averagePower[],
                                                ViChar errorMessage[])
{
    return RSCMU_GMS_NSig_TxArray (instrSession, 7, averagePower, errorMessage);
}

/*===========================================================================*/
/* Function: Read, Fetch and Sample Subarray Results
/* Purpose : This function is always a query. It returns a list containing
/*           the average burst power.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GMS_NSig_TxSubarray (ViSession instrSession,
                                                ViInt32 commandNr,
                                                ViReal64 averagePower[],
                                                ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
    ViInt32     NbOfMeasValues;
    ViChar      BurstPowerTmp[669][20];

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    sprintf (wrtBuf, "%s:SUB:POW:TXC?", StrCommand[commandNr]);
    if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
        return RSCMU_Status;

    // Find all burst power values by breaking the read buffer:
    NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

    RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, averagePower);

    return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Read Subarray Results
/* Purpose : This function is always a query. It returns a list containing
/*           the average burst power.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubPowTxc (ViSession instrSession,
                                                ViReal64 averagePower[],
                                                ViChar errorMessage[])
{
    return RSCMU_GMS_NSig_TxSubarray (instrSession, 5, averagePower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Subarray Results
/* Purpose : This function is always a query. It returns a list containing
/*           the average burst power.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubPowTxc (ViSession instrSession,
                                                ViReal64 averagePower[],
                                                ViChar errorMessage[])
{
    return RSCMU_GMS_NSig_TxSubarray (instrSession, 6, averagePower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Subarray Results
/* Purpose : This function is always a query. It returns a list containing
/*           the average burst power.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubPowTxc (ViSession instrSession,
                                                ViReal64 averagePower[],
                                                ViChar errorMessage[])
{
    return RSCMU_GMS_NSig_TxSubarray (instrSession, 7, averagePower, errorMessage);
}

/*===========================================================================*/
/* Function: Init, Abort, Stop and Continue Measurement
/* Purpose : This function controls the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_ControlPowRxc (ViSession instrSession,
                                                ViInt32 commandNr,
                                                ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    sprintf (wrtBuf, "%s:RFG:RXC", StrCommand[commandNr]);

    return RSCMU_sendCmd (instrSession, wrtBuf);
}

/*===========================================================================*/
/* Function: Start Modulation Measurements
/* Purpose : This function starts the modulation measurement,
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_InitRfgRxc (ViSession instrSession,
                                             ViChar errorMessage[])
{
    return RSCMU_GSM_NSig_ControlPowRxc (instrSession, 1, errorMessage);
}

/*===========================================================================*/
/* Function: Abort Modulation Measurements
/* Purpose : This function abort the running modulation measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborRfgRxc (ViSession instrSession,
                                             ViChar errorMessage[])
{
    return RSCMU_GSM_NSig_ControlPowRxc (instrSession, 2, errorMessage);
}

/*===========================================================================*/
/* Function: Modulation Measurement Status
/* Purpose : This function returns the current RXCal test signal generator status.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcRfgRxcStat (ViSession instrSession,
                                                 ViInt32 *measurementStatus,
                                                 ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    RETMSG(RSCMU_getEnum(instrSession, "FETC:RFG:RXC:STAT?",
                            measurementStatus,
                            measurementStatusArr,
                            RSCMU_ERROR_PARAMETER2));
}


/*===========================================================================*/
/* Function: Level Mode
/* Purpose : This function specifies how the levels for the individual slots
/*           are defined.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcMode (ViSession instrSession,
                                             ViInt32 mode,
                                             ViChar _VI_FAR errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V5_00, RSCMU_ERROR_FW_VERSION_5_00));

    RETMSG(RSCMU_setEnum(instrSession, "SOUR:RFG:RXC:MODE", mode, rxcLevelModeArr,
                       RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: SB T1 Countdown Start
/* Purpose : This function selects the value of timer T1 in the first
/*           transmitted synchronization burst (SB).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcSco (ViSession instrSession,
                                                 ViInt32 timerT1,
                                                 ViChar errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V5_00,RSCMU_ERROR_FW_VERSION_5_00));

  RETMSG(RSCMU_setViInt32(instrSession,
                          "SOUR:RFG:RXC:SCO",
                          timerT1,
                          0, 2047,
                          RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Ramping
/* Purpose : This function enables or disables ramping of the generated
/*           signal.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcRamp (ViSession instrSession,
                                          ViInt32 ramping, ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V5_00,RSCMU_ERROR_FW_VERSION_5_00));

    RETMSG(RSCMU_setViString(instrSession, "SOUR:RFG:RXC:RAMP",
                            mode_On_Off[ramping],
                            RSCMU_ERROR_PARAMETER2));
}

/*===========================================================================*/
/* Function: Burst Type
/* Purpose : This function specifies the burst type for the RXCal test signal
/*           in frame number.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcFreqBtyp (ViSession instrSession,
                                                     ViInt32 frameNumber,
                                                     ViInt32 burstType,
                                                     ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;
    ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    CHECK_VI_INT32_RANGE(instrSession, frameNumber, 1, 100, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf (wrtBuf, "SOUR:RFG:RXC:FREQ:BTYP%d", frameNumber);

    RETMSG(RSCMU_setEnum(instrSession, wrtBuf,
                            burstType,
                            burstTypeArr,
                            RSCMU_ERROR_PARAMETER3));
}

/*===========================================================================*/
/* Function: Frequency
/* Purpose : This function specifies the burst type for the RXCal test signal
/*           in frame number.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcFreqFreq (ViSession instrSession,
                                                     ViInt32 frameNumber,
                                                     ViReal64 frequency,
                                                     ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    ViChar      wrBuf[WR_BUFFER_SIZE]= "";
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    CHECK_VI_INT32_RANGE(instrSession, frameNumber, 1, 100, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrBuf, "SOUR:RFG:RXC:FREQ:FREQ%d", frameNumber);
    
    if (frequency < 10.0)
    {
        RETMSG (RSCMU_setViString (instrSession, wrBuf, "OFF", 0));
    }
    else
        RETMSG(RSCMU_setViReal64(instrSession, wrBuf, frequency, 10, 2.7e+3, RSCMU_ERROR_PARAMETER3));
}

/*===========================================================================*/
/* Function: Frequency List
/* Purpose : This function defines the complete frequency list for the RXCal
/*           test signal in all frames no. 1 to 100.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcFreqAll (ViSession instrSession,
                                                    ViReal64 frequencies[],
                                                    ViInt32 slotLevels[],
                                                    ViInt32 burstTypes[],
                                                    ViChar errorMessage[])
{
    ViChar      wrBuf[RD_BUFFER_SIZE_ARRAY]= "";
    ViChar      *p2buf;
    int         i = 0;

    p2buf = wrBuf + sprintf(wrBuf, "SOUR:RFG:RXC:FREQ:ALL ");
    
    for (i = 0; i < 100; i++)
        p2buf += sprintf (p2buf, "%lG,%s,%s,", frequencies[i], powerLevelArr[slotLevels[i]], burstTypeArr[burstTypes[i]]);
    *p2buf = '\0';
    *--p2buf = '\n';
    RETMSG (RSCMU_sendCmd (instrSession, wrBuf));
}

/*===========================================================================*/
/* Function: Slot Level
/* Purpose : This function specifies the slot levels for the RXCal test signal
/*           in frame number. The reference level (slot 0) is defined via
/*           SOURce:RFGenerator:RXCal:RLEVel. The remaining slots are defined
/*           via SOURce:RFGenerator:RXCal:PLEVel.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcFreqPlev (ViSession instrSession,
                                                     ViInt32 frameNumber,
                                                     ViInt32 powerLevel,
                                                     ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    ViChar      wrBuf[WR_BUFFER_SIZE]= "";
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    CHECK_VI_INT32_RANGE(instrSession, frameNumber, 1, 50, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrBuf, "SOUR:RFG:RXC:FREQ:PLEV%d", frameNumber);

    RETMSG(RSCMU_setEnum(instrSession,
                        wrBuf,
                        powerLevel,
                        powerLevelArr,
                        RSCMU_ERROR_PARAMETER3));
}

/*===========================================================================*/
/* Function: Power Level All
/* Purpose : This function specifies the output levels for the RXCal test
/*           signal in slots number 1 to 6.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcPlevAll (ViSession instrSession,
                                                    ViReal64 relativeOutputLevel[],
                                                    ViChar errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViInt32     i;
    ViChar*     p2buf;

    GET_WRT_BUF(instrSession);

    CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));

    p2buf = wrtBuf + sprintf (wrtBuf, "SOUR:RFG:RXC:PLEV:ALL ");

    for (i = 1; i <=6; i++)
    {
        p2buf += sprintf (p2buf,"%Lf,", relativeOutputLevel[i]);

    }

    *--p2buf = '\0';

    RETMSG (RSCMU_sendCmd (instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Power Level
/* Purpose : This function specifies the output levels for the RXCal test
/*           signal in slots number 1 to 6.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcPlev (ViSession instrSession,
                                                 ViInt32 slotNumber,
                                                 ViReal64 outputLevel,
                                                 ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    ViChar      wrBuf[WR_BUFFER_SIZE]= "";
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, slotNumber, 1, 6, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf(wrBuf, "SOUR:RFG:RXC:PLEV%d %lf", slotNumber, outputLevel);

    RETMSG(RSCMU_sendCmd(instrSession, wrBuf));
}

/*===========================================================================*/
/* Function: Reference Level
/* Purpose : This function specifies the output levels for the RXCal test
/*           signal in slots number 1 to 6.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcRlev (ViSession instrSession,
                                                 ViReal64 referenceLevel,
                                                 ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    ViChar      wrBuf[WR_BUFFER_SIZE]= "";
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_60)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_60, errorMessage);

    sprintf(wrBuf, "SOUR:RFG:RXC:RLEV %lf", referenceLevel);

    RETMSG(RSCMU_sendCmd(instrSession, wrBuf));
}

/*===========================================================================*/
/* Function: Individual Frame Level
/* Purpose : This function specifies the individual frame levels for the
/*           RXCal test signal.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcIFLev (ViSession instrSession,
                                                 ViInt32 frameNumber,
                                                 ViReal64 ifLevel,
                                                 ViChar errorMessage[])
{
    ViStatus    RSCMU_Status;
    ViChar      wrBuf[WR_BUFFER_SIZE]= "";
    struct      RSCMU_SESSION_Globals  *p_globalvarBase;

    // Version manager
    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
        return RSCMU_Status;

    // Version manager
    //CHECKRETMSG(RSCMU_checkVersion(instrSession, RSCMU200_V3_60, RSCMU_ERROR_FW_VERSION_3_60));
    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V5_00)
        return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_5_00, errorMessage);

    sprintf(wrBuf, "SOURce:RFGenerator:RXCal:FREQuency:IFLevel%ld %lf", frameNumber, ifLevel);

    RETMSG(RSCMU_sendCmd(instrSession, wrBuf));
}

/*===========================================================================*/
/* Function: Frame Level List
/* Purpose : This function specifies the individual frame levels for the RXCal 
/*           test signal in frames no. 1 to 100.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcIFLevAll (ViSession instrSession,
                                                     ViReal64 frameLevels[],
                                                     ViChar errorMessage[])
{
    ViChar      wrBuf[RD_BUFFER_SIZE_ARRAY]= "";
    ViChar      *p2buf;
    int         i = 0;

    p2buf = wrBuf + sprintf(wrBuf, "SOUR:RFG:RXC:FREQ:IFL:ALL ");
    
    for (i = 0; i < 100; i++)
        p2buf += sprintf (p2buf, "%lG,", frameLevels[i]);
    *p2buf = '\0';
    *--p2buf = '\n';
    RETMSG (RSCMU_sendCmd (instrSession, wrBuf));
}

/*****************************************************************************/
/*= CLASS: UTILITY ==========================================================*/
/*****************************************************************************/
/*===========================================================================*/
/* Function: RSCMU_K2G_RevisionQuery
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_K2G_RevisionQuery (ViSession instrSession,
                                                                 ViChar    instrDriverRev[],
                                                                 ViChar    instrRev[],
                                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  size_t      invertCommaPos;
  ViChar      rdBuf[RD_BUFFER_SIZE]="";
  ViChar      tab[100][100];

  if ((RSCMU_Status = RSCMU_Query (instrSession, "*IDN?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the current Firmware Version
  invertCommaPos = strcspn (tab[3], "\"");
  strncpy (instrRev,tab[3], invertCommaPos);
  instrRev[invertCommaPos] = 0;

  /*-----------------------------------------------------------------------*/
  /* Instrument driver revision:
  /* The format for instrDriverRev is a string with four fields separated by
  /* commas, the first field is the revision of the instrument driver, the
  /* second field is the month and year of the version's release, the third
  /* field is the time of the version's release, and the four field is the
  /* version of CVI used to write the current version.
  /*-----------------------------------------------------------------------*/
  strcpy (instrDriverRev, RSCMU_K2G_REVISION);
  strcat (instrDriverRev, ", ");
  /* From the complilation date of the current file */
  strcat (instrDriverRev, __DATE__);
  strcat (instrDriverRev, ", ");
  /* From the complilation time of the current file */
  strcat (instrDriverRev, __TIME__);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Error Message
/* Purpose : This function translates the error return value from the
/*           instrument driver into a user-readable string.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_K2G_errorMessage (ViSession       instrSession,
                                                                 ViStatus        statusCode,
                                                                 ViChar  message[])
{
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViInt16 i;

    /*=======================================================================*/
    /* RSCMU_stringValPair is used in the RSCMU_K2G_errorMessage function
    /*=======================================================================*/
    typedef struct  RSCMU_stringValPair
    {
        ViStatus stringVal;
        ViString stringName;
    }  RSCMU_tStringValPair;

    RSCMU_Status = RSCMU_Base_errorMessage (instrSession, statusCode, message);

    if (RSCMU_Status == VI_WARN_UNKNOWN_STATUS)
    {
       #define K2G_EXPAND(id, value, text) {id, text},
       RSCMU_tStringValPair statusDescArray[] = {
           RSCMU_LIST_OF_SPECIFIC_K2G_ERROR_MESSAGES
       };
     #define NUM_K2G_ERRORS (sizeof(statusDescArray) / sizeof(RSCMU_tStringValPair))

       #undef K2G_EXPAND

       // Search GSM specific errors.
       for (i=0; (i < NUM_K2G_ERRORS) && statusDescArray[i].stringName; i++)
       {
          if (statusDescArray[i].stringVal == statusCode)
          {
             strcpy (message, statusDescArray[i].stringName);
             return (statusCode);
          }
       }
       sprintf( message, "Unknown Error 0x%08lX", statusCode );
       return( VI_WARN_UNKNOWN_STATUS );

    }
    return RSCMU_Status;
}

/*****************************************************************************/
/*======================= LOCAL FUNCTIONS ===================================*/
/*****************************************************************************/
/*===========================================================================*/
/* Function: RSCMU_ScanMod
/* Purpose :
/*===========================================================================*/
ViStatus RSCMU_ScanMod (  ViChar    tab [100][100],
                          ViInt32   i_StartingIndex,
                          ViInt32   i_selectBurst,
                          ViReal64  *phErrPeak,
                          ViReal64  *phErrRMS,
                          ViReal64  *freqErr,
                          ViReal64  *averBurstPowercurrent,
                          ViReal64  *burstOutOfTolerance)
{

  switch (i_selectBurst)
  {
    case RSCMU_CURRENT:
      // Get max phase error with single-value measurement
      if (strcmp (tab[i_StartingIndex], "NAN") != 0)
        sscanf (tab[i_StartingIndex], "%lf", phErrPeak);
      else *phErrPeak = RSCMU_NAN;
      // Get RMS phase error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%lf", phErrRMS);
      else *phErrRMS = RSCMU_NAN;
      // Get frequency error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%lf", freqErr);
      else *freqErr = RSCMU_NAN;
      break;

    case RSCMU_AVERAGE:
      // Get max phase error with average measurement
      if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 1], "%lf", phErrPeak);
      else *phErrPeak = RSCMU_NAN;
      // Get RMS phase error with average measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%lf", phErrRMS);
      else *phErrRMS = RSCMU_NAN;
      // Get frequency error with average measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%lf", freqErr);
      else *freqErr = RSCMU_NAN;
      break;

    case RSCMU_MAXMIN:
      // Get max phase error with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 2], "%lf", phErrPeak);
      else *phErrPeak = RSCMU_NAN;
      // Get RMS phase error with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%lf", phErrRMS);
      else *phErrRMS = RSCMU_NAN;
      // Get frequency error with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%lf", freqErr);
      else *freqErr = RSCMU_NAN;
      break;
  }

  // Get Average burst power with single-value measurement
  if (strcmp (tab[i_StartingIndex + 9], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 9], "%lf", averBurstPowercurrent);
  else *averBurstPowercurrent = RSCMU_NAN;
  // Get relative portion of faulty burst
  if (strcmp (tab[i_StartingIndex + 10], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 10], "%lf", burstOutOfTolerance);
    else *burstOutOfTolerance = RSCMU_NAN;

    return 0;
}

/*===========================================================================*/
/* Function: RSCMU_ScanMod
/* Purpose :
/*===========================================================================*/
ViStatus RSCMU_ScanModXper (ViChar    tab [100][100],
                            ViInt32   i_StartingIndex,
                            ViInt32   i_selectBurst,
                            ViReal64  *phErrPeak,
                            ViReal64  *phErrRMS,
                            ViReal64  *originOffset,
                            ViReal64  *IQImbalance,
                            ViReal64  *freqErr,
                            ViReal64  *averBurstPowercurrent,
                            ViReal64  *burstOutOfTolerance,
                            ViReal64  *phaseOfOriginOffsetVector)
{

  switch (i_selectBurst)
  {
    case RSCMU_CURRENT:
      // Get max phase error with single-value measurement
      if (strcmp (tab[i_StartingIndex], "NAN") != 0)
        sscanf (tab[i_StartingIndex], "%lf", phErrPeak);
      else *phErrPeak = RSCMU_NAN;
      // Get RMS phase error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%lf", phErrRMS);
      else *phErrRMS = RSCMU_NAN;
      // Get origin offset with single-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;
      // Get I/Q Imbalanced with single-value measurement
      if (strcmp (tab[i_StartingIndex + 9], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 9], "%lf",IQImbalance);
      else *IQImbalance = RSCMU_NAN;
      // Get frequency error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 12], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 12], "%lf", freqErr);
      else *freqErr = RSCMU_NAN;
      break;

    case RSCMU_AVERAGE:
      // Get max phase error with average measurement
      if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 1], "%lf", phErrPeak);
      else *phErrPeak = RSCMU_NAN;
      // Get RMS phase error with average measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%lf", phErrRMS);
      else *phErrRMS = RSCMU_NAN;
      // Get origin offset with single-value measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;
      // Get I/Q Imbalanced with single-value measurement
      if (strcmp (tab[i_StartingIndex + 10], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 10], "%lf", IQImbalance);
      else *IQImbalance = RSCMU_NAN;
      // Get frequency error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 13], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 13], "%lf", freqErr);
      else *freqErr = RSCMU_NAN;
      break;

    case RSCMU_MAXMIN:
      // Get max phase error with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 2], "%lf", phErrPeak);
      else *phErrPeak = RSCMU_NAN;
      // Get RMS phase error with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%lf", phErrRMS);
      else *phErrRMS = RSCMU_NAN;
      // Get origin offset with single-value measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;
      // Get I/Q Imbalanced with single-value measurement
      if (strcmp (tab[i_StartingIndex + 11], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 11], "%lf", IQImbalance);
      else *IQImbalance = RSCMU_NAN;
      // Get frequency error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 14], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 14], "%lf", freqErr);
      else *freqErr = RSCMU_NAN;
      break;
  }

  // Get Average burst power with single-value measurement
  if (strcmp (tab[i_StartingIndex + 15], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 15], "%lf", averBurstPowercurrent);
  else *averBurstPowercurrent = RSCMU_NAN;

  // Get relative portion of faulty burst
  if (strcmp (tab[i_StartingIndex + 16], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 16], "%lf", burstOutOfTolerance);
  else *burstOutOfTolerance = RSCMU_NAN;

  // Get the phase of the origin offset vector
  if (strcmp (tab[i_StartingIndex + 17], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 17], "%lf", phaseOfOriginOffsetVector);
  else *phaseOfOriginOffsetVector = RSCMU_NAN;

  return 0;
}

/*===========================================================================*/
/* Function: RSCMU_ScanModOver     <V3.07
/* Purpose : Extracts the scalar results in modulation OVERview:EPSK
/*===========================================================================*/
ViStatus RSCMU_ScanModOver (ViChar    tab [100][100],
                            ViInt32   i_StartingIndex,
                            ViInt32   i_selectBurst,
                            ViReal64  *EVM95,
                            ViReal64  *MagErr95,
                            ViReal64  *PhaseErr95,
                            ViReal64  *EVMPeak,
                            ViReal64  *EVMRMS,
                            ViReal64  *magnErrorPeak,
                            ViReal64  *magnErrorRMS,
                            ViReal64  *phaseErrorPeak,
                            ViReal64  *phaseErrorRMS,
                            ViReal64  *originOffset,
                            ViReal64  *IQIm_balance,
                            ViReal64  *frequencyError,
                            ViReal64  *avgBurstPowerCurr,
                            ViReal64  *burstOutOfTol)

{



  // Get the 95% EVM
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%lf", EVM95);
  else *EVM95 = RSCMU_NAN;

  // Get the 95% Magnitude Error
  if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 1], "%lf", MagErr95);
  else *MagErr95 = RSCMU_NAN;

  // Get the 95% Phase Error
  if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 2], "%lf", PhaseErr95);
  else *PhaseErr95 = RSCMU_NAN;

  switch (i_selectBurst)
  {
    case RSCMU_CURRENT:
      // Get the EVM peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%lf", EVMPeak);
      else *EVMPeak = RSCMU_NAN;

      // Get the EVM RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%lf", EVMRMS);
      else *EVMRMS = RSCMU_NAN;

      // Get the Magnitude Error Peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 9], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 9], "%lf", magnErrorPeak);
      else *magnErrorPeak = RSCMU_NAN;

      // Get the Magnitude Error RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 12], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 12], "%lf", magnErrorRMS);
      else *magnErrorRMS = RSCMU_NAN;

      // Get the Phase Error Peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 15], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 15], "%lf", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 18], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 18], "%lf", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with single-value measurement
      if (strcmp (tab[i_StartingIndex + 21], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 21], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      // Get the IQ/IM balance with single-value measurement
      if (strcmp (tab[i_StartingIndex + 24], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 24], "%lf", IQIm_balance);
      else *IQIm_balance = RSCMU_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 27], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 27], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;

    case RSCMU_AVERAGE:
      // Get the EVM peak with average measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%lf", EVMPeak);
      else *EVMPeak = RSCMU_NAN;

      // Get the EVM RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%lf", EVMRMS);
      else *EVMRMS = RSCMU_NAN;

      // Get the Magnitude Error Peak with average measurement
      if (strcmp (tab[i_StartingIndex + 10], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 10], "%lf", magnErrorPeak);
      else *magnErrorPeak = RSCMU_NAN;

      // Get the Magnitude Error RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 13], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 13], "%lf", magnErrorRMS);
      else *magnErrorRMS = RSCMU_NAN;

      // Get the Phase Error Peak with average measurement
      if (strcmp (tab[i_StartingIndex + 16], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 16], "%lf", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 19], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 19], "%lf", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with average measurement
      if (strcmp (tab[i_StartingIndex + 22], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 22], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      // Get the IQ/IM balance with average measurement
      if (strcmp (tab[i_StartingIndex + 25], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 25], "%lf", IQIm_balance);
      else *IQIm_balance = RSCMU_NAN;

      // Get the Frequency Error with average measurement
      if (strcmp (tab[i_StartingIndex + 28], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 28], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;

    case RSCMU_MAXMIN:
      // Get the EVM peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%lf", EVMPeak);
      else *EVMPeak = RSCMU_NAN;

      // Get the EVM RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%lf", EVMRMS);
      else *EVMRMS = RSCMU_NAN;

      // Get the Magnitude Error Peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 11], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 11], "%lf", magnErrorPeak);
      else *magnErrorPeak = RSCMU_NAN;

      // Get the Magnitude Error RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 14], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 14], "%lf", magnErrorRMS);
      else *magnErrorRMS = RSCMU_NAN;

      // Get the Phase Error Peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 17], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 17], "%lf", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 20], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 20], "%lf", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 23], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 23], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      // Get the IQ/IM balance with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 26], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 26], "%lf", IQIm_balance);
      else *IQIm_balance = RSCMU_NAN;

      // Get the Frequency Error with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 29], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 29], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;
  }

  // Get the Average Burst Power Current
  if (strcmp (tab[i_StartingIndex + 30], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 30], "%lf", avgBurstPowerCurr);
  else *avgBurstPowerCurr = RSCMU_NAN;

  // Get the Burst Out Of Tolerance
  if (strcmp (tab[i_StartingIndex + 31], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 31], "%lf", burstOutOfTol);
  else *burstOutOfTol = RSCMU_NAN;

  return 0;
}


/*===========================================================================*/
/* Function: RSCMU_ScanModOverV307      >= V3.07
/* Purpose : Extracts the scalar results in modulation OVERview:EPSK
/*           IQ Imbalance is with V307 not supported (Set to NAN)
/*===========================================================================*/
ViStatus RSCMU_ScanModOverV307 (ViChar    tab [100][100],
                            ViInt32   i_StartingIndex,
                            ViInt32   i_selectBurst,
                            ViReal64  *EVM95,
                            ViReal64  *MagErr95,
                            ViReal64  *PhaseErr95,
                            ViReal64  *EVMPeak,
                            ViReal64  *EVMRMS,
                            ViReal64  *magnErrorPeak,
                            ViReal64  *magnErrorRMS,
                            ViReal64  *phaseErrorPeak,
                            ViReal64  *phaseErrorRMS,
                            ViReal64  *originOffset,
                            ViReal64  *IQIm_balance,
                            ViReal64  *frequencyError,
                            ViReal64  *avgBurstPowerCurr,
                            ViReal64  *burstOutOfTol)

{



  // Get the 95% EVM
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%lf", EVM95);
  else *EVM95 = RSCMU_NAN;

  // Get the 95% Magnitude Error
  if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 1], "%lf", MagErr95);
  else *MagErr95 = RSCMU_NAN;

  // Get the 95% Phase Error
  if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 2], "%lf", PhaseErr95);
  else *PhaseErr95 = RSCMU_NAN;

  switch (i_selectBurst)
  {
    case RSCMU_CURRENT:
      // Get the EVM peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%lf", EVMPeak);
      else *EVMPeak = RSCMU_NAN;

      // Get the EVM RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%lf", EVMRMS);
      else *EVMRMS = RSCMU_NAN;

      // Get the Magnitude Error Peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 9], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 9], "%lf", magnErrorPeak);
      else *magnErrorPeak = RSCMU_NAN;

      // Get the Magnitude Error RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 12], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 12], "%lf", magnErrorRMS);
      else *magnErrorRMS = RSCMU_NAN;

      // Get the Phase Error Peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 15], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 15], "%lf", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 18], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 18], "%lf", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with single-value measurement
      if (strcmp (tab[i_StartingIndex + 21], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 21], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 24], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 24], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      *IQIm_balance = RSCMU_NAN;
      break;

    case RSCMU_AVERAGE:
      // Get the EVM peak with average measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%lf", EVMPeak);
      else *EVMPeak = RSCMU_NAN;

      // Get the EVM RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%lf", EVMRMS);
      else *EVMRMS = RSCMU_NAN;

      // Get the Magnitude Error Peak with average measurement
      if (strcmp (tab[i_StartingIndex + 10], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 10], "%lf", magnErrorPeak);
      else *magnErrorPeak = RSCMU_NAN;

      // Get the Magnitude Error RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 13], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 13], "%lf", magnErrorRMS);
      else *magnErrorRMS = RSCMU_NAN;

      // Get the Phase Error Peak with average measurement
      if (strcmp (tab[i_StartingIndex + 16], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 16], "%lf", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 19], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 19], "%lf", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with average measurement
      if (strcmp (tab[i_StartingIndex + 22], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 22], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      // Get the Frequency Error with average measurement
      if (strcmp (tab[i_StartingIndex + 25], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 25], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;

      *IQIm_balance = RSCMU_NAN;
      break;

    case RSCMU_MAXMIN:
      // Get the EVM peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%lf", EVMPeak);
      else *EVMPeak = RSCMU_NAN;

      // Get the EVM RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%lf", EVMRMS);
      else *EVMRMS = RSCMU_NAN;

      // Get the Magnitude Error Peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 11], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 11], "%lf", magnErrorPeak);
      else *magnErrorPeak = RSCMU_NAN;

      // Get the Magnitude Error RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 14], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 14], "%lf", magnErrorRMS);
      else *magnErrorRMS = RSCMU_NAN;

      // Get the Phase Error Peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 17], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 17], "%lf", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 20], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 20], "%lf", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 23], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 23], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      // Get the Frequency Error with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 26], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 26], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;

      *IQIm_balance = RSCMU_NAN;

      break;
  }

  // Get the Average Burst Power Current
  if (strcmp (tab[i_StartingIndex + 27], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 27], "%lf", avgBurstPowerCurr);
  else *avgBurstPowerCurr = RSCMU_NAN;

  // Get the Burst Out Of Tolerance
  if (strcmp (tab[i_StartingIndex + 28], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 28], "%lf", burstOutOfTol);
  else *burstOutOfTol = RSCMU_NAN;

  return 0;
}

/*===========================================================================*/
/* Function: RSCMU_ScanModOverV423      >= V4.23
/* Purpose : Extracts the scalar results in modulation OVERview:EPSK
/*           IQ Imbalance is with V307 not supported (Set to NAN)
/*===========================================================================*/
ViStatus RSCMU_ScanModOverV423 (ViChar    tab [100][100],
                            ViInt32   i_StartingIndex,
                            ViInt32   i_selectBurst,
                            ViReal64  *EVM95,
                            ViReal64  *MagErr95,
                            ViReal64  *PhaseErr95,
                            ViReal64  *EVMPeak,
                            ViReal64  *EVMRMS,
                            ViReal64  *magnErrorPeak,
                            ViReal64  *magnErrorRMS,
                            ViReal64  *phaseErrorPeak,
                            ViReal64  *phaseErrorRMS,
                            ViReal64  *originOffset,
                            ViReal64  *IQIm_balance,
                            ViReal64  *frequencyError,
                            ViReal64  *avgBurstPowerCurr,
                            ViReal64  *burstOutOfTol)

{



  // Get the 95% EVM
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%lf", EVM95);
  else *EVM95 = RSCMU_NAN;

  // Get the 95% Magnitude Error
  if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 1], "%lf", MagErr95);
  else *MagErr95 = RSCMU_NAN;

  // Get the 95% Phase Error
  if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 2], "%lf", PhaseErr95);
  else *PhaseErr95 = RSCMU_NAN;

  switch (i_selectBurst)
  {
    case RSCMU_CURRENT:
      // Get the EVM peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%lf", EVMPeak);
      else *EVMPeak = RSCMU_NAN;

      // Get the EVM RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%lf", EVMRMS);
      else *EVMRMS = RSCMU_NAN;

      // Get the Magnitude Error Peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 9], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 9], "%lf", magnErrorPeak);
      else *magnErrorPeak = RSCMU_NAN;

      // Get the Magnitude Error RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 12], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 12], "%lf", magnErrorRMS);
      else *magnErrorRMS = RSCMU_NAN;

      // Get the Phase Error Peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 15], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 15], "%lf", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 18], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 18], "%lf", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with single-value measurement
      if (strcmp (tab[i_StartingIndex + 21], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 21], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 24], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 24], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      if (strcmp (tab[i_StartingIndex + 29], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 29], "%lf", IQIm_balance);
      else *IQIm_balance = RSCMU_NAN;
      break;

    case RSCMU_AVERAGE:
      // Get the EVM peak with average measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%lf", EVMPeak);
      else *EVMPeak = RSCMU_NAN;

      // Get the EVM RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%lf", EVMRMS);
      else *EVMRMS = RSCMU_NAN;

      // Get the Magnitude Error Peak with average measurement
      if (strcmp (tab[i_StartingIndex + 10], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 10], "%lf", magnErrorPeak);
      else *magnErrorPeak = RSCMU_NAN;

      // Get the Magnitude Error RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 13], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 13], "%lf", magnErrorRMS);
      else *magnErrorRMS = RSCMU_NAN;

      // Get the Phase Error Peak with average measurement
      if (strcmp (tab[i_StartingIndex + 16], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 16], "%lf", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 19], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 19], "%lf", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with average measurement
      if (strcmp (tab[i_StartingIndex + 22], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 22], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      // Get the Frequency Error with average measurement
      if (strcmp (tab[i_StartingIndex + 25], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 25], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;

      if (strcmp (tab[i_StartingIndex + 30], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 30], "%lf", IQIm_balance);
      else *IQIm_balance = RSCMU_NAN;
      break;

    case RSCMU_MAXMIN:
      // Get the EVM peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%lf", EVMPeak);
      else *EVMPeak = RSCMU_NAN;

      // Get the EVM RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%lf", EVMRMS);
      else *EVMRMS = RSCMU_NAN;

      // Get the Magnitude Error Peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 11], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 11], "%lf", magnErrorPeak);
      else *magnErrorPeak = RSCMU_NAN;

      // Get the Magnitude Error RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 14], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 14], "%lf", magnErrorRMS);
      else *magnErrorRMS = RSCMU_NAN;

      // Get the Phase Error Peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 17], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 17], "%lf", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 20], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 20], "%lf", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 23], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 23], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      // Get the Frequency Error with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 26], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 26], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;

      if (strcmp (tab[i_StartingIndex + 31], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 31], "%lf", IQIm_balance);
      else *IQIm_balance = RSCMU_NAN;

      break;
  }

  // Get the Average Burst Power Current
  if (strcmp (tab[i_StartingIndex + 27], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 27], "%lf", avgBurstPowerCurr);
  else *avgBurstPowerCurr = RSCMU_NAN;

  // Get the Burst Out Of Tolerance
  if (strcmp (tab[i_StartingIndex + 28], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 28], "%lf", burstOutOfTol);
  else *burstOutOfTol = RSCMU_NAN;

  return 0;
}



/*===========================================================================*/
/* Function: RSCMU_ScanModEvm       <3.07
/* Purpose : Extracts the scalar results in modulation EVMagnitude:EPSK
:/*===========================================================================*/
ViStatus RSCMU_ScanModEvm (ViChar    tab [100][100],
                           ViInt32   i_StartingIndex,
                           ViInt32   i_selectBurst,
                           ViReal64 *EVM95,
                           ViReal64 *EVMPeak,
                           ViReal64 *EVMRMS,
                           ViReal64 *originOffset,
                           ViReal64 *IQImBalance,
                           ViReal64 *frequencyError,
                           ViReal64 *avgBurstPowerCurr,
                           ViReal64 *burstOutOfTol)
{
  // Get the 95% EVM
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%lf", EVM95);
  else *EVM95 = RSCMU_NAN;

  switch (i_selectBurst)
  {
    case RSCMU_CURRENT:
      // Get the EVM peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 1], "%lf", EVMPeak);
      else *EVMPeak = RSCMU_NAN;

      // Get the EVM RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%lf", EVMRMS);
      else *EVMRMS = RSCMU_NAN;

      // Get the Origin Offset with single-value measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      // Get the IQ/Im Balance with single-value measurement
      if (strcmp (tab[i_StartingIndex + 10], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 10], "%lf", IQImBalance);
      else *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 13], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 13], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;

    case RSCMU_AVERAGE:
      // Get the EVM peak with average measurement
      if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 2], "%lf", EVMPeak);
      else *EVMPeak = RSCMU_NAN;

      // Get the EVM RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%lf", EVMRMS);
      else *EVMRMS = RSCMU_NAN;

      // Get the Origin Offset with average measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      // Get the IQ/Im Balance with average measurement
      if (strcmp (tab[i_StartingIndex + 11], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 11], "%lf", IQImBalance);
      else *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with average measurement
      if (strcmp (tab[i_StartingIndex + 14], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 14], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;

    case RSCMU_MAXMIN:
      // Get the EVM peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%lf", EVMPeak);
      else *EVMPeak = RSCMU_NAN;

      // Get the EVM RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%lf", EVMRMS);
      else *EVMRMS = RSCMU_NAN;

      // Get the Origin Offset with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 9], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 9], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      // Get the IQ/Im Balance with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 12], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 12], "%lf", IQImBalance);
      else *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 15], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 15], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;
  }

  // Get the Average Burst Power Current
  if (strcmp (tab[i_StartingIndex + 16], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 16], "%lf", avgBurstPowerCurr);
  else *avgBurstPowerCurr = RSCMU_NAN;

  // Get the Burst Out Of Tolerance
  if (strcmp (tab[i_StartingIndex + 17], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 17], "%lf", burstOutOfTol);
  else *burstOutOfTol = RSCMU_NAN;

  return 0;
}



/*===========================================================================*/
/* Function: RSCMU_ScanModEvm         =>3.07
/* Purpose : Extracts the scalar results in modulation EVMagnitude:EPSK
/*           IQ Imbalance is with V307 not supported (Set to NAN)
/*===========================================================================*/
ViStatus RSCMU_ScanModEvmV307 (ViChar    tab [100][100],
                           ViInt32   i_StartingIndex,
                           ViInt32   i_selectBurst,
                           ViReal64 *EVM95,
                           ViReal64 *EVMPeak,
                           ViReal64 *EVMRMS,
                           ViReal64 *originOffset,
                           ViReal64 *IQImBalance,
                           ViReal64 *frequencyError,
                           ViReal64 *avgBurstPowerCurr,
                           ViReal64 *burstOutOfTol)
{
  // Get the 95% EVM
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%lf", EVM95);
  else *EVM95 = RSCMU_NAN;

  switch (i_selectBurst)
  {
    case RSCMU_CURRENT:
      // Get the EVM peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 1], "%lf", EVMPeak);
      else *EVMPeak = RSCMU_NAN;

      // Get the EVM RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%lf", EVMRMS);
      else *EVMRMS = RSCMU_NAN;

      // Get the Origin Offset with single-value measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

//with Version V3.07 IQ Imbalance are not supported in EPSK
      *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 10], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 10], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;

    case RSCMU_AVERAGE:
      // Get the EVM peak with average measurement
      if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 2], "%lf", EVMPeak);
      else *EVMPeak = RSCMU_NAN;

      // Get the EVM RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%lf", EVMRMS);
      else *EVMRMS = RSCMU_NAN;

      // Get the Origin Offset with average measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

//with Version V3.07 IQ Imbalance are not supported in EPSK
      *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with average measurement
      if (strcmp (tab[i_StartingIndex + 11], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 11], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;

    case RSCMU_MAXMIN:
      // Get the EVM peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%lf", EVMPeak);
      else *EVMPeak = RSCMU_NAN;

      // Get the EVM RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%lf", EVMRMS);
      else *EVMRMS = RSCMU_NAN;

      // Get the Origin Offset with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 9], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 9], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

//with Version V3.07 IQ Imbalance are not supported in EPSK
      *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 12], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 12], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;
  }

  // Get the Average Burst Power Current
  if (strcmp (tab[i_StartingIndex + 13], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 13], "%lf", avgBurstPowerCurr);
  else *avgBurstPowerCurr = RSCMU_NAN;

  // Get the Burst Out Of Tolerance
  if (strcmp (tab[i_StartingIndex + 14], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 14], "%lf", burstOutOfTol);
  else *burstOutOfTol = RSCMU_NAN;

  return 0;
}

/*===========================================================================*/
/* Function: RSCMU_ScanModEvm         =>4.23
/* Purpose : Extracts the scalar results in modulation EVMagnitude:EPSK
/*           IQ Imbalance is with V423 not supported (Set to NAN)
/*===========================================================================*/
ViStatus RSCMU_ScanModEvmV423 (ViChar    tab [100][100],
                           ViInt32   i_StartingIndex,
                           ViInt32   i_selectBurst,
                           ViReal64 *EVM95,
                           ViReal64 *EVMPeak,
                           ViReal64 *EVMRMS,
                           ViReal64 *originOffset,
                           ViReal64 *IQImBalance,
                           ViReal64 *frequencyError,
                           ViReal64 *avgBurstPowerCurr,
                           ViReal64 *burstOutOfTol)
{
  // Get the 95% EVM
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%lf", EVM95);
  else *EVM95 = RSCMU_NAN;

  switch (i_selectBurst)
  {
    case RSCMU_CURRENT:
      // Get the EVM peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 1], "%lf", EVMPeak);
      else *EVMPeak = RSCMU_NAN;

      // Get the EVM RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%lf", EVMRMS);
      else *EVMRMS = RSCMU_NAN;

      // Get the Origin Offset with single-value measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      if (strcmp (tab[i_StartingIndex + 15], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 15], "%lf", IQImBalance);
      else *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 10], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 10], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;

    case RSCMU_AVERAGE:
      // Get the EVM peak with average measurement
      if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 2], "%lf", EVMPeak);
      else *EVMPeak = RSCMU_NAN;

      // Get the EVM RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%lf", EVMRMS);
      else *EVMRMS = RSCMU_NAN;

      // Get the Origin Offset with average measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      if (strcmp (tab[i_StartingIndex + 16], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 16], "%lf", IQImBalance);
      else *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with average measurement
      if (strcmp (tab[i_StartingIndex + 11], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 11], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;

    case RSCMU_MAXMIN:
      // Get the EVM peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%lf", EVMPeak);
      else *EVMPeak = RSCMU_NAN;

      // Get the EVM RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%lf", EVMRMS);
      else *EVMRMS = RSCMU_NAN;

      // Get the Origin Offset with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 9], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 9], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      if (strcmp (tab[i_StartingIndex + 17], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 17], "%lf", IQImBalance);
      else *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 12], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 12], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;
  }

  // Get the Average Burst Power Current
  if (strcmp (tab[i_StartingIndex + 13], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 13], "%lf", avgBurstPowerCurr);
  else *avgBurstPowerCurr = RSCMU_NAN;

  // Get the Burst Out Of Tolerance
  if (strcmp (tab[i_StartingIndex + 14], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 14], "%lf", burstOutOfTol);
  else *burstOutOfTol = RSCMU_NAN;

  return 0;
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_ScanModPerr    <V3.07
/* Purpose : Extracts the scalar results in modulation PERRor:EPSK
/*===========================================================================*/
ViStatus RSCMU_EDGE_ScanModPerr (ViChar    tab [100][100],
                                 ViInt32   i_StartingIndex,
                                 ViInt32   i_selectBurst,
                                 ViReal64 *PhaseError95,
                                 ViReal64 *phaseErrorPeak,
                                 ViReal64 *phaseErrorRMS,
                                 ViReal64 *originOffset,
                                 ViReal64 *IQImBalance,
                                 ViReal64 *frequencyError,
                                 ViReal64 *avgBurstPowerCurr,
                                 ViReal64 *burstOutOfTol)
{
  // Get the 95% Phase Error
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%lf", PhaseError95);
  else *PhaseError95 = RSCMU_NAN;

  switch (i_selectBurst)
  {
    case RSCMU_CURRENT:
      // Get the Phase Error peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 1], "%lf", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%lf", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with single-value measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      // Get the IQ/IM Balance with average measurement
      if (strcmp (tab[i_StartingIndex + 10], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 10], "%lf", IQImBalance);
      else *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 13], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 13], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;

    case RSCMU_AVERAGE:
      // Get the Phase Error peak with average measurement
      if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 2], "%lf", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%lf", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with average measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      // Get the IQ/IM Balance with average measurement
      if (strcmp (tab[i_StartingIndex + 11], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 11], "%lf", IQImBalance);
      else *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with average measurement
      if (strcmp (tab[i_StartingIndex + 14], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 14], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;

    case RSCMU_MAXMIN:
      // Get the Phase Error peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%lf", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%lf", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 9], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 9], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      // Get the IQ/IM Balance with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 12], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 12], "%lf", IQImBalance);
      else *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 15], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 15], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;
  }

  // Get the Average Burst Power Current
  if (strcmp (tab[i_StartingIndex + 16], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 16], "%lf", avgBurstPowerCurr);
  else *avgBurstPowerCurr = RSCMU_NAN;

  // Get the Burst Out Of Tolerance
  if (strcmp (tab[i_StartingIndex + 17], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 17], "%lf", burstOutOfTol);
  else *burstOutOfTol = RSCMU_NAN;

  return 0;
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_ScanModPerrV423    >=V4.23
/* Purpose : Extracts the scalar results in modulation PERRor:EPSK
/*           IQ Imbalance is with V423 supported
/*===========================================================================*/
ViStatus RSCMU_EDGE_ScanModPerrV423 (ViChar    tab [100][100],
                                 ViInt32   i_StartingIndex,
                                 ViInt32   i_selectBurst,
                                 ViReal64 *PhaseError95,
                                 ViReal64 *phaseErrorPeak,
                                 ViReal64 *phaseErrorRMS,
                                 ViReal64 *originOffset,
                                 ViReal64 *IQImBalance,
                                 ViReal64 *frequencyError,
                                 ViReal64 *avgBurstPowerCurr,
                                 ViReal64 *burstOutOfTol)
{
  // Get the 95% Phase Error
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%lf", PhaseError95);
  else *PhaseError95 = RSCMU_NAN;

  switch (i_selectBurst)
  {
    case RSCMU_CURRENT:
      // Get the Phase Error peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 1], "%lf", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%lf", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with single-value measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      if (strcmp (tab[i_StartingIndex + 15], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 15], "%lf", IQImBalance);
      else *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 10], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 10], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;

    case RSCMU_AVERAGE:
      // Get the Phase Error peak with average measurement
      if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 2], "%lf", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%lf", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with average measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      if (strcmp (tab[i_StartingIndex + 16], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 16], "%lf", IQImBalance);
      else *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with average measurement
      if (strcmp (tab[i_StartingIndex + 11], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 11], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;

    case RSCMU_MAXMIN:
      // Get the Phase Error peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%lf", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%lf", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 9], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 9], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      if (strcmp (tab[i_StartingIndex + 17], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 17], "%lf", IQImBalance);
      else *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 12], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 12], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;
  }

  // Get the Average Burst Power Current
  if (strcmp (tab[i_StartingIndex + 13], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 13], "%lf", avgBurstPowerCurr);
  else *avgBurstPowerCurr = RSCMU_NAN;

  // Get the Burst Out Of Tolerance
  if (strcmp (tab[i_StartingIndex + 14], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 14], "%lf", burstOutOfTol);
  else *burstOutOfTol = RSCMU_NAN;

  return 0;
}

/*===========================================================================*/
/* Function: RSCMU_EDGE_ScanModPerrV307    >=V3.07
/* Purpose : Extracts the scalar results in modulation PERRor:EPSK
/*           IQ Imbalance is with V307 not supported (Set to NAN)
/*===========================================================================*/
ViStatus RSCMU_EDGE_ScanModPerrV307 (ViChar    tab [100][100],
                                 ViInt32   i_StartingIndex,
                                 ViInt32   i_selectBurst,
                                 ViReal64 *PhaseError95,
                                 ViReal64 *phaseErrorPeak,
                                 ViReal64 *phaseErrorRMS,
                                 ViReal64 *originOffset,
                                 ViReal64 *IQImBalance,
                                 ViReal64 *frequencyError,
                                 ViReal64 *avgBurstPowerCurr,
                                 ViReal64 *burstOutOfTol)
{
  // Get the 95% Phase Error
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%lf", PhaseError95);
  else *PhaseError95 = RSCMU_NAN;

  switch (i_selectBurst)
  {
    case RSCMU_CURRENT:
      // Get the Phase Error peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 1], "%lf", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%lf", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with single-value measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

//with Version V3.07 IQ Imbalance are not supported in EPSK
      *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 10], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 10], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;

    case RSCMU_AVERAGE:
      // Get the Phase Error peak with average measurement
      if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 2], "%lf", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%lf", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with average measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

//with Version V3.07 IQ Imbalance are not supported in EPSK
      *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with average measurement
      if (strcmp (tab[i_StartingIndex + 11], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 11], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;

    case RSCMU_MAXMIN:
      // Get the Phase Error peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%lf", phaseErrorPeak);
      else *phaseErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%lf", phaseErrorRMS);
      else *phaseErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 9], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 9], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

//with Version V3.07 IQ Imbalance are not supported in EPSK
      *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 12], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 12], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;
  }

  // Get the Average Burst Power Current
  if (strcmp (tab[i_StartingIndex + 13], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 13], "%lf", avgBurstPowerCurr);
  else *avgBurstPowerCurr = RSCMU_NAN;

  // Get the Burst Out Of Tolerance
  if (strcmp (tab[i_StartingIndex + 14], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 14], "%lf", burstOutOfTol);
  else *burstOutOfTol = RSCMU_NAN;

  return 0;
}



/*===========================================================================*/
/* Function: RSCMU_ScanModMerr     < V3.07
/* Purpose : Extracts the scalar results in modulation MERRor:EPSK
/*===========================================================================*/
ViStatus RSCMU_ScanModMerr (ViChar    tab [100][100],
                            ViInt32   i_StartingIndex,
                            ViInt32   i_selectBurst,
                            ViReal64 *MagnError95,
                            ViReal64 *MagnErrorPeak,
                            ViReal64 *MagnErrorRMS,
                            ViReal64 *originOffset,
                            ViReal64 *IQImBalance,
                            ViReal64 *frequencyError,
                            ViReal64 *avgBurstPowerCurr,
                            ViReal64 *burstOutOfTol)
{
  // Get the 95% Phase Error
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%lf", MagnError95);
  else *MagnError95 = RSCMU_NAN;

  switch (i_selectBurst)
  {
    case RSCMU_CURRENT:
      // Get the Phase Error peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 1], "%lf", MagnErrorPeak);
      else *MagnErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%lf", MagnErrorRMS);
      else *MagnErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with single-value measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      // Get the IQ/IM Balance with single-value measurement
      if (strcmp (tab[i_StartingIndex + 10], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 10], "%lf", IQImBalance);
      else *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 13], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 13], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;

    case RSCMU_AVERAGE:
      // Get the Phase Error peak with average measurement
      if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 2], "%lf", MagnErrorPeak);
      else *MagnErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%lf", MagnErrorRMS);
      else *MagnErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with average measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      // Get the IQ/IM Balance with average measurement
      if (strcmp (tab[i_StartingIndex + 11], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 11], "%lf", IQImBalance);
      else *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with average measurement
      if (strcmp (tab[i_StartingIndex + 14], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 14], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;

    case RSCMU_MAXMIN:
      // Get the Phase Error peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%lf", MagnErrorPeak);
      else *MagnErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%lf", MagnErrorRMS);
      else *MagnErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 9], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 9], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      // Get the IQ/IM Balance with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 12], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 12], "%lf", IQImBalance);
      else *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 15], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 15], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;
  }

  // Get the Average Burst Power Current
  if (strcmp (tab[i_StartingIndex + 16], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 16], "%lf", avgBurstPowerCurr);
  else *avgBurstPowerCurr = RSCMU_NAN;

  // Get the Burst Out Of Tolerance
  if (strcmp (tab[i_StartingIndex + 17], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 17], "%lf", burstOutOfTol);
  else *burstOutOfTol = RSCMU_NAN;

  return 0;
}


/*===========================================================================*/
/* Function: RSCMU_ScanModMerrV423     => V4.23
/* Purpose : Extracts the scalar results in modulation MERRor:EPSK
/*           IQ Imbalance is with V423 supported
/*===========================================================================*/
ViStatus RSCMU_ScanModMerrV423 (ViChar    tab [100][100],
                            ViInt32   i_StartingIndex,
                            ViInt32   i_selectBurst,
                            ViReal64 *MagnError95,
                            ViReal64 *MagnErrorPeak,
                            ViReal64 *MagnErrorRMS,
                            ViReal64 *originOffset,
                            ViReal64 *IQImBalance,
                            ViReal64 *frequencyError,
                            ViReal64 *avgBurstPowerCurr,
                            ViReal64 *burstOutOfTol)
{
  // Get the 95% Phase Error
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%lf", MagnError95);
  else *MagnError95 = RSCMU_NAN;

  switch (i_selectBurst)
  {
    case RSCMU_CURRENT:
      // Get the Phase Error peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 1], "%lf", MagnErrorPeak);
      else *MagnErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%lf", MagnErrorRMS);
      else *MagnErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with single-value measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      if (strcmp (tab[i_StartingIndex + 15], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 15], "%lf", IQImBalance);
      else *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 10], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 10], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;

    case RSCMU_AVERAGE:
      // Get the Phase Error peak with average measurement
      if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 2], "%lf", MagnErrorPeak);
      else *MagnErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%lf", MagnErrorRMS);
      else *MagnErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with average measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      if (strcmp (tab[i_StartingIndex + 16], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 16], "%lf", IQImBalance);
      else *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with average measurement
      if (strcmp (tab[i_StartingIndex + 11], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 11], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;

    case RSCMU_MAXMIN:
      // Get the Phase Error peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%lf", MagnErrorPeak);
      else *MagnErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%lf", MagnErrorRMS);
      else *MagnErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 9], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 9], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

      if (strcmp (tab[i_StartingIndex + 17], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 17], "%lf", IQImBalance);
      else *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 12], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 12], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;
  }

  // Get the Average Burst Power Current
  if (strcmp (tab[i_StartingIndex + 13], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 13], "%lf", avgBurstPowerCurr);
  else *avgBurstPowerCurr = RSCMU_NAN;

  // Get the Burst Out Of Tolerance
  if (strcmp (tab[i_StartingIndex + 14], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 14], "%lf", burstOutOfTol);
  else *burstOutOfTol = RSCMU_NAN;

  return 0;
}

/*===========================================================================*/
/* Function: RSCMU_ScanModMerrV307     => V3.07
/* Purpose : Extracts the scalar results in modulation MERRor:EPSK
/*           IQ Imbalance is with V307 not supported (Set to NAN)
/*===========================================================================*/
ViStatus RSCMU_ScanModMerrV307 (ViChar    tab [100][100],
                            ViInt32   i_StartingIndex,
                            ViInt32   i_selectBurst,
                            ViReal64 *MagnError95,
                            ViReal64 *MagnErrorPeak,
                            ViReal64 *MagnErrorRMS,
                            ViReal64 *originOffset,
                            ViReal64 *IQImBalance,
                            ViReal64 *frequencyError,
                            ViReal64 *avgBurstPowerCurr,
                            ViReal64 *burstOutOfTol)
{
  // Get the 95% Phase Error
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%lf", MagnError95);
  else *MagnError95 = RSCMU_NAN;

  switch (i_selectBurst)
  {
    case RSCMU_CURRENT:
      // Get the Phase Error peak with single-value measurement
      if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 1], "%lf", MagnErrorPeak);
      else *MagnErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with single-value measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%lf", MagnErrorRMS);
      else *MagnErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with single-value measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

//with Version V3.07 IQ Imbalance are not supported in EPSK
      *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 10], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 10], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;

    case RSCMU_AVERAGE:
      // Get the Phase Error peak with average measurement
      if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 2], "%lf", MagnErrorPeak);
      else *MagnErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with average measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%lf", MagnErrorRMS);
      else *MagnErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with average measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

//with Version V3.07 IQ Imbalance are not supported in EPSK
      *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with average measurement
      if (strcmp (tab[i_StartingIndex + 11], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 11], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;

    case RSCMU_MAXMIN:
      // Get the Phase Error peak with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%lf", MagnErrorPeak);
      else *MagnErrorPeak = RSCMU_NAN;

      // Get the Phase Error RMS with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%lf", MagnErrorRMS);
      else *MagnErrorRMS = RSCMU_NAN;

      // Get the Origin Offset with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 9], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 9], "%lf", originOffset);
      else *originOffset = RSCMU_NAN;

//with Version V3.07 IQ Imbalance are not supported in EPSK
      *IQImBalance = RSCMU_NAN;

      // Get the Frequency Error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 12], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 12], "%lf", frequencyError);
      else *frequencyError = RSCMU_NAN;
      break;
  }

  // Get the Average Burst Power Current
  if (strcmp (tab[i_StartingIndex + 13], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 13], "%lf", avgBurstPowerCurr);
  else *avgBurstPowerCurr = RSCMU_NAN;

  // Get the Burst Out Of Tolerance
  if (strcmp (tab[i_StartingIndex + 14], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 14], "%lf", burstOutOfTol);
  else *burstOutOfTol = RSCMU_NAN;

  return 0;
}
/*===========================================================================*/
/* Function: RSCMU_ScanModulation
/* Purpose : This function Modulation Result string.
/*===========================================================================*/
ViStatus RSCMU_ScanModulation ( ViChar    tab [100][100],
                                ViInt32   i_StartingIndex,
                                ViInt32   i_selectBurst,
                                ViReal64  *phErrPeak,
                                ViReal64  *phErrRMS,
                                ViReal64  *freqErr)
{
  switch (i_selectBurst)
  {
    case RSCMU_CURRENT:
      // Get max phase error with single-value measurement
      if (strcmp (tab[i_StartingIndex], "NAN") != 0)
        sscanf (tab[i_StartingIndex], "%lf", phErrPeak);
      else *phErrPeak = RSCMU_NAN;
      // Get RMS phase error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 3], "%lf", phErrRMS);
      else *phErrRMS = RSCMU_NAN;
      // Get frequency error with single-value measurement
      if (strcmp (tab[i_StartingIndex + 6], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 6], "%lf", freqErr);
      else *freqErr = RSCMU_NAN;
      break;

    case RSCMU_AVERAGE:
      // Get max phase error with average measurement
      if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 1], "%lf", phErrPeak);
      else *phErrPeak = RSCMU_NAN;
      // Get RMS phase error with average measurement
      if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 4], "%lf", phErrRMS);
      else *phErrRMS = RSCMU_NAN;
      // Get frequency error with average measurement
      if (strcmp (tab[i_StartingIndex + 7], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 7], "%lf", freqErr);
      else *freqErr = RSCMU_NAN;
      break;

    case RSCMU_MAXMIN:
      // Get max phase error with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 2], "%lf", phErrPeak);
      else *phErrPeak = RSCMU_NAN;
      // Get RMS phase error with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 5], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 5], "%lf", phErrRMS);
      else *phErrRMS = RSCMU_NAN;
      // Get frequency error with extreme-value measurement
      if (strcmp (tab[i_StartingIndex + 8], "NAN") != 0)
        sscanf (tab[i_StartingIndex + 8], "%lf", freqErr);
      else *freqErr = RSCMU_NAN;
      break;
  }

  return 0;
}

/*===========================================================================*/
/* Function: RSCMU_Sig_ScanPow
/* Purpose : This function scan a power result string
/*           (in signalling mode).
/*===========================================================================*/
ViStatus RSCMU_Sig_ScanPow (ViChar     tab[100][100],
                            ViReal64  *AvgBurstPwCurr,
                            ViReal64  *PeakBurstPwCurr,
                            ViInt32   *PowerControlLevel,
                            ViReal64  *TimingAdvError,
                            ViReal64  *BurstOutOfTol,
                            ViInt32   *BurstMatching,
                            ViReal64  *AvgBurstPwAvg)
{
  ViReal64    PwrCtrlLev;

  // Get the average burst power (current burst):
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%lf", AvgBurstPwCurr);
  else
    *AvgBurstPwCurr = RSCMU_NAN;

  // Get the peak burst power (current burst):
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%lf", PeakBurstPwCurr);
  else
    *PeakBurstPwCurr = RSCMU_NAN;

  // Get the power control level:
  if (strcmp (tab[2], "NAN") != 0)
  {
    sscanf (tab[2], "%lf", &PwrCtrlLev);
    PwrCtrlLev += 0.001; // To avoid a problem due to the fraction part
    *PowerControlLevel = (ViInt32) PwrCtrlLev;
  }
  else
    *PowerControlLevel = RSCMU_NAN_VI_INT32;

  // Get the timing advance error:
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%lf", TimingAdvError);
  else
    *TimingAdvError = RSCMU_NAN;

  // Get the burst out of tolerance:
  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%lf", BurstOutOfTol);
  else
    *BurstOutOfTol = RSCMU_NAN;

  // Get the burst template matching:
  RSCMU_GetMatchingValue (BurstMatching, tab, 5);

  // Get the average burst power of average trace:
  if (strcmp (tab[6], "NAN") != 0)
    sscanf (tab[6], "%lf", AvgBurstPwAvg);
  else
    *AvgBurstPwAvg = RSCMU_NAN;

  return 0;
}

/*===========================================================================*/
/* Function: RSCMU_NSig_ScanPow
/* Purpose : This function scan a power result string
/*           (in non-signalling mode).
/*===========================================================================*/
ViStatus RSCMU_NSig_ScanPow (ViChar     tab[100][100],
                             ViReal64  *AvgBurstPwCurr,
                             ViReal64  *PeakBurstPwCurr,
                             ViReal64  *BurstOutOfTol,
                             ViInt32   *BurstMatching,
                             ViReal64  *AvgBurstPwAvg)
{
  // Get the average burst power (current burst):
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%lf", AvgBurstPwCurr);
  else
    *AvgBurstPwCurr = RSCMU_NAN;

  // Get the peak burst power (current burst):
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%lf", PeakBurstPwCurr);
  else
    *PeakBurstPwCurr = RSCMU_NAN;

  // Get the burst out of tolerance:
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%lf", BurstOutOfTol);
  else
    *BurstOutOfTol = RSCMU_NAN;

  // Get the burst template matching:
  RSCMU_GetMatchingValue (BurstMatching, tab, 3);

  // Get the average burst power of average trace:
  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%lf", AvgBurstPwAvg);
  else
    *AvgBurstPwAvg = RSCMU_NAN;

  return 0;
}

/*===========================================================================*/
/* Function: RSCMU_Sig_ScanPowMsl
/* Purpose : This function scan a power/t multislot result string
/*           (in signalling mode).
/*===========================================================================*/
ViStatus RSCMU_Sig_ScanPowMsl (ViChar     tab[100][100],
                               ViReal64  *BurstOutOfTol,
                               ViReal64  *AvgBurstPwCurr,
                               ViReal64  *AvgBurstPwAvg,
                               ViReal64  *PeakBurstPwCurr,
                               ViReal64  *TimingAdvError,
                               ViInt32   *BurstMatching)
{
  // Get the burst out of tolerance:
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%lf", BurstOutOfTol);
  else
    *BurstOutOfTol = RSCMU_NAN;

  // Get the average burst power (current burst):
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%lf", AvgBurstPwCurr);
  else
    *AvgBurstPwCurr = RSCMU_NAN;

  // Get the average burst power of average trace:
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%lf", AvgBurstPwAvg);
  else
    *AvgBurstPwAvg = RSCMU_NAN;

  // Get the peak burst power (current burst):
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%lf", PeakBurstPwCurr);
  else
    *PeakBurstPwCurr = RSCMU_NAN;

  // Get the timing advance error:
  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%lf", TimingAdvError);
  else
    *TimingAdvError = RSCMU_NAN;

  // Get the burst template matching:
  RSCMU_GetMatchingValue (BurstMatching, tab, 5);

  return 0;
}

/*===========================================================================*/
/* Function: RSCMU_Sig_ScanPowMpr
/* Purpose : This function scan a combined power & modulation result string
/*           (in signalling mode).
/*===========================================================================*/
ViStatus RSCMU_Sig_ScanPowMpr (ViChar     tab[100][100],
                               ViInt32    StatisticsMode,
                               ViReal64  *AvgBurstPwCurr,
                               ViReal64  *PeakBurstPwCurr,
                               ViInt32   *PowerControlLevel,
                               ViReal64  *TimingAdvError,
                               ViReal64  *BurstOutOfTol,
                               ViInt32   *BurstMatching,
                               ViReal64  *PhErrPeak,
                               ViReal64  *PhErrRMS,
                               ViReal64  *FreqErr,
                               ViReal64  *AvgBurstPwAvg)
{
  ViReal64    PwrCtrlLev;

  // Get the average burst power (current burst):
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%lf", AvgBurstPwCurr);
  else
    *AvgBurstPwCurr = RSCMU_NAN;

  // Get the peak burst power (current burst):
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%lf", PeakBurstPwCurr);
  else
    *PeakBurstPwCurr = RSCMU_NAN;

  // Get the power control level:
  if (strcmp (tab[2], "NAN") != 0)
  {
    sscanf (tab[2], "%lf", &PwrCtrlLev);
    PwrCtrlLev += 0.001; // To avoid a problem due to the fraction part
    *PowerControlLevel = (ViInt32) PwrCtrlLev;
  }
  else
    *PowerControlLevel = RSCMU_NAN_VI_INT32;

  // Get the timing advance error:
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%lf", TimingAdvError);
  else
    *TimingAdvError = RSCMU_NAN;

  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%lf", BurstOutOfTol);
  else
    *BurstOutOfTol = RSCMU_NAN;

  // Get the burst template matching:
  RSCMU_GetMatchingValue (BurstMatching, tab, 5);

  switch (StatisticsMode)
  {
    case RSCMU_CURRENT:
      // Get phase error peak current:
      if (strcmp (tab[6], "NAN") != 0)
        sscanf (tab[6], "%lf", PhErrPeak);
      else
        *PhErrPeak = RSCMU_NAN;
      // Get phase error RMS current:
      if (strcmp (tab[9], "NAN") != 0)
        sscanf (tab[9], "%lf", PhErrRMS);
      else
        *PhErrRMS = RSCMU_NAN;
      // Get frequency error current:
      if (strcmp (tab[12], "NAN") != 0)
        sscanf (tab[12], "%lf", FreqErr);
      else
        *FreqErr = RSCMU_NAN;
      break;

    case RSCMU_AVERAGE:
      // Get phase error peak average:
      if (strcmp (tab[7], "NAN") != 0)
        sscanf (tab[7], "%lf", PhErrPeak);
      else
        *PhErrPeak = RSCMU_NAN;
      // Get phase error RMS average:
      if (strcmp (tab[10], "NAN") != 0)
        sscanf (tab[10], "%lf", PhErrRMS);
      else
        *PhErrRMS = RSCMU_NAN;
      // Get frequency error average:
      if (strcmp (tab[13], "NAN") != 0)
        sscanf (tab[13], "%lf", FreqErr);
      else
        *FreqErr = RSCMU_NAN;
      break;

    case RSCMU_MAXMIN:
      // Get phase error peak max./min.:
      if (strcmp (tab[8], "NAN") != 0)
        sscanf (tab[8], "%lf", PhErrPeak);
      else
        *PhErrPeak = RSCMU_NAN;
      // Get phase error RMS max./min.:
      if (strcmp (tab[11], "NAN") != 0)
        sscanf (tab[11], "%lf", PhErrRMS);
      else
        *PhErrRMS = RSCMU_NAN;
      // Get frequency error max./min.:
      if (strcmp (tab[14], "NAN") != 0)
        sscanf (tab[14], "%lf", FreqErr);
      else
        *FreqErr = RSCMU_NAN;
      break;
  }

  // Get the average burst power of average trace:
  if (strcmp (tab[15], "NAN") != 0)
    sscanf (tab[15], "%lf", AvgBurstPwAvg);
  else
    *AvgBurstPwAvg = RSCMU_NAN;

  return 0;
}

/*===========================================================================*/
/* Function: RSCMU_NSig_ScanPowMpr
/* Purpose : This function scan a combined power & modulation result string.
/*           (in non-signalling mode)
/*===========================================================================*/
ViStatus RSCMU_NSig_ScanPowMpr (ViChar     tab[100][100],
                                ViInt32    StatisticsMode,
                                ViReal64  *AvgBurstPwCurr,
                                ViReal64  *PeakBurstPwCurr,
                                ViReal64  *BurstOutOfTol,
                                ViInt32   *BurstMatching,
                                ViReal64  *PhErrPeak,
                                ViReal64  *PhErrRMS,
                                ViReal64  *FreqErr,
                                ViReal64  *AvgBurstPwAvg)
{
  // Get the average burst power (current burst):
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%lf", AvgBurstPwCurr);
  else
    *AvgBurstPwCurr = RSCMU_NAN;

  // Get the peak burst power (current burst):
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%lf", PeakBurstPwCurr);
  else
    *PeakBurstPwCurr = RSCMU_NAN;

  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%lf", BurstOutOfTol);
  else
    *BurstOutOfTol = RSCMU_NAN;

  // Get the burst template matching:
  RSCMU_GetMatchingValue (BurstMatching, tab, 3);

  switch (StatisticsMode)
  {
    case RSCMU_CURRENT:
      // Get phase error peak current:
      if (strcmp (tab[4], "NAN") != 0)
        sscanf (tab[4], "%lf", PhErrPeak);
      else
        *PhErrPeak = RSCMU_NAN;
      // Get phase error RMS current:
      if (strcmp (tab[7], "NAN") != 0)
        sscanf (tab[7], "%lf", PhErrRMS);
      else
        *PhErrRMS = RSCMU_NAN;
      // Get frequency error current:
      if (strcmp (tab[10], "NAN") != 0)
        sscanf (tab[10], "%lf", FreqErr);
      else
        *FreqErr = RSCMU_NAN;
      break;

    case RSCMU_AVERAGE:
      // Get phase error peak average:
      if (strcmp (tab[5], "NAN") != 0)
        sscanf (tab[5], "%lf", PhErrPeak);
      else
        *PhErrPeak = RSCMU_NAN;
      // Get phase error RMS average:
      if (strcmp (tab[8], "NAN") != 0)
        sscanf (tab[8], "%lf", PhErrRMS);
      else
        *PhErrRMS = RSCMU_NAN;
      // Get frequency error average:
      if (strcmp (tab[11], "NAN") != 0)
        sscanf (tab[11], "%lf", FreqErr);
      else
        *FreqErr = RSCMU_NAN;
      break;

    case RSCMU_MAXMIN:
      // Get phase error peak max./min.:
      if (strcmp (tab[6], "NAN") != 0)
        sscanf (tab[6], "%lf", PhErrPeak);
      else
        *PhErrPeak = RSCMU_NAN;
      // Get phase error RMS max./min.:
      if (strcmp (tab[9], "NAN") != 0)
        sscanf (tab[9], "%lf", PhErrRMS);
      else
        *PhErrRMS = RSCMU_NAN;
      // Get frequency error max./min.:
      if (strcmp (tab[12], "NAN") != 0)
        sscanf (tab[12], "%lf", FreqErr);
      else
        *FreqErr = RSCMU_NAN;
      break;
  }

  // Get the average burst power of average trace:
  if (strcmp (tab[13], "NAN") != 0)
    sscanf (tab[13], "%lf", AvgBurstPwAvg);
  else
    *AvgBurstPwAvg = RSCMU_NAN;

  return 0;
}

/*===========================================================================*/
/* Function: RSCMU_SendCommand
/* Purpose : This function send a
/*===========================================================================*/
ViStatus RSCMU_SendCommand (ViSession instrSession,
                            ViChar    errorMessage[],
                            const char *formatString, ...)
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  va_list     arglist;

  va_start (arglist, formatString);
  vsprintf (wrtBuf, formatString, arglist);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set Grid (ON/OFF)
/* Purpose : This function switches the grid lines in the test diagrams on or off.
/*===========================================================================*/
ViStatus RSCMU_DisplayGrid (ViSession instrSession,
                            ViInt32   Object,
                            ViInt32   Modulation,
                            ViInt32   gridLines,
                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) gridLines, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if ((p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15) &&
      ((Modulation == RSCMU_EPSK)||(Object > RSCMU_POWMPR)))
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  sprintf (wrtBuf, "DISP%s%s:CONT:GRID %s", StrObject[Object], StrModulation[Modulation], mode_On_Off[gridLines]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set Default limit Lines (ON/OFF)
/* Purpose : This function switches the default limit lines on or off.
/*===========================================================================*/
ViStatus RSCMU_ConfLimLineDef (ViSession  instrSession,
                               ViInt32    Object,
                               ViInt32    Modulation,
                               ViInt32    DefaultLimitLines,
                               ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, DefaultLimitLines, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if ((p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15) &&
      ((Modulation == RSCMU_EPSK)||(Object > RSCMU_POWMPR)))
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  sprintf (wrtBuf, "CONF%s%s:LIM:LINE:DEF ON", StrObject[Object], StrModulation[Modulation]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Burst SubRanges
/* Purpose : This function configurates the READ..., FETCh... and
/*           SAMPle:SUBArrays:... commands.
/*           If the requested number of results exceeds the measurement
/*           range, the count parameter will be corrected by the system.
/*===========================================================================*/
ViStatus RSCMU_ConfSubarrays (ViSession instrSession,
                              ViInt32   Object,
                              ViInt32   Modulation,
                              ViInt32   Statistics,
                              ViReal64  FirstMeasurementFreq,
                              ViInt32   MeasureResultsNumber,
                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if ((p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15) &&
      ((Modulation == RSCMU_EPSK)||(Object > RSCMU_POWMPR)))
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  if ((p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_00) && (Object == RSCMU_POWABUR))
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_00, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Statistics, 0, 4, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SUB%s%s %s,%lf,%d", StrObject[Object], StrModulation[Modulation], StrStatistics[Statistics], FirstMeasurementFreq,MeasureResultsNumber);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Configure Subarrays
/* Purpose : this function is called by the global functions for the
/*           configuration of the subarrays
/*===========================================================================*/
ViStatus RSCMU_ConfSub (ViSession  instrSession,
                        ViChar    *StrObject,
                        ViInt32    Statistics,
                        ViReal64   StartTime,
                        ViInt32    NumberOfSamples,
                        ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_BUFS(instrSession);

  // The parameters check has to be done in the global function
  sprintf(wrtBuf, "CONFigure:SUBarrays:%s %s,%lf,%d", StrObject, StrStatistics[Statistics],
                                                     StartTime, NumberOfSamples);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: All scalar measured values
/* Purpose : This function starts a single shot measurement and output all
/*           scalar measurement results. These are:
/*             Average power of current burst
/*             Peak power of current burst
/*             Bursts out of tolerance
/*             Burst template matching
/*             Average power of averaged trace
/*===========================================================================*/
ViStatus RSCMU_MeasScalarPowerBurst (ViSession   instrSession,
                                     ViInt32     Command,
                                     ViInt32     Modulation,
                                     ViReal64   *AvgBurstPwCurr,
                                     ViReal64   *PeakBurstPwCurr,
                                     ViReal64   *BurstsOutOfTol,
                                     ViInt32    *BurstMatching,
                                     ViReal64   *AvgBurstPwAvg,
                                     ViChar      errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViChar      TableOfDataValues[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if ((p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15) && (Modulation == RSCMU_EPSK))
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  sprintf(wrtBuf, "%s:POW%s?", StrCommand[Command], StrModulation[Modulation]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Scan the results of power:
  RSCMU_Status = RSCMU_NSig_ScanPow (TableOfDataValues, AvgBurstPwCurr, PeakBurstPwCurr, BurstsOutOfTol, BurstMatching, AvgBurstPwAvg);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Meas Burst Power...
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern. The number of measured
/*           values is max. 669 samples.
/*===========================================================================*/
ViStatus RSCMU_MeasArrayPowerBurst (ViSession instrSession,
                                    ViInt32   Command,
                                    ViInt32   Modulation,
                                    ViInt32   Mode,
                                    ViReal64  BurstPower[],
                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if ((p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15) && (Modulation == RSCMU_EPSK))
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  //JMG 030324 sprintf (wrtBuf, "%s:ARR:POW%s:BURS:%s?", StrCommand[Command], StrModulation[Modulation], StrStatMode[Mode]);
  sprintf (wrtBuf, "%s:ARR:POW%s:%s?", StrCommand[Command], StrModulation[Modulation], StrStatMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, BurstPower);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Burst power measured values (SubArray)
/* Purpose : This function outputs the burst power versus time in a fixed
/*           -bit pattern and in subranges defined ny means of the
/*           configuration.
/*===========================================================================*/
ViStatus RSCMU_MeasSubarraysPowerBurst (ViSession  instrSession,
                                        ViInt32    Command,
                                        ViInt32    Modulation,
                                        ViInt32    statMode,
                                        ViReal64   BurstPower[],
                                        ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, statMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if ((p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15) && (Modulation == RSCMU_EPSK))
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  sprintf (wrtBuf, "%s:SUB:POW%s:BURS:%s?", StrCommand[Command], StrModulation[Modulation], StrStatMode[statMode]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, BurstPower);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Range Violation
/* Purpose : This command is always query. ANy set bit of the two returned
/*           fiels indicates the violation of the corresponding section
/*           of the limit times
/*===========================================================================*/
ViStatus RSCMU_CalcPowAreaLimMatc (ViSession  instrSession,
                                   ViInt32    Modulation,
                                   ViInt32    StatisticsMode,
                                   ViInt32   *UpperLimit,
                                   ViInt32   *LowerLimit,
                                   ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if ((p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15) && (Modulation == RSCMU_EPSK))
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  sprintf (wrtBuf, "CALC:ARR:POW%s:AREA:LIM:MATC:%s?", StrModulation[Modulation], StrStatMode[StatisticsMode]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the upper Limit Matching
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%d", UpperLimit);
  else *UpperLimit = RSCMU_NAN_VI_INT32;

  // Get the lower Limit Matching
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%d", LowerLimit);
  else *LowerLimit = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Power/t Limit Check
/* Purpose :
/*===========================================================================*/
ViStatus RSCMU_CalcArrPowLimMatc (ViSession  instrSession,
                                  ViInt32    Modulation,
                                  ViInt32    StatisticsMode,
                                  ViInt32   *ToleranceError,
                                  ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if ((p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15) && (Modulation == RSCMU_EPSK))
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CALC:POW%s:BURS:LIM:MATC:%s?", StrModulation[Modulation], StrStatMode[StatisticsMode]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Get the tolerance error value
  RSCMU_SeparateDataValues (rdBuf, ",", tab);
  RSCMU_GetMatchingValue (ToleranceError, tab, 0);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Power/t Limit Check
/* Purpose : This function indicates whether and in which way the per-
/*           missible tolerances for the scalar measured values  have
/*           been exceeded.
/*===========================================================================*/
ViStatus RSCMU_CalcScalPowLimMatc (ViSession  instrSession,
                                   ViInt32    Modulation,
                                   ViInt32   *AvgBurstPwCurr,
                                   ViInt32   *PeakBurstPwCurr,
                                   ViInt32   *BurstMatching,
                                   ViInt32   *AvgBurstPwAvg,
                                   ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      TableOfDataValues[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if ((p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15) && (Modulation == RSCMU_EPSK))
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  sprintf(wrtBuf, "CALC:POW%s:LIM:MATC?", StrModulation[Modulation]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Get the limit check for average power of current burst:
  if ((RSCMU_Status = RSCMU_GetLimitCheckValue (TableOfDataValues, 0, AvgBurstPwCurr)) < 0)
    return RSCMU_Status;

  // Get the limit check for peak power of current burst:
  if ((RSCMU_Status = RSCMU_GetLimitCheckValue (TableOfDataValues, 1, PeakBurstPwCurr)) < 0)
    return RSCMU_Status;

  // Burst Matching
  RSCMU_Status = RSCMU_GetMatchingValue (BurstMatching, TableOfDataValues, 2);

  // Get the limit check for average power of averaged trace:
  if ((RSCMU_Status = RSCMU_GetLimitCheckValue (TableOfDataValues, 3, AvgBurstPwAvg)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set offset time
/* Purpose : This function defines an offset time by which the burst is shifted
/*           relative to the time axis and the tolerance template
/*===========================================================================*/
ViStatus RSCMU_ConfPowTimeBoff (ViSession instrSession,
                                ViInt32   Modulation,
                                ViReal64  offset,
                                ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";

  // Check if the function is correctly used:
  CHECK_VI_REAL64_RANGE(instrSession, offset, -4.0, 4.0, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:POW%s:TIME:BOFF %lf", StrModulation[Modulation]
                                             , offset);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Upper limit Line
/* Purpose :
/*===========================================================================*/
ViStatus RSCMU_ConfPowLimLineUpp (ViSession instrSession,
                                  ViInt32   Modulation,
                                  ViInt32   Area,
                                  ViInt32   StartTimeOnOff,
                                  ViReal64  StartTime,
                                  ViInt32   EndTimeOnOff,
                                  ViReal64  EndTime,
                                  ViInt32   StartRelLevOnOff,
                                  ViReal64  StartRelLev,
                                  ViInt32   EndRelLevOnOff,
                                  ViReal64  EndRelLev,
                                  ViInt32   StartAbsLevOnOff,
                                  ViReal64  StartAbsLev,
                                  ViInt32   EndAbsLevOnOff,
                                  ViReal64  EndAbsLev,
                                  ViInt32   Visibility,
                                  ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      StringStartTime [20];
  ViChar      StringEndTime [20];
  ViChar      StringStartRelLev [20];
  ViChar      StringEndRelLev  [20];
  ViChar      StringStartAbsLev  [20];
  ViChar      StringEndAbsLev  [20];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Area, 1, 16, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Version Manager
  if ((p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15) && (Modulation == RSCMU_EPSK))
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);


  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V2_10)
  {
   if (StartTimeOnOff == RSCMU_ON)
    sprintf (StringStartTime, "%lf", StartTime);
   else
    sprintf (StringStartTime, "%s", mode_On_Off [StartTimeOnOff]);

   if (EndTimeOnOff == RSCMU_ON)
    sprintf (StringEndTime, "%lf", EndTime);
   else
    sprintf (StringEndTime, "%s", mode_On_Off [EndTimeOnOff]);

   if (StartRelLevOnOff == RSCMU_ON)
    sprintf (StringStartRelLev , "%lf", StartRelLev);
   else
    sprintf (StringStartRelLev, "%s", mode_On_Off [StartRelLevOnOff]);

   if (EndRelLevOnOff == RSCMU_ON)
    sprintf (StringEndRelLev , "%lf", EndRelLev);
   else
    sprintf (StringEndRelLev, "%s", mode_On_Off [EndRelLevOnOff]);

   if (StartAbsLevOnOff == RSCMU_ON)
    sprintf (StringStartAbsLev, "%lf", StartAbsLev);
   else
    sprintf (StringStartAbsLev, "%s", mode_On_Off [StartAbsLevOnOff]);

   if (EndAbsLevOnOff == RSCMU_ON)
    sprintf (StringEndAbsLev , "%lf", EndAbsLev);
   else
    sprintf (StringEndAbsLev, "%s", mode_On_Off [EndAbsLevOnOff]);

    sprintf ( wrtBuf, "CONF:POW%s:LIM:LINE:UPP%d %s,%s,%s,%s,%s,%s,%s",
              StrModulation[Modulation],
              Area,
              StringStartTime,
              StringEndTime,
              StringStartRelLev,
              StringEndRelLev,
              StringStartAbsLev,
              StringEndAbsLev,
              mode_On_Off [Visibility]);
   }
   else
   {
     sprintf (wrtBuf, "CONF:POW:LIM:LINE:UPP%d %lf,%lf,%lf,%lf,%lf,%lf,%s",
             Area,
             (StartTimeOnOff == RSCMU_ON) ? StartTime : 0.0,
             (EndTimeOnOff == RSCMU_ON) ? EndTime : 0.0,
             (StartRelLevOnOff == RSCMU_ON) ? StartRelLev : 0.0,
             (EndRelLevOnOff == RSCMU_ON) ? EndRelLev : 0.0,
             (StartAbsLevOnOff == RSCMU_ON) ? StartAbsLev : 0.0,
             (EndAbsLevOnOff == RSCMU_ON) ? EndAbsLev : 0.0,
             Visibility);

    }
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Lower limit Line
/* Purpose :
/*===========================================================================*/
ViStatus RSCMU_ConfPowLimLineLow (ViSession instrSession,
                                  ViInt32   Modulation,
                                  ViInt32   Area,
                                  ViInt32   StartTimeOnOff,
                                  ViReal64  StartTime,
                                  ViInt32   EndTimeOnOff,
                                  ViReal64  EndTime,
                                  ViInt32   StartRelLevOnOff,
                                  ViReal64  StartRelLev,
                                  ViInt32   EndRelLevOnOff,
                                  ViReal64  EndRelLev,
                                  ViInt32   StartAbsLevOnOff,
                                  ViReal64  StartAbsLev,
                                  ViInt32   EndAbsLevOnOff,
                                  ViReal64  EndAbsLev,
                                  ViInt32   Visibility,
                                  ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      StringStartTime [20];
  ViChar      StringEndTime [20];
  ViChar      StringStartRelLev [20];
  ViChar      StringEndRelLev  [20];
  ViChar      StringStartAbsLev  [20];
  ViChar      StringEndAbsLev  [20];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Area, 1, 16, RSCMU_ERROR_PARAMETER2, errorMessage);

  if ((p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15) && (Modulation == RSCMU_EPSK))
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  // Version Manager
  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V2_10)
  {
   if (StartTimeOnOff == RSCMU_ON)
    sprintf (StringStartTime, "%lf", StartTime);
   else
    sprintf (StringStartTime, "%s", mode_On_Off [StartTimeOnOff]);

   if (EndTimeOnOff == RSCMU_ON)
    sprintf (StringEndTime, "%lf", EndTime);
   else
    sprintf (StringEndTime, "%s", mode_On_Off [EndTimeOnOff]);

   if (StartRelLevOnOff == RSCMU_ON)
    sprintf (StringStartRelLev , "%lf", StartRelLev);
   else
    sprintf (StringStartRelLev, "%s", mode_On_Off [StartRelLevOnOff]);

   if (EndRelLevOnOff == RSCMU_ON)
    sprintf (StringEndRelLev , "%lf", EndRelLev);
   else
    sprintf (StringEndRelLev, "%s", mode_On_Off [EndRelLevOnOff]);

   if (StartAbsLevOnOff == RSCMU_ON)
    sprintf (StringStartAbsLev, "%lf", StartAbsLev);
   else
    sprintf (StringStartAbsLev, "%s", mode_On_Off [StartAbsLevOnOff]);

   if (EndAbsLevOnOff == RSCMU_ON)
    sprintf (StringEndAbsLev , "%lf", EndAbsLev);
   else
    sprintf (StringEndAbsLev, "%s", mode_On_Off [EndAbsLevOnOff]);

    sprintf ( wrtBuf, "CONF:POW%s:LIM:LINE:LOW%d %s,%s,%s,%s,%s,%s,%s",
              StrModulation[Modulation],
              Area,
              StringStartTime,
              StringEndTime,
              StringStartRelLev,
              StringEndRelLev,
              StringStartAbsLev,
              StringEndAbsLev,
              mode_On_Off [Visibility]);
   }
   else
   {
     sprintf (wrtBuf, "CONF:POW:LIM:LINE:LOW%d %lf,%lf,%lf,%lf,%lf,%lf,%s",
             Area,
             (StartTimeOnOff == RSCMU_ON) ? StartTime : 0.0,
             (EndTimeOnOff == RSCMU_ON) ? EndTime : 0.0,
             (StartRelLevOnOff == RSCMU_ON) ? StartRelLev : 0.0,
             (EndRelLevOnOff == RSCMU_ON) ? EndRelLev : 0.0,
             (StartAbsLevOnOff == RSCMU_ON) ? StartAbsLev : 0.0,
             (EndAbsLevOnOff == RSCMU_ON) ? EndAbsLev : 0.0,
             Visibility);

   }



  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Dynamic Correction of Upper limit Line
/* Purpose :
/*===========================================================================*/
ViStatus RSCMU_ConfPowLimLineUppDyn (ViSession instrSession,
                                              ViInt32   modulation,
                                              ViInt32   Area,
                                              ViInt32   TPCLRange,
                                              ViInt32   FromTPCLOnOff,
                                              ViInt32   FromTPCL,
                                              ViInt32   ToTPCLOnOff,
                                              ViInt32   ToTPCL,
                                              ViInt32   CorrectionOnOff,
                                              ViReal64  Correction,
                                              ViInt32   Enable,
                                              ViChar    errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;
  ViChar    wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar    StringFromTPCL[20];
  ViChar    StringToTPCL[20];
  ViChar    StringCorrection[20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Area, 1, 16, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, TPCLRange, 1, 10, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) FromTPCLOnOff, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, FromTPCL, 0, 31, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) ToTPCLOnOff, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, ToTPCL, 0, 31, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) CorrectionOnOff, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, Correction, -10, 10, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) Enable, RSCMU_ERROR_PARAMETER4, errorMessage);

  if (FromTPCLOnOff == RSCMU_ON)
    sprintf (StringFromTPCL, "%d", FromTPCL);
  else
    sprintf (StringFromTPCL, "%s", mode_On_Off [FromTPCLOnOff]);

  if (ToTPCLOnOff == RSCMU_ON)
    sprintf (StringToTPCL, "%d", ToTPCL);
  else
    sprintf (StringToTPCL, "%s", mode_On_Off [ToTPCLOnOff]);

  if (CorrectionOnOff == RSCMU_ON)
    sprintf (StringCorrection, "%lf", Correction);
  else
    sprintf (StringCorrection, "%s", mode_On_Off [CorrectionOnOff]);

  sprintf (wrtBuf, "CONF:POW%s:LIM:LINE:UPP%d:DYN%d %s,%s,%s,%s", StrModulation[modulation]
                                                                , Area
                                                                , TPCLRange
                                                                , StringFromTPCL
                                                                , StringToTPCL
                                                                , StringCorrection
                                                                , mode_On_Off[Enable]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Dynamic Correction of Lower limit Line
/* Purpose :
/*===========================================================================*/
ViStatus RSCMU_ConfPowLimLineLowDyn (ViSession instrSession,
                                     ViInt32   modulation,
                                     ViInt32   Area,
                                     ViInt32   TPCLRange,
                                     ViInt32   FromTPCLOnOff,
                                     ViInt32   FromTPCL,
                                     ViInt32   ToTPCLOnOff,
                                     ViInt32   ToTPCL,
                                     ViInt32   CorrectionOnOff,
                                     ViReal64  Correction,
                                     ViInt32   Enable,
                                     ViChar    errorMessage[])
{
  ViStatus  RSCMU_Status = VI_SUCCESS;
  ViChar    wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar    StringFromTPCL[20];
  ViChar    StringToTPCL[20];
  ViChar    StringCorrection[20];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Area, 1, 16, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, TPCLRange, 1, 10, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) FromTPCLOnOff, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, FromTPCL, 0, 31, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) ToTPCLOnOff, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, ToTPCL, 0, 31, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) CorrectionOnOff, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, Correction, -10, 10, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) Enable, RSCMU_ERROR_PARAMETER4, errorMessage);

  if (FromTPCLOnOff == RSCMU_ON)
    sprintf (StringFromTPCL, "%d", FromTPCL);
  else
    sprintf (StringFromTPCL, "%s", mode_On_Off [FromTPCLOnOff]);

  if (ToTPCLOnOff == RSCMU_ON)
    sprintf (StringToTPCL, "%d", ToTPCL);
  else
    sprintf (StringToTPCL, "%s", mode_On_Off [ToTPCLOnOff]);

  if (CorrectionOnOff == RSCMU_ON)
    sprintf (StringCorrection, "%lf", Correction);
  else
    sprintf (StringCorrection, "%s", mode_On_Off [CorrectionOnOff]);

  sprintf (wrtBuf, "CONF:POW%s:LIM:LINE:LOW%d:DYN%d %s,%s,%s,%s", StrModulation[modulation]
                                                                , Area
                                                                , TPCLRange
                                                                , StringFromTPCL
                                                                , StringToTPCL
                                                                , StringCorrection
                                                                , mode_On_Off[Enable]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Dynamic Correction of Upper limit Line On/Off
/* Purpose :
/*===========================================================================*/
ViStatus RSCMU_ConfPowLimUppDynMod (ViSession instrSession,
                                    ViInt32   Modulation,
                                    ViInt32   area,
                                    ViInt32   enable,
                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  CHECK_VI_INT32_RANGE(instrSession, area, 0, 16, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) enable, RSCMU_ERROR_PARAMETER3, errorMessage);

  if(area == 0)
    sprintf (wrtBuf, "CONF:POW%s:LIM:LINE:UPP:ALL:DYN:ENAB %s", StrModulation[Modulation]
                                                              , mode_On_Off [enable]);
  else
    sprintf (wrtBuf, "CONF:POW%s:LIM:LINE:UPP%d:DYN:ENAB %s", StrModulation[Modulation]
                                                            , area
                                                            , mode_On_Off [enable]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Dynamic Correction of Lower limit Line On/Off
/* Purpose :
/*===========================================================================*/
ViStatus RSCMU_ConfPowLimLowDynMod (ViSession instrSession,
                                    ViInt32   Modulation,
                                    ViInt32   area,
                                    ViInt32   enable,
                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  CHECK_VI_INT32_RANGE(instrSession, area, 0, 16, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) enable, RSCMU_ERROR_PARAMETER3, errorMessage);

  if(area == 0)
    sprintf (wrtBuf, "CONF:POW%s:LIM:LINE:LOW:ALL:DYN:ENAB %s", StrModulation[Modulation]
                                                              , mode_On_Off [enable]);
  else
    sprintf (wrtBuf, "CONF:POW%s:LIM:LINE:LOW%d:DYN:ENAB %s", StrModulation[Modulation]
                                                            , area
                                                            , mode_On_Off [enable]);

  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus RSCMU_ConfPowContRepStat (ViSession  instrSession,
                                   ViInt32    Modulation,
                                   ViInt32    NbRepetition,
                                   ViInt32    StopCondition,
                                   ViInt32    StepMode,
                                   ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, NbRepetition, RSCMU_MULT_MEAS_MIN, RSCMU_MULT_MEAS_MAX, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) StopCondition, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) StepMode, RSCMU_ERROR_PARAMETER4, errorMessage);

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if ((p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15) && (Modulation == RSCMU_EPSK))
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  sprintf (wrtBuf, "CONF:POW%s:CONT:REP %d,%s,%s", StrModulation[Modulation], NbRepetition, StrStopCondition[StopCondition], StrStepMode[StepMode]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: average power in selected slot
/* Purpose : This function starts a single shot measurement and output all
/*           scalar measurement results.
/*===========================================================================*/
ViStatus RSCMU_MeasScalarPower (ViSession   instrSession,
                                ViInt32     Command,
                                ViInt32     Object,
                                ViInt32     Timeslot,
                                ViReal64   *AvgPw,
                                ViChar      errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViChar      TableOfDataValues[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  switch (Object)
  {
    case RSCMU_POWSLOT:
      // Check if the function is correctly used:
      CHECK_VI_INT32_RANGE(instrSession, Timeslot, 1, 8, RSCMU_ERROR_PARAMETER2, errorMessage);

      sprintf(wrtBuf, "%s%s:SPOW%d?", StrCommand[Command], StrObject[Object], Timeslot);
    break;
    case RSCMU_POWXSL:
      // Check if the function is correctly used:
      CHECK_VI_INT32_RANGE(instrSession, Timeslot, 1, 128, RSCMU_ERROR_PARAMETER2, errorMessage);

      sprintf(wrtBuf, "%s%s:SPOW%d?", StrCommand[Command], StrObject[Object], Timeslot);
    break;
    case RSCMU_POWFRAM:
      // Check if the function is correctly used:
      if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_40)
      {
        CHECK_VI_INT32_RANGE(instrSession, Timeslot, 1, 128, RSCMU_ERROR_PARAMETER2, errorMessage);
      }
      else
      {
        CHECK_VI_INT32_RANGE(instrSession, Timeslot, 1, 256, RSCMU_ERROR_PARAMETER2, errorMessage);
      }
      sprintf(wrtBuf, "%s%s:FPOW%d?", StrCommand[Command], StrObject[Object], Timeslot);
    break;
    default:
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);
  }

  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", TableOfDataValues);

  // Get the limit check for average power of current timeslot:
  RSCMU_Status = RSCMU_GetViReal64Value(TableOfDataValues, 0, AvgPw);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: average power in all timeslots
/* Purpose : This function starts a single shot measurement and output all
/*           scalar measurement results.
/*===========================================================================*/
ViStatus RSCMU_MeasArrayPower (ViSession instrSession,
                               ViInt32   Command,
                               ViInt32   Object,
                               ViReal64  SlotPower[],
                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      SlotPowerTmp[669][20];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  sprintf (wrtBuf, "%s:ARR%s?", StrCommand[Command], StrObject[Object]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all slot power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, SlotPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, SlotPowerTmp, SlotPower);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Measurement subarrays
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern.
/*===========================================================================*/
ViStatus RSCMU_MeasSubarraysPower (ViSession instrSession,
                                   ViInt32   Command,
                                   ViInt32   Object,
                                   ViReal64  SlotPower[],
                                   ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      SlotPowerTmp[669][20];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  sprintf (wrtBuf, "%s:SUB%s?", StrCommand[Command], StrObject[Object]);

  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all slot power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, SlotPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, SlotPowerTmp, SlotPower);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: array measurement for power/t multislot
/* Purpose : This function starts a single shot measurement and output all
/*           scalar measurement results.
/*===========================================================================*/
ViStatus RSCMU_MeasArrayPowerMsl (ViSession  instrSession,
                                  ViInt32    Command,
                                  ViInt32    StatisticsMode,
                                  ViReal64   Values[],
                                  ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViChar     *StrValue;
  ViInt16     Index = 0;
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "%s:ARR:POW:MSL:%s?", StrCommand[Command], StrStatMode[StatisticsMode]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all values by breaking the read buffer:
  StrValue = strtok (rdBuf, ",");

  while (StrValue)
  {
    if (strcmp (StrValue, "NAN") != 0)
      sscanf (StrValue, "%lf", &Values[Index]);
    else Values[Index] = RSCMU_NAN;

    StrValue = strtok (NULL, ",");

    Index++;
  }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Measurement subarrays for power/t multislot
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern.
/*===========================================================================*/
ViStatus RSCMU_MeasSubarraysPowerMsl (ViSession instrSession,
                                      ViInt32   Command,
                                      ViInt32   StatisticsMode,
                                      ViReal64  BurstPower[],
                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  sprintf (wrtBuf, "%s:SUB:POW:MSL:%s?", StrCommand[Command], StrStatMode[StatisticsMode]);

  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all slot power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, BurstPower);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Limit Upper Mode
/* Purpose : This function switches the upper limit checking
/*===========================================================================*/
ViStatus RSCMU_ConfModLimMod (ViSession instrSession,
                              ViInt32   lowUpp,
                              ViInt32   object,
                              ViBoolean limitCheck,
                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if ((p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15)&&(object == RSCMU_MODXPER))
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) limitCheck, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF%s:LIM%s:MODE %s", StrObject[object], mode_low_upp[lowUpp], mode_On_Off[limitCheck]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function start a measurement and output all scalar,
/*           numeric measurement results.
/*===========================================================================*/
ViStatus RSCMU_MeasModXper (ViSession instrSession,
                            ViInt32   object,
                            ViInt32   command,
                            ViInt32   statistics,
                            ViReal64 *phErrPeak,
                            ViReal64 *phErrRMS,
                            ViReal64 *originOffset,
                            ViReal64 *IQImbalance,
                            ViReal64 *freqErr,
                            ViReal64 *avgBurstPowerCurr,
                            ViReal64 *burstOutOfTol,
                            ViReal64 *PhaseOfOriginOffsetVector,
                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      tab[100][100];

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, statistics, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "%s:MOD:XPER?", StrCommand[command]);
  // Sense the current signalling state of the CMU
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  RSCMU_Status = RSCMU_ScanModXper (tab , 0, statistics, phErrPeak, phErrRMS, originOffset, IQImbalance, freqErr, avgBurstPowerCurr, burstOutOfTol, PhaseOfOriginOffsetVector);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Measure arrays/subarrays values
/* Purpose : This function outputs the different power values of the
/*           bursts in a fixed -bit pattern.
/*===========================================================================*/
ViStatus RSCMU_MeasArrModXper (ViSession instrSession,
                               ViInt32   command,
                               ViInt32   Mode,
                               ViReal64  BurstValues[],
                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      ListValuesTmp[669][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  sprintf (wrtBuf, "%s:ARR:MOD:XPER:%s?", StrCommand[command], StrMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, ListValuesTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, ListValuesTmp, BurstValues);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Read Phase Error in Burst (SubArray)...
/* Purpose : This function outputs the phase error versus time in a fixed
/*           -bit pattern and in the subranges defined by means of the
/*           configuration.
/*===========================================================================*/
ViStatus RSCMU_MeasSubArrModXper (ViSession instrSession,
                                  ViInt32   command,
                                  ViInt32   Mode,
                                  ViReal64  PhaseErrorValues[],
                                  ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      PhaseErrorTmp[669][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  sprintf (wrtBuf, "%s:SUB:MOD:XPER:%s?", StrCommand[command], StrMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, PhaseErrorTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, PhaseErrorTmp, PhaseErrorValues);

  return RSCMU_Status;
}

/*===========================================================================*/
/* local Function
/*===========================================================================*/
ViStatus RSCMU_MeasSclarDemodBit (ViSession  instrSession,
                                  ViChar    *StrCommand,
                                  ViInt32   *result,
                                  ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  sprintf (wrtBuf, "%s", StrCommand);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Get the result
  if (strcmp (rdBuf, "NAN") != 0)
    sscanf (rdBuf, "%d", result);
  else *result = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}

/*===========================================================================*/
/* local Function
/*===========================================================================*/
ViStatus RSCMU_MeasPeakDemodBit (ViSession  instrSession,
                                 ViChar    *StrCommand,
                                 ViInt32   *xValue,
                                 ViInt32   *yValue,
                                 ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      Tab[100][100];

  sprintf (wrtBuf, "%s", StrCommand);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", Tab);

  // Get the x-value
  if (strcmp (Tab[0], "NAN") != 0)
    sscanf (Tab[0], "%d", xValue);
  else *xValue = RSCMU_NAN_VI_INT32;

  // Get the y-value
  if (strcmp (Tab[0], "NAN") != 0)
    sscanf (Tab[0], "%d", yValue);
  else *yValue = RSCMU_NAN_VI_INT32;

  return RSCMU_Status;
}


/*===========================================================================*/
/* Function: Set Default limit Lines (ON/OFF)
/* Purpose : This function switches the default limit lines on or off.
/*===========================================================================*/
ViStatus RSCMU_ConfModOempLimLineDef (ViSession instrSession,
                                      ViBoolean DefaultLimitLines,
                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) DefaultLimitLines, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:OEMP:EPSK:LIM:DEF %s", mode_On_Off[DefaultLimitLines]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Upper Limit Lines
/* Purpose : This function defines upper limits for the Current, Max./Min and
/*           Average traces and for the scalar modulation parameters derived
/*           from them.
/*===========================================================================*/
ViStatus RSCMU_ConfModOempLimLineUpp (ViSession instrSession,
                                               ViInt32   Limits,
                                               ViReal64  EVMErrorPeak,
                                               ViReal64  EVMErrorRMS,
                                               ViReal64  magnErrorPeak,
                                               ViReal64  magnErrorRMS,
                                               ViReal64  phaseErrorPeak,
                                               ViReal64  phaseErrorRMS,
                                               ViReal64  originOffset,
                                               ViReal64  IQImBalance,
                                               ViInt32   frequencyError,
                                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrLimits[] = {"CURR","AVER"};
 struct      RSCMU_SESSION_Globals  *p_globalvarBase;


// Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;


   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15)
   return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_INT32_RANGE(instrSession, Limits, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, EVMErrorPeak, 0, 50, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, EVMErrorRMS, 0, 50, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, magnErrorPeak, 0, 50, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, magnErrorRMS, 0, 50, RSCMU_ERROR_PARAMETER6, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, phaseErrorPeak, 0, 180, RSCMU_ERROR_PARAMETER7, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, phaseErrorRMS, 0, 180, RSCMU_ERROR_PARAMETER8, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, originOffset, -100, 0, RSCMU_ERROR_PARAMETER9, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, frequencyError, 0, 999, RSCMU_ERROR_PARAMETER11, errorMessage);



if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
    {
     CHECK_VI_REAL64_RANGE(instrSession, IQImBalance, -100, 0, RSCMU_ERROR_PARAMETER10, errorMessage);
     sprintf (wrtBuf, "CONF:MOD:OEMP:EPSK:LIM:%s %lf,%lf,%lf,%lf,%lf,%lf,%lf,%lf,%d", StrLimits[Limits]
                                                                                 , EVMErrorPeak
                                                                                 , EVMErrorRMS
                                                                                 , magnErrorPeak
                                                                                 , magnErrorRMS
                                                                                 , phaseErrorPeak
                                                                                 , phaseErrorRMS
                                                                                 , originOffset
                                                                                 , IQImBalance
                                                                                 , frequencyError);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;
}


 //with Version V3.07 IQ Imbalance are not supported in EPSK
  if ((p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V3_07) && (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V4_23))
    {
   sprintf (wrtBuf, "CONF:MOD:OEMP:EPSK:LIM:%s %lf,%lf,%lf,%lf,%lf,%lf,%lf,%d", StrLimits[Limits]
                                                                                 , EVMErrorPeak
                                                                                 , EVMErrorRMS
                                                                                 , magnErrorPeak
                                                                                 , magnErrorRMS
                                                                                 , phaseErrorPeak
                                                                                 , phaseErrorRMS
                                                                                 , originOffset
                                                                                 , frequencyError);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;
    }

 //and since with Version V4.23 IQ Imbalance is again supported, but at different place...
  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V4_23)
    {
    CHECK_VI_REAL64_RANGE(instrSession, IQImBalance, -100, 0, RSCMU_ERROR_PARAMETER10, errorMessage);
   sprintf (wrtBuf, "CONF:MOD:OEMP:EPSK:LIM:%s %lf,%lf,%lf,%lf,%lf,%lf,%lf,%d,%lf", StrLimits[Limits]
                                                                                 , EVMErrorPeak
                                                                                 , EVMErrorRMS
                                                                                 , magnErrorPeak
                                                                                 , magnErrorRMS
                                                                                 , phaseErrorPeak
                                                                                 , phaseErrorRMS
                                                                                 , originOffset
                                                                                 , frequencyError,
                                                                                  IQImBalance);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;
    }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: 95% Upper Limits
/* Purpose : This function defines upper limits for the 95 th percentile of
/*           the three quantities error vector magnitude, modulation error,
/*           and phase error. The 95 th percentile is the limit below which
/*           95% of the measured errors are located.
/*===========================================================================*/
ViStatus RSCMU_ConfModOempLimLine95 (ViSession instrSession,
                                              ViReal64  EVM95,
                                              ViReal64  modulationError95,
                                              ViReal64  phaseError95,
                                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the calling function is correctly used (parameter "modulation" does not count):
  CHECK_VI_REAL64_RANGE(instrSession, EVM95, 0, 50, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, modulationError95, 0, 50, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, phaseError95, 0, 180, RSCMU_ERROR_PARAMETER4, errorMessage);

  sprintf (wrtBuf, "CONF:MOD:OEMP:EPSK:LIM:P95T %lf,%lf,%lf", EVM95
                                                            , modulationError95
                                                            , phaseError95);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all
/*           scalar measurement results (see chapter 4). The calculation of
/*           results in an average or peak measurement is described in chapter
/*           3 (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus RSCMU_MeasModOver (ViSession instrSession,
                            ViInt32   command,
                            ViInt32   StatisticsMode,
                            ViPReal64 EVM95,
                            ViPReal64 MagErr95,
                            ViPReal64 PhaseErr95,
                            ViPReal64 EVMPeak,
                            ViPReal64 EVMRMS,
                            ViPReal64 magnErrorPeak,
                            ViPReal64 magnErrorRMS,
                            ViPReal64 phaseErrorPeak,
                            ViPReal64 phaseErrorRMS,
                            ViPReal64 originOffset,
                            ViPReal64 IQIm_balance,
                            ViPReal64 frequencyError,
                            ViPReal64 avgBurstPowerCurr,
                            ViPReal64 burstOutOfTol,
                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

// Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;


   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15)
   return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  // Sense the current signalling state of the CMU
  sprintf (wrtBuf, "%s:MOD:OVER:EPSK?", StrCommand[command]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);


  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
    {
        RSCMU_Status = RSCMU_ScanModOver (tab, 0, StatisticsMode, EVM95, MagErr95, PhaseErr95, EVMPeak, EVMRMS, magnErrorPeak,
                                 magnErrorRMS, phaseErrorPeak, phaseErrorRMS, originOffset, IQIm_balance, frequencyError,
                                 avgBurstPowerCurr, burstOutOfTol);
    }


 //with Version V3.07 IQ Imbalance are not supported in EPSK
  if ((p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V3_07) && (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V4_23))
    {
        RSCMU_Status = RSCMU_ScanModOverV307 (tab, 0, StatisticsMode, EVM95, MagErr95, PhaseErr95, EVMPeak, EVMRMS, magnErrorPeak,
                                 magnErrorRMS, phaseErrorPeak, phaseErrorRMS, originOffset, IQIm_balance, frequencyError,
                                 avgBurstPowerCurr, burstOutOfTol);
    }

  //... and since Version V4.23 IQ Imbalance is again supported in EPSK, but at different place
  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V4_23)
    {
        RSCMU_Status = RSCMU_ScanModOverV423 (tab, 0, StatisticsMode, EVM95, MagErr95, PhaseErr95, EVMPeak, EVMRMS, magnErrorPeak,
                                 magnErrorRMS, phaseErrorPeak, phaseErrorRMS, originOffset, frequencyError,avgBurstPowerCurr, 
                                 burstOutOfTol,IQIm_balance);
    }

return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus RSCMU_CalcModOverLimMatc (ViSession instrSession,
                                   ViInt32   StatisticsMode,
                                   ViInt32  *EVM95,
                                   ViInt32  *MagErr95,
                                   ViInt32  *PhaseErr95,
                                   ViInt32  *EVMPeak,
                                   ViInt32  *EVMRMS,
                                   ViInt32  *magnErrorPeak,
                                   ViInt32  *magnErrorRMS,
                                   ViInt32  *phaseErrorPeak,
                                   ViInt32  *phaseErrorRMS,
                                   ViInt32  *originOffset,
                                   ViInt32  *IQIm_balance,
                                   ViInt32  *frequencyError,
                                   ViInt32  *avgBurstPowerCurr,
                                   ViChar   errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15)
   return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);


  if ((RSCMU_Status = RSCMU_Query (instrSession, "CALC:MOD:OVER:EPSK:LIM:MATC?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // 95% EVM with single-value measurement
  RSCMU_Status = RSCMU_GetMatchingValue(EVM95,tab,0);

  // 95% Magnitude Error with single-value measurement
  RSCMU_Status = RSCMU_GetMatchingValue(MagErr95,tab,1);

  // 95% Phase Error with single-value measurement
  RSCMU_Status = RSCMU_GetMatchingValue(PhaseErr95,tab,2);

  switch (StatisticsMode)
  {
    case RSCMU_CURRENT:
        // EVM peak with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(EVMPeak,tab,3);

        // EVM RMS with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(EVMRMS,tab,6);

        // Magnitude Error Peak with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(magnErrorPeak,tab,9);

        // Magnitude Error RMS with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(magnErrorRMS,tab,12);

        // Phase Error Peak with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(phaseErrorPeak,tab,15);

        // Phase Error RMS with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(phaseErrorRMS,tab,18);

        // Origin Offset with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(originOffset,tab,21);

 //with Version V3.07 IQ Imbalance are not supported in EPSK
        if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
            {
              // IQ/IM Balance with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(IQIm_balance,tab,24);

        // Frequency Error with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,27);
            }
        else
            {
             // IQ/IM Balance with single-value measurement
       // RSCMU_Status = RSCMU_GetMatchingValue(IQIm_balance,tab,24);
         *IQIm_balance= RSCMU_INV;
        // Frequency Error with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,24);
            // since Version V4.23 IQ Imbalance is again supported
            if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V4_23)
            {
                // IQ/IM Balance with single-value measurement
                RSCMU_Status = RSCMU_GetMatchingValue(IQIm_balance,tab,28);
            }
            }

        break;

    case RSCMU_AVERAGE:
        // EVM peak with average measurement
        RSCMU_Status = RSCMU_GetMatchingValue(EVMPeak,tab,4);

        // EVM RMS with average measurement
        RSCMU_Status = RSCMU_GetMatchingValue(EVMRMS,tab,7);

        // Magnitude Error Peak with average measurement
        RSCMU_Status = RSCMU_GetMatchingValue(magnErrorPeak,tab,10);

        // Magnitude Error RMS with average measurement
        RSCMU_Status = RSCMU_GetMatchingValue(magnErrorRMS,tab,13);

        // Phase Error Peak with average measurement
        RSCMU_Status = RSCMU_GetMatchingValue(phaseErrorPeak,tab,16);

        // Phase Error RMS with average measurement
        RSCMU_Status = RSCMU_GetMatchingValue(phaseErrorRMS,tab,19);

        // Origin Offset with average measurement
        RSCMU_Status = RSCMU_GetMatchingValue(originOffset,tab,22);

//with Version V3.07 IQ Imbalance are not supported in EPSK
            if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
            {
       // IQ/IM Balance with average measurement
        RSCMU_Status = RSCMU_GetMatchingValue(IQIm_balance,tab,25);

        // Frequency Error with average measurement
        RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,28);
            }
        else
            {
       // IQ/IM Balance with average measurement
   //     RSCMU_Status = RSCMU_GetMatchingValue(IQIm_balance,tab,25);
       *IQIm_balance= RSCMU_INV;
        // Frequency Error with average measurement
        RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,25);
           // since Version V4.23 IQ Imbalance is again supported
            if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V4_23)
            {
                // IQ/IM Balance with single-value measurement
                RSCMU_Status = RSCMU_GetMatchingValue(IQIm_balance,tab,29);
            }
            }


    break;

    case RSCMU_MAXMIN:
        // EVM peak with extreme-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(EVMPeak,tab,5);

        // EVM RMS with extreme-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(EVMRMS,tab,7);

        // Magnitude Error Peak with extreme-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(magnErrorPeak,tab,11);

        // Magnitude Error RMS with extreme-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(magnErrorRMS,tab,14);

        // Phase Error Peak with extreme-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(phaseErrorPeak,tab,17);

        // Phase Error RMS with extreme-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(phaseErrorRMS,tab,20);

        // Origin Offset with extreme-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(originOffset,tab,23);

//with Version V3.07 IQ Imbalance are not supported in EPSK
            if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
            {
        // IQ/IM Balance with extreme-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(IQIm_balance,tab,26);

        // Frequency Error with extreme-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,29);
            }
        else
            {
        // IQ/IM Balance with extreme-value measurement
//        RSCMU_Status = RSCMU_GetMatchingValue(IQIm_balance,tab,26);
        *IQIm_balance=RSCMU_INV;


        // Frequency Error with extreme-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,26);
           // since Version V4.23 IQ Imbalance is again supported
            if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V4_23)
            {
                // IQ/IM Balance with single-value measurement
                RSCMU_Status = RSCMU_GetMatchingValue(IQIm_balance,tab,30);
            }
            }
    break;
  }

//with Version V3.07 IQ Imbalance are not supported in EPSK
            if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
            {
  // Average Burst Power Current with single-value measurement
  RSCMU_Status = RSCMU_GetMatchingValue(avgBurstPowerCurr,tab,30);
            }
        else
            {
  // Average Burst Power Current with single-value measurement
  RSCMU_Status = RSCMU_GetMatchingValue(avgBurstPowerCurr,tab,27);
            }


  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4). The calculation of results in
/*           an average or peak measurement is described in chapter 3 (see
/*           calculation of statistical quantities). The symbol (x3) behind a
/*           value indicates that the list contains three results corresponding
/*           to the Current, the Average, and the MMax value.
/*===========================================================================*/
ViStatus RSCMU_MeasModEvm (ViSession instrSession,
                           ViInt32   command,
                           ViInt32   StatisticsMode,
                           ViReal64 *EVM95,
                           ViReal64 *EVMPeak,
                           ViReal64 *EVMRMS,
                           ViReal64 *originOffset,
                           ViReal64 *IQImBalance,
                           ViReal64 *frequencyError,
                           ViReal64 *avgBurstPowerCurr,
                           ViReal64 *burstOutOfTol,
                           ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

// Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;


   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15)
   return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  // Sense the current signalling state of the CMU
  sprintf (wrtBuf, "%s:MOD:EVM:EPSK?", StrCommand[command]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);


   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
    {
  RSCMU_Status = RSCMU_ScanModEvm (tab, 0, StatisticsMode, EVM95, EVMPeak, EVMRMS, originOffset, IQImBalance, frequencyError,
                                   avgBurstPowerCurr, burstOutOfTol);
   }


 //with Version V3.07 IQ Imbalance are not supported in EPSK
  if ((p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V3_07) && (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V4_23))
    {
 RSCMU_Status = RSCMU_ScanModEvmV307 (tab, 0, StatisticsMode, EVM95, EVMPeak, EVMRMS, originOffset, IQImBalance, frequencyError,
                                   avgBurstPowerCurr, burstOutOfTol);
    }

 //... and since Version V4.23 IQ Imbalance is again supported in EPSK, but at different place
  if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V4_23)
    {
        RSCMU_Status = RSCMU_ScanModEvmV423 (tab, 0, StatisticsMode, EVM95, EVMPeak, EVMRMS, originOffset, IQImBalance, frequencyError,
                                   avgBurstPowerCurr, burstOutOfTol);
    }



  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus RSCMU_CalcModEvmLimMatc (ViSession instrSession,
                                  ViInt32   StatisticsMode,
                                  ViInt32  *EVM95,
                                  ViInt32  *phaseErrorPeak,
                                  ViInt32  *phaseErrorRMS,
                                  ViInt32  *originOffset,
                                  ViInt32  *IQImBalance,
                                  ViInt32  *frequencyError,
                                  ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15)
   return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  if ((RSCMU_Status = RSCMU_Query (instrSession, "CALC:MOD:EVM:EPSK:LIM:MATC?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // 95% EVM with single-value measurement
  RSCMU_Status = RSCMU_GetMatchingValue(EVM95,tab,0);

  switch (StatisticsMode)
  {
    case RSCMU_CURRENT:
        // Phase Error Peak with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(phaseErrorPeak,tab,1);

        // Phase Error RMS with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(phaseErrorRMS,tab,4);

        // Origin Offset with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(originOffset,tab,7);


 //with Version V3.07 IQ Imbalance are not supported in EPSK
        if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
            {
                // IQ/Im Balance with single-value measurement
                RSCMU_Status = RSCMU_GetMatchingValue(IQImBalance,tab,10);

                // Frequency Error with single-value measurement
                RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,13);
            }
        else
            {
                if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V4_23)
                {
                         // IQ/IM Balance with single-value measurement
                   // RSCMU_Status = RSCMU_GetMatchingValue(IQIm_balance,tab,10);
                     *IQImBalance  = RSCMU_INV;
                    // Frequency Error with single-value measurement
                    RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,10);
                }
                else
                {
                    // IQ/Im Balance with single-value measurement
                    RSCMU_Status = RSCMU_GetMatchingValue(IQImBalance,tab,13);

                    // Frequency Error with single-value measurement
                    RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,10);
                }
            }
    break;

    case RSCMU_AVERAGE:
        // Phase Error Peak with average measurement
        RSCMU_Status = RSCMU_GetMatchingValue(phaseErrorPeak,tab,2);

        // Phase Error RMS with average measurement
        RSCMU_Status = RSCMU_GetMatchingValue(phaseErrorRMS,tab,5);

        // Origin Offset with average measurement
        RSCMU_Status = RSCMU_GetMatchingValue(originOffset,tab,8);

 //with Version V3.07 IQ Imbalance are not supported in EPSK
        if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
        {
            // IQ/Im Balance with single-value measurement
            RSCMU_Status = RSCMU_GetMatchingValue(IQImBalance,tab,11);

            // Frequency Error with single-value measurement
            RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,14);
        }
        else
        {
            if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V4_23)
            {
                // IQ/IM Balance with single-value measurement
                // RSCMU_Status = RSCMU_GetMatchingValue(IQIm_balance,tab,11);
                *IQImBalance  = RSCMU_INV;
                // Frequency Error with single-value measurement
                RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,11);
                }
            else
            {
                // IQ/Im Balance with single-value measurement
                RSCMU_Status = RSCMU_GetMatchingValue(IQImBalance,tab,14);

                // Frequency Error with single-value measurement
                RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,11);
            }
        }
    break;

    case RSCMU_MAXMIN:
        // Phase Error Peak with extreme-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(phaseErrorPeak,tab,3);

        // Phase Error RMS with extreme-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(phaseErrorRMS,tab,6);

        // Origin Offset with extreme-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(originOffset,tab,9);

 //with Version V3.07 IQ Imbalance are not supported in EPSK
        if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
        {
            // IQ/Im Balance with single-value measurement
            RSCMU_Status = RSCMU_GetMatchingValue(IQImBalance,tab,12);

            // Frequency Error with single-value measurement
            RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,15);
        }
        else
        {
            if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V4_23)
            {
                // IQ/IM Balance with single-value measurement
                // RSCMU_Status = RSCMU_GetMatchingValue(IQIm_balance,tab,12);
                *IQImBalance= RSCMU_INV;
                // Frequency Error with single-value measurement
                RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,12);
            }
            else
            {
                // IQ/Im Balance with single-value measurement
                RSCMU_Status = RSCMU_GetMatchingValue(IQImBalance,tab,14);

                // Frequency Error with single-value measurement
                RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,12);
            }
        }
    break;
  }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Measures Error Vector Magnitude
/* Purpose : This function returns the error vector magnitude vs. time at fixed,
/*           equidistant test points. The number of measured values is 588,
/*           corresponding to a time range of 0 Bit to 146  Bit.
/*           The calculation of current, average, and mmax (Min./Max.) results
/*           is explained in chapter 3 (see display mode).
/*===========================================================================*/
ViStatus RSCMU_MeasArrModEvm (ViSession instrSession,
                              ViInt32   command,
                              ViInt32   Mode,
                              ViReal64  EVMValues[],
                              ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      EVMValuesTmp[588][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "%s:ARR:MOD:EVM:EPSK:%s?", StrCommand[command], StrMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, EVMValuesTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse(NbOfMeasValues,EVMValuesTmp,EVMValues);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Measures Subarray
/* Purpose : this function measures and returns the error vector magnitude
/*           versus time in the subranges defined by means of the CONFigure:
/*           SUBarrays:MODulation:EVMagnitude:EPSK[:TCH] command.
/*===========================================================================*/
ViStatus RSCMU_MeasSubArrModEvm (ViSession instrSession,
                                 ViInt32   command,
                                 ViInt32   Mode,
                                 ViReal64  EVMValues[],
                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      EVMValuesTmp[32][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "%s:SUB:MOD:EVM:EPSK:%s?", StrCommand[command], StrMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, EVMValuesTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse(NbOfMeasValues,EVMValuesTmp,EVMValues);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus RSCMU_EDGE_MeasModPerr (ViSession instrSession,
                                 ViInt32   command,
                                 ViInt32   StatisticsMode,
                                 ViReal64 *PhaseError95,
                                 ViReal64 *phaseErrorPeak,
                                 ViReal64 *phaseErrorRMS,
                                 ViReal64 *originOffset,
                                 ViReal64 *IQImBalance,
                                 ViReal64 *frequencyError,
                                 ViReal64 *avgBurstPowerCurr,
                                 ViReal64 *burstOutOfTol,
                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

// Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;


   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15)
   return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  // Sense the current signalling state of the CMU
  sprintf(wrtBuf, "%s:MOD:PERR:EPSK?", StrCommand[command]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);




  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
        {
     RSCMU_Status = RSCMU_EDGE_ScanModPerr (tab, 0, StatisticsMode, PhaseError95, phaseErrorPeak, phaseErrorRMS, originOffset,
                                         IQImBalance, frequencyError, avgBurstPowerCurr, burstOutOfTol);
   }


 //with Version V3.07 IQ Imbalance are not supported in EPSK
  if ((p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V3_07) && (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V4_23))
        {
     RSCMU_Status = RSCMU_EDGE_ScanModPerrV307 (tab, 0, StatisticsMode, PhaseError95, phaseErrorPeak, phaseErrorRMS, originOffset,
                                         IQImBalance, frequencyError, avgBurstPowerCurr, burstOutOfTol);
        }
    // since Version V4.23 IQ Imbalance is again supported
    if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V4_23)
    {
        // IQ/IM Balance with single-value measurement
        RSCMU_Status = RSCMU_EDGE_ScanModPerrV423 (tab, 0, StatisticsMode, PhaseError95, phaseErrorPeak, phaseErrorRMS, originOffset,
                                         IQImBalance, frequencyError, avgBurstPowerCurr, burstOutOfTol);
    }
  

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus RSCMU_EDGE_CalcModPerrLimMatc (ViSession instrSession,
                                        ViInt32   StatisticsMode,
                                        ViInt32  *PhaseError95,
                                        ViInt32  *phaseErrorPeak,
                                        ViInt32  *phaseErrorRMS,
                                        ViInt32  *originOffset,
                                        ViInt32  *IQImBalance,
                                        ViInt32  *frequencyError,
                                        ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

    // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15)
   return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  if ((RSCMU_Status = RSCMU_Query (instrSession, "CALC:MOD:PERR:EPSK:LIM:MATC?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // 95% Phase Error with single-value measurement
  RSCMU_Status = RSCMU_GetMatchingValue(PhaseError95,tab,0);

  switch (StatisticsMode)
  {
    case RSCMU_CURRENT:
        // Phase Error Peak with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(phaseErrorPeak,tab,1);

        // Phase Error RMS with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(phaseErrorRMS,tab,4);

        // Origin Offset with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(originOffset,tab,7);

 //with Version V3.07 IQ Imbalance are not supported in EPSK
        if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
        {
            // IQ/Im Balance with single-value measurement
            RSCMU_Status = RSCMU_GetMatchingValue(IQImBalance,tab,10);

            // Frequency Error with single-value measurement
            RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,13);
        }
        else
        {
            // since Version V4.23 IQ Imbalance is again supported
            if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V4_23)
            {
                // IQ/IM Balance with single-value measurement
                RSCMU_Status = RSCMU_GetMatchingValue(IQImBalance,tab,13);
            }
            else
                *IQImBalance  = RSCMU_INV;
            // Frequency Error with single-value measurement
            RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,10);
        }
    break;

    case RSCMU_AVERAGE:
        // Phase Error Peak with average measurement
        RSCMU_Status = RSCMU_GetMatchingValue(phaseErrorPeak,tab,2);

        // Phase Error RMS with average measurement
        RSCMU_Status = RSCMU_GetMatchingValue(phaseErrorRMS,tab,5);

        // Origin Offset with average measurement
        RSCMU_Status = RSCMU_GetMatchingValue(originOffset,tab,8);

 //with Version V3.07 IQ Imbalance are not supported in EPSK
        if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
        {
            // IQ/Im Balance with single-value measurement
            RSCMU_Status = RSCMU_GetMatchingValue(IQImBalance,tab,11);

            // Frequency Error with single-value measurement
            RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,14);
        }
        else
        {
            // since Version V4.23 IQ Imbalance is again supported
            if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V4_23)
            {
                // IQ/IM Balance with single-value measurement
                RSCMU_Status = RSCMU_GetMatchingValue(IQImBalance,tab,14);
            }
            else
                *IQImBalance  = RSCMU_INV;
        // Frequency Error with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,11);
        }
    break;

    case RSCMU_MAXMIN:
        // Phase Error Peak with extreme-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(phaseErrorPeak,tab,3);

        // Phase Error RMS with extreme-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(phaseErrorRMS,tab,6);

        // Origin Offset with extreme-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(originOffset,tab,9);

 //with Version V3.07 IQ Imbalance are not supported in EPSK
        if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
        {
            // IQ/Im Balance with single-value measurement
            RSCMU_Status = RSCMU_GetMatchingValue(IQImBalance,tab,12);

            // Frequency Error with single-value measurement
            RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,15);
        }
        else
        {
            // since Version V4.23 IQ Imbalance is again supported
            if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V4_23)
            {
                // IQ/IM Balance with single-value measurement
                RSCMU_Status = RSCMU_GetMatchingValue(IQImBalance,tab,15);
            }
            else
                *IQImBalance  = RSCMU_INV;
        // Frequency Error with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,12);
        }
    break;
  }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Measures Phase Error in Burst...
/* Purpose : This function returns the the phase error vs. time at fixed,
/*           equidistant test points. The number of measured values is 588,
/*           corresponding to a time range of 0 Bit to 146  Bit.
/*===========================================================================*/
ViStatus RSCMU_EDGE_MeasArrModPerr (ViSession instrSession,
                                    ViInt32   command,
                                    ViInt32   Mode,
                                    ViReal64  PhaseErrorValues[],
                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      PhaseErrorValuesTmp[588][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "%s:ARR:MOD:PERR:EPSK:%s?", StrCommand[command], StrMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, PhaseErrorValuesTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse(NbOfMeasValues,PhaseErrorValuesTmp,PhaseErrorValues);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Measures Subarray
/* Purpose : this function measures and returns the phase error versus time in
/*           the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:PERRor:EPSK command.
/*===========================================================================*/
ViStatus RSCMU_EDGE_MeasSubArrModPerr (ViSession instrSession,
                                       ViInt32   command,
                                       ViInt32   Mode,
                                       ViReal64  PhaseErrorValues[],
                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      PhaseErrorValuesTmp[32][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "%s:SUB:MOD:PERR:EPSK:%s?", StrCommand[command], StrMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, PhaseErrorValuesTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse(NbOfMeasValues,PhaseErrorValuesTmp,PhaseErrorValues);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : this function starts a modulation measurement and output all scalar
/*           measurement results (see chapter 4), either for the whole burst or
/*           for the 1 st ten valid symbols in the burst. The calculation of
/*           results in an average or peak measurement is described in chapter 3
/*           (see calculation of statistical quantities).
/*===========================================================================*/
ViStatus RSCMU_MeasModMerr (ViSession instrSession,
                            ViInt32   command,
                            ViInt32   StatisticsMode,
                            ViReal64 *MagnError95,
                            ViReal64 *MagnErrorPeak,
                            ViReal64 *MagnErrorRMS,
                            ViReal64 *originOffset,
                            ViReal64 *IQImBalance,
                            ViReal64 *frequencyError,
                            ViReal64 *avgBurstPowerCurr,
                            ViReal64 *burstOutOfTol,
                            ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

// Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;


   if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15)
   return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);

  // Sense the current signalling state of the CMU
  sprintf(wrtBuf, "%s:MOD:MERR:EPSK?", StrCommand[command]);
      if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);


  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
        {
  RSCMU_Status = RSCMU_ScanModMerr (tab, 0, StatisticsMode, MagnError95, MagnErrorPeak, MagnErrorRMS, originOffset,
                                    IQImBalance, frequencyError, avgBurstPowerCurr, burstOutOfTol);
    }


 //with Version V3.07 IQ Imbalance are not supported in EPSK
  if ((p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V3_07) && (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V4_23))
        {
  RSCMU_Status = RSCMU_ScanModMerrV307 (tab, 0, StatisticsMode, MagnError95, MagnErrorPeak, MagnErrorRMS, originOffset,
                                    IQImBalance, frequencyError, avgBurstPowerCurr, burstOutOfTol);
        }

    // since Version V4.23 IQ Imbalance is again supported
    if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V4_23)
    {
        RSCMU_Status = RSCMU_ScanModMerrV423 (tab, 0, StatisticsMode, MagnError95, MagnErrorPeak, MagnErrorRMS, originOffset,
                                        IQImBalance, frequencyError, avgBurstPowerCurr, burstOutOfTol);
    }
  return RSCMU_Status;

}

/*===========================================================================*/
/* Function: Match Tolerances
/* Purpose : This function indicates whether and in which way the
/*           permissible error limits for the scalar measured values
/*           have been exceeded.
/*===========================================================================*/
ViStatus RSCMU_CalcModMerrLimMatc (ViSession instrSession,
                                   ViInt32   StatisticsMode,
                                   ViInt32  *MagnError95,
                                   ViInt32  *MagnErrorPeak,
                                   ViInt32  *MagnErrorRMS,
                                   ViInt32  *originOffset,
                                   ViInt32  *IQImBalance,
                                   ViInt32  *frequencyError,
                                   ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, StatisticsMode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

    // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

    if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V2_15)
   return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_2_15, errorMessage);


  if ((RSCMU_Status = RSCMU_Query (instrSession, "CALC:MOD:MERR:EPSK:LIM:MATC?", rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // 95% Phase Error with single-value measurement
  RSCMU_Status = RSCMU_GetMatchingValue(MagnError95,tab,0);

  switch (StatisticsMode)
  {
    case RSCMU_CURRENT:
        // Phase Error Peak with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(MagnErrorPeak,tab,1);

        // Phase Error RMS with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(MagnErrorRMS,tab,4);

        // Origin Offset with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(originOffset,tab,7);

 //with Version V3.07 IQ Imbalance are not supported in EPSK
        if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
        {
            // IQ/Im Balance with single-value measurement
            RSCMU_Status = RSCMU_GetMatchingValue(IQImBalance,tab,10);

            // Frequency Error with single-value measurement
            RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,13);
        }
        else
        {
           // since Version V4.23 IQ Imbalance is again supported
            if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V4_23)
            {
                // IQ/IM Balance with single-value measurement
                RSCMU_Status = RSCMU_GetMatchingValue(IQImBalance,tab,13);
            }
            else
             *IQImBalance  = RSCMU_INV;
        // Frequency Error with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,10);
        }
    break;

    case RSCMU_AVERAGE:
        // Phase Error Peak with average measurement
        RSCMU_Status = RSCMU_GetMatchingValue(MagnErrorPeak,tab,2);

        // Phase Error RMS with average measurement
        RSCMU_Status = RSCMU_GetMatchingValue(MagnErrorRMS,tab,5);

        // Origin Offset with average measurement
        RSCMU_Status = RSCMU_GetMatchingValue(originOffset,tab,8);

 //with Version V3.07 IQ Imbalance are not supported in EPSK
        if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
        {
            // IQ/Im Balance with single-value measurement
            RSCMU_Status = RSCMU_GetMatchingValue(IQImBalance,tab,11);

            // Frequency Error with single-value measurement
            RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,14);
        }
        else
        {
           // since Version V4.23 IQ Imbalance is again supported
            if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V4_23)
            {
                // IQ/IM Balance with single-value measurement
                RSCMU_Status = RSCMU_GetMatchingValue(IQImBalance,tab,14);
            }
            else
                *IQImBalance  = RSCMU_INV;
        // Frequency Error with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,11);
        }
    break;

    case RSCMU_MAXMIN:
        // Phase Error Peak with extreme-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(MagnErrorPeak,tab,3);

        // Phase Error RMS with extreme-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(MagnErrorRMS,tab,6);

        // Origin Offset with extreme-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(originOffset,tab,9);

 //with Version V3.07 IQ Imbalance are not supported in EPSK
        if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_07)
        {
            // IQ/Im Balance with single-value measurement
            RSCMU_Status = RSCMU_GetMatchingValue(IQImBalance,tab,12);

            // Frequency Error with single-value measurement
            RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,15);
            }
        else
        {
           // since Version V4.23 IQ Imbalance is again supported
            if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V4_23)
            {
                // IQ/IM Balance with single-value measurement
                RSCMU_Status = RSCMU_GetMatchingValue(IQImBalance,tab,15);
            }
            else
                *IQImBalance  = RSCMU_INV;
        // Frequency Error with single-value measurement
        RSCMU_Status = RSCMU_GetMatchingValue(frequencyError,tab,12);
        }
    break;
  }

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Measures Magnitude Error in Burst...
/* Purpose : This function returns the magnitude error vs. time at fixed,
/*           equidistant test points. The number of measured values is 588,
/*           corresponding to a time range of 0 Bit to 146 3/4 Bit.
/*===========================================================================*/
ViStatus RSCMU_MeasArrModMerr (ViSession instrSession,
                               ViInt32   command,
                               ViInt32   Mode,
                               ViReal64  MagnErrorValues[],
                               ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      MagnErrorValuesTmp[588][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 3, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "%s:ARR:MOD:MERR:EPSK:%s?", StrCommand[command], StrMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, MagnErrorValuesTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse(NbOfMeasValues,MagnErrorValuesTmp,MagnErrorValues);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Measures Subarray
/* Purpose : this function measures and returns the phase error versus time in
/*           the subranges defined by means of the CONFigure:SUBarrays:
/*           MODulation:MERRor:EPSK command.
/*===========================================================================*/
ViStatus RSCMU_MeasSubArrModMerr (ViSession instrSession,
                                  ViInt32   command,
                                  ViInt32   Mode,
                                  ViReal64  MagnErrorValues[],
                                  ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      MagnErrorValuesTmp[32][20];
  ViString    StrMode[] = {"CURR", "AVER", "MMAX"};

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Mode, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "%s:SUB:MOD:MERR:EPSK:%s?", StrCommand[command], StrMode[Mode]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, MagnErrorValuesTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse(NbOfMeasValues,MagnErrorValuesTmp,MagnErrorValues);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Limit Lines
/* Purpose : These commands activate and define limit lines for the spectrum
/*           due to switching measurement.
/*===========================================================================*/
ViStatus RSCMU_ConfSpecSwitLimLine (ViSession instrSession,
                                    ViInt32   modulation,
                                    ViInt32   PowerLevel,
                                    ViReal64  power,
                                    ViInt32   enable,
                                    ViReal64  value1,
                                    ViReal64  value2,
                                    ViReal64  value3,
                                    ViReal64  value4,
                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, PowerLevel, RSCMU_POWLEV1, RSCMU_POWLEV10, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) enable, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:SWIT%s:LIM:LINE:UPP%d %lf,%lf,%lf,%lf,%lf,%s", StrModulation[modulation]
                                                                           , PowerLevel
                                                                           , power
                                                                           , value1
                                                                           , value2
                                                                           , value3
                                                                           , value4
                                                                           , mode_On_Off[enable]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Limit Lines On/Off
/* Purpose : This function switches the limit checking for all measurepoints.
/*===========================================================================*/
ViStatus RSCMU_ConfSpecSwitLimLineMod (ViSession instrSession,
                                       ViInt32   modulation,
                                       ViInt32   limitLines,
                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) limitLines, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:SWIT%s:LIM:LINE:MODE:UPP %s", StrModulation[modulation]
                                                          , mode_On_Off[limitLines]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Measure Points
/* Purpose : This function permits to select which frequencies a spectrum
/*           switching measurement is performed. A reduction of the
/*           measurement points enhances the measurement speed.
/*===========================================================================*/
ViStatus RSCMU_ConfSpecSwitContMpo (ViSession  instrSession,
                                    ViInt32    modulation,
                                    ViInt32    MeasurePoint,
                                    ViInt32    Enable,
                                    ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";


  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, MeasurePoint, RSCMU_MPO1, RSCMU_MPO4, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Enable, RSCMU_OFF, RSCMU_ON, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:SWIT%s:CONT:MPO%d:ENAB %s", StrModulation[modulation], MeasurePoint, mode_On_Off[Enable]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Measurement scalar
/* Purpose : This function starts the measurement and outputs some results.
/*===========================================================================*/
ViStatus RSCMU_MeasSpecSwit (ViSession  instrSession,
                             ViInt32    command,
                             ViInt32    modulation,
                             ViReal64  *referencePower,
                             ViInt32   *matching,
                             ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  sprintf (wrtBuf, "%s:SPEC:SWIT%s?", StrCommand[command], StrModulation[modulation]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the Average Burst Power
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%lf", referencePower);
  else *referencePower = RSCMU_NAN;

  // Get the matching
  RSCMU_Status = RSCMU_GetMatchingValue (matching,tab, 1);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Measurement Array
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus RSCMU_MeasArrSpecSwit (ViSession instrSession,
                                ViInt32   command,
                                ViInt32   modulation,
                                ViReal64  BurstPower[],
                                ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[669][20];

  sprintf (wrtBuf, "%s:ARR:SPEC:SWIT%s?", StrCommand[command], StrModulation[modulation]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, BurstPower);

  return RSCMU_Status;
}

//move to base!
//ViStatus RSCMU_MeasArray (ViSession  instrSession,
//                          ViChar    *StrCommand,
//                          ViReal64   Values[],
//                          ViChar     errorMessage[])
//{
//  ViStatus    RSCMU_Status = VI_SUCCESS;
//  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
//  ViChar     *StrValue;
//  ViInt16     Index = 0;
//
//  sprintf (wrtBuf, "%s?", StrCommand);
//  // Write data to the CMU
//  if ((RSCMU_Status = RSCMU_Write (instrSession, wrtBuf, RSCMU_STB_ON, strlen(wrtBuf), errorMessage)) < 0)
//    return RSCMU_Base_errorMessage (instrSession, RSCMU_Status, errorMessage);
//
//  // Read the resulting output
//  if ((RSCMU_Status = RSCMU_Read (instrSession, rdBuf, RD_BUFFER_SIZE_ARRAY, errorMessage)) < 0)
//    return RSCMU_Base_errorMessage (instrSession, RSCMU_Status, errorMessage);
//
//  // Find all values by breaking the read buffer:
//  StrValue = strtok(rdBuf, ",");
//
//  while (StrValue)
//  {
//    if (strcmp (StrValue, "NAN") != 0)
//      sscanf (StrValue, "%lf", &Values[Index]);
//    else Values[Index] = RSCMU_NAN;
//
//    StrValue = strtok (NULL, ",");
//
//    Index++;
//  }
//
//  return RSCMU_Status;
//}

/*===========================================================================*/
/* Function: Measurement scalar
/* Purpose : This function starts the measurement and outputs some results.
/*===========================================================================*/
ViStatus RSCMU_MeasSpecModSwitch (ViSession  instrSession,
                                  ViInt32    command,
                                  ViReal64  *refPowMod,
                                  ViInt32   *matchingMod,
                                  ViReal64  *refPowSwitch,
                                  ViInt32   *matchingSwitch,
                                  ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      tab[100][100];
  GET_BUFS(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  sprintf (wrtBuf, "%s:SCALar:SPECtrum:MSWitching?", StrCommand[command]);
  CHECKRETMSG(RSCMU_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%lf", refPowMod);
  else *refPowMod = RSCMU_NAN;

  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%lf", refPowSwitch);
  else *refPowSwitch = RSCMU_NAN;

  RSCMU_Status = RSCMU_GetMatchingValue (matchingMod,tab, 2);

  RSCMU_Status = RSCMU_GetMatchingValue (matchingSwitch,tab, 3);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Variable Measure Points
/*===========================================================================*/
ViStatus RSCMU_MeasSpecVarMeaPoint (ViSession instrSession,
                                    ViChar    *StrCommand,
                                    ViInt32   nr,
                                    ViInt32   enable,
                                    ViReal64  frequencyMHz,
                                    ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_50,RSCMU_ERROR_FW_VERSION_3_50));

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, nr, RSCMU_MPO1, RSCMU_MPO4, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, enable, RSCMU_OFF, RSCMU_ON, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, frequencyMHz, -2.5, 2.5, RSCMU_ERROR_PARAMETER4, errorMessage);

  if (enable == RSCMU_OFF)
    sprintf (wrtBuf, "%s%d %s", StrCommand, nr, mode_On_Off[enable]);
  else
    sprintf (wrtBuf, "%s%d %lf", StrCommand, nr, frequencyMHz);

  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}


/*===========================================================================*/
/* Function: Modulation IQAN measurement (scalar)
/* Purpose : this function is called by the Read, Fetch and Sample modulation
/*           IQA measurements
/*===========================================================================*/
ViStatus RSCMU_MeasIqanScalarSig (ViSession  instrSession,
                               ViChar    *StrCommand,
                               ViReal64  *EvmRMS,
                               ViReal64  *MerrRMS,
                               ViReal64  *PerrRMS,
                               ViReal64  *TimeErr,
                               ViReal64  *AvgBurstPow,
                               ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      Tab[100][100];

  sprintf (wrtBuf, "%s?", StrCommand);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", Tab);

  // Get the EVM RMS:
  if (strcmp (Tab[0], "NAN") != 0)
    sscanf (Tab[0], "%lf", EvmRMS);
  else *EvmRMS = RSCMU_NAN;

  // Get the MERR RMS:
  if (strcmp (Tab[1], "NAN") != 0)
    sscanf (Tab[1], "%lf", MerrRMS);
  else *MerrRMS = RSCMU_NAN;

  // Get the MERR RMS:
  if (strcmp (Tab[2], "NAN") != 0)
    sscanf (Tab[2], "%lf", PerrRMS);
  else *PerrRMS = RSCMU_NAN;

  // Get the Timing Error:
  if (strcmp (Tab[3], "NAN") != 0)
    sscanf (Tab[3], "%lf", TimeErr);
  else *TimeErr = RSCMU_NAN;

  // Get the Average Burst Power:
  if (strcmp (Tab[4], "NAN") != 0)
    sscanf (Tab[4], "%lf", AvgBurstPow);
  else *AvgBurstPow = RSCMU_NAN;

  return RSCMU_Status;
}
ViStatus RSCMU_MeasIqanScalarNSig (ViSession  instrSession,
                               ViChar    *StrCommand,
                               ViReal64  *EvmRMS,
                               ViReal64  *MerrRMS,
                               ViReal64  *PerrRMS,
                               ViReal64  *AvgBurstPow,
                               ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      Tab[100][100];

  sprintf (wrtBuf, "%s?", StrCommand);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Split the multiple data values separated by a comma:
  RSCMU_SeparateDataValues (rdBuf, ",", Tab);

  // Get the EVM RMS:
  if (strcmp (Tab[0], "NAN") != 0)
    sscanf (Tab[0], "%lf", EvmRMS);
  else *EvmRMS = RSCMU_NAN;

  // Get the MERR RMS:
  if (strcmp (Tab[1], "NAN") != 0)
    sscanf (Tab[1], "%lf", MerrRMS);
  else *MerrRMS = RSCMU_NAN;

  // Get the MERR RMS:
  if (strcmp (Tab[2], "NAN") != 0)
    sscanf (Tab[2], "%lf", PerrRMS);
  else *PerrRMS = RSCMU_NAN;

  // Get the Average Burst Power:
  if (strcmp (Tab[4], "NAN") != 0)
    sscanf (Tab[4], "%lf", AvgBurstPow);
  else *AvgBurstPow = RSCMU_NAN;

  return RSCMU_Status;
}


/*===========================================================================*/
/* Function: Measurement SubArray
/* Purpose : This outputs the different power values at user defined measure
/*           points.
/*===========================================================================*/
ViStatus RSCMU_MeasSubArrSpecSwit (ViSession instrSession,
                                   ViInt32   command,
                                   ViInt32   modulation,
                                   ViReal64  BurstPower[],
                                   ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE_ARRAY] = "";
  ViInt32     NbOfMeasValues;
  ViChar      BurstPowerTmp[32][20];

  sprintf (wrtBuf, "%s:ARR:SPEC:SWIT%s?", StrCommand[command], StrModulation[modulation]);
  if ((RSCMU_Status = RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Find all burst power values by breaking the read buffer:
  NbOfMeasValues = RSCMU_scanStringBurst (rdBuf, BurstPowerTmp);

  RSCMU_Status = RSCMU_ReturnCMUResponse (NbOfMeasValues, BurstPowerTmp, BurstPower);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Reference Power
/* Purpose : This function defines the MS carrier output power domain where
/*           the limit lines are to be determined by linear interpolation
/*           (see Table 1). Below Min. Power, the lower limit line applies,
/*           above Max. Power, the upper limit line applies.
/*===========================================================================*/
ViStatus RSCMU_ConfSpecModLimLineRefp (ViSession instrSession,
                                       ViInt32   modulation,
                                       ViReal64  minPower,
                                       ViReal64  maxPower,
                                       ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  sprintf (wrtBuf, "CONF:SPEC:MOD%s:LIM:LINE:REFP %lf,%lf", StrModulation[modulation], minPower, maxPower);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Limit Lines
/* Purpose : These commands activate and define limit lines for the spectrum
/*           due to modulation measurement.
/*           The limit lines for the spectrum due to modulation as specified
/*           in standard GSM 05.05 depend on the GSM band, the frequency, and
/*           (for frequencies that differ from the carrier frequency by more
/*           than 400 kHz) on the output power of the mobile station.
/*===========================================================================*/
ViStatus RSCMU_ConfSpecModLimLine (ViSession instrSession,
                                   ViInt32   modulation,
                                   ViInt32   measurePoint,
                                   ViInt32   enable,
                                   ViReal64  minPower,
                                   ViReal64  maxPower,
                                   ViReal64  AbsLevel,
                                   ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, measurePoint, RSCMU_0_10MHZ, RSCMU_1_80MHZ, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) enable, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD%s:LIM:LINE:UPP%d %lf,%lf,%lf,%s", StrModulation[modulation]
                                                                  , measurePoint
                                                                  , minPower
                                                                  , maxPower
                                                                  , AbsLevel
                                                                  , mode_On_Off[enable]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Limit Lines On/Off
/* Purpose : This function switches the limit checking for all measurepoints.
/*===========================================================================*/
ViStatus RSCMU_ConfSpecModLimLineMod (ViSession instrSession,
                                      ViInt32   modulation,
                                      ViInt32   limitLines,
                                      ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";

  // Check if the function is correctly used:
  CHECK_VI_BOOLEAN_RANGE(instrSession, (ViBoolean) (ViBoolean) limitLines, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD%s:LIM:LINE:MODE %s", StrModulation[modulation], mode_On_Off[limitLines]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Measure Points
/* Purpose : This function permits to select which frequencies a spectrum
/*           modulation measurement is performed. A reduction of the
/*           measurement points enhances the measurement speed.
/*===========================================================================*/
ViStatus RSCMU_ConfSpecModContMpo (ViSession  instrSession,
                                   ViInt32    modulation,
                                   ViInt32    MeasurePoint,
                                   ViInt32    Enable,
                                   ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";


  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, MeasurePoint, RSCMU_MPO1, RSCMU_MPO11, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, Enable, RSCMU_OFF, RSCMU_ON, RSCMU_ERROR_PARAMETER3, errorMessage);

  sprintf (wrtBuf, "CONF:SPEC:MOD%s:CONT:MPO%d:ENAB %s", StrModulation[modulation], MeasurePoint, mode_On_Off[Enable]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Measurement scalar
/* Purpose : This function starts the measurement and outputs some results.
/*===========================================================================*/
ViStatus RSCMU_MeasSpecMod (ViSession  instrSession,
                            ViInt32    command,
                            ViInt32    modulation,
                            ViReal64  *referencePower,
                            ViInt32   *matching,
                            ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  sprintf (wrtBuf, "%s:SPEC:MOD%s?", StrCommand[command], StrModulation[modulation]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the Average Burst Power
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%lf", referencePower);
  else *referencePower = RSCMU_NAN;

  // Get the matching
  RSCMU_Status = RSCMU_GetMatchingValue (matching,tab, 1);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Set Filter
/* Purpose : This function selects the measurement filter. The default filter
/*           setting differs for the two modulation schemes.
/*===========================================================================*/
ViStatus RSCMU_ConfFilt (ViSession instrSession,
                         ViInt32   Command,
                         ViInt32   Modulation,
                         ViInt32   Filter,
                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViString    StrFilter[] = {"G500","B600","G1000"};
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_05)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_05, errorMessage);

  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, Filter, 0, 2, RSCMU_ERROR_PARAMETER2, errorMessage);

  sprintf (wrtBuf, "CONF%s%s:FILT %s", StrObject[Command]
                                     , StrModulation[Modulation]
                                     , StrFilter[Filter]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Check for the minimum firmware version required
/* Purpose : This function checks if the firmware required is present
/*===========================================================================*/
ViStatus RSCMU_CheckMinFwVersion (ViSession  instrSession,
                                  ViInt32    FwVersion,
                                  ViInt32    Error,
                                  ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < FwVersion)
    return RSCMU_Base_errorMessage(instrSession, Error, errorMessage);

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Measurement scalar for narrow-band power
/* Purpose : This function starts the measurement and outputs the results.
/*===========================================================================*/
ViStatus RSCMU_MeasNpow (ViSession  instrSession,
                         ViInt32    command,
                         ViReal64  *AvgPowCurr,
                         ViReal64  *MinPowCurr,
                         ViReal64  *MaxPowCurr,
                         ViReal64  *AvgPowAvg,
                         ViReal64  *MinPowAvg,
                         ViReal64  *MaxPowAvg,
                         ViChar     errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "", rdBuf[RD_BUFFER_SIZE]= "";
  ViChar      tab[100][100];

  sprintf (wrtBuf, "%s:NPOW?", StrCommand[command]);
  if ((RSCMU_Status = RSCMU_Query (instrSession, wrtBuf, rdBuf, RSCMU_STB_ON, errorMessage)) < 0)
    return RSCMU_Status;

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get the Average Power of Current Burst
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%lf", AvgPowCurr);
  else *AvgPowCurr = RSCMU_NAN;

  // Get the Minimum Power of Current Burst
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%lf", MinPowCurr);
  else *MinPowCurr = RSCMU_NAN;

  // Get the Maximum Power of Current Burst
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%lf", MaxPowCurr);
  else *MaxPowCurr = RSCMU_NAN;

  // Get the Average Power of Average Burst
  if (strcmp (tab[3], "NAN") != 0)
    sscanf (tab[3], "%lf", AvgPowAvg);
  else *AvgPowAvg = RSCMU_NAN;

  // Get the Minimum Power of Average Burst
  if (strcmp (tab[4], "NAN") != 0)
    sscanf (tab[4], "%lf", MinPowAvg);
  else *MinPowAvg = RSCMU_NAN;

  // Get the Maximum Power of Average Burst
  if (strcmp (tab[5], "NAN") != 0)
    sscanf (tab[5], "%lf", MaxPowAvg);
  else *MaxPowAvg = RSCMU_NAN;

  return RSCMU_Status;
}

/*===========================================================================*/
/* Function: RSCMU_ScanSensRfer
/* Purpose : Extracts the results in Sensitivity RFER
/*===========================================================================*/
ViStatus RSCMU_ScanSensRfer (ViChar    tab [100][100],
                             ViInt32   i_StartingIndex,
                             ViPReal64 progressTime,
                             ViPReal64 RBERClass2Bits,
                             ViPReal64 RBERClass1bBits,
                             ViPReal64 frameErasureRate,
                             ViPInt32  CRCerrors,
                             ViPInt32  measurementStatus)
{
  // Get the number of frames evaluated
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%lf", progressTime);
  else *progressTime = RSCMU_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 1], "%lf", RBERClass2Bits);
  else *RBERClass2Bits = RSCMU_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 2], "%lf", RBERClass1bBits);
  else *RBERClass1bBits = RSCMU_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 3], "%lf", frameErasureRate);
  else *frameErasureRate = RSCMU_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 4], "%d", CRCerrors);
  else *CRCerrors = RSCMU_NAN_VI_INT32;

  // Get the measurement status
  return RSCMU_GetSensMeasStatVal (measurementStatus, tab, i_StartingIndex + 5);
}

/*===========================================================================*/
/* Function: RSCMU_ScanSensBer
/* Purpose : Extracts the results in Sensitivity BER
/*===========================================================================*/
ViStatus RSCMU_ScanSensBer (ViChar    tab [100][100],
                            ViInt32   i_StartingIndex,
                            ViPReal64 progressTime,
                            ViPReal64 BERClass2Bits,
                            ViPReal64 BERClass1bBits,
                            ViPInt32  CRCerrors,
                            ViPInt32  measurementStatus)
{
  // Get the number of frames evaluated
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%lf", progressTime);
  else  *progressTime = RSCMU_NAN;
  // Get the bit error rate for class 2 Bits
  if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 1], "%lf", BERClass2Bits);
  else  *BERClass2Bits = RSCMU_NAN;
  // Get the bit error rate for class 1b Bits
  if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 2], "%lf", BERClass1bBits);
  else  *BERClass1bBits = RSCMU_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 3], "%d", CRCerrors);
  else  *CRCerrors = RSCMU_NAN_VI_INT32;

  // Get the measurement status
  return RSCMU_GetSensMeasStatVal (measurementStatus, tab, i_StartingIndex + 4);
}

/*===========================================================================*/
/* Function: RSCMU_ScanSensBbb
/* Purpose : Extracts the results in Sensitivity Burst By Burst
/*===========================================================================*/
ViStatus RSCMU_ScanSensBbb (ViChar    tab [100][100],
                            ViInt32   i_StartingIndex,
                            ViPReal64 progressTime,
                            ViPReal64 Ber,
                            ViPInt32  CRCerrors,
                            ViPInt32  measurementStatus)
{
  // Get the number of frames evaluated
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%lf", progressTime);
  else *progressTime = RSCMU_NAN;
  // Get the bit error rate
  if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 1], "%lf", Ber);
  else *Ber = RSCMU_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 2], "%d", CRCerrors);
  else *CRCerrors = RSCMU_NAN_VI_INT32;

  // Get the measurement status
  return RSCMU_GetSensMeasStatVal (measurementStatus, tab, i_StartingIndex + 3);
}

/*===========================================================================*/
/* Function: RSCMU_ScanSensDbler
/* Purpose : Extracts the results in Sensitivity DBler
/*===========================================================================*/
ViStatus RSCMU_ScanSensDbler (ViChar    tab [100][100],
                              ViInt32   i_StartingIndex,
                              ViPReal64 progressTime,
                              ViPReal64 Ber,
                              ViPReal64 Usfbler,
                              ViPReal64 dbler,
                              ViPInt32  CRCerrors,
                              ViPInt32  measurementStatus)
{
  // Get the number of frames evaluated
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%lf", progressTime);
  else *progressTime = RSCMU_NAN;
  // Get the bit error rate
  if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 1], "%lf", Ber);
  else *Ber = RSCMU_NAN;

  // Get the USF BLER
  if (strcmp (tab[i_StartingIndex + 2], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 2], "%lf", Usfbler);
  else *Usfbler = RSCMU_NAN;

//  *Usfbler = RSCMU_NAN;   // Documented but missing in FW 3.05

  // Get the DBLER
  if (strcmp (tab[i_StartingIndex + 3], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 3], "%lf", dbler);
  else *dbler = RSCMU_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[i_StartingIndex + 4], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 4], "%d", CRCerrors);
  else *CRCerrors = RSCMU_NAN_VI_INT32;

  // Get the measurement status
  return RSCMU_GetSensMeasStatVal (measurementStatus, tab, i_StartingIndex + 5);
}

/*===========================================================================*/
/* Function: RSCMU_ScanSensRfer
/* Purpose : Extracts the results in Sensitivity RFER
/*===========================================================================*/
ViStatus RSCMU_ScanSensAibf (ViChar    tab [100][100],
                             ViInt32   i_StartingIndex,
                             ViPReal64 progressTime,
                             ViPReal64 frameErasureRate,
                             ViPInt32  measurementStatus)
{
  // Get the number of frames evaluated
  if (strcmp (tab[i_StartingIndex], "NAN") != 0)
    sscanf (tab[i_StartingIndex], "%lf", progressTime);
  else *progressTime = RSCMU_NAN;
  // Get the number of Cyclic redundancy errors
  if (strcmp (tab[i_StartingIndex + 1], "NAN") != 0)
    sscanf (tab[i_StartingIndex + 1], "%lf", frameErasureRate);
  else *frameErasureRate = RSCMU_NAN;
  // Get the number of Cyclic redundancy errors

  // Get the measurement status
  return RSCMU_GetSensMeasStatVal (measurementStatus, tab, i_StartingIndex + 2);
}

/*===========================================================================*/
/* Function: Spectrum Switching continuous statistical mode
/* Purpose : This function defines the continuous statistical mode for the
/*           Spectrum due to Switching measurement.
/*===========================================================================*/
ViStatus RSCMU_ConfSpecSwitContStatMod (ViSession  instrSession,
                                        ViInt32    Modulation,
                                        ViInt32    continuousStatisticalMode,
                                        ViChar     errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      wrtBuf[WR_BUFFER_SIZE];
    ViString    list[] = {"PHOL","SCO", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, continuousStatisticalMode, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf (wrtBuf, "CONF:SPEC:SWIT%s:CSM %s", StrModulation[Modulation], list[continuousStatisticalMode]);

    RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Spectrum Switching Slot Count
/* Purpose : This function defines whether a single timeslot or all timeslots
/*           are considered for the Spectrum due to Switching measurement..
/*===========================================================================*/
ViStatus RSCMU_ConfSpecSwitSlotCount (ViSession  instrSession,
                                      ViInt32    Modulation,
                                      ViInt32    slotCount,
                                      ViChar     errorMessage[])
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViChar      wrtBuf[WR_BUFFER_SIZE];
    ViString    list[] = {"SSL","MSL", VI_NULL};

    // Version manager
    CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_10,RSCMU_ERROR_FW_VERSION_3_10));

    // Check if the function is correctly used:
    CHECK_VI_INT32_RANGE(instrSession, slotCount, 0, 1, RSCMU_ERROR_PARAMETER2, errorMessage);

    sprintf (wrtBuf, "CONF:SPEC:SWIT%s:SCO %s", StrModulation[Modulation], list[slotCount]);

    RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: All Measured Values
/* Purpose : This function start a measurement and output all scalar,
/*           numeric measurement results.
/*===========================================================================*/
ViStatus RSCMU_MeasBler (ViSession instrSession, ViInt32   command,
                                                 ViReal64 *progressTime,
                                                 ViReal64 *BLEROverall,
                                                 ViReal64 *RLCBlocksOverall,
                                                 ViReal64  BLER[],
                                                 ViReal64  RLCBlocks[],
                                                 ViReal64 *dataRateOverall,
                                                 ViReal64  dataRate[],
                                                 ViReal64 *longThermThroughput,
                                                 ViReal64 *longThermThroughputSlot,
                                                 ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      rdBuf[RD_BUFFER_SIZE] = "";
  ViChar      wrtBuf[WR_BUFFER_SIZE] = "";
  ViChar      tab[100][100];
  ViInt32     i;
  struct      RSCMU_SESSION_Globals  *p_globalvarBase;

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_10)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_10, errorMessage);

  sprintf (wrtBuf, "%s:RXQ:BLER?", StrCommand[command]);

  CHECKRETMSG(RSCMU_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  // Separate the CMU response:
  RSCMU_SeparateDataValues (rdBuf, ",", tab);

  // Get
  if (strcmp (tab[0], "NAN") != 0)
    sscanf (tab[0], "%lf", progressTime);
  else *progressTime = RSCMU_NAN;
    // Get
  if (strcmp (tab[1], "NAN") != 0)
    sscanf (tab[1], "%lf", BLEROverall);
  else *BLEROverall = RSCMU_NAN;
  // Get
  if (strcmp (tab[2], "NAN") != 0)
    sscanf (tab[2], "%lf", RLCBlocksOverall);
  else *RLCBlocksOverall = RSCMU_NAN;
  // Get
  for (i=0; i<8; i++)
  {
    // Get
    if (strcmp (tab[i*2+3], "NAN") != 0)
      sscanf (tab[i*2+3], "%lf", &BLER[i]);
    else BLER[i] = RSCMU_NAN;
  // Get
  if (strcmp (tab[i*2+4], "NAN") != 0)
    sscanf (tab[i*2+4], "%lf", &RLCBlocks[i]);
  else RLCBlocks[i] = RSCMU_NAN;
  }
  // Get
  if (strcmp (tab[19], "NAN") != 0)
    sscanf (tab[19], "%lf", dataRateOverall);
  else *dataRateOverall = RSCMU_NAN;

  if (p_globalvarBase->RSCMU_FW_Version > RSCMU200_V3_10)
    {
    for (i=0; i<8; i++)
      {
        // Get
        if (strcmp (tab[i+19], "NAN") != 0)
          sscanf (tab[i+19], "%lf", &dataRate[i]);
        else dataRate[i] = RSCMU_NAN;
      }
      if (p_globalvarBase->RSCMU_FW_Version >= RSCMU200_V3_50)
        {
        // Get longTermThroughput
        if (strcmp (tab[28], "NAN") != 0)
          sscanf (tab[28], "%lf", longThermThroughput);
        else *longThermThroughput = RSCMU_NAN;

        // Get longTermThroughputSlot
        if (strcmp (tab[29], "NAN") != 0)
          sscanf (tab[29], "%lf", longThermThroughputSlot);
        else *longThermThroughputSlot = RSCMU_NAN;
        }
    else
      {
      *longThermThroughput = RSCMU_NAN;
      *longThermThroughputSlot = RSCMU_NAN;
      }
    }
  else
    {
    for (i=0; i<8; i++)
      {
        dataRate[i] = RSCMU_NAN;
      }
    }

  return RSCMU_Status;
}


/*===========================================================================*/
/* Function: Configure Additional Measurepoints
/* Purpose : This function permits to configure the frequencies for two
/*           additional Measurepoints for spectrum switching measurement.
/*===========================================================================*/
ViStatus RSCMU_ConfSpecSwitAddMeaPoints (ViSession instrSession,
                                         ViInt32   modulation,
                                         ViInt32   enableMP1,
                                         ViReal64  frequencyMP1,
                                         ViInt32   enableMP2,
                                         ViReal64  frequencyMP2,
                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar      freqMP1Buf[64]= "", freqMP2Buf[64]= "";

  GET_WRT_BUF(instrSession);

  // Version manager
  CHECKRETMSG(RSCMU_checkVersion(instrSession,RSCMU200_V3_20,RSCMU_ERROR_FW_VERSION_3_20));


  // Check if the function is correctly used:
  CHECK_VI_INT32_RANGE(instrSession, modulation, RSCMU_GMSK, RSCMU_EPSK, RSCMU_ERROR_PARAMETER2, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, enableMP1, RSCMU_OFF, RSCMU_ON, RSCMU_ERROR_PARAMETER3, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, frequencyMP1, 0.0, 1.80, RSCMU_ERROR_PARAMETER4, errorMessage);
  CHECK_VI_INT32_RANGE(instrSession, enableMP2, RSCMU_OFF, RSCMU_ON, RSCMU_ERROR_PARAMETER5, errorMessage);
  CHECK_VI_REAL64_RANGE(instrSession, frequencyMP2, 0.0, 1.80, RSCMU_ERROR_PARAMETER6, errorMessage);

  if (enableMP1 == RSCMU_ON)
    sprintf(freqMP1Buf, "%lf", frequencyMP1);
  else sprintf(freqMP1Buf, "%s", "OFF");

  if (enableMP2 == RSCMU_ON)
    sprintf(freqMP2Buf, "%lf", frequencyMP2);
  else sprintf(freqMP2Buf, "%s", "OFF");

  sprintf (wrtBuf, "CONFigure:SPECtrum:SWITching%s:AMPoints:FREQuency %s, %s", StrModulation[modulation], freqMP1Buf,freqMP2Buf);
  RETMSG(RSCMU_sendCmd(instrSession, wrtBuf));
}

/*===========================================================================*/
/* Function: Fetch scalar results for Additional Measurepoints
/* Purpose : This function output the off-carrier power due to switching
/*           in the additional Measurepoints.
/*===========================================================================*/
ViStatus RSCMU_FetcSpecSwitAddMeaPoints (ViSession instrSession,
                                         ViInt32   modulation,
                                         ViReal64  *valueMP1Neg,
                                         ViReal64  *valueMP1Pos,
                                         ViReal64  *valueMP2Neg,
                                         ViReal64  *valueMP2Pos,
                                         ViChar    errorMessage[])
{
  ViStatus    RSCMU_Status = VI_SUCCESS;
  ViChar*     str;
  struct   RSCMU_SESSION_Globals  *p_globalvarBase;
  GET_BUFS(instrSession);

  // Version manager
  if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
    return RSCMU_Status;

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_20)
    return RSCMU_Base_errorMessage(instrSession, RSCMU_ERROR_FW_VERSION_3_20, errorMessage);

  if (p_globalvarBase->RSCMU_FW_Version < RSCMU200_V3_40)
  {
  sprintf(wrtBuf, "FETCh:SCALar:SPECtrum:SWITching%s:AMPoints:POWer?", StrModulation[modulation]);
  }
  else
  {
  sprintf(wrtBuf, "FETCh:ARRay:SPECtrum:SWITching%s:AMPoints:POWer?", StrModulation[modulation]);
  }
  CHECKRETMSG(RSCMU_getViString(instrSession,wrtBuf,rdBuf,RD_BUFFER_SIZE,0));

  GET_VI_REAL64(*valueMP1Neg,rdBuf);
  GET_VI_REAL64(*valueMP2Neg,NULL);
  GET_VI_REAL64(*valueMP1Pos,NULL);
  GET_VI_REAL64(*valueMP2Pos,NULL);

  return RSCMU_Status;
}


/*###########################################################################*/
/*                                                                           */
/*  VXI PLUG & PLAY COMPATIBILITY FUNCTIONS                                  */
/*                                                                           */
/*  These functions provide a VXIplug&play compatibily of this instrument    */
/*  driver with regard to the following documents:                           */
/*                                                                           */
/*  VPP-3.1: Instrument Drivers                                              */
/*      Architecture and Design                                              */
/*      Specification                                                        */
/*      Revision 4.0                                                         */
/*      February 5, 1996                                                     */
/*                                                                           */
/*  VPP-3.2: Instrument Driver                                               */
/*      Functional Body Specification                                        */
/*      Revision 4.0                                                         */
/*      February 2, 1996                                                     */
/*                                                                           */
/*  By: Jan Sima, ELCOM, a.s., Czech Republic                                */
/*                                                                           */
/*###########################################################################*/
#ifndef _REMVXIPNP

#include <errno.h>

/*===========================================================================*/
/* Function: RSCMU_GSM_NSig_GetResourceName                                  */
/* Purpose:  This function returns resource descriptor for GSM NSig option.  */
/*           Session parameter must contain at least 256 elements ViChar[256]*/
/*===========================================================================*/

ViStatus _VI_FUNC RSCMU_GSM_NSig_GetResourceName (ViSession instrSession,
                                                  ViSession instrSessionBase,
                                                  ViChar _VI_FAR sessionName[])

{
    ViStatus    RSCMU_Status    = VI_SUCCESS;
    ViInt32     comp;
    struct RSCMU_Base_Globals  *p_globalvarBase;
    struct RSCMU_GSM_NSig_Globals  *p_globalvarGSM;

    /* Get a copy of the global data for base session. */
   if( (RSCMU_Status = viGetAttribute( instrSessionBase
                                     , VI_ATTR_USER_DATA
                                     , (ViAddr)&p_globalvarBase
                                     )) < VI_SUCCESS )
   {
      return RSCMU_Status;
   }

   /* Get a copy of the global data for this session. */
   if( (RSCMU_Status = viGetAttribute( instrSession
                                     , VI_ATTR_USER_DATA
                                     , (ViAddr)&p_globalvarGSM
                                     )) < VI_SUCCESS )
   {
      return RSCMU_Status;
   }

      // Hardware Connection
      comp = strncmp( "GPIB"
                    , p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection
                    , 4
                    );

    if( comp == 0 )
      {
         sprintf( sessionName
                , "%s::%d::%d::INSTR"
                , p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection
                , p_globalvarBase->RSCMU_tGlobal.RSCMU_primary_address
                , p_globalvarGSM->RSCMU_tGlobal.RSCMU_secondary_address
                );
      }
      else
      {
         sprintf( sessionName
                , "%s::INSTR"
                , p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection
                );
      }

    return RSCMU_Status;
}

/*===========================================================================*/
/* Function: RSCMU_GSM_Sig_GetResourceName                                   */
/* Purpose:  This function returns resource descriptor for GSM Sig option .  */
/*           Session parameter must contain at least 256 elements ViChar[256]*/
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GSM_Sig_GetResourceName (ViSession instrSession,
                                                  ViSession instrSessionBase,
                                                  ViChar _VI_FAR sessionName[])

{
    ViStatus    RSCMU_Status    = VI_SUCCESS;
    ViInt32     comp;
    struct RSCMU_Base_Globals  *p_globalvarBase;
    struct RSCMU_GSM_Sig_Globals  *p_globalvarGSM;

    /* Get a copy of the global data for base session. */
   if( (RSCMU_Status = viGetAttribute( instrSessionBase
                                     , VI_ATTR_USER_DATA
                                     , (ViAddr)&p_globalvarBase
                                     )) < VI_SUCCESS )
   {
      return RSCMU_Status;
   }

   /* Get a copy of the global data for this session. */
   if( (RSCMU_Status = viGetAttribute( instrSession
                                     , VI_ATTR_USER_DATA
                                     , (ViAddr)&p_globalvarGSM
                                     )) < VI_SUCCESS )
   {
      return RSCMU_Status;
   }

      // Hardware Connection
      comp = strncmp( "GPIB"
                    , p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection
                    , 4
                    );

    if( comp == 0 )
      {
         sprintf( sessionName
                , "%s::%d::%d::INSTR"
                , p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection
                , p_globalvarBase->RSCMU_tGlobal.RSCMU_primary_address
                , p_globalvarGSM->RSCMU_tGlobal.RSCMU_secondary_address
                );
      }
      else
      {
         sprintf( sessionName
                , "%s::INSTR"
                , p_globalvarBase->RSCMU_tGlobal.RSCMU_SCPIConnection
                );
      }
    return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Initialize                                                      */
/* Purpose:  This function opens the instrument, queries the instrument      */
/*           for its ID, and initializes the instrument to a known state.    */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_init (ViRsrc resourceName, ViBoolean IDQuery,
                    ViBoolean resetDevice, ViPSession instrSession)
{
    ViStatus    RSCMU_status = VI_SUCCESS;
    ViString    p2str;
    ViInt32     board = 0,
                primaryAddr = 0,
                secondaryAddr = 0;
    ViChar      errorMessage[WR_BUFFER_SIZE];
    ViSession   rmHandle;

    p2str = resourceName;

    if (strncmp (p2str, "GPIB", 4) != 0)
        return VI_ERROR_INV_RSRC_NAME;

    p2str += 4;

    if (p2str[0] >= '0' && p2str[0] <= '9')
        board = (p2str++)[0] - '0';

    if (strncmp (p2str, "::", 2) != 0)
        return VI_ERROR_INV_RSRC_NAME;

    primaryAddr = atoi (p2str += 2);
    if (errno != 0)
        return VI_ERROR_INV_RSRC_NAME;

    p2str += (primaryAddr > 9) ? 2 : 1;

    if (strlen (p2str) != 0 && strncmp (p2str, "::", 2) != 0)
        return VI_ERROR_INV_RSRC_NAME;

    if (strlen (p2str) != 0) {
        secondaryAddr = atoi (p2str += 2);
        if (errno != 0)
            return VI_ERROR_INV_RSRC_NAME;

        p2str += (secondaryAddr > 9) ? 2 : 1;

        if (strlen (p2str) != 0 && strcmp (p2str, "::INSTR") != 0)
            return VI_ERROR_INV_RSRC_NAME;
    }

    if (secondaryAddr == 0) {
        if ((RSCMU_status = RSCMU_Init_Base (instrSession, RSCMU_GPIB, board, primaryAddr,
                                             IDQuery, resetDevice, errorMessage)) < 0)
            return RSCMU_status;
    } else {
        if ((RSCMU_status = viOpenDefaultRM (&rmHandle)) != 0)
            return RSCMU_status;

        if ((RSCMU_status = viOpen (rmHandle, resourceName, VI_NULL, VI_NULL, instrSession)) != 0)
            return RSCMU_status;

        if ((RSCMU_status = viGpibControlREN (*instrSession, VI_GPIB_REN_ASSERT)) < 0)
            return RSCMU_status;
    }

    return RSCMU_status;
}

/*===========================================================================*/
/* Function: Init GSM Non Signalling                                         */
/* Purpose:  This function initializes the GSM non signalling module's       */
/*           global data structures. This function is used in VEE where this */
/*           can not be a part of the VXIpnp init function.                  */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_initGSMNSig (ViSession  instrSession,
                                    ViSession   BaseSession,
                                    ViUInt32    GSMFunctionGpr)
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViSession   globalSession = 0;
    ViInt32     secondAddr = 0, comp = 1;
    ViChar      FctGrpBuffer[128]= "";
    ViReal64    Flag = RSCMU_OFF;
    ViChar      errorMessage[WR_BUFFER_SIZE];

    struct RSCMU_Base_Globals     *p_globalvarBase;
    struct RSCMU_GSM_NSig_Globals  *p_globalvarGSM;

    // Which Fonction Group does the User want?
    switch (GSMFunctionGpr)
    {
      case RSCMU_GSM400:
        strcpy (FctGrpBuffer, "\"GSM400MS_NSig\"");
        break;
      case RSCMU_GSM900:
        strcpy (FctGrpBuffer, "\"GSM900MS_NSig\"");
        break;
      case RSCMU_GSM1800:
        strcpy (FctGrpBuffer, "\"GSM1800MS_NSig\"");
        break;
      case RSCMU_GSM1900:
        strcpy (FctGrpBuffer, "\"GSM1900MS_NSig\"");
        break;
      case RSCMU_GSMGT800:
        strcpy (FctGrpBuffer, "\"GSMGT800MS_NSig\"");
        break;      
    }

    // Init the Error Message
    strcpy (errorMessage, "No Error");

    // Get the current options (= Function Group Names) in the CMU.
    if ((RSCMU_Status = viGetAttribute (BaseSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvarBase)) < 0)
      return RSCMU_K2G_errorMessage (BaseSession, RSCMU_Status, errorMessage);

    // Find the Secondary address for GSM_NSig
    while ((comp != 0) && (secondAddr < 30))
    {
      comp = strncmp (p_globalvarBase->RSCMU_tSecAddr[secondAddr].FctGrp, FctGrpBuffer, strlen(FctGrpBuffer));
      secondAddr++;
      if (comp == 0)  Flag = RSCMU_ON;
    }

    if (Flag == RSCMU_OFF)
      return RSCMU_Base_errorMessage (instrSession, RSCMU_ERROR_INVALID_FCT_GRP, errorMessage);

    // Allocate space for "struct RSCMU_SESSION_Globals"
    if ((p_globalvarGSM = (struct RSCMU_GSM_NSig_Globals *)malloc(sizeof(struct RSCMU_GSM_NSig_Globals))) == 0)
      return RSCMU_initCleanUp (globalSession, instrSession, RSCMU_Status);

    if ((RSCMU_Status = viSetAttribute(instrSession, VI_ATTR_USER_DATA,(ViAttrState)p_globalvarGSM)) < 0)
      return RSCMU_initCleanUp (globalSession, instrSession, RSCMU_Status);

    // Set initial values of variables for function Group 'GSM_NonSig' .
    strcpy (p_globalvarGSM->RSCMU_tGlobal.FGrp_Name, FctGrpBuffer);
    p_globalvarGSM->RSCMU_tGlobal.RSCMU_primary_address = p_globalvarBase->RSCMU_tGlobal.RSCMU_primary_address;
    p_globalvarGSM->RSCMU_tGlobal.RSCMU_secondary_address = secondAddr - 1;
    p_globalvarGSM->RSCMU_tGlobal.RSCMU_TRACE = p_globalvarBase->RSCMU_tGlobal.RSCMU_TRACE;
    p_globalvarGSM->RSCMU_tGlobal.RSCMU_TRACE = p_globalvarBase->RSCMU_tGlobal.RSCMU_TRACE;
    // Base CMU FW available
    strcpy (p_globalvarGSM->RSCMU_tGlobal.CmuVersion, p_globalvarBase->RSCMU_tGlobal.CmuVersion);
    if (p_globalvarGSM->RSCMU_tGlobal.RSCMU_TRACE == RSCMU_ON)
      p_globalvarGSM->RSCMU_tGlobal.RSCMU_AddrTargetFile = p_globalvarBase->RSCMU_tGlobal.RSCMU_AddrTargetFile;

    // Record the execution of this Init Function.
    p_globalvarBase->RSCMU_tSecAddr[secondAddr - 1].SessionNb = instrSession;

    // Timeout changed from 10s to 30 seconds
    if ((RSCMU_Status = viSetAttribute (instrSession, VI_ATTR_TMO_VALUE, RSCMU_TMO_VALUE)) < 0)
      return RSCMU_Status;

    return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Init GSM Signalling                                             */
/* Purpose:  This function initializes the GSM signalling module's           */
/*           global data structures. This function is used in VEE where this */
/*           can not be a part of the VXIpnp init function.                  */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_initGSMSig (ViSession   instrSession,
                                    ViSession   BaseSession,
                                    ViUInt32    GSMFunctionGpr)
{
    ViStatus    RSCMU_Status = VI_SUCCESS;
    ViSession   globalSession = 0;
    ViInt32     secondAddr = 0, comp = 1;
    ViReal64    Flag = RSCMU_OFF;
    ViChar      FctGrpBuffer[128]= "";
    ViChar      errorMessage[WR_BUFFER_SIZE];

    struct RSCMU_Base_Globals     *p_globalvarBase;
    struct RSCMU_GSM_Sig_Globals  *p_globalvarGSM;

    // Which Function Group does the User want?
    switch (GSMFunctionGpr)
    {
      case RSCMU_GSM400:
        strcpy (FctGrpBuffer, "\"GSM400MS_Sig\"");
        break;
      case RSCMU_GSM850:
        strcpy (FctGrpBuffer, "\"GSM850MS_Sig\"");
        break;
      case RSCMU_GSM900:
        strcpy (FctGrpBuffer, "\"GSM900MS_Sig\"");
        break;
      case RSCMU_GSM1800:
        strcpy (FctGrpBuffer, "\"GSM1800MS_Sig\"");
        break;
      case RSCMU_GSM1900:
        strcpy (FctGrpBuffer, "\"GSM1900MS_Sig\"");
        break;
      case RSCMU_GSMGT800MS_SIG:
        strcpy (FctGrpBuffer, "\"GSMGT800MS_Sig\"");
        break;
    }

    // Init the Error Message
    strcpy (errorMessage, "No Error");

    // Get the current options (= Function Group Names) in the CMU.
    if ((RSCMU_Status = viGetAttribute (BaseSession, VI_ATTR_USER_DATA,(ViAddr) &p_globalvarBase)) < 0)
      return RSCMU_K2G_errorMessage (BaseSession, RSCMU_Status, errorMessage);

    // Find the Secondary address for GSM_Sig
    while ((comp != 0) && (secondAddr < 30))
    {
      comp = strncmp (p_globalvarBase->RSCMU_tSecAddr[secondAddr].FctGrp, FctGrpBuffer, strlen(FctGrpBuffer));
      secondAddr++;
      if (comp == 0)  Flag = RSCMU_ON;
    }

    if (Flag == RSCMU_OFF)
      return RSCMU_K2G_errorMessage (instrSession, RSCMU_ERROR_INVALID_FCT_GRP, errorMessage);

    // Allocate space for "struct RSCMU_SESSION_Globals"
    if ((p_globalvarGSM = (struct RSCMU_GSM_Sig_Globals *) malloc (sizeof (struct RSCMU_GSM_Sig_Globals))) == 0)
      return RSCMU_initCleanUp (globalSession, instrSession, RSCMU_Status);

    if ((RSCMU_Status = viSetAttribute(instrSession, VI_ATTR_USER_DATA,(ViAttrState)p_globalvarGSM)) < 0)
      return RSCMU_initCleanUp (globalSession, instrSession, RSCMU_Status);

    // Set initial values of variables for function Group 'GSM_Sig'.
    strcpy (p_globalvarGSM->RSCMU_tGlobal.FGrp_Name, FctGrpBuffer);
    p_globalvarGSM->RSCMU_tGlobal.RSCMU_primary_address = p_globalvarBase->RSCMU_tGlobal.RSCMU_primary_address;
    p_globalvarGSM->RSCMU_tGlobal.RSCMU_secondary_address = secondAddr - 1;
    p_globalvarGSM->RSCMU_tGlobal.RSCMU_TRACE = p_globalvarBase->RSCMU_tGlobal.RSCMU_TRACE;
    // Base CMU FW available
    strcpy (p_globalvarGSM->RSCMU_tGlobal.CmuVersion, p_globalvarBase->RSCMU_tGlobal.CmuVersion);
    p_globalvarGSM->RSCMU_tGlobal.RSCMU_FW_Version = p_globalvarBase->RSCMU_tGlobal.RSCMU_FW_Version;
    if (p_globalvarGSM->RSCMU_tGlobal.RSCMU_TRACE == RSCMU_ON)
      p_globalvarGSM->RSCMU_tGlobal.RSCMU_AddrTargetFile = p_globalvarBase->RSCMU_tGlobal.RSCMU_AddrTargetFile;

    // Record the execution of this Init Function.
    p_globalvarBase->RSCMU_tSecAddr[secondAddr - 1].SessionNb = instrSession;

    // Record the "HandOverName" for the actual Session.
    switch (GSMFunctionGpr)
    {
      case RSCMU_GSM400:
        strcpy (p_globalvarGSM->RSCMU_tHandOver.HandOverSessionName, "\"GSM400MsDualBand\"");
        break;
      case RSCMU_GSM850:
        strcpy (p_globalvarGSM->RSCMU_tHandOver.HandOverSessionName, "\"GSM850MsDualBand\"");
        break;
      case RSCMU_GSM900:
        strcpy (p_globalvarGSM->RSCMU_tHandOver.HandOverSessionName, "\"GSM900MsDualBand\"");
        break;
      case RSCMU_GSM1800:
        strcpy (p_globalvarGSM->RSCMU_tHandOver.HandOverSessionName, "\"GSM1800MsDualBand\"");
        break;
      case RSCMU_GSM1900:
        strcpy (p_globalvarGSM->RSCMU_tHandOver.HandOverSessionName, "\"GSM1900MsDualBand\"");
        break;
    }

    // Timeout changed from 10s to 30 seconds
    if ((RSCMU_Status = viSetAttribute (instrSession, VI_ATTR_TMO_VALUE, RSCMU_TMO_VALUE)) < 0)
      return RSCMU_Status;

    return RSCMU_Status;
}

/*===========================================================================*/
/* Function: Get Instrument Handle                                           */
/* Purpose:  This function passes the instrument handle from the first       */
/*           parameter to the second parameter. This function is used in VEE */
/*           where it allows to get the current instrument handle.           */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_GetInstrumentHandle (ViSession instrSession,
                                             ViSession *instrSessionOut)
{
    *instrSessionOut = instrSession;
    return 0;
}

/*===========================================================================*/
/* Function: Reset                                                           */
/* Purpose:  This function resets the instrument.  If the reset function     */
/*           is not supported by the instrument, this function returns       */
/*           the warning VI_WARN_NSUP_RESET.                                 */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_reset (ViSession instrSession)
{
    return VI_WARN_NSUP_RESET;
}

/*===========================================================================*/
/* Function: Self-Test                                                       */
/* Purpose:  This function executes the instrument self-test and returns     */
/*           the result. If the self test function is not supported by the   */
/*           instrument, this function returns the warning                   */
/*           VI_WARN_NSUP_SELF_TEST.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_self_test (ViSession instrSession,
                                    ViPInt16 testResult,
                                    ViChar testMessage[])
{
    return VI_WARN_NSUP_SELF_TEST;
}

/*===========================================================================*/
/* Function: Error Query                                                     */
/* Purpose:  This function queries the instrument error queue, and returns   */
/*           the result.                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_error_query (ViSession instrSession,
                                      ViPInt32 errorCode,
                                      ViChar errorMessage[])
{
    return RSCMU_ErrorQuery (instrSession, errorCode, errorMessage);
}

/*===========================================================================*/
/* Function: Error Message                                                   */
/* Purpose:  This function translates the error return value from the        */
/*           instrument driver into a user-readable string.                  */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_error_message (ViSession instrSession,
                                        ViStatus statusCode,
                                        ViChar errMessage[])
{
    return RSCMU_K2G_errorMessage (instrSession, statusCode, errMessage);
}

/*===========================================================================*/
/* Function: Revision Query                                                  */
/* Purpose:  This function returns the driver and instrument revisions.      */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_revision_query (ViSession instrSession,
                    ViChar driverRev[], ViChar instrRev[])
{
    ViChar  errorMessage[WR_BUFFER_SIZE];

    return RSCMU_K2G_RevisionQuery (instrSession, driverRev, instrRev, errorMessage);
}

/*===========================================================================*/
/* Function: Close                                                           */
/* Purpose:  This function closes the instrument.                            */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU_close (ViSession instrSession)
{
    ViStatus RSCMU_Status = VI_SUCCESS;
    ViChar  errorMessage[WR_BUFFER_SIZE];
    ViUInt16 secAddr;

    if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_GPIB_SECONDARY_ADDR, &secAddr)) < 0)
        return RSCMU_Status;

    if (secAddr == 0) {
        if ((RSCMU_Status = RSCMU_Close_Base (instrSession, errorMessage)) < 0)
            return RSCMU_Status;
    } else {
        struct RSCMU_RF_NSig_Globals *p_globalvar;

        if ((RSCMU_Status = viGetAttribute (instrSession, VI_ATTR_USER_DATA, (ViAddr) &p_globalvar)) < 0)
            return RSCMU_Status;

        // Deallocate all system resources
        if ((RSCMU_Status = viClose (instrSession)) < 0)
            return RSCMU_Status;

        // Deallocate the space pointed by p_globalvar
        if (p_globalvar)
            free (p_globalvar);
    }
    return RSCMU_Status;
}

#endif
