/*=  Include File     =======================================================*/

#ifndef __K2G_HEADER
#define __K2G_HEADER

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

#if (!defined _DLL) && (!defined _VXIPNP)
#define _REMVXIPNP
#endif

#if defined(_MSC_VER) || defined(_CVI_)
    #define _OUTSIDEVEE_
#endif


/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
/*---------------------------------------------------------------------------*/
/* The codes for instrument specific ERRORS must be in the range             */
/* 0xBFFC0900 to 0xBFFC0FFF and defined as follows:                          */
/* #define PREFIX_SPECIFIC_ERROR (VI_INSTR_ERROR_OFFSET + n)                 */
/*                                                                           */
/* The codes for instrument specific WARNINGS must be in the range           */
/* 0x3FFC0900 to 0x3FFC0FFF and defined as follows:                          */
/* #define PREFIX_SPECIFIC_WARNING (VI_INSTR_WARNINGS_OFFSET + n)            */
/*                                                                           */
/* Where n represents each instrument specific error/warning number.         */
/* The valid range for n is 0x100 to 0x17F  for K2G Option (GSM MS)          */
/* For ease of use the lower 16 bits of warnings and errors should not       */
/* overlap in the same driver.                                               */
/*                                                                           */
/*---------------------------------------------------------------------------*/

#ifdef _OUTSIDEVEE_

#define VI_INSTR_WARNING_OFFSET                          (0x3FFC0900L)
#define VI_INSTR_ERROR_OFFSET                  (_VI_ERROR+0x3FFC0900L)

#define RSCMU_LIST_OF_SPECIFIC_K2G_ERROR_MESSAGES \
K2G_EXPAND(RSCMU_ERROR_CALL_FROM_MS_FAILED,      (VI_INSTR_ERROR_OFFSET + 0x200L), "Call from mobile station failed") \
K2G_EXPAND(RSCMU_ERROR_CALL_TO_MS_FAILED,        (VI_INSTR_ERROR_OFFSET + 0x201L), "Call to mobile station failed") \
K2G_EXPAND(RSCMU_ERROR_RELEASE_TO_MS_FAILED,     (VI_INSTR_ERROR_OFFSET + 0x202L), "Release to mobile station failed") \
K2G_EXPAND(RSCMU_ERROR_INVALID_SIGN_STAT,        (VI_INSTR_ERROR_OFFSET + 0x203L), "The RSCMU is in an internal signalling state where the command is not allowed") \
K2G_EXPAND(RSCMU_ERROR_INVALID_HANDOVER_TARGET,  (VI_INSTR_ERROR_OFFSET + 0x204L), "The handover target is not available") \
K2G_EXPAND(RSCMU_ERROR_INVALID_CHANNEL_NUMBER,   (VI_INSTR_ERROR_OFFSET + 0x205L), "Channel number out of range") \
K2G_EXPAND(RSCMU_ERROR_INVALID_GPRS_STAT,        (VI_INSTR_ERROR_OFFSET + 0x206L), "GPRS Service state unknown")

typedef enum {
#define K2G_EXPAND(id, value, text) id = value,
    RSCMU_LIST_OF_SPECIFIC_K2G_ERROR_MESSAGES
#undef K2G_EXPAND
} RSCMU_ErrorList_K2G;

#endif


/************************************************************/
/*                      DEFINES                             */
/************************************************************/

#ifndef _OUTSIDEVEE_

// Command defines
#define RSCMU_COMMAND_CONF      0
#define RSCMU_COMMAND_INIT      1
#define RSCMU_COMMAND_ABOR      2
#define RSCMU_COMMAND_STOP      3
#define RSCMU_COMMAND_CONT      4
#define RSCMU_COMMAND_READ      5
#define RSCMU_COMMAND_FETC      6
#define RSCMU_COMMAND_SAMP      7
#define RSCMU_COMMAND_CALC      8

// Logical values:
#define RSCMU_FALSE 0
#define RSCMU_TRUE  1

// On/Off values:
#define RSCMU_ON      1
#define RSCMU_OFF     0
#define RSCMU_VAL_ON  1
#define RSCMU_VAL_OFF 0

// None value:
#define RSCMU_NONE    0

/*---------------------------------------------------------------------------*/

#define RSCMU_SECONDARY_ADDRESS_MIN  1
#define RSCMU_SECONDARY_ADDRESS_MAX 30

#define RSCMU_TMO_VALUE                     10000

/*---------------------------------------------------------------------------*/
/* File I/O buffer size:
/*---------------------------------------------------------------------------*/

#define WR_BUFFER_SIZE             512L
#define RD_BUFFER_SIZE             512L
#define RD_BUFFER_SIZE_ARRAY     32767L

// Mathematical Values
#define RSCMU_NAN                 9.91e+37
#define RSCMU_NAN_VI_INT32        0x80000000

//Function Group Names FW2.0
#define RSCMU_NOT_MAPPED         -1
#define RSCMU_BASE                0
#define RSCMU_RF_NSIG             1
#define RSCMU_GSM400MS_NSIG       2
#define RSCMU_GSM400MS_SIG        3
#define RSCMU_GSM850MS_NSIG       4
#define RSCMU_GSM850MS_SIG        5
#define RSCMU_GSM900MS_NSIG       6
#define RSCMU_GSM900MS_SIG        7
#define RSCMU_GSMGT800MS_SIG      8   /*upd V5.00*/
#define RSCMU_GSM1800MS_NSIG      10
#define RSCMU_GSM1800MS_SIG       11
#define RSCMU_GSM1900MS_NSIG      14
#define RSCMU_GSM1900MS_SIG       15
#define RSCMU_IS136800MS_NSIG     18
#define RSCMU_IS136800MS_SIG      19
#define RSCMU_IS1361900MS_NSIG    20
#define RSCMU_IS1361900MS_SIG     21
#define RSCMU_AUDIO_NSIG          22
#define RSCMU_AMPSMS_NSIG         23
#define RSCMU_AMPSMS_SIG          24
#define RSCMU_CDMA800MS_NSIG      25
#define RSCMU_CDMA800MS_SIG       26
#define RSCMU_CDMA1900MS_NSIG     27
#define RSCMU_CDMA1900MS_SIG      28
#define RSCMU_BLUETOOTH_NSIG      29
#define RSCMU_BLUETOOTH_SIG       30
#define RSCMU_WCDMA1900FDDMS_NSIG 31
#define RSCMU_WCDMA1900FDDMS_SIG  32
#define RSCMU_CDMA2K450MS_NSIG    33
#define RSCMU_CDMA2K450MS_SIG     34
#define RSCMU_CDMA2KCELLMS_NSIG   35
#define RSCMU_CDMA2KCELLMS_SIG    36
#define RSCMU_CDMA2KPCSMS_NSIG    37
#define RSCMU_CDMA2KPCSMS_SIG     38
#define RSCMU_CDMA2KIMT2KMS_NSIG  39
#define RSCMU_CDMA2KIMT2KMS_SIG   40

//Units
#define RSCMU_HZ                  0
#define RSCMU_KHZ                 1
#define RSCMU_MHZ                 2
#define RSCMU_GHZ                 3
#define RSCMU_US                  0
#define RSCMU_MS                  1
#define RSCMU_S                   2

#define RSCMU_10HZ                0
#define RSCMU_20HZ                1
#define RSCMU_30HZ                2
#define RSCMU_50HZ                3
#define RSCMU_100HZ               4
#define RSCMU_200HZ               5
#define RSCMU_300HZ               6
#define RSCMU_500HZ               7
#define RSCMU_1KHZ                8
#define RSCMU_2KHZ                9
#define RSCMU_3KHZ               10
#define RSCMU_5KHZ               11
#define RSCMU_10KHZ              12
#define RSCMU_20KHZ              13
#define RSCMU_30KHZ              14
#define RSCMU_50KHZ              15
#define RSCMU_100KHZ             16
#define RSCMU_200KHZ             17
#define RSCMU_300KHZ             18
#define RSCMU_500KHZ             19
#define RSCMU_1MHZ               20
#define RSCMU_WIDE               21
#define RSCMU_FREQ_AUTO          21

//SCPI Connection
#define RSCMU_GPIB                0
#define RSCMU_COM                 1
#define RSCMU_COM1                1
#define RSCMU_COM2                2

//Parity
#define RSCMU_PARITY_NONE         0
#define RSCMU_PARITY_ODD          1
#define RSCMU_PARITY_EVEN         2

//Protocol
#define RSCMU_PROTOCOL_NONE       0
#define RSCMU_PROTOCOL_XON        1
#define RSCMU_PROTOCOL_ACK        2

// Status byte
#define RSCMU_STB_OFF             0
#define RSCMU_STB_ON              1

//Query
#define RSCMU_DO_QUERY            1
#define RSCMU_SKIP_QUERY          0

//Reset
#define RSCMU_RESET_ON            1
#define RSCMU_RESET_OFF           0

//Reference Frequency
#define RSCMU_INTERNAL            0
#define RSCMU_EXTERNAL            1
#define RSCMU_REF_FRQ_MIN         1.2190
#define RSCMU_REF_FRQ_MAX         39.0

//Attenuation
#define RSCMU_NORM                0
#define RSCMU_LNO                 1
#define RSCMU_LDIS                2
#define RSCMU_LOW_NOISE           1
#define RSCMU_LOW_DIST            2

//Trigger Condition
#define RSCMU_IMM                 0
#define RSCMU_FRUN                0
#define RSCMU_RFP                 1
#define RSCMU_IFP                 2
#define RSCMU_EXT                 3
#define RSCMU_SIGN                3

//Trigger Condition
#define RSCMU_LOW                 0
#define RSCMU_MED                 1
#define RSCMU_HIGH                2

//Measurement Repetition
#define RSCMU_STOP_ON             1
#define RSCMU_STOP_ALIM           1
#define RSCMU_STOP_FLIM           2
#define RSCMU_STEP                1
#define RSCMU_STEP_ON             1
#define RSCMU_ON_LIMIT_FAILURE    1

//Measurement Repetition FW 2.0
#define RSCMU_CONTINUOUS          0
#define RSCMU_SINGLE_SHOT         1

//Event Reporting
#define RSCMU_SRQ                 1
#define RSCMU_SOPC                2
#define RSCMU_SRSQ                3

// TimeOuts
#define RSCMU_SENS_TRIG_MEAS_TMO_MIN    1.0
#define RSCMU_SENS_TRIG_MEAS_TMO_MAX    1000.0

// Audio channels
#define RSCMU_ALL_AF              0
#define RSCMU_AF1                 1
#define RSCMU_AF2                 2

// Multitone results
#define RSCMU_RLEV                0
#define RSCMU_TON                 1

// Measurement time mode
#define RSCMU_LOWF                0
#define RSCMU_EXPF                1

// Multitone level mode
#define RSCMU_SEP                 0
#define RSCMU_TLEV                1

/*===========================================================================*/
/*                          Measurement Control                              */
/*===========================================================================*/
// Generator Status
#define RSCMU_GEN_STAT_OFF        0
#define RSCMU_GEN_STAT_RUN        1
#define RSCMU_GEN_STAT_ERR        2

// Measurement Status
#define RSCMU_MEAS_STAT_OFF       0
#define RSCMU_MEAS_STAT_RUN       1
#define RSCMU_MEAS_STAT_STOP      2
#define RSCMU_MEAS_STAT_ERR       3
#define RSCMU_MEAS_STAT_STEP      4
#define RSCMU_MEAS_STAT_RDY       5

// Sensitivity Measurement Status
#define RSCMU_MEAS_STAT_PASS      0
#define RSCMU_MEAS_STAT_INV       1
#define RSCMU_MEAS_STAT_FAIL      2
#define RSCMU_MEAS_STAT_TMER      3
#define RSCMU_MEAS_STAT_IMP       4

/*===========================================================================*/
/*                                                                           */
/*===========================================================================*/
//Frequency Bandwidth
#define RSCMU_BAND_RESTRICT       0
#define RSCMU_BAND_WIDE           1
#define RSCMU_BANDWIDTH_30KHZ     1
#define RSCMU_BANDWIDTH_300KHZ    2

// Generator Modulation
#define RSCMU_SSB                 1

//Input connectors
#define RSCMU_INPUT_RF1           0
#define RSCMU_INPUT_RF2           1
#define RSCMU_INPUT_RF4           2

//Output Connectors
#define RSCMU_OUTPUT_RF1          0
#define RSCMU_OUTPUT_RF2          1
#define RSCMU_OUTPUT_RF3          2

// Audio input signal
#define RSCMU_AFAN_AFIN           0
#define RSCMU_AFAN_AUX1           1

// Audio path coupling
#define RSCMU_AFAN_AC             0
#define RSCMU_AFAN_DC             1

// Audio weighting filter
//      RSCMU_OFF
#define RSCMU_CME                 1
#define RSCMU_CCI                 2

// Audio fixed band pass selection
#define RSCMU_BP01                1
#define RSCMU_BP02                2
#define RSCMU_BP03                3
#define RSCMU_BP04                4
#define RSCMU_BP05                5
#define RSCMU_BP06                6
#define RSCMU_BP07                7
#define RSCMU_BP08                8
#define RSCMU_BP09                9
#define RSCMU_BP10                10
#define RSCMU_BP11                11
#define RSCMU_BP12                12
#define RSCMU_BP13                13
#define RSCMU_BP14                14
#define RSCMU_BP15                15
#define RSCMU_BP16                16
#define RSCMU_BP17                17
#define RSCMU_BP18                18

// Speech Encoder Input
#define RSCMU_SPEN_HAND           0
#define RSCMU_SPEN_GEN            1
#define RSCMU_SPEN_AUX1           2

// Speech Decoder Output
#define RSCMU_SPD_HAND            0
#define RSCMU_SPD_ANAL            1
#define RSCMU_SPD_AUX2            2

// Limit Check
#define RSCMU_OK                  0
#define RSCMU_INV                 1
#define RSCMU_NMAU                2
#define RSCMU_NMAL                3

#define RSCMU_MATCH_MATC          0
#define RSCMU_MATCH_INV           1
#define RSCMU_MATCH_NMAT          2
#define RSCMU_MATCH_NTSC          3
#define RSCMU_MATCH_OUT           4
#define RSCMU_MATCH_NTR           5
#define RSCMU_MATCH_BNF           6
#define RSCMU_MATCH_NRAM          7
#define RSCMU_MATCH_OFF           8
#define RSCMU_MATCH_OFLOW         9
#define RSCMU_MATCH_UFLOW        10

#define RSCMU_MANUAL              0
#define RSCMU_AUTO                1
#define RSCMU_PCL                 2
#define RSCMU_ALWAYS              0

#define RSCMU_CURRENT             0
#define RSCMU_AVERAGE             1
#define RSCMU_MAXMIN              2
#define RSCMU_MAXIMUM             2
#define RSCMU_MINIMUM             3
#define RSCMU_AVERAGED            1 // Do not remove it is due to keep the compatibility

//Serial interface
#define RSCMU_APPL_TRAN           0
#define RSCMU_APPL_REM            1
#define RSCMU_APPL_PRIN           2

//Input/output attenuation
#define RSCMU_ATT_MIN             -50
#define RSCMU_ATT_MAX             +50

//Multiple Measurement
#define RSCMU_MULT_MEAS_MIN        1
#define RSCMU_MULT_MEAS_MAX        10000

//Absolute level on used Timeslot
//#define RSCMU_USEDSLOTMIN         -137.0
//#define RSCMU_USEDSLOTMAX         +13.0

//Frequency offset
#define RSCMU_FREQ_OFFSET_MIN     -135000
#define RSCMU_FREQ_OFFSET_MAX     +135000

//Power Level Range
#define RSCMU_LEV_RANGE_MIN            10
#define RSCMU_LEV_RANGE_MAX           100

//Test Points Number
#define RSCMU_TEST_PTS_MIN              1
#define RSCMU_TEST_PTS_MAX            560

#define RSCMU_REG_MAX               32767
#define RSCMU_SUB_REG_MAX              15
#define RSCMU_ADDR_PRIM_MAX            30
#define RSCMU_ADDR_SEC_MAX             30

#define RSCMU_DATABITS_MIN              7
#define RSCMU_DATABITS_MAX              8
#define RSCMU_STOPBITS_MIN              1
#define RSCMU_STOPBITS_MAX              2

#define RSCMU_SUM1                      1
#define RSCMU_SUM2                      2

//Keyboard Assignment
#define RSCMU_KBUS                  0
#define RSCMU_KBGR                  1

//positive / negative
#define RSCMU_POS                 1
#define RSCMU_NEG                 0

// Frequency hopping
#define RSCMU_REL                 0
#define RSCMU_ABS                 1

//Mode Values
#define RSCMU_VALUE_ALL           0
#define RSCMU_VALUE_ARIT          1
#define RSCMU_VALUE_MIN           2
#define RSCMU_VALUE_MAX           3
#define RSCMU_VALUE_IVAL          4

#endif // end of rscmu200 defines for VEE


//Function Groups
#define RSCMU_GSM400              0
#define RSCMU_GSM900              1
#define RSCMU_GSM1800             2
#define RSCMU_GSM1900             3
#define RSCMU_GSM850              4
#define RSCMU_GSMGT800            5  

//Training Sequence
#define RSCMU_ALL                 0
#define RSCMU_GSM0                1
#define RSCMU_GSM1                2
#define RSCMU_GSM2                3
#define RSCMU_GSM3                4
#define RSCMU_GSM4                5
#define RSCMU_GSM5                6
#define RSCMU_GSM6                7
#define RSCMU_GSM7                8
#define RSCMU_DUMMY               9
#define RSCMU_ANY                10

//Bit Sequence
#define RSCMU_PRBS                1
#define RSCMU_DUMM                2
#define RSCMU_ALL0                3
#define RSCMU_EALL0               4
#define RSCMU_EPRBS               5

//Transmission mode
#define RSCMU_TRAN_BURS           0
#define RSCMU_TRAN_CONT           1

//Time mode
#define RSCMU_GSM                 1
#define RSCMU_OFFS                0

//Frequency Offset
#define RSCMU_GSM_SIG_FREQNEG     -100000
#define RSCMU_GSM_SIG_FREQPOS     +100000

//Measured Values Type
#define RSCMU_SCALAR              0
#define RSCMU_ARRAY               1

//Measure points
#define RSCMU_0_10MHZ             1
#define RSCMU_0_20MHZ             2
#define RSCMU_0_25MHZ             3
#define RSCMU_0_40MHZ             4
#define RSCMU_0_60MHZ             5
#define RSCMU_0_80MHZ             6
#define RSCMU_1_00MHZ             7
#define RSCMU_1_20MHZ             8
#define RSCMU_1_40MHZ             9
#define RSCMU_1_60MHZ            10
#define RSCMU_1_80MHZ            11

#define RSCMU_MPO1                1
#define RSCMU_MPO2                2
#define RSCMU_MPO3                3
#define RSCMU_MPO4                4
#define RSCMU_MPO5                5
#define RSCMU_MPO6                6
#define RSCMU_MPO7                7
#define RSCMU_MPO8                8
#define RSCMU_MPO9                9
#define RSCMU_MPO10              10
#define RSCMU_MPO11              11

#define RSCMU_POWLEV1             1
#define RSCMU_POWLEV2             2
#define RSCMU_POWLEV3             3
#define RSCMU_POWLEV4             4
#define RSCMU_POWLEV5             5
#define RSCMU_POWLEV6             6
#define RSCMU_POWLEV7             7
#define RSCMU_POWLEV8             8
#define RSCMU_POWLEV9             9
#define RSCMU_POWLEV10           10

// CMU Signalling State
#define RSCMU_UNKNOWN_STATE      -1
#define RSCMU_STATE_SOFF          0
#define RSCMU_STATE_SON           1
#define RSCMU_STATE_SYNC          2
#define RSCMU_STATE_CEST          3
#define RSCMU_STATE_CPEN          4
#define RSCMU_STATE_CED           5
#define RSCMU_STATE_ALER          6

#define RSCMU_SOFF                0
#define RSCMU_SON                 1
#define RSCMU_MTC                 2
#define RSCMU_SMS                 3
#define RSCMU_CREL                4
#define RSCMU_EDA_AUTO                      2
#define RSCMU_HAND                5

// GPRS Signalling Control
#define RSCMU_GPRS_CONT_SOFF      0
#define RSCMU_GPRS_CONT_SON       1
#define RSCMU_GPRS_CONT_CTMA      2
#define RSCMU_GPRS_CONT_CTMB      3
#define RSCMU_GPRS_CONT_DISC      4
#define RSCMU_GPRS_CONT_CRS       5
#define RSCMU_GPRS_CONT_CBL       6
#define RSCMU_GPRS_CONT_CDL       7
#define RSCMU_GPRS_CONT_CRA       8
#define RSCMU_GPRS_CONT_CRES      9  // FW >= 3.25
#define RSCMU_GPRS_CONT_CREA      10 // FW >= 3.25
#define RSCMU_GPRS_CONT_HAND      11 // FW >= 3.25
#define RSCMU_GPRS_CONT_CLBS      12 // FW >= 3.50
#define RSCMU_GPRS_CONT_CLBA      13 // FW >= 3.50
#define RSCMU_GPRS_CONT_CBUL      14 // FW >= 4.11
#define RSCMU_GPRS_CONT_SAT       15
#define RSCMU_GPRS_CONT_CRUD      16 // FW >= 4.50 
    
// GPRS Service State
//      RSCMU_UNKNOWN_STATE      -1
#define RSCMU_GPRS_STATE_IDLE     0  // FW >= 3.01
#define RSCMU_GPRS_STATE_ATT      1
#define RSCMU_GPRS_STATE_RAUP     2
#define RSCMU_GPRS_STATE_AIPR     3
#define RSCMU_GPRS_STATE_DIPR     4
#define RSCMU_GPRS_STATE_OFF      5  // FW >= 3.05
#define RSCMU_GPRS_STATE_CTBF     6
#define RSCMU_GPRS_STATE_TEST     7
#define RSCMU_GPRS_STATE_TED      8  // FW >= 3.25
#define RSCMU_GPRS_STATE_CBUL     9  // FW >= 4.11

// GPRS Service
#define RSCMU_GPRS_SERV_TMA       0
#define RSCMU_GPRS_SERV_TMB       1
#define RSCMU_GPRS_SERV_RSIG      2
#define RSCMU_GPRS_SERV_RSA       3
#define RSCMU_GPRS_SERV_DLON      4
#define RSCMU_GPRS_SERV_BLER      5
#define RSCMU_GPRS_SERV_RSCS      6
#define RSCMU_GPRS_SERV_RSCA      7
#define RSCMU_GPRS_SERV_LBS       8
#define RSCMU_GPRS_SERV_LBA       9
#define RSCMU_GPRS_SERV_ATES      10
#define RSCMU_GPRS_SERV_BULT      11 
#define RSCMU_GPRS_SERV_RUDL      12 

//Hopping Sequence Values
#define RSCMU_HOPPING_SEQ_OFF     0
#define RSCMU_HOPPING_SEQ_A       1
#define RSCMU_HOPPING_SEQ_B       2
#define RSCMU_HOPPING_SEQ_C       3
#define RSCMU_HOPPING_SEQ_D       4

//Speech modes
#define RSCMU_SPEECH_ECHO         0
#define RSCMU_SPEECH_LOOP         1
#define RSCMU_SPEECH_PR9          2
#define RSCMU_SPEECH_PR11         3
#define RSCMU_SPEECH_PR15         4
#define RSCMU_SPEECH_PR16         5
#define RSCMU_SPEECH_HANDSET      6
#define RSCMU_SPEECH_CCAL         7   // FW >= 2.10
#define RSCMU_SPEECH_ECAL         8
#define RSCMU_SPEECH_HLOW         9   // FW >= 3.00
#define RSCMU_SPEECH_DCAL         10
#define RSCMU_SPEECH_FA0          11  // FW >= 4.50 
#define RSCMU_SPEECH_FA1          12
#define RSCMU_SPEECH_FA01         13
#define RSCMU_SPEECH_LC9          14
#define RSCMU_SPEECH_LC11         15
#define RSCMU_SPEECH_LC15         16
#define RSCMU_SPEECH_LC16         17

//Speed of Power Change
#define RSCMU_POWERCHANGE_SLOW    0
#define RSCMU_POWERCHANGE_FAST    1
#define RSCMU_POWERCHANGE_EPC     2

#define RSCMU_EPC_POWERCONTROL_SACCH 0
#define RSCMU_EPC_POWERCONTROL_EPCCH 1

//Signalling Channel
#define RSCMU_SIGN_SDCCH          1
#define RSCMU_SIGN_FACCH          2

//Speech Coding modes
#define RSCMU_SPEECH_CODING_FRV1  0
#define RSCMU_SPEECH_CODING_FRV2  1
#define RSCMU_SPEECH_CODING_HRV1  2
#define RSCMU_SPEECH_CODING_FD24  3
#define RSCMU_SPEECH_CODING_FD48  4
#define RSCMU_SPEECH_CODING_FD96  5
#define RSCMU_SPEECH_CODING_HD24  6
#define RSCMU_SPEECH_CODING_HD48  7
#define RSCMU_SPEECH_CODING_FD14  8
#define RSCMU_SPEECH_CODING_C1TM  9
#define RSCMU_SPEECH_CODING_C2TM  10
#define RSCMU_SPEECH_CODING_C3TM  11
#define RSCMU_SPEECH_CODING_C4TM  12
#define RSCMU_SPEECH_CODING_MC1TM 13
#define RSCMU_SPEECH_CODING_MC2TM 14
#define RSCMU_SPEECH_CODING_MC3TM 15
#define RSCMU_SPEECH_CODING_MC4TM 16
#define RSCMU_SPEECH_CODING_MC5TM 17
#define RSCMU_SPEECH_CODING_MC6TM 18
#define RSCMU_SPEECH_CODING_MC7TM 19
#define RSCMU_SPEECH_CODING_MC8TM 20
#define RSCMU_SPEECH_CODING_MC9TM 21
#define RSCMU_SPEECH_CODING_AMR_FR 22
#define RSCMU_SPEECH_CODING_AMR_HR 23
#define RSCMU_SPEECH_CODING_AMR_HR_8PSK 24
#define RSCMU_SPEECH_CODING_GMSK_FULL 25
#define RSCMU_SPEECH_CODING_AMR_WB_FR_8PSK 26
#define RSCMU_SPEECH_CODING_AMR_WB_HR_8PSK 27

//Loop Command
#define RSCMU_LOOP_DISABLE        2
#define RSCMU_LOOP_ENABLE         1
#define RSCMU_LOOP_BER            0

//Radio Cells Access
#define RSCMU_NBAR                1
#define RSCMU_BARR                0

//GSM Phase
#define RSCMU_PH1                 1
#define RSCMU_PH2                 2
#define RSCMU_PH2P                3

//Application Number
#define RSCMU_AP1                 1
#define RSCMU_AP2                 2
#define RSCMU_AP3                 3
#define RSCMU_AP4                 4
#define RSCMU_AP5                 5
#define RSCMU_AP6                 6
#define RSCMU_AP7                 7
#define RSCMU_AP8                 8
#define RSCMU_AP9                 9
#define RSCMU_AP10                10

//Test Setup FW 2.0
#define RSCMU_TS1                 1
#define RSCMU_TS2                 2
#define RSCMU_TS3                 3
#define RSCMU_TS4                 4
#define RSCMU_TS5                 5
#define RSCMU_TS6                 6
#define RSCMU_TS7                 7
#define RSCMU_TS8                 8
#define RSCMU_TS9                 9
#define RSCMU_TS10                10

//BER measurements FW 2.0
#define RSCMU_BER                 0
#define RSCMU_RFER                1
#define RSCMU_BBB                 2
#define RSCMU_BDBL                3  // FW >= 3.05
#define RSCMU_AIBF                4  // FW >= 3.60
#define RSCMU_BFI                 5  // FW >= 4.20
#define RSCMU_SRES                6  // FW >= 4.20
#define RSCMU_SREV                7  // FW >= 4.20
#define RSCMU_RUFR                8  // FW >= 4.20
#define RSCMU_AEVS                9  // FW >= 4.20
#define RSCMU_AEVR               10  // FW >= 4.20


//Start/Stop measurements
#define RSCMU_MEAS_OFF            0
#define RSCMU_MEAS_RUN            1
#define RSCMU_MEAS_STOP           2
#define RSCMU_MEAS_ERR            3
#define RSCMU_MEAS_STEP           4
#define RSCMU_MEAS_RDY            5
#define RSCMU_MEAS_NEXT           6

// Type of output measurement values
#define RSCMU_ARIT                1
#define RSCMU_MIN                 2
#define RSCMU_MAX                 3

//Timeslot Number
#define RSCMU_TIMESLOT_MIN        2
#define RSCMU_TIMESLOT_MAX        6

// Identity for the mobile radio network
#define RSCMU_NCC_MIN             0
#define RSCMU_NCC_MAX             7
#define RSCMU_MCC_MIN             0
#define RSCMU_MCC_MAX             999
#define RSCMU_MNC_MIN             0
#define RSCMU_MNC_MAX             99
#define RSCMU_BCC_MIN             0
#define RSCMU_BCC_MAX             7
#define RSCMU_LAC_MIN             0
#define RSCMU_LAC_MAX             65535
#define RSCMU_RAC_MIN             0
#define RSCMU_RAC_MAX             255

// Mobile Subscriber Id. No.
#define RSCMU_MSIN_MIN            "0"
#define RSCMU_MSIN_MAX            "9999999999"

//number of burst per statistics cycle
#define RSCMU_NBBURST_MIN         1
#define RSCMU_NBBURST_MAX         1000

//Absolute level on unused Timeslot
#define RSCMU_GSM_SIG_UNUSEDSLOTMIN         -47.0
#define RSCMU_GSM_SIG_UNUSEDSLOTMAX         +13.0
#define RSCMU_GSMNONSIG_UNUSEDSLOTMIN      -110.0
#define RSCMU_GSMNONSIG_UNUSEDSLOTMAX       +40.0

//Network System Parameters
#define RSCMU_NBBLCKSRES_MAX            7
#define RSCMU_PAGINGREQINT_MIN          2
#define RSCMU_PAGINGREQINT_MAX          9

//Network Timeouts
#define RSCMU_SACCHBLOCKS_MIN           4
#define RSCMU_SACCHBLOCKS_MAX          64
#define RSCMU_TESTSET_TIMEOUT_MIN       4
#define RSCMU_TESTSET_TIMEOUT_MAX      64
#define RSCMU_MTC_TIMEOUT              60

//Error Limits
#define RSCMU_PHASE_ERROR_LIM_MAX        50
#define RSCMU_PHASE_ERROR_LIM_MIN       -50
#define RSCMU_ORIGIN_OFFSET_LIM_MAX      40
#define RSCMU_ORIGIN_OFFSET_LIM_MIN    -100
#define RSCMU_FREQ_ERROR_LIM_MAX        999
#define RSCMU_FREQ_ERROR_LIM_MIN       -999

//Nb of Frames (BER)
#define RSCMU_NBFRAMES_MIN               1
#define RSCMU_NBFRAMES_AVER_MAX        500
#define RSCMU_NBFRAMES_SENT_MAX     200000

// Absolute level of control channel
#define RSCMU_ABSLEVEL_MIN            -137
#define RSCMU_ABSLEVEL_MAX             +13

#define RSCMU_VAL_MAX   2

// Modulation view
#define RSCMU_MODVIEW_GMSK      0
#define RSCMU_MODVIEW_EPSK      1
#define RSCMU_MODVIEW_ANY       2
#define RSCMU_MODVIEW_OFF       3
#define RSCMU_MODVIEW_ABURST    4

// Slot count parameters
#define RSCMU_S128      0
#define RSCMU_S256      1
#define RSCMU_S384      2
#define RSCMU_S512      3

#define RSCMU_LOW       0
#define RSCMU_UPP       1

// Decoding for the modulation measurement
#define RSCMU_STAN      0
#define RSCMU_GTB       1

// Speech Encoder
#define RSCMU_GENERATOR      0
#define RSCMU_ANALYSER       0
#define RSCMU_HANDSET        1
#define RSCMU_ANALYSER2      2
#define RSCMU_BOTH_ANALYSERS 3

// DAI acoustic device
#define RSCMU_DAI_NORMAL  0
#define RSCMU_DAI_DECODER 1
#define RSCMU_DAI_ENCODER 2
#define RSCMU_DAI_ADEVICE 3

// Network Support
#define RSCMU_GGPR      0
//      RSCMU_GSM       1
#define RSCMU_GEGP      2

// Network Main Service
#define RSCMU_CSW       0
#define RSCMU_PDAT      1

// Coding Scheme GPRS
#define RSCMU_CS1       1
#define RSCMU_CS2       2
#define RSCMU_CS3       3
#define RSCMU_CS4       4

// Coding Scheme EGPRS
#define RSCMU_MCS1       1
#define RSCMU_MCS2       2
#define RSCMU_MCS3       3
#define RSCMU_MCS4       4
#define RSCMU_MCS5       5
#define RSCMU_MCS6       6
#define RSCMU_MCS7       7
#define RSCMU_MCS8       8
#define RSCMU_MCS9       9

// Punctering Scheme
#define RSCMU_P1       0
#define RSCMU_P2       1
#define RSCMU_P3       2

// Power filter
#define RSCMU_FILTER_G500   0
#define RSCMU_FILTER_B600   1
#define RSCMU_FILTER_G1000   2

// Repetition Mode
//      RSCMU_CONTINUOUS    0
//      RSCMU_SINGLE_SHOT   1

// Symbolic Status Event Register
//      RSCMU_NONE          0
#define RSCMU_EVENT_CFM     1
#define RSCMU_EVENT_RFM     2
#define RSCMU_EVENT_SLOS    3
#define RSCMU_EVENT_LUPD    4
#define RSCMU_EVENT_RFNS    5
#define RSCMU_EVENT_IDET    6
#define RSCMU_EVENT_SMSR    7
#define RSCMU_EVENT_MREP    8

// Reference Power Mode
#define RSCMU_RPM_CURR      0
#define RSCMU_RPM_AVER      1
#define RSCMU_RPM_DCOM      2

// Control Channel Mode
#define RSCMU_BCCHMODE_BATC 0
#define RSCMU_BCCHMODE_BOTC 1

// AuxTx Channel Type
#define RSCMU_AUXTXMODE_OFF        0
#define RSCMU_AUXTXMODE_BCCH       1
#define RSCMU_AUXTXMODE_BCCH_PBCCH 2
#define RSCMU_AUXTXMODE_PBCCH      3

// BS Signal Level Mode
#define RSCMU_LEVELMODE_UUN 0
#define RSCMU_LEVELMODE_IND 1



#define RSCMU_BCCH          0
#define RSCMU_PDCH          1

#define RSCMU_UNACK         0
#define RSCMU_ACK           1

#define RSCMU_SCOD          0
#define RSCMU_MSUP          1

#define RSCMU_G18           0
#define RSCMU_G19           1

#define RSCMU_DEF           0
#define RSCMU_CUR           1

//Loop
#define RSCMU_LOOPTYPE_OFF     0
#define RSCMU_LOOPTYPE_A       1
#define RSCMU_LOOPTYPE_B       2
#define RSCMU_LOOPTYPE_C       3
#define RSCMU_LOOPTYPE_D       4
#define RSCMU_LOOPTYPE_E       5
#define RSCMU_LOOPTYPE_F       6
#define RSCMU_LOOPTYPE_G       7
#define RSCMU_LOOPTYPE_H       8
#define RSCMU_LOOPTYPE_I       9

//Trigger
#define RSCMU_TRIG_NONE           0
#define RSCMU_TRIG_FRAMECLOCK     1
#define RSCMU_TRIG_26MULTIFRAME   2
#define RSCMU_TRIG_52MULTIFRAME   3
#define RSCMU_TRIG_104MULTIFRAME  4
#define RSCMU_TRIG_HOPPING        5

//Ext. Trigger
#define RSCMU_PIN2                 0
#define RSCMU_PIN3                 1
#define RSCMU_PIN4                 2
#define RSCMU_PIN5                 3

//Spectrum/Switch continuous statistical mode
#define RSCMU_PEAK_HOLD           0
#define RSCMU_STAT_COUNT          1

//Spectrum/Switch Slot Count
#define RSCMU_SINGLESLOT          0
#define RSCMU_MULTISLOT           1

//USF Duty Cycle
#define RSCMU_1_ASSIGNED          0
#define RSCMU_0_ASSIGNED          1
#define RSCMU_12_5_ASSIGNED       2

//AMR Codec Mode
#define RSCMU_AMR_CODMODE_4_75    1
#define RSCMU_AMR_CODMODE_5_15    2
#define RSCMU_AMR_CODMODE_5_9     3
#define RSCMU_AMR_CODMODE_6_7     4
#define RSCMU_AMR_CODMODE_7_4     5
#define RSCMU_AMR_CODMODE_7_95    6
#define RSCMU_AMR_CODMODE_10_2    7
#define RSCMU_AMR_CODMODE_12_2    8

#define RSCMU_AMR_WB_CODMODE_6_6     1
#define RSCMU_AMR_WB_CODMODE_8_85    2
#define RSCMU_AMR_WB_CODMODE_12_65   3
#define RSCMU_AMR_WB_CODMODE_15_85   4
#define RSCMU_AMR_WB_CODMODE_23_85   5

//Confidence BER early Fail/Pass
#define RSCMU_CONF_095      0
#define RSCMU_CONF_099      1
#define RSCMU_CONF_0998     2
#define RSCMU_CONF_09998    3

//Confidence BER Resullt Window
#define RSCMU_CONF_RES_WIND_P10    1
#define RSCMU_CONF_RES_WIND_P20    2
#define RSCMU_CONF_RES_WIND_P30    3

//Stop Condition Confidence
#define RSCMU_STOP_CLEV           3
#define RSCMU_STOP_RFLS           4

//Confidence BER Result values
#define RSCMU_CONF_STAT_RESULTS_RUN   1
#define RSCMU_CONF_STAT_RESULTS_EFAIL 2
#define RSCMU_CONF_STAT_RESULTS_EPASS 3
#define RSCMU_CONF_STAT_RESULTS_FAIL  4
#define RSCMU_CONF_STAT_RESULTS_PASS  5
#define RSCMU_CONF_STAT_RESULTS_THIGH 6
#define RSCMU_CONF_STAT_RESULTS_TLOW  7


#define RSCMU_REJECT 0
#define RSCMU_ACCEPT 1

//Handover
#define RSCMU_HANDOVER_WGSM   1
#define RSCMU_HANDOVER_FSYN   1

//Averaging Areas
#define RSCMU_AVG_AREAS_A    0
#define RSCMU_AVG_AREAS_B    1
#define RSCMU_AVG_AREAS_AB   2


#define RSCMU_N180  1
#define RSCMU_N160  2
#define RSCMU_N140  3
#define RSCMU_N120  4
#define RSCMU_N100  5
#define RSCMU_N080  6
#define RSCMU_N060  7
#define RSCMU_N040  8
#define RSCMU_N025  9
#define RSCMU_N020 10
#define RSCMU_N010 11
#define RSCMU_REF  12
#define RSCMU_P010 13
#define RSCMU_P020 14
#define RSCMU_P025 15
#define RSCMU_P040 16
#define RSCMU_P060 17
#define RSCMU_P080 18
#define RSCMU_P100 19
#define RSCMU_P120 20
#define RSCMU_P140 21
#define RSCMU_P160 22
#define RSCMU_P180 23
#define RSCMU_NV4  24
#define RSCMU_NV3  25
#define RSCMU_NV2  26
#define RSCMU_NV1  27
#define RSCMU_PV1  28
#define RSCMU_PV2  29
#define RSCMU_PV3  30
#define RSCMU_PV4  31

// Control Ack Type
#define RSCMU_NORMAL_BURST  0
#define RSCMU_ACCESS_BURST  1

#define RSCMU_BANDWIDTH_10K 0
#define RSCMU_BANDWIDTH_30K 1

/*********************************************/
/*          New with firmware 3.60           */
/*********************************************/

// Raw Symbol Timing Recovery
#define RSCMU_NON           0
#define RSCMU_TSC           1

// Off Template
#define RSCMU_RMAX          0
#define RSCMU_RSL           1

// Half Rate Subchannel
#define RSCMU_SUBCHANNEL_0          0
#define RSCMU_SUBCHANNEL_1          1

// Bands
#define RSCMU_G450          0
#define RSCMU_G480          1
#define RSCMU_G700          2
#define RSCMU_G850          3
#define RSCMU_G900PGSM      4
#define RSCMU_G900EGSM      5
#define RSCMU_G900RGSM      6
#define RSCMU_G1800         7
#define RSCMU_G1900         8
#define RSCMU_GGT800        9
#define RSCMU_UFDD          10
#define RSCMU_U384TDD       11
#define RSCMU_U128TDD       12
#define RSCMU_C2000         13

// DTM Multislot
#define RSCMU_CL5           0
#define RSCMU_CL6           1
#define RSCMU_CL9           2
#define RSCMU_CL10          3
#define RSCMU_CL11          4

// EPSK Power Class
#define RSCMU_E1            0
#define RSCMU_E2            1
#define RSCMU_E3            2

// Repetition Mode
#define RSCMU_CONT          0
#define RSCMU_SING          1
#define RSCMU_MULT          2

// Burst Type
#define RSCMU_SCH           0
#define RSCMU_FCH           1
#define RSCMU_FS6D          2
#define RSCMU_DALL          3
#define RSCMU_FS5D          4

// Power Level
#define RSCMU_POWER_LEVEL_LLIS          0
#define RSCMU_POWER_LEVEL_RLEV          1
#define RSCMU_POWER_LEVEL_PLEV1         2
#define RSCMU_POWER_LEVEL_PLEV2         3
#define RSCMU_POWER_LEVEL_PLEV3         4
#define RSCMU_POWER_LEVEL_PLEV4         5
#define RSCMU_POWER_LEVEL_PLEV5         6
#define RSCMU_POWER_LEVEL_PLEV6         7

// RF Search Level
#define RSCMU_LLR           0
#define RSCMU_MCR           1
#define RSCMU_VAL           2

// Mobile Network Code - digits
#define RSCMU_TWO           0
#define RSCMU_THREE         1

// IQ Analyzer
#define RSCMU_ISIREMOVED    0
#define RSCMU_UNFILTERED    1

#define RSCMU_P38           0
#define RSCMU_P38REMOVED    1

#define RSCMU_NORMAL        0
#define RSCMU_MEDIUM        1
#define RSCMU_SHORT         2


#define RSCMU_CTRL_ACK_MAIN  1
#define RSCMU_CTRL_ACK_OTHER 2

#define RSCMU_MOD_PERR       0
#define RSCMU_MOD_EVM        1
#define RSCMU_MOD_MERR       2

#define RSCMU_GSM_WSTR_MASTER 1
#define RSCMU_GSM_WSTR_SLAVE  2

#define RSCMU_GSM_FSTYPE_DBUR 0
#define RSCMU_GSM_FSTYPE_PRBS 1

#define RSCMU_GSM_WSTR_DRIFT_REMOVE 1
#define RSCMU_GSM_WSTR_DRIFT_ADD    2

#define RSCMU_GSM_2G 0
#define RSCMU_GSM_3G 1

#define RSCMU_GSM_FRQ_RSCP 0
#define RSCMU_GSM_FRQ_ECNO 1

// Repetition Interval
#define RSCMU_BSS_CBROADCAST_OFF 0
#define RSCMU_BSS_CBROADCAST_VAL 1

// Procedure Mode
#define RSCMU_NETW_PMODE_FAST 0
#define RSCMU_NETW_PMODE_REL  1

// SMS Content
#define RSCMU_NETW_SMS_HANDLE_INT 0
#define RSCMU_NETW_SMS_HANDLE_FILE 1

// CMI Phase 
#define RSCMU_NETW_AMR_CMIPH_ODD  0
#define RSCMU_NETW_AMR_CMIPH_EVEN 1

// Rate Set Reconfigure 
#define RSCMU_NETW_AMR_RSR_RATSCCH 0
#define RSCMU_NETW_AMR_RSR_CMM     1

// Traffic Mode after Handover 
#define RSCMU_NETW_TRAF_HANDOVER_SOURCE 0
#define RSCMU_NETW_TRAF_HANDOVER_DEST   1

// Invalid Result Detection Timeout
#define RSCMU_ABURST_IRDT_20  0
#define RSCMU_ABURST_IRDT_60  1
#define RSCMU_ABURST_IRDT_120 2

// Repeated Downlink SACCH
#define RSCMU_REP_DOWNLINK_DISABLE 0
#define RSCMU_REP_DOWNLINK_ENABLE  1
#define RSCMU_REP_DOWNLINK_SRR     2

//Level Mode
#define RSCMU_RFGEN_RXC_MODE_LLIST   0
#define RSCMU_RFGEN_RXC_MODE_IFLEVEL 1  

//SMS Message Class 
#define RSCMU_NETW_SMS_MSG_NONE     0
#define RSCMU_NETW_SMS_MSG_C0       1
#define RSCMU_NETW_SMS_MSG_C1       2
#define RSCMU_NETW_SMS_MSG_C2       3
#define RSCMU_NETW_SMS_MSG_C3       4

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//          INIT Functions
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

ViStatus _VI_FUNC RSCMU_Init_GSM_NSig         (ViSession, ViPSession, ViUInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_Init_GSM_Sig          (ViSession, ViPSession, ViUInt32, ViChar[]);

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//          CLOSE Functions
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

ViStatus _VI_FUNC RSCMU_Close_GSM_NSig        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_Close_GSM_Sig         (ViSession, ViChar[]);

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// Class: GSM Signalling & Non Signalling
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
ViStatus _VI_FUNC RSCMU_GSM_SigNSig_ConfIQIFRXTX    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_SigNSig_ConfIQIFRXPath  (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_SigNSig_ConfIQIFTXPath  (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_TrigMtg (ViSession instrumentHandle,
                                         ViInt32 triggerGap,
                                         ViChar errorMessage[]);

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// Class: GSM Non Signalling
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
ViStatus _VI_FUNC RSCMU_GSM_NSig_SensLevMode        (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SensLevMax         (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SensLevAtt         (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_TrigSour           (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_TrigThr            (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_TrigThrRFPow       (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_TrigThrIFPow       (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_TrigSlop           (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_TrigSourExt        (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_RfanChan           (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_RfanFreq           (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_RfanFreqOffs       (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_RfanTseq           (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfRfanTpcl       (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfRfan           (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfRfanMconTsoff  (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgLevUtim     (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgLevUnt      (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgFreqChan    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgFreq        (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgFmDev       (ViSession, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfRfgModTseqSel  (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfRfgModBitSel   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfRfgModTran     (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_InitRfg            (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborRfg            (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcRfgStat        (ViSession, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_AuxTXGenLevel      (ViSession,ViReal64,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_AuxTXGenFreq       (ViSession,ViReal64,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_AuxTXGenInit       (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_AuxTXGenAbort      (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_AuxTXGenFetchStat  (ViSession,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_AuxTXOutp          (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_AuxTXCorrOut       (ViSession,ViInt32,ViReal64,ViChar[]);



ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgOverLevAuxTx (ViSession,ViInt32,ViBoolean,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_AuxTXOvrLv (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_AuxTXCorrOvrLv (ViSession,ViInt32,ViReal64,ViChar[]);



ViStatus _VI_FUNC RSCMU_GSM_NSig_Inp                (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_Outp               (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SensCorrLossInp    (ViSession, ViInt32, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_SourCorrLossOutp   (ViSession, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_RoutSpenInp        (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_RoutSpdOutp        (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_SourDmCloc         (ViSession, ViInt32, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpowContRep    (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpowContRepStat(ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_InitSpow           (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborSpow           (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopSpow           (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContSpow           (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSpowStat       (ViSession, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpowErep       (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSpow           (ViSession, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSpow           (ViSession, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSpow           (ViSession, ViReal64*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfNpowCont       (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfNpowContRep    (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfNpowContStat   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfNpowContRepStat(ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_InitNpow           (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborNpow           (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopNpow           (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContNpow           (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcNpowStat       (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfNpowErep       (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadNpow           (ViSession, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcNpow           (ViSession, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampNpow           (ViSession, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowTimeMode    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowTimeBoff    (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowFilt        (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowContRep     (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_DispPowContGrid    (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowLimLineDef    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowLimLineLow    (ViSession, ViInt32, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowLimLineUpp    (ViSession, ViInt32, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowLimLineUppDyn (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowLimLineLowDyn (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowLimUppDynMod  (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowLimLowDynMod  (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowLimAbp        (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViReal64, ViInt32, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowCont        (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubPowRang     (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_InitPow            (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborPow            (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopPow            (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContPow            (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPowStat        (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowErep        (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadPow            (ViSession, ViReal64*, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPow            (ViSession, ViReal64*, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampPow            (ViSession, ViReal64*, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcPowLimMatc     (ViSession, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrPowBurs     (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrPowBurs     (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrPowBurs     (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcPowBursLimMatc (ViSession, ViInt32, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcPowResAreaLimMatc (ViSession, ViInt32, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrPowBurs  (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrPowBurs  (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrPowBurs  (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMslContRep    (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMslFilt (ViSession instrumentHandle_GSMNSig,
                                                 ViInt32 filter,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_DispPowMslContGrid   (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMslLimLineOtem (ViSession instrumentHandle, ViBoolean off_template, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMslCont       (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMslContRepStat(ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMslTsal (ViSession instrumentHandle, ViReal64 level, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMslMvi        (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMslSco        (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMslToff       (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMslLimGlev    (ViSession, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubPowMslRang    (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_InitPowMsl           (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborPowMsl           (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopPowMsl           (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContPowMsl           (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPowMslStat       (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMslErep       (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadPowMsl           (ViSession, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPowMsl           (ViSession, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampPowMsl           (ViSession, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcPowMslLimMatc    (ViSession, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrPowMsl        (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrPowMsl        (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrPowMsl        (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcArrPowMslLimMatc (ViSession, ViInt32, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcPowMslAreaLimMatc (ViSession, ViInt32, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrPowMsl     (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrPowMsl     (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrPowMsl     (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModContRep     (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModContDef     (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModLimLow      (ViSession, ViInt32, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModLimUpp      (ViSession, ViInt32, ViReal64, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModLimUppMod   (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModLimLowMod   (ViSession, ViBoolean, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModCont        (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModTimeDec     (ViSession, ViBoolean, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubModRang     (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_InitMod            (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborMod            (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopMod            (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContMod            (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcModStat        (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModErep        (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadMod            (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcMod            (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampMod            (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcModLimMatc     (ViSession, ViInt32, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrModBurs     (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrModBurs     (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrModBurs     (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrModBurs  (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrModBurs  (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrModBurs  (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_PowerTimeMeasTimeout (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMprContRep  (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMprCont     (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMprContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMprSubRang  (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_InitPowMpr         (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborPowMpr         (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopPowMpr         (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContPowMpr         (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPowMprStat     (ViSession instrSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowMprErep     (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadPowMpr         (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPowMpr         (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampPowMpr         (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcPowMprLimMatc  (ViSession, ViInt32, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrPowMprBurs  (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrPowMprBurs  (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrPowMprBurs  (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrPowMprBurs (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrPowMprBurs (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrPowMprBurs (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowSlotContDef (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowSlotContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowSlotContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubPowSlot (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_InitPowSlot (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborPowSlot (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopPowSlot (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContPowSlot (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPowSlotStat (ViSession, ViInt32*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowSlotErep (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadPowSlotSpow (ViSession, ViInt32, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPowSlotSpow (ViSession, ViInt32, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampPowSlotSpow (ViSession, ViInt32, ViReal64*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrPowSlot (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrPowSlot (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrPowSlot (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrPowSlot (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrPowSlot (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrPowSlot (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowXslContDef     (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowXslContRep     (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowXslContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubPowXsl    (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowXslSco    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowXslSco305 (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_InitPowXsl (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborPowXsl (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopPowXsl (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContPowXsl (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPowXslStat (ViSession, ViInt32*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowXslErep (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadPowXslSpow (ViSession, ViInt32, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPowXslSpow (ViSession, ViInt32, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampPowXslSpow (ViSession, ViInt32, ViReal64*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrPowXsl (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrPowXsl (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrPowXsl (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrPowXsl (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrPowXsl (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrPowXsl (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowFramContDef (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowFramContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowFramContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubPowFram (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_InitPowFram (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborPowFram (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopPowFram (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContPowFram (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPowFramStat (ViSession, ViInt32*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowFramErep (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadPowFramFpow (ViSession, ViInt32, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcPowFramFpow (ViSession, ViInt32, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampPowFramFpow (ViSession, ViInt32, ViReal64*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrPowFram (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrPowFram (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrPowFram (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrPowFram (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrPowFram (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrPowFram (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_InitModXper (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborModXper (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopModXper (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContModXper (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcModXperStat (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModXperErep (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModXperCont (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModXperContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModXperContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModXperContDef (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModXperLim (ViSession, ViBoolean, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModXperLimUppMod (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModXperLimLowMod (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModXperTimeDec (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModXperRstr (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfModXperFilt (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubModXper (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadModXper (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcModXper (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampModXper (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcModXperLimMatc (ViSession, ViInt32, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadModXperPoov (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcModXperPoov (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampModXperPoov (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcModXperPoovLimMatc (ViSession, ViInt32, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrModXper (ViSession ,ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrModXper (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrModXper (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrModXper (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrModXper (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrModXper (ViSession, ViInt32, ViReal64[], ViChar[]);










ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModDemodBits (ViSession,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadArrModDemodBits (ViSession,ViInt32,ViInt32[],ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcArrModDemodBits (ViSession,ViInt32,ViInt32[],ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampArrModDemodBits (ViSession,ViInt32,ViInt32[],ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadScalModDemodBits (ViSession,ViInt32,ViInt32,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcScalModDemodBits (ViSession,ViInt32,ViInt32,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampScalModDemodBits (ViSession,ViInt32,ViInt32,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadPeakModDemodBits (ViSession,ViInt32,ViInt32 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcPeakModDemodBits (ViSession,ViInt32,ViInt32 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampPeakModDemodBits (ViSession,ViInt32,ViInt32 *,ViInt32 *,ViChar[]);



ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfIqanContRmod (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfIqanContRep (ViSession,ViInt32,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfIqanIQFilter (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfIqanRotation (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_InitIqan (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_AborIqan (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_StopIqan (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ContIqan (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcIqanStat (ViSession,ViInt32 *,ViInt32 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfIqanErep (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadIqan (ViSession,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcIqan (ViSession,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampIqan (ViSession,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadArrIqanIPh (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadArrIqanQPh (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcArrIqanIPh (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcArrIqanQPh (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampArrIqanIPh (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampArrIqanQPh (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ModulationMeasTimeout (ViSession,ViInt32 ,ViChar[]);


ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecLimLineSel (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SpectrumMeasTimeout (ViSession instrumentHandle,
                                                      ViInt32 invalidResultDetectedTimeout,
                                                      ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitContDef  (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitContRep  (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_SpecSwitContStatMod (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_SpecSwitNoOfSlot (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_SpecSwitSlotCount   (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitFSelFTimeD (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_DispSpecSwitContGrid (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitLimLineDef (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitLimLine    (ViSession, ViInt32, ViReal64, ViInt32, ViReal64, ViReal64, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitLimLineMod   (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitCont       (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitContRepSta (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitContMpo  (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitVarMpo (ViSession,ViInt32,ViInt32,ViReal64,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubSpecSwit  (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubSpecSwitTime (ViSession,ViInt32,ViReal64,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_InitSpecSwit       (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborSpecSwit       (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopSpecSwit       (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContSpecSwit       (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSpecSwitStat   (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitErep   (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSpecSwit     (ViSession, ViReal64*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSpecSwit     (ViSession, ViReal64*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSpecSwit     (ViSession, ViReal64*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrSpecSwit    (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrSpecSwit    (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrSpecSwit     (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcSpecSwiAreaLimMatc (ViSession,ViInt32*,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrVarSpecSwit (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrVarSpecSwit (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrVarSpecSwit (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrSpecSwitTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrSpecSwitTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrSpecSwitTime (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrSpecSwit (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrSpecSwit (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrSpecSwit (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrSpecSwitTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrSpecSwitTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrSpecSwitTime (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_SensSpecSwiLimLineUsed (ViSession,ViInt32*,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecSwitConfAMP (ViSession,ViInt32,ViReal64,ViInt32,ViReal64,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSpecSwitAMP (ViSession,ViReal64*,ViReal64*,ViReal64*,ViReal64*,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModContDef (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_SpecModAvgAreas (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModFSelFTimeD (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_DispSpecModContGrid (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModLimLineDef  (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModLimLineRefp (ViSession, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModLimLine     (ViSession, ViInt32, ViInt32, ViReal64, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModLimLineMod  (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModCont    (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModContMpo (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModVarMpo (ViSession,ViInt32,ViInt32,ViReal64,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubSpecMod     (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubSpecModTime (ViSession,ViInt32,ViReal64,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_InitSpecMod        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborSpecMod        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopSpecMod        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContSpecMod        (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSpecModStat    (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecModErep    (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSpecMod        (ViSession, ViReal64*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSpecMod        (ViSession, ViReal64*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSpecMod        (ViSession, ViReal64*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrSpecMod     (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrSpecMod     (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrSpecMod     (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcSpecModAreaLimMatc (ViSession,ViInt32*,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrVarSpecMod (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrVarSpecMod (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrVarSpecMod (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrSpecModTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrSpecModTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrSpecModTime (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrSpecMod  (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrSpecMod  (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrSpecMod  (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubArrSpecModTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubArrSpecModTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubArrSpecModTime (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_SensSpecModLimLineUsed (ViSession,ViInt32*,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecMSwContRep (ViSession,ViInt32,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_InitSpecMSw        (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_AborSpecMSw        (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_StopSpecMSw        (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ContSpecMSw        (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSpecMSwStat    (ViSession,ViInt32 *,ViInt32 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecMSwErep    (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSpecMSw (ViSession,ViReal64 *,ViInt32 *,ViReal64 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSpecMSw (ViSession,ViReal64 *,ViInt32 *,ViReal64 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSpecMSw (ViSession,ViReal64 *,ViInt32 *,ViReal64 *,ViInt32 *,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrSpecMSw (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrSpecMSw (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrSpecMSw (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_CalcSpecMSwAreaLimMatc (ViSession,ViInt32 *,ViInt32 *,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrVarSpecMSw (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrVarSpecMSw (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrVarSpecMSw (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_SensSpecMswLimLineUsed (ViSession,ViInt32 *,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensSpecModLimLineUsed (ViSession,ViInt32*,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecMSwContRep (ViSession,ViInt32,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_InitSpecMSw        (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborSpecMSw        (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopSpecMSw        (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContSpecMSw        (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSpecMSwStat    (ViSession,ViInt32 *,ViInt32 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecMSwErep    (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSpecMSw (ViSession,ViReal64 *,ViInt32 *,ViReal64 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSpecMSw (ViSession,ViReal64 *,ViInt32 *,ViReal64 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSpecMSw (ViSession,ViReal64 *,ViInt32 *,ViReal64 *,ViInt32 *,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrSpecMSw (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrSpecMSw (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrSpecMSw (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcSpecMSwAreaLimMatc (ViSession,ViInt32 *,ViInt32 *,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrVarSpecMSw (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrVarSpecMSw (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrVarSpecMSw (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensSpecMswLimLineUsed (ViSession,ViInt32 *,ViChar[]);



ViStatus _VI_FUNC RSCMU_GSM_NSig_StatOperSymbEnab   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_StatOperSymb       (ViSession, ViInt32[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_AborMeas (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_TrigThrRFPow (ViSession, ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_TrigThrIFPow (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_TrigSlop (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ExtTrigOutSignal (ViSession,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ExtTrigOutDelayEnable (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ExtTrigOutDelayValue (ViSession, ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_WstrMode (ViSession instrumentHandle_GSMSig,
                                          ViInt32 triggerMode,
                                          ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_WstrFnum (ViSession instrumentHandle_GSMSig,
                                          ViInt32 masteSlave,
                                          ViInt32 frameNumber,
                                          ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_WstrMasterRout (ViSession instrumentHandle_GSMSig,
                                                ViInt32 PINNumber,
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_WstrSlaveSlot (ViSession instrumentHandle_GSMSig,
                                               ViInt32 slaveSlot,
                                               ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_WstrSlaveQsof (ViSession instrumentHandle_GSMSig,
                                               ViInt32 quarterSymbolOffset,
                                               ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_WstrSlaveSlop (ViSession instrumentHandle_GSMSig,
                                               ViInt32 triggerSlope,
                                               ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_WstrSlaveRout (ViSession instrumentHandle_GSMSig,
                                               ViInt32 PINNumber,
                                               ViChar errorMessage[]);

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// Class: GSM Signalling
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensLevMode         (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensLevMax          (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensLevAtt          (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_TrigSour            (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_TrigThr             (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignAct         (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensSignStat        (ViSession, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensSignSMS         (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSignSMS         (ViSession, ViChar[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignChcc          (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignMsPcl         (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignTchChan       (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignTchFhopSeq    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignTchTim        (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignDAI           (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignTadv          (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignMslMtim       (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignSslLoop (ViSession,ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSlotMode (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignMslBsSconfInd (ViSession, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignCswMslSconf (ViSession ,ViInt32,
                                                       ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,
                                                       ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,
                                                       ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,
                                                       ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,
                                                       ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignMslLoop  (ViSession,ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_HandTargListStat (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfHandTarg     (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfHandAlert (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfHandCSync (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignHandTargPrep (ViSession instrumentHandle_GSMSig,
                                                      ViBoolean GSMSignal,
                                                      ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfMssMconMesl  (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfMssCchPcl    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfMssDtx       (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfMssTadv      (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfMssMsPcl (ViSession instrumentHandle_GSMSig,
                                              ViInt32 powerControlLevel_PCL,
                                              ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfMssSslLoop (ViSession,ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfMssMslSconf  (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfMssMslLoop (ViSession,ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssSpe          (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcBssSpe          (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssFmDev        (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcBssFmDev        (ViSession, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcBssRandFmDev    (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssCchMode      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssCchChan      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssCchLevAbs    (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssAuxTxCchType   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssAuxTxCchChan   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssAuxTxCchLevAbs (ViSession, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssCchLevAbs (ViSession instrumentHandle_GSMSig,
                                                  ViReal64 ctrlChannelAbsLevel_dBm,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssCchCbr (ViSession instrumentHandle_GSMSig,
                                               ViBoolean state,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssCchCbrRep (ViSession instrumentHandle_GSMSig,
                                                  ViInt32 selectInterval,
                                                  ViReal64 repetitionInterval,
                                                  ViChar _VI_FAR errorMessage[]);


ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfCchBssAuxTxCcch (ViSession instrumentHandle_GSMSig, ViBoolean channelConflictCheck, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssCchAuxTxHlm (ViSession instrumentHandle_GSMSig,
                                                    ViBoolean state,
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssTchChan      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssTchTim       (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssTchLevUtim   (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcBssTchLevUtim   (ViSession, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssTchLevUnt    (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcBssTchLevUnt    (ViSession, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssDtx (ViSession instrumentHandle_GSMSig,
                                            ViBoolean DTXEnable,
                                            ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssFstype (ViSession instrumentHandle_GSMSig,
                                               ViInt32 fillingSignalType,
                                               ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssFsl (ViSession instrumentHandle_GSMSig,
                                            ViReal64 fillingSignalLevel,
                                            ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssTimAdv       (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcBssTimAdv       (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcBssTchFhopSeq   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssTchFhopChan  (ViSession, ViInt32, ViChar[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssMslRlev      (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcBssMslRlev      (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssMslMtim      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssMslLmod      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssMslSconfUun  (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssMslSconfInd  (ViSession, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssDrifPer (ViSession instrumentHandle_GSMSig,
                                                ViInt32 timingDriftPeriod,
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssDrifSsiz (ViSession instrumentHandle_GSMSig,
                                                 ViInt32 step_size,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwIdenNcc     (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwIdenMcc     (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwIdenMnc     (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwIdenMncDig (ViSession instrumentHandle_GSMSig, ViInt32 mobileNetworkCode_MNC_Digit, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwIdenBcc     (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwIdenLac     (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodLoc     (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodImsi    (ViSession, ViInt32, ViInt32, ViChar[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodCid (ViSession instrumentHandle_GSMSig,
                                                 ViChar CID[],
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodPch     (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodEupc (ViSession instrumentHandle_GSMSig,
                                                  ViInt32 EPCUplinkPowerControl,
                                                  ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodSch     (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcNetwSmodTraf (ViSession instrumentHandle_GSMSig, ViInt32 speechCoding, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcNetwSmodTrafHrs (ViSession instrumentHandle_GSMSig, ViInt32 halfRateSubchannel, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodTraf    (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodTrafHrs (ViSession instrumentHandle_GSMSig, ViInt32 halfRateSubchannel, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodBits    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcNetwSmodBits    (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcRusAct (ViSession instrumentHandle_GSMSig,
                                            ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatBpp (ViSession instrumentHandle_GSMSig,
                                                 ViBoolean state,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodLcom    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodStim    (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwTstime (ViSession instrumentHandle_GSMSig,
                                                ViInt32 startingTime,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatBpib (ViSession instrumentHandle_GSMSig,
                                                  ViBoolean state,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatPmode (ViSession instrumentHandle_GSMSig,
                                                   ViInt32 procedureMode,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmodTrafHand
             (ViSession instrumentHandle_GSMSig, ViInt32 trafficMode_afterHandover,
              ViChar _VI_FAR errorMessage[]);


ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwReqImsi     (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwReqImei     (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwReqAuth     (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwReqHand     (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwReqCthree (ViSession instrumentHandle_GSMSig, ViBoolean classmark3Request, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwDtx         (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPow         (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepRepc (ViSession instrumentHandle_GSMSig,
                                              ViInt32 *EPCRXQuality,
                                              ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSystBsag    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSystBsp     (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSystBspr    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSystCacc    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSystAcl     (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSystDusw (ViSession instrumentHandle_GSMSig,
                                                  ViBoolean DLULSwap,
                                                  ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSystBandInd (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSystPLUpdate (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwTimRlin     (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwTimRlinTest (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwTimMtc      (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwBal         (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwAOC         (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetw3GNCellEnable  (ViSession,ViBoolean,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetw3GNCellChannel (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetw3GNCellPSCode  (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwEmr (ViSession instrumentHandle_GSMSig,
                                             ViBoolean EMREnable,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwT2A (ViSession instrumentHandle_GSMSig,
                                             ViBoolean t200Auto,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwT2 (ViSession instrumentHandle_GSMSig,
                                            ViInt32 t200, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwNCell (ViSession instrumentHandle_GSMSig,
                                               ViInt32 generation,
                                               ViInt32 neighborCell,
                                               ViBoolean state,
                                               ViInt32 RFChannel,
                                               ViInt32 BSICScramblingCode,
                                               ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqMrepContDef (ViSession instrumentHandle_GSMSig,
                                                    ViBoolean state,
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqMrepContQsc (ViSession instrumentHandle_GSMSig,
                                                    ViInt32 qSearchC,
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqMrepContTgsp (ViSession instrumentHandle_GSMSig,
                                                     ViBoolean state,
                                                     ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatQsi (ViSession instrumentHandle_GSMSig,
                                                 ViInt32 qSearchI,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatFqoffset
             (ViSession instrumentHandle_GSMSig, ViInt32 FDDQOffset,
              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatFqmin (ViSession instrumentHandle_GSMSig,
                                                   ViInt32 FDDQMin,
                                                   ViChar _VI_FAR errorMessage[]);


ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqMrepContFrq (ViSession instrumentHandle_GSMSig,
                                                    ViInt32 FDDREPQuadrant,
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepNcelGsm (ViSession instrumentHandle_GSMSig,
                                                 ViInt32 neighborCell,
                                                 ViInt32 *RFChannel,
                                                 ViInt32 *GSMBSIC,
                                                 ViInt32 *indicator_ofRxLevel,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepNcelUfdd (ViSession instrumentHandle_GSMSig,
                                                  ViInt32 neighborCell,
                                                  ViInt32 *RFChannel,
                                                  ViInt32 *scramblingCode,
                                                  ViInt32 *CPICH,
                                                  ViReal64 *signalStrength,
                                                  ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwHoppHsn (ViSession instrumentHandle_GSMSig,
                                                 ViInt32 hoppingSequenceNumber,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwHoppMaio (ViSession instrumentHandle_GSMSig,
                                                  ViInt32 indexOffset,
                                                  ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReloadNetwSmsFile (ViSession instrumentHandle_GSMSig,
                                                ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmsIncSav (ViSession instrumentHandle_GSMSig,
                                                   ViBoolean automaticSaving,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmsIncAinc
             (ViSession instrumentHandle_GSMSig, ViBoolean automaticIncrementation,
              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmsIncLast
             (ViSession instrumentHandle_GSMSig, ViChar _VI_FAR SMSFile[],
              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwSmsFileStat (ViSession instrumentHandle,
                                                 ViPInt32 reloadStatus,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_CswSms (ViSession instrumentHandle_GSMSig,
                                        ViChar _VI_FAR SMSText[],
                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_CswSmsLrecEnc (ViSession instrumentHandle_GSMSig,
                                               ViPInt32 encoding,
                                               ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_CswSmsLrecLeng (ViSession instrumentHandle_GSMSig,
                                                ViPInt32 length,
                                                ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmsHand (ViSession instrumentHandle_GSMSig,
                                                 ViInt32 SMSContent,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmsClass (ViSession instrumentHandle_GSMSig,
                                                  ViInt32 SMSMessageClass,
                                                  ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmsFile (ViSession instrumentHandle_GSMSig,
                                                 ViInt32 messageContentIndex,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmsFileLeng
             (ViSession instrumentHandle_GSMSig, ViPInt32 length,
              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmsFileEnc
             (ViSession instrumentHandle_GSMSig, ViPInt32 encoding,
              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwSmsFileText
             (ViSession instrumentHandle_GSMSig, ViChar _VI_FAR messageText[],
              ViChar _VI_FAR errorMessage[]);


ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqFfacContRdf (ViSession instrumentHandle_GSMSig,
                                                    ViBoolean enable,
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_Inp                 (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_Outp                (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SourCorrLossOutp    (ViSession, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensCorrLossInp     (ViSession, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_RoutSpenInp         (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_RoutSpdOutp         (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SourDmCloc          (ViSession, ViInt32, ViReal64, ViChar[]);




ViStatus _VI_FUNC RSCMU_GSM_Sig_WsPort (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_WsIpAddress (ViSession,ViInt32,ViInt32,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_StartApplTest (ViSession,ViChar[]);




ViStatus _VI_FUNC RSCMU_GSM_Sig_L3MLogChangeDest      (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_L3MLogEnableBuffWrite (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_L3MLogSave            (ViSession, ViChar[], ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_L3MLogBufferEmpty     (ViSession, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepRxl         (ViSession, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepRxlFull (ViSession instrumentHandle_GSMSig,
                                                 ViPInt32 RXLevelFull,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepRxlSub (ViSession instrumentHandle_GSMSig,
                                                ViPInt32 RXLevelSub,
                                                ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepRxq         (ViSession, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepRxqFull (ViSession instrumentHandle_GSMSig,
                                                 ViPInt32 RXQualityFull,
                                                 ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepRxqSub (ViSession instrumentHandle_GSMSig,
                                                ViPInt32 RXQualitySub,
                                                ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepNceli       (ViSession, ViInt32[], ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepRPcl        (ViSession, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepDtx         (ViSession, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepCount       (ViSession, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepCValue   (ViSession,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepSVar     (ViSession,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepGmeanBep (ViSession,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrep8meanBep (ViSession,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepGCVBep   (ViSession,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrep8CVBep   (ViSession,ViInt32 *,ViChar[]);





ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwEnhMeasureRep (ViSession,ViBoolean,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepMeanBepEH (ViSession,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepCVBepEH (ViSession,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensRrepNrBlocksEH (ViSession,ViInt32 *,ViChar[]);



ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssImsi         (ViSession, ViInt32*, ViInt32*, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssImei         (ViSession, ViChar[], ViChar[], ViChar[], ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssRev          (ViSession, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssDnum         (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssTraf         (ViSession, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssPowClas      (ViSession, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssCtt (ViSession instrumentHandle_GSMSig,
                                            ViPInt32 CTMTextTelephony,
                                            ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssBand (ViSession instrumentHandle_GSMSig, ViInt32 band, ViChar support[], ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssSban (ViSession instrumentHandle_GSMSig, ViChar band[], ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssMsclCsw      (ViSession, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssMsclPdatGprs  (ViSession, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssMsclPdatEgprs (ViSession, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrHrCModeDL (ViSession instrumentHandle_GSMSig,
                                                  ViInt32 independentValue,
                                                  ViInt32 codecModeDL,
                                                  ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrHrCModeUL (ViSession instrumentHandle_GSMSig,
                                                  ViInt32 independentValue,
                                                  ViInt32 codecModeUL,
                                                  ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrHrRSet (ViSession instrumentHandle_GSMSig,
                                               ViInt32 independentValue,
                                               ViInt32 codecMode4,
                                               ViInt32 codecMode3,
                                               ViInt32 codecMode2,
                                               ViInt32 codecMode1,
                                               ViReal64 thresholdDown4,
                                               ViReal64 thresholdUp3,
                                               ViReal64 thresholdDown3,
                                               ViReal64 thresholdUp2,
                                               ViReal64 thresholdDown2,
                                               ViReal64 thresholdUp1,
                                               ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbFrRSet (ViSession instrumentHandle_GSMSig,
                                                 ViInt32 independentValue,
                                                 ViInt32 codecMode4,
                                                 ViInt32 codecMode3,
                                                 ViInt32 codecMode2,
                                                 ViInt32 codecMode1,
                                                 ViReal64 thresholdDown4,
                                                 ViReal64 thresholdUp3,
                                                 ViReal64 thresholdDown3,
                                                 ViReal64 thresholdUp2,
                                                 ViReal64 thresholdDown2,
                                                 ViReal64 thresholdUp1,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrFrUlcmCstr (ViSession instrumentHandle_GSMSig,
                                                   ViBoolean CMCStress,
                                                   ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbFrUlcmCstr
             (ViSession instrumentHandle_GSMSig, ViBoolean CMCStress,
              ViChar _VI_FAR errorMessage[]);



ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrHrECModeDL (ViSession instrumentHandle_GSMSig,
                                                   ViInt32 independentValue,
                                                   ViInt32 codecModeDL,
                                                   ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbHrECModeDL (ViSession instrumentHandle_GSMSig,
                                                     ViInt32 independentValue,
                                                     ViInt32 codecModeDL,
                                                     ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrHrECModeUL (ViSession instrumentHandle_GSMSig,
                                                   ViInt32 independentValue,
                                                   ViInt32 codecModeUL,
                                                   ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbHrECModeUL (ViSession instrumentHandle_GSMSig,
                                                     ViInt32 independentValue,
                                                     ViInt32 codecModeDL,
                                                     ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrHrERSet (ViSession instrumentHandle_GSMSig,
                                                ViInt32 independentValue,
                                                ViInt32 codecMode4,
                                                ViInt32 codecMode3,
                                                ViInt32 codecMode2,
                                                ViInt32 codecMode1,
                                                ViReal64 thresholdDown4,
                                                ViReal64 thresholdUp3,
                                                ViReal64 thresholdDown3,
                                                ViReal64 thresholdUp2,
                                                ViReal64 thresholdDown2,
                                                ViReal64 thresholdUp1,
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbHrERSet (ViSession instrumentHandle_GSMSig,
                                                  ViInt32 independentValue,
                                                  ViInt32 codecMode4,
                                                  ViInt32 codecMode3,
                                                  ViInt32 codecMode2,
                                                  ViInt32 codecMode1,
                                                  ViReal64 thresholdDown4,
                                                  ViReal64 thresholdUp3,
                                                  ViReal64 thresholdDown3,
                                                  ViReal64 thresholdUp2,
                                                  ViReal64 thresholdDown2,
                                                  ViReal64 thresholdUp1,
                                                  ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrHrEUlcmCstr
             (ViSession instrumentHandle_GSMSig, ViBoolean CMCStress,
              ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbHrEUlcmCstr
             (ViSession instrumentHandle_GSMSig, ViBoolean CMCStress,
              ViChar _VI_FAR errorMessage[]);


ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbFrECModeDL (ViSession instrumentHandle_GSMSig,
                                                     ViInt32 independentValue,
                                                     ViInt32 codecModeDL,
                                                     ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbFrECModeUL (ViSession instrumentHandle_GSMSig,
                                                     ViInt32 independentValue,
                                                     ViInt32 codecModeUL,
                                                     ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbFrECSet (ViSession instrumentHandle_GSMSig,
                                                  ViInt32 independentValue,
                                                  ViInt32 codecMode4,
                                                  ViInt32 codecMode3,
                                                  ViInt32 codecMode2,
                                                  ViInt32 codecMode1,
                                                  ViReal64 thresholdDown4,
                                                  ViReal64 thresholdUp3,
                                                  ViReal64 thresholdDown3,
                                                  ViReal64 thresholdUp2,
                                                  ViReal64 thresholdDown2,
                                                  ViReal64 thresholdUp1,
                                                  ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbFrEUlcmCstr
             (ViSession instrumentHandle_GSMSig, ViBoolean CMCStress,
              ViChar _VI_FAR errorMessage[]);


ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrFrDl (ViSession,ViInt32*,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrWbFrDl (ViSession instrumentHandle_GSMSig,
                                                  ViInt32 *codecMode,
                                                  ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrWbFrUl (ViSession instrumentHandle_GSMSig,
                                                  ViInt32 *codecMode,
                                                  ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrFrUl (ViSession,ViInt32*,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrHrDl (ViSession,ViInt32*,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrHrUl (ViSession,ViInt32*,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssMsclDtmGprs (ViSession instrumentHandle_GSMSig, ViInt32 *multislotClass, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssMsclDtmEgprs (ViSession instrumentHandle_GSMSig, ViInt32 *multislotClass, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssPowClasGmsk (ViSession instrumentHandle_GSMSig, ViInt32 *powerClass, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssPowClasEpsk (ViSession instrumentHandle_GSMSig, ViInt32 *powerClass, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpowContRep     (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpowContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_InitSpow            (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborSpow            (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopSpow            (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContSpow            (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSpowStat        (ViSession, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpowErep        (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSpow            (ViSession, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSpow            (ViSession, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSpow            (ViSession, ViReal64*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNpowCont        (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNpowContRep     (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNpowContStat    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNpowContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_InitNpow            (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborNpow            (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopNpow            (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContNpow            (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcNpowStat        (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNpowErep        (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadNpow            (ViSession, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcNpow            (ViSession, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampNpow            (ViSession, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowTimeMode     (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowTimeBoff     (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowFilt         (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowContRep      (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_DispPowContGrid     (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowLimLineDef   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowLimLineUpp   (ViSession, ViInt32, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowLimLineLow   (ViSession, ViInt32, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowLimLineUppDyn (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowLimLineLowDyn (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowLimUppDynMod  (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowLimLowDynMod  (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowLimAbp       (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViReal64, ViInt32, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowCont         (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowContRepStat  (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubPowRang      (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_InitPow             (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborPow             (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopPow             (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContPow             (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowStat         (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowErep         (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowAbursIrdt (ViSession instrumentHandle_GSMSig,
                                                  ViInt32 detectionTimeout,
                                                  ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPow             (ViSession, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPow             (ViSession, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampPow             (ViSession, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcPowLimMatc      (ViSession, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrPowBurs      (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrPowBurs      (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrPowBurs      (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrPowBurs   (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrPowBurs   (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrPowBurs   (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcPowBursLimMatc    (ViSession, ViInt32, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcPowResAreaLimMatc (ViSession, ViInt32, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMslContRep     (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_DispPowMslContGrid    (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMslLimLineOtem (ViSession instrumentHandle_GSMSig, ViBoolean off_template, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMslCont        (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMslContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMslTsal (ViSession instrumentHandle_GSMSig, ViReal64 level, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMslMvi         (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMslSco         (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMslToff        (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMslLimGlev     (ViSession, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubPowMslRang     (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_InitPowMsl            (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborPowMsl            (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopPowMsl            (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContPowMsl            (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowMslStat        (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMslErep        (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowMsl            (ViSession, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowMsl            (ViSession, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampPowMsl            (ViSession, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcPowMslLimMatc     (ViSession, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrPowMsl         (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrPowMsl         (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrPowMsl         (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcArrPowMslLimMatc  (ViSession, ViInt32, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcPowMslAreaLimMatc (ViSession, ViInt32, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrPowMsl      (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrPowMsl      (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrPowMsl      (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_PowerTimeMeasTimeout (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowAburTimeBoff (ViSession, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubPowAburRang  (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_InitPowAbur         (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborPowAbur         (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopPowAbur         (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContPowAbur         (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowAburStat     (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowAburErep     (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowAbur         (ViSession, ViReal64 *, ViReal64 *, ViInt32 *, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowAbur         (ViSession, ViReal64 *, ViReal64 *, ViInt32 *, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampPowAbur         (ViSession, ViReal64 *, ViReal64 *, ViInt32 *, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcPowAburLimMatc  (ViSession, ViInt32 *, ViInt32 *, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrPowAbur      (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrPowAbur      (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrPowAbur      (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcArrPowAburLimMatc  (ViSession, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcPowAburAreaLimMatc (ViSession, ViInt32 *, ViInt32 *, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrPowAbur   (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrPowAbur   (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrPowAbur   (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowSlotContDef     (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowSlotContRep     (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowSlotContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubPowSlot (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_InitPowSlot (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborPowSlot (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopPowSlot (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContPowSlot (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowSlotStat (ViSession, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowSlotErep (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowSlot (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowSlot (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampPowSlot (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowSlotSpow (ViSession, ViInt32, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowSlotSpow (ViSession, ViInt32, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampPowSlotSpow (ViSession, ViInt32, ViReal64*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrPowSlot (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrPowSlot (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrPowSlot (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrPowSlot (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrPowSlot (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrPowSlot (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowXslContDef     (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowXslContRep     (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowXslContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubPowXsl    (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowXslSco    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowXslSco305 (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_InitPowXsl (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborPowXsl (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopPowXsl (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContPowXsl (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowXslStat (ViSession, ViInt32*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowXslErep (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowXslSpow (ViSession, ViInt32, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowXslSpow (ViSession, ViInt32, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampPowXslSpow (ViSession, ViInt32, ViReal64*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrPowXsl (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrPowXsl (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrPowXsl (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrPowXsl (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrPowXsl (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrPowXsl (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowFramContDef (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowFramContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowFramContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubPowFram (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_InitPowFram (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborPowFram (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopPowFram (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContPowFram (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowFramStat (ViSession, ViInt32*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowFramErep (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowFramFpow (ViSession, ViInt32, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowFramFpow (ViSession, ViInt32, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampPowFramFpow (ViSession, ViInt32, ViReal64*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrPowFram (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrPowFram (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrPowFram (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrPowFram (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrPowFram (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrPowFram (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowPclContRep     (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowPclContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowPclChanCount   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowPclChan        (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowPcl7Chan (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_InitPowPcl          (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborPowPcl          (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopPowPcl          (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContPowPcl          (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowPclStat      (ViSession, ViPInt32, ViPInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowPclErep      (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowPcl          (ViSession, ViReal64[], ViReal64[], ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowPcl          (ViSession, ViReal64[], ViReal64[], ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampPowPcl          (ViSession, ViReal64[], ViReal64[], ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcPowPclLimMatc   (ViSession, ViInt32[], ViInt32[], ViInt32[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowPclp         (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowPclp         (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampPowPclp         (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMprCont      (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMprContRep   (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMprContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMprSubRang  (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrSpecSwitTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrSpecSwitTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrSpecSwitTime (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrSpecSwit  (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrSpecSwit  (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrSpecSwit  (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_InitPowMpr        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborPowMpr        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopPowMpr        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContPowMpr        (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowMprStat      (ViSession instrSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowMprErep      (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowMpr        (ViSession, ViInt32, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcPowMpr        (ViSession, ViInt32, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampPowMpr        (ViSession, ViInt32, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcPowMprLimMatc   (ViSession, ViInt32, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrPowMprBurs   (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrPowMprBurs   (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrPowMprBurs   (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrPowMprBurs (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrPowMprBurs (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrPowMprBurs (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModContRep      (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModContDef (ViSession instrumentHandle,
                                                    ViBoolean setDefaultValues,
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModLimDef (ViSession instrumentHandle,
                                               ViBoolean defaultLimitLines,
                                               ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModLim          (ViSession, ViInt32, ViReal64, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModLimUppMod    (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModLimLowMod    (ViSession, ViBoolean, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModCont         (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModContRepStat  (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModTimeDec      (ViSession, ViBoolean, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModFilt (ViSession instrumentHandle_GSMNSig,
                                             ViInt32 filter,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubModRang      (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_InitMod             (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborMod             (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopMod             (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContMod             (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcModStat         (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModErep         (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadMod             (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcMod (ViSession instrumentHandle_GSMSig,
                                         ViInt32 statisticsMode,
                                         ViReal64 *phErrPeak_Deg,
                                         ViReal64 *phErrRMS_Deg,
                                         ViReal64 *freqErr_Hz,
                                         ViReal64 *avgBurstPowerCurr_dBm,
                                         ViReal64 *burstOutOfTol_,
                                         ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampMod             (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcModLimMatc      (ViSession, ViInt32, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrModBurs      (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrModBurs      (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrModBurs      (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrModBurs   (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrModBurs   (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrModBurs   (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_InitModXper (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborModXper (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopModXper (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContModXper (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcModXperStat (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModXperErep (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModXperCont (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModXperContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModXperContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModXperContDef (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModXperLim (ViSession, ViBoolean, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModXperLimUppMod (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModXperLimLowMod (ViSession, ViBoolean, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModXperTimeDec (ViSession, ViBoolean, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModXperRstr (ViSession instrumentHandle_GSMSig, ViBoolean raw_symbol_timing_recovery, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfModXperFilt (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubModXper (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadModXper (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcModXper (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampModXper (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcModXperLimMatc (ViSession, ViInt32, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadModXperPoov (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcModXperPoov (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampModXperPoov (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcModXperPoovLimMatc (ViSession, ViInt32, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrModXper (ViSession ,ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrModXper (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrModXper (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrModXper (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrModXper (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrModXper (ViSession, ViInt32, ViReal64[], ViChar[]);






ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModDemodBits (ViSession,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadArrModDemodBits (ViSession,ViInt32,ViInt32[],ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcArrModDemodBits (ViSession,ViInt32,ViInt32[],ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampArrModDemodBits (ViSession,ViInt32,ViInt32[],ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadScalModDemodBits (ViSession,ViInt32,ViInt32,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcScalModDemodBits (ViSession,ViInt32,ViInt32,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampScalModDemodBits (ViSession,ViInt32,ViInt32,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadPeakModDemodBits (ViSession,ViInt32,ViInt32 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcPeakModDemodBits (ViSession,ViInt32,ViInt32 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampPeakModDemodBits (ViSession,ViInt32,ViInt32 *,ViInt32 *,ViChar[]);





ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfIqanContRmod (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfIqanContRep (ViSession,ViInt32,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfIqanIQFilter (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfIqanRotation (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_InitIqan (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_AborIqan (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_StopIqan (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ContIqan (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcIqanStat (ViSession,ViInt32 *,ViInt32 *,ViInt32 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfIqanErep (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadIqan (ViSession,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcIqan (ViSession,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampIqan (ViSession,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViReal64 *,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadArrIqanIPh (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadArrIqanQPh (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcArrIqanIPh (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcArrIqanQPh (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampArrIqanIPh (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampArrIqanQPh (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ModulationMeasTimeout (ViSession,ViInt32,ViChar[]);








ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecLimLineSel (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecTriggerMode (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSpecBand (ViSession instrumentHandle,
                                              ViInt32 resolution,
                                              ViChar errorMessage[]);


ViStatus _VI_FUNC RSCMU_GSM_Sig_SpectrumMeasTimeout (ViSession instrumentHandle,
                                                     ViInt32 invalidResultDetectedTimeout,
                                                     ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitContDef (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SpecSwitContStatMod (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SpecSwitNoOfSlot (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SpecSwitSlotCount   (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitFSelFTimeD (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_DispSpecSwitContGrid(ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitLimLineDef  (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitLimLine (ViSession, ViInt32, ViReal64, ViInt32, ViReal64, ViReal64, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitLimLineMode (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitCont    (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitContMpo (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitVarMpo (ViSession,ViInt32,ViInt32,ViReal64,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubSpecSwit     (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubSpecSwitTime (ViSession,ViInt32,ViReal64,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_InitSpecSwit        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborSpecSwit        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopSpecSwit        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContSpecSwit        (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSpecSwitStat    (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitErep    (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSpecSwit      (ViSession, ViReal64*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSpecSwit      (ViSession, ViReal64*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSpecSwit      (ViSession, ViReal64*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrSpecSwit     (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrSpecSwit     (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrSpecSwit     (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcSpecSwiAreaLimMatc (ViSession,ViInt32*,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrVarSpecSwit (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrVarSpecSwit (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrVarSpecSwit (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrSpecSwitTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrSpecSwitTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrSpecSwitTime (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensSpecSwiLimLineUsed (ViSession,ViInt32*,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecSwitConfAMP (ViSession,ViInt32,ViReal64,ViInt32,ViReal64,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSpecSwitAMP (ViSession,ViReal64*,ViReal64*,ViReal64*,ViReal64*,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModContDef  (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SpecModAvgAreas (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModContRep  (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModFSelFTimeD (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_DispSpecModContGrid (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModLimLineDef   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModLimLineRefp  (ViSession, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModLimLine    (ViSession, ViInt32, ViInt32, ViReal64, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModLimLineMod   (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModCont         (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModContRepStat  (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModContMpo  (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModVarMpo (ViSession,ViInt32,ViInt32,ViReal64,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubSpecMod      (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSubSpecModTime (ViSession,ViInt32,ViReal64,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_InitSpecMod         (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborSpecMod         (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopSpecMod         (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContSpecMod         (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSpecModStat     (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSpecModErep     (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSpecMod       (ViSession, ViReal64*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSpecMod       (ViSession, ViReal64*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSpecMod       (ViSession, ViReal64*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrSpecMod      (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrSpecMod      (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrSpecMod    (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_CalcSpecModAreaLimMatc (ViSession,ViInt32*,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrVarSpecMod (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrVarSpecMod (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrVarSpecMod (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadArrSpecModTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcArrSpecModTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampArrSpecModTime (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrSpecMod   (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrSpecMod   (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrSpecMod   (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadSubArrSpecModTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSubArrSpecModTime (ViSession,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SampSubArrSpecModTime (ViSession,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensContHtim  (ViSession, ViReal64, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensBitStream (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqContAgct (ViSession instrumentHandle_GSMSig, ViReal64 AGCHoldoffTime, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensConfEarlyFail (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensConfEarlyPass (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensConfResWind (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensConfMinTTime (ViSession, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensSearchMaxCycles (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensSearchUppLevLim (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensSearchLowLevLim (ViSession, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensContDef   (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensCont      (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensContPData (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensContRep   (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensContLevUtim    (ViSession, ViInt32, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensContLevUnt     (ViSession, ViInt32, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensContMslRlev    (ViSession, ViInt32, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensMslRlevPdata   (ViSession, ViInt32, ViInt32, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensContMslLevInd  (ViSession, ViInt32, ViInt32, ViInt32, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensContMslLevSlot (ViSession, ViInt32, ViInt32, ViInt32, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensContMslLevIndPd (ViSession ,ViInt32 ,ViInt32 ,ViInt32 ,ViReal64 ,ViReal64 ,ViReal64 ,ViReal64 ,ViReal64 ,ViReal64 ,ViReal64 ,ViReal64 ,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensMslLevSlotPdata (ViSession,ViInt32,ViInt32,ViInt32,ViReal64,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensLimDef    (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensLimCLII   (ViSession, ViInt32, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensLimCLIB   (ViSession, ViInt32, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensLimFERR   (ViSession, ViInt32, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensLimDBLER  (ViSession, ViInt32, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensLimUSFB   (ViSession, ViInt32, ViInt32, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensTset    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_InitSens      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborSens      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_StopSens      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ContSens      (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSensStat    (ViSession, ViInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfSensErep    (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_Rfer_ReadSens     (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_Rfer_FetcSens     (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_Rfer_SampSens     (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcSensStatProg (ViSession instrumentHandle,
                                                  ViPInt32 progressTime,
                                                  ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_Res_Rfer (ViSession instrumentHandle_GSMSig,
                                          ViInt32 command,
                                          ViReal64 *progressTime,
                                          ViReal64 *classIIBits_,
                                          ViReal64 *classIbBits_,
                                          ViReal64 *frameErasureRate_,
                                          ViInt32 *CRC_errors, ViInt32 *status,
                                          ViInt32 *statisticalResult,
                                          ViInt32 *RFSearchLevel,
                                          ViReal64 *RFSearchLevelValue,
                                          ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_Rfer_CalcSensLimMatc (ViSession, ViInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_Res_Confidence_Rfer (ViSession,ViInt32,ViPReal64,ViPReal64,ViPReal64,ViPReal64,ViPInt32,ViPInt32,ViPInt32,ViChar[]);


ViStatus _VI_FUNC RSCMU_GSM_Sig_Ber_ReadSens    (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_Ber_FetcSens    (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_Ber_SampSens    (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_Res_BER (ViSession instrumentHandle_GSMSig,
                                         ViInt32 command, ViReal64 *progressTime,
                                         ViReal64 *classIIBits_,
                                         ViReal64 *classIbBits_,
                                         ViInt32 *CRC_errors, ViInt32 *status,
                                         ViInt32 *statisticalResult,
                                         ViInt32 *RFSearchLevel,
                                         ViReal64 *RFSearchLevelValue,
                                         ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_Ber_CalcSensLimMatc (ViSession, ViInt32, ViPInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_Res_Confidence_BER (ViSession,ViInt32,ViPReal64,ViPReal64,ViPReal64,ViPInt32,ViPInt32,ViPInt32,ViChar[]);


ViStatus _VI_FUNC RSCMU_GSM_Sig_Bbb_ReadSens (ViSession, ViInt32, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_Bbb_FetcSens (ViSession, ViInt32, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_Bbb_SampSens (ViSession, ViInt32, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_Res_Bbb (ViSession instrumentHandle_GSMSig,
                                         ViInt32 command, ViReal64 *progressTime,
                                         ViReal64 *ber, ViInt32 *CRC_errors,
                                         ViInt32 *status,
                                         ViInt32 *statisticalResult,
                                         ViInt32 *RFSearchLevel,
                                         ViReal64 *RFSearchLevelValue,
                                         ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_Bbb_CalcSensLimMatc (ViSession, ViInt32, ViPInt32, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_Res_Confidence_Bbb (ViSession,ViInt32,ViPReal64,ViPReal64,ViPInt32,ViPInt32,ViPInt32,ViChar[]);


ViStatus _VI_FUNC RSCMU_GSM_Sig_Dbler_ReadSens (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_Dbler_FetcSens (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_Dbler_SampSens (ViSession, ViInt32, ViPReal64, ViPReal64, ViPReal64, ViPReal64, ViPInt32, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_Dbler_CalcSensLimMatc (ViSession,ViInt32,ViPInt32,ViPInt32,ViPInt32,ViPInt32,ViPInt32,ViPInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_Res_Confidence_Dbler  (ViSession,ViInt32,ViPReal64,ViPReal64,ViPReal64,ViPReal64,ViPInt32,ViPInt32,ViPInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_BER_Res_Dbler_352 (ViSession,ViInt32,ViPReal64,ViPReal64,ViPReal64,ViPReal64,ViPInt32,ViPInt32,ViPInt32,ViPReal64,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_BER_Res_Dbler (ViSession instrumentHandle_GSMSig,
                                               ViInt32 command,
                                               ViReal64 *progressTime,
                                               ViReal64 *ber, ViReal64 *usfBler,
                                               ViReal64 *dbler,
                                               ViInt32 *CRC_errors,
                                               ViInt32 *status,
                                               ViInt32 *statisticalResult,
                                               ViReal64 *falseUsfDetection,
                                               ViInt32 *RFSearchLevel,
                                               ViReal64 *RFSearchLevelValue,
                                               ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_BAV_Res_Dbler_352 (ViSession,ViInt32,ViPReal64,ViPReal64,ViPReal64,ViPReal64,ViPInt32,ViPInt32,ViPReal64,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_Dbler_CalcLimMatc_352 (ViSession,ViInt32,ViPInt32,ViPInt32,ViPInt32,ViPInt32,ViPInt32,ViPInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_Aibf_CalcSensLimMatc (ViSession instrumentHandle_GSMSig,
                                                      ViInt32 measurementType,
                                                      ViInt32 *total,
                                                      ViInt32 *frameErasureRate,
                                                      ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_Res_Aibf (ViSession instrumentHandle_GSMSig,
                                          ViInt32 command,
                                          ViReal64 *progressTime,
                                          ViReal64 *frameErasureRate_,
                                          ViInt32 *status,
                                          ViInt32 *statisticalResult,
                                          ViInt32 *RFSearchLevel,
                                          ViReal64 *RFSearchLevelValue,
                                          ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_Aibf_FetcSens (ViSession instrumentHandle_GSMSig,
                                               ViInt32 application,
                                               ViReal64 *progressTime,
                                               ViReal64 *frameErasureRate_,
                                               ViInt32 *status,
                                               ViChar errorMessage[]);


ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqRdContRep (ViSession instrumentHandle,
                                                  ViInt32 repetition,
                                                  ViInt32 stopCondition,
                                                  ViInt32 stepMode,
                                                  ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqRdsContDef (ViSession instrumentHandle,
                                                   ViBoolean setDefaultValues,
                                                   ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqRdsLimRsac (ViSession instrumentHandle,
                                                   ViReal64 repeatedSACCHLimit,
                                                   ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqRdsContLevUtim (ViSession instrumentHandle,
                                                       ViReal64 usedTimeslot,
                                                       ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqRdsContLevUnt (ViSession instrumentHandle,
                                                      ViReal64 unusedTimeslot,
                                                      ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqRdsContRds
             (ViSession instrumentHandle_GSMNSig, ViInt32 repeatedDownlinkSACCH,
              ViChar _VI_FAR errorMessage[]);


ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqRdsContMslRlev (ViSession instrumentHandle,
                                                       ViReal64 referenceLevel,
                                                       ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqRdsContMslLevInd (ViSession instrumentHandle,
                                                         ViReal64 referenceLevel[],
                                                         ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_InitRxqRds (ViSession instrumentHandle,
                                            ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_AborRxqRds (ViSession instrumentHandle,
                                            ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_StopRxqRds (ViSession instrumentHandle,
                                            ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ContRxqRds (ViSession instrumentHandle,
                                            ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqRdsErep (ViSession instrumentHandle,
                                                ViInt32 measurementEventReporting,
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcRxqRdsStat (ViSession instrumentHandle,
                                                ViInt32 *measurementStatus,
                                                ViInt32 *counter_for_current_stat_cycle,
                                                ViInt32 *counter_for_current_eval_period,
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadRxqRds (ViSession instrumentHandle,
                                            ViReal64 *repeatedSACCH,
                                            ViReal64 *repeatedSACCH_,
                                            ViReal64 *SACCHSent, ViInt32 *status,
                                            ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcRxqRds (ViSession instrumentHandle,
                                            ViReal64 *repeatedSACCH,
                                            ViReal64 *repeatedSACCH_,
                                            ViReal64 *SACCHSent, ViInt32 *status,
                                            ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SampRxqRds (ViSession instrumentHandle,
                                            ViReal64 *repeatedSACCH,
                                            ViReal64 *repeatedSACCH_,
                                            ViReal64 *SACCHSent, ViInt32 *status,
                                            ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_CalcRxqRdsLimMatc (ViSession instrumentHandle,
                                                    ViInt32 *totalStatus,
                                                    ViInt32 *repeatedSACCH,
                                                    ViInt32 *repeatedSACCH_,
                                                    ViInt32 *SACCHSent,
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrEHrDl (ViSession instrumentHandle_GSMSig,
                                                 ViInt32 *codecMode,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrWbEHrDl (ViSession instrumentHandle_GSMSig,
                                                   ViInt32 *codecMode,
                                                   ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrWbEHrUl (ViSession instrumentHandle_GSMSig,
                                                   ViInt32 *codecMode,
                                                   ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrEHrUl (ViSession instrumentHandle_GSMSig,
                                                 ViInt32 *codecMode,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrWbEFrDl (ViSession instrumentHandle_GSMSig,
                                                   ViInt32 *codecMode,
                                                   ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrWbEFrUl (ViSession instrumentHandle_GSMSig,
                                                   ViInt32 *codecMode,
                                                   ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqCmrpContTlev (ViSession instrumentHandle,
                                                     ViReal64 targetLevel,
                                                     ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqFfacContRep (ViSession instrumentHandle,
                                                    ViInt32 repetition,
                                                    ViInt32 stopCondition,
                                                    ViInt32 stepMode,
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqFfacContDef (ViSession instrumentHandle,
                                                    ViBoolean setDefaultValues,
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqFfacLimFer (ViSession instrumentHandle,
                                                   ViReal64 repeatedFFACCHLimit,
                                                   ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqFfacContLevUnt (ViSession instrumentHandle,
                                                       ViReal64 unusedTimeslot,
                                                       ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqFfaContMslLevInd (ViSession instrumentHandle,
                                                         ViReal64 referenceLevel[],
                                                         ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_InitRxqFfac (ViSession instrumentHandle,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_AborRxqFfac (ViSession instrumentHandle,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_StopRxqFfac (ViSession instrumentHandle,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ContRxqFfac (ViSession instrumentHandle,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqFfacErep (ViSession instrumentHandle,
                                                 ViInt32 measurementEventReporting,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcRxqFfacStat (ViSession instrumentHandle,
                                                 ViInt32 *measurementStatus,
                                                 ViInt32 *counter_for_current_stat_cycle,
                                                 ViInt32 *counter_for_current_eval_period,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadRxqFfac (ViSession instrumentHandle,
                                             ViReal64 *l2FramesRepeated,
                                             ViReal64 *FER, ViReal64 *framesSent,
                                             ViInt32 *status,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcRxqFfac (ViSession instrumentHandle,
                                             ViReal64 *l2FramesRepeated,
                                             ViReal64 *FER, ViReal64 *framesSent,
                                             ViInt32 *status,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SampRxqFfac (ViSession instrumentHandle,
                                             ViReal64 *l2FramesRepeated,
                                             ViReal64 *FER, ViReal64 *framesSent,
                                             ViInt32 *status,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_StatOperSymbEnab (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_StatOperSymb     (ViSession, ViInt32[], ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwIden        (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwReq         (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwTim         (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_AborMeas      (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_Init_Measurements   (ViSession, ViBoolean, ViBoolean, ViBoolean, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowMprRfer       (ViSession, ViInt32, ViReal64, ViReal64*, ViInt32*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowMprBbb        (ViSession, ViInt32, ViReal64, ViReal64*, ViInt32*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_WaitForMsSync       (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_CallToMobile        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_CallFromMobile      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ReleaseCallFromCMU  (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_HandOver            (ViSession, ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfPowLim          (ViSession, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViChar[]);

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// Class:
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowTimeBoff (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowContRep  (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowFilt     (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowRPMode   (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_DispPowContGrid (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowLimLineDef (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowLimLineUpp (ViSession, ViInt32, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64,
                                                      ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowLimLineLow (ViSession, ViInt32, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64,
                                                      ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowLimLineUppDyn (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowLimLineLowDyn (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowLimUppDynMod  (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowLimLowDynMod  (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowCont (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfArrPowRang (ViSession, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSubPowRang (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_InitPow (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_AborPow (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_StopPow (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ContPow (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcPowStat (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfPowErep (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadPow (ViSession, ViReal64*, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcPow (ViSession, ViReal64*, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampPow (ViSession, ViReal64*, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViChar []);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_CalcPowLimMatc (ViSession, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadArrPowBurs (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcArrPowBurs (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampArrPowBurs (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_CalcPowBursLimMatc (ViSession, ViInt32, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_CalcPowResAreaLimMatc (ViSession, ViInt32, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadSubArrPowBurs (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcSubArrPowBurs (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampSubArrPowBurs (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModOverContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModOverContDef (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModOempRPMode  (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModOempAptoffs
             (ViSession instrumentHandle_GSMNSig, ViBoolean AMPMTimingOffset,
              ViChar _VI_FAR errorMessage[]);


ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModOverLimLineDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModOverLimLineUpp (ViSession, ViInt32, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModOverLimLine95 (ViSession, ViReal64, ViReal64, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModOverCont (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModOverContRepSta (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_InitModOver (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_AborModOver (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_StopModOver (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ContModOver (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModOverErep (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcModOverStat (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ModOverRes (ViSession instrumentHandle,
                                                  ViInt32 command,
                                                  ViReal64 _VI_FAR measurementResults[],
                                                  ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadModOver (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcModOver (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampModOver (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_CalcModOverLimMatc (ViSession, ViInt32, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModEvmContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModEvmContDef (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModEvmLimLineDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModEvmLimLineUpp (ViSession, ViInt32, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModEvmLimLine95 (ViSession, ViReal64, ViReal64, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModEvmCont (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModEvmContRepSta (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSubModEvmRang (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_InitModEvm (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_AborModEvm (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_StopModEvm (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ContModEvm (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModEvmErep (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcModEvmStat (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadModEvm (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcModEvm (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampModEvm (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_CalcModEvmLimMatc (ViSession, ViInt32, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadArrModEvm (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcArrModEvm (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampArrModEvm (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadSubArrModEvm (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcSubArrModEvm (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampSubArrModEvm (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModPerrContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModPerrContDef (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModPerrLimLineDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModPerrLimLineUpp (ViSession, ViInt32, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModPerrLimLine95 (ViSession, ViReal64, ViReal64, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModPerrCont (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModPerrContRepSta (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSubModPerrRang (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_InitModPerr (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_AborModPerr (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_StopModPerr (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ContModPerr (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModPerrErep (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcModPerrStat (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadModPerr (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcModPerr (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampModPerr (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_CalcModPerrLimMatc (ViSession, ViInt32, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadArrModPerr (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcArrModPerr (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampArrModPerr (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadSubArrModPerr (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcSubArrModPerr (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampSubArrModPerr (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModMerrContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModMerrContDef (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModMerrLimLineDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModMerrLimLineUpp (ViSession, ViInt32, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModMerrLimLine95 (ViSession, ViReal64, ViReal64, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModMerrCont (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModMerrContRepSta (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSubModMerrRang (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_InitModMerr (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_AborModMerr (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_StopModMerr (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ContModMerr (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfModMerrErep (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcModMerrStat (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadModMerr (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcModMerr (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampModMerr (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_CalcModMerrLimMatc (ViSession, ViInt32, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadArrModMerr (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcArrModMerr (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampArrModMerr (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadSubArrModMerr (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcSubArrModMerr (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampSubArrModMerr (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecSwitContDef  (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecSwitContRep  (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_SpecSwitContStatMod (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SpecSwitSlotCount   (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_DispSpecSwitContGrid (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecSwitLimLinDef (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecSwitLimLine   (ViSession, ViInt32, ViReal64, ViInt32, ViReal64, ViReal64, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecSwitLimLinMod (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecSwitCont      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecSwitContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecSwitContMpo  (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSubSpecSwit  (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_InitSpecSwit       (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_AborSpecSwit       (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_StopSpecSwit       (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ContSpecSwit       (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcSpecSwitStat   (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecSwitErep   (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadSpecSwit     (ViSession, ViReal64*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcSpecSwit     (ViSession, ViReal64*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampSpecSwit     (ViSession, ViReal64*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadArrSpecSwit    (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcArrSpecSwit    (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampArrSpecSwit     (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadSubArrSpecSwit (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcSubArrSpecSwit (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampSubArrSpecSwit (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecSwitConfAMP (ViSession,ViInt32,ViReal64,ViInt32,ViReal64,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcSpecSwitAMP (ViSession,ViReal64*,ViReal64*,ViReal64*,ViReal64*,ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecModContDef (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecModContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_DispSpecModContGrid (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecModLimLineDef (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecModLimLinRefp (ViSession, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecModLimLine    (ViSession, ViInt32, ViInt32, ViReal64, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecModLimLineMod (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecModCont    (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecModContRepSta (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecModContMpo (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSubSpecMod     (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_InitSpecMod        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_AborSpecMod        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_StopSpecMod        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_ContSpecMod        (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcSpecModStat    (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ConfSpecModErep    (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadSpecMod        (ViSession, ViReal64*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcSpecMod        (ViSession, ViReal64*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampSpecMod        (ViSession, ViReal64*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadArrSpecMod (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcArrSpecMod (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampArrSpecMod (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_NSig_ReadSubArrSpecMod (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_FetcSubArrSpecMod (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_NSig_SampSubArrSpecMod (ViSession, ViReal64[], ViChar[]);


// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// Class: EDGE Signalling
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowTimeBoff     (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowFilt         (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowRPMode       (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowContRep      (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_DispPowContGrid     (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowLimLineDef   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowLimLineUpp   (ViSession, ViInt32, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowLimLineLow   (ViSession, ViInt32, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowLimLineUppDyn (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowLimLineLowDyn (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowLimUppDynMod  (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowLimLowDynMod  (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowCont         (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowContRepStat  (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSubPowRang      (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_InitPow             (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_AborPow             (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_StopPow             (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ContPow             (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcPowStat         (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfPowErep         (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadPow             (ViSession, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcPow             (ViSession, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampPow             (ViSession, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViReal64*, ViInt32*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_CalcPowLimMatc      (ViSession, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadArrPowBurs      (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcArrPowBurs      (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampArrPowBurs      (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadSubArrPowBurs   (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcSubArrPowBurs   (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampSubArrPowBurs   (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_CalcPowBursLimMatc    (ViSession, ViInt32, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_CalcPowResAreaLimMatc (ViSession, ViInt32, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModOverContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModOverContDef (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModOempRPMode  (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModOempAptoffs
             (ViSession instrumentHandle_GSMNSig, ViBoolean AMPMTimingOffset,
              ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModOverLimLineDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModOverLimLineUpp (ViSession, ViInt32, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModOverLimLine95 (ViSession, ViReal64, ViReal64, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModOverCont (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModOverContRepSta (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_InitModOver (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_AborModOver (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_StopModOver (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ContModOver (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModOverErep (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcModOverStat (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ModOverRes (ViSession instrumentHandle,
                                                 ViInt32 command,
                                                 ViReal64 _VI_FAR measurementResults[],
                                                 ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadModOver (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcModOver (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampModOver (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_CalcModOverLimMatc (ViSession, ViInt32, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModEvmContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModEvmContDef (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModEvmLimLineDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModEvmLimLineUpp (ViSession, ViInt32, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModEvmLimLine95 (ViSession, ViReal64, ViReal64, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModEvmCont (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModEvmContRepSta (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSubModEvmRang (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_InitModEvm (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_AborModEvm (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_StopModEvm (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ContModEvm (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModEvmErep (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcModEvmStat (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadModEvm (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcModEvm (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampModEvm (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_CalcModEvmLimMatc (ViSession, ViInt32, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadArrModEvm (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcArrModEvm (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampArrModEvm (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadSubArrModEvm (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcSubArrModEvm (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampSubArrModEvm (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModPerrContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModPerrContDef (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModPerrLimLineDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModPerrLimLineUpp (ViSession, ViInt32, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModPerrLimLine95 (ViSession, ViReal64, ViReal64, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModPerrCont (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModPerrContRepSta (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSubModPerrRang (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_InitModPerr (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_AborModPerr (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_StopModPerr (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ContModPerr (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModPerrErep (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcModPerrStat (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadModPerr (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcModPerr (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampModPerr (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_CalcModPerrLimMatc (ViSession, ViInt32, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadArrModPerr (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcArrModPerr (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampArrModPerr (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadSubArrModPerr (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcSubArrModPerr (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampSubArrModPerr (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModMerrContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModMerrContDef (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModMerrLimLineDef (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModMerrLimLineUpp (ViSession, ViInt32, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModMerrLimLine95 (ViSession, ViReal64, ViReal64, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModMerrCont (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModMerrContRepSta (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSubModMerrRang (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_InitModMerr (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_AborModMerr (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_StopModMerr (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ContModMerr (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfModMerrErep (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcModMerrStat (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadModMerr (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcModMerr (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampModMerr (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_CalcModMerrLimMatc (ViSession, ViInt32, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadArrModMerr (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcArrModMerr (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampArrModMerr (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadSubArrModMerr (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcSubArrModMerr (ViSession, ViInt32, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampSubArrModMerr (ViSession, ViInt32, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecSwitContDef  (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecSwitContRep  (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_SpecSwitContStatMod (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SpecSwitSlotCount (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_DispSpecSwitContGrid (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecSwitLimLinDef (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecSwitLimLine   (ViSession, ViInt32, ViReal64, ViInt32, ViReal64, ViReal64, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecSwitLimLinMod (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecSwitCont      (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecSwitContRepSt (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecSwitContMpo  (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSubSpecSwit  (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_InitSpecSwit       (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_AborSpecSwit       (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_StopSpecSwit       (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ContSpecSwit       (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcSpecSwitStat   (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecSwitErep   (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadSpecSwit     (ViSession, ViReal64*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcSpecSwit     (ViSession, ViReal64*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampSpecSwit     (ViSession, ViReal64*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadArrSpecSwit    (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcArrSpecSwit    (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampArrSpecSwit     (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadSubArrSpecSwit (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcSubArrSpecSwit (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampSubArrSpecSwit (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecSwitConfAMP (ViSession,ViInt32,ViReal64,ViInt32,ViReal64,ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcSpecSwitAMP (ViSession,ViReal64*,ViReal64*,ViReal64*,ViReal64*,ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecModContDef (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecModContRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_DispSpecModContGrid (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecModLimLineDef (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecModLimLinRefp (ViSession, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecModLimLine    (ViSession, ViInt32, ViInt32, ViReal64, ViReal64, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecModLimLineMod (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecModCont    (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecModContRepSta (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecModContMpo (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSubSpecMod     (ViSession, ViInt32, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_InitSpecMod        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_AborSpecMod        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_StopSpecMod        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_ContSpecMod        (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcSpecModStat    (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ConfSpecModErep    (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadSpecMod        (ViSession, ViReal64*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcSpecMod        (ViSession, ViReal64*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampSpecMod        (ViSession, ViReal64*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadArrSpecMod (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcArrSpecMod (ViSession, ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampArrSpecMod (ViSession, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU_EDGE_Sig_ReadSubArrSpecMod (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_FetcSubArrSpecMod (ViSession, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU_EDGE_Sig_SampSubArrSpecMod (ViSession, ViReal64[],ViChar[]);

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// Class: GPRS Signalling
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignPdatAct        (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensPdatStat           (ViSession, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensSignPdatServ       (ViSession, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignPdatMslChan    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignPdatAutSconf   (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignPdatMslSconf   (ViSession ,ViInt32,
                                                        ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,
                                                        ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,
                                                        ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,
                                                        ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,
                                                        ViChar[]);


ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignPdatMslMtim    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignPdatMslBsSconf (ViSession, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignPdatMslMsSconf (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignPdatMslGamma   (ViSession, ViInt32 TS0Gamma,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfMssPdatMslSconf (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfMssPdatCchPcl   (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssPdatMslP0    (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssPdatMslChan  (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_SensBssPdatMslRlev  (ViSession, ViInt32 *, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssPdatMslMtim  (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssPdatMslSconf (ViSession, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64,
                                                      ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViInt32, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssPdatFhopChan   (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcBssPdatFhopEnable (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwNSup         (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwIdenRac      (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwMainServ (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensNetwMainServ (ViSession instrumentHandle_GSMSig,
                                                  ViPInt32 mainService,
                                                  ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwB52Mode      (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatUsf      (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwPdatUSFDutyCycle (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatEda      (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatNopdu    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatSoff     (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatTwack    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatBitStr   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcNetwPdatBitStr   (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_PdatPDPContextActiv (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_PdatTavgt (ViSession instrumentHandle_GSMSig, ViInt32 tAVG_T, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_PdatBepPeriod (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_PdatTrfl (ViSession instrumentHandle_GSMSig, ViInt32 TRFL, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_PdatAct (ViSession instrumentHandle_GSMSig,
                                         ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_PdatCtrlAckType (ViSession,ViInt32,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatGprsCsch (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcNetwPdatGprsCsch (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatBpinGprs
             (ViSession instrumentHandle_GSMSig, ViInt32 BLERPollingInterval,
              ViChar _VI_FAR errorMessage[]);


ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatIncRed   (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfNetwPdatBpinEgprs
             (ViSession instrumentHandle_GSMSig, ViInt32 BLERPollingInterval,
              ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_PdatRLCMode          (ViSession, ViInt32, ViChar[]);


ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBlerRep (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBlerRLCBlockCount (ViSession,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBlerRefLev (ViSession,ViReal64,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBlerLevInd (ViSession,ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerDLResUse (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerInit (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerAbort (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerStop (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerContinue (ViSession,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerFetcStat (ViSession,ViInt32*,ViInt32*,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerErep (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerRead350   (ViSession,ViReal64*,ViReal64*,ViReal64*,ViReal64[],ViReal64[],ViReal64*,ViReal64[],ViReal64*,ViReal64*,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerFetch350  (ViSession,ViReal64*,ViReal64*,ViReal64*,ViReal64[],ViReal64[],ViReal64*,ViReal64[],ViReal64*,ViReal64*,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerSample350 (ViSession,ViReal64*,ViReal64*,ViReal64*,ViReal64[],ViReal64[],ViReal64*,ViReal64[],ViReal64*,ViReal64*,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerRead   (ViSession,ViReal64*,ViReal64*,ViReal64*,ViReal64[],ViReal64[],ViReal64*,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerFetch  (ViSession,ViReal64*,ViReal64*,ViReal64*,ViReal64[],ViReal64[],ViReal64*,ViReal64[],ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_BlerSample (ViSession,ViReal64*,ViReal64*,ViReal64*,ViReal64[],ViReal64[],ViReal64*,ViReal64[],ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMsclPdat         (ViSession, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_PdatPCMeasChan       (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadPowMprDbler   (ViSession, ViInt32, ViReal64, ViReal64*, ViInt32*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_WaitForMsAttached (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConnectToMobile   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConnectFromMobile (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_DisconnectFromCMU (ViSession, ViChar[]);


// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// Class: EGPRS Signalling
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwPdatEgprsCsch    (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwPdatPunctScheme  (ViSession,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViChar[]);


// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// DTM
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssDTMCswTS (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfBssDTMMslSconf (ViSession,ViInt32,ViReal64,ViInt32,ViReal64,ViInt32,ViReal64,ViInt32,ViReal64,
                                                    ViInt32,ViReal64,ViInt32,ViReal64,ViInt32,ViReal64,ViInt32,ViReal64,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfMssDTMMslSconf (ViSession,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,
                                                    ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,
                                                    ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcSignDTMMslSconf (ViSession,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,
                                                     ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,
                                                     ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,
                                                     ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32,
                                                     ViInt32,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ProcBssDTMSconfPower (ViSession,ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,ViChar[]);

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// AMR
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrNsbc      (ViSession,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrCmip (ViSession instrumentHandle_GSMSig,
                                             ViInt32 CMIPhase,
                                             ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrRsr (ViSession instrumentHandle_GSMSig,
                                            ViInt32 rateSetReconfigure,
                                            ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrHrCModeDL (ViSession,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrHrCModeUL (ViSession,ViInt32,ViInt32,ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrHrRSet    (ViSession,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32, ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrHrUlcmCstr (ViSession instrumentHandle_GSMSig,
                                                   ViBoolean CMCStress,
                                                   ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrFrCModeDL (ViSession,ViInt32,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbFrCModeDL (ViSession instrumentHandle_GSMSig,
                                                    ViInt32 independentValue,
                                                    ViInt32 codecModeDL,
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrFrCModeUL (ViSession,ViInt32,ViInt32,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrWbFrCModeUL (ViSession instrumentHandle_GSMSig,
                                                    ViInt32 independentValue,
                                                    ViInt32 codecModeUL,
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_NetwAmrFrRSet    (ViSession,ViInt32,ViInt32,ViInt32,ViInt32,ViInt32, ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,ViReal64,ViChar[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrHrDl (ViSession instrumentHandle_GSMSig,
                                                ViInt32 *codecMode,
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SensMssAmrHrUl (ViSession instrumentHandle_GSMSig,
                                                ViInt32 *codecMode,
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqFfacContRep (ViSession instrumentHandle,
                                                    ViInt32 repetition,
                                                    ViInt32 stopCondition,
                                                    ViInt32 stepMode,
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqFfacContDef (ViSession instrumentHandle,
                                                    ViBoolean setDefaultValues,
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqFfacLimFer (ViSession instrumentHandle,
                                                    ViReal64 repeatedFERFACCHLimit,
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqFfacContLevUtim (ViSession instrumentHandle,
                                                        ViReal64 usedTimeslot,
                                                        ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqFfacContLevUnt (ViSession instrumentHandle,
                                                       ViReal64 unusedTimeslot,
                                                       ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqFfacContMslRlev (ViSession instrumentHandle,
                                                        ViReal64 referenceLevel,
                                                        ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqRdsContMslLevInd (ViSession instrumentHandle,
                                                         ViReal64 referenceLevel[],
                                                         ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_InitRxqCmrp (ViSession instrumentHandle,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_AborRxqCmrp (ViSession instrumentHandle,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_StopRxqCmrp (ViSession instrumentHandle,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ContRxqCmrp (ViSession instrumentHandle,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ConfRxqCmrpErep (ViSession instrumentHandle,
                                                 ViInt32 measurementEventReporting,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcRxqCmrpStat (ViSession instrumentHandle,
                                                 ViInt32 *measurementStatus,
                                                 ViInt32 *counter_for_current_stat_cycle,
                                                 ViInt32 *counter_for_current_eval_period,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_ReadRxqCmrp (ViSession instrumentHandle,
                                             ViInt32 results[],
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_FetcRxqCmrp (ViSession instrumentHandle,
                                             ViInt32 results[],
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_Sig_SampRxqCmrp (ViSession instrumentHandle,
                                             ViInt32 results[],
                                             ViChar errorMessage[]);

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// Class K47 (TX / RX)
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowTxcContRep (ViSession instrumentHandle_GSMNSig,
                                                    ViInt32 repetition,
                                                    ViInt32 multipleMeasurement,
                                                    ViInt32 stopCondition,
                                                    ViInt32 stepMode,
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowTxcContDef (ViSession instrumentHandle_GSMNSig,
                                                    ViInt32 setDefaultValues,
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowTxcFreqAll (ViSession instrumentHandle_GSMNSig,
                                                    ViBoolean state[],
                                                    ViReal64 frequencyValue[],
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowTxcFreq (ViSession instrumentHandle_GSMNSig,
                                                 ViInt32 frequencyNumber,
                                                 ViReal64 frequency,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfSubPowTxc (ViSession instrumentHandle_GSMNSig,
                                                ViInt32 statisticsMode,
                                                ViReal64 startTime_bit,
                                                ViInt32 number_of_samples,
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ControlPowTxc (ViSession instrSession,
                                                ViInt32 commandNr,
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_InitPowTxc (ViSession instrumentHandle_GSMNSig,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_AborPowTxc (ViSession instrumentHandle_GSMNSig,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_StopPowTxc (ViSession instrumentHandle_GSMNSig,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ContPowTxc (ViSession instrumentHandle_GSMNSig,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ConfPowTxcErep (ViSession instrumentHandle_GSMNSig,
                                                 ViInt32 measurementEventReporting,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcScalPowTxcStat (ViSession instrumentHandle_GSMNSig,
                                                     ViInt32 *measurementStatus,
                                                     ViInt32 *counter_for_current_stat_cycle,
                                                     ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadScalPowTxc (ViSession instrumentHandle_GSMNSig,
                                                 ViInt32 timeslotNumber,
                                                 ViReal64 *averagePower,
                                                 ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_TxScalar (ViSession instrSession,
                                                 ViInt32 commandNr,
                                                 ViInt32 timeslotNumber,
                                                 ViReal64 *averagePower,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcScalPowTxcPow (ViSession instrumentHandle_GSMNSig,
                                                    ViInt32 timeslotNumber,
                                                    ViReal64 *averagePower,
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_SampScalPowTxcPow (ViSession instrumentHandle_GSMNSig,
                                                    ViInt32 timeslotNumber,
                                                    ViReal64 *averagePower,
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadArrPowTxc (ViSession instrumentHandle_GSMNSig,
                                                ViReal64 averagePower[],
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GMS_NSig_TxArray (ViSession instrSession,
                                                ViInt32 commandNr,
                                                ViReal64 averagePower[],
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcArrPowTxc (ViSession instrumentHandle_GSMNSig,
                                                ViReal64 averagePower[],
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_SampArrPowTxc (ViSession instrumentHandle_GSMNSig,
                                                ViReal64 averagePower[],
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GMS_NSig_TxSubarray (ViSession instrSession,
                                                ViInt32 commandNr,
                                                ViReal64 averagePower[],
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ReadSubPowTxc (ViSession instrumentHandle_GSMNSig,
                                                ViReal64 averagePower[],
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcSubPowTxc (ViSession instrumentHandle_GSMNSig,
                                                ViReal64 averagePower[],
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_SampSubPowTxc (ViSession instrumentHandle_GSMNSig,
                                                ViReal64 averagePower[],
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_ControlPowRxc (ViSession instrSession,
                                                ViInt32 commandNr,
                                                ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_InitRfgRxc (ViSession instrumentHandle_GSMNSig,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_AborRfgRxc (ViSession instrumentHandle_GSMNSig,
                                             ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_FetcRfgRxcStat (ViSession instrumentHandle_GSMNSig,
                                                 ViInt32 *measurementStatus,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcMode (ViSession instrumentHandle_GSMNSig,
                                                 ViInt32 levelMode,
                                                 ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcSco (ViSession instrumentHandle_GSMNSig,
                                                ViInt32 timerT1,
                                                ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcRamp (ViSession instrumentHandle_GSMNSig,
                                                 ViInt32 ramping, ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcFreqBtyp (ViSession instrumentHandle_GSMNSig,
                                                     ViInt32 frameNumber,
                                                     ViInt32 burstType,
                                                     ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcFreqFreq (ViSession instrumentHandle_GSMNSig,
                                                     ViInt32 frameNumber,
                                                     ViReal64 frequency,
                                                     ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcFreqAll (ViSession instrumentHandle_GSMNSig,
                                                    ViReal64 frequencies[],
                                                    ViInt32 slotLevels[],
                                                    ViInt32 burstTypes[],
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcFreqPlev (ViSession instrumentHandle_GSMNSig,
                                                     ViInt32 frameNumber,
                                                     ViInt32 powerLevel,
                                                     ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcPlevAll (ViSession instrumentHandle_GSMNSig,
                                                    ViReal64 relativeOutputLevel[],
                                                    ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcPlev (ViSession instrumentHandle_GSMNSig,
                                                 ViInt32 slotNumber,
                                                 ViReal64 outputLevel,
                                                 ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcRlev (ViSession instrumentHandle_GSMNSig,
                                                 ViReal64 referenceLevel,
                                                 ViChar errorMessage[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcIFLev (ViSession instrumentHandle_GSMNSig,
                                                  ViInt32 frameNumber,
                                                  ViReal64 individualFrameLevel,
                                                  ViChar errorMessage[]);

ViStatus _VI_FUNC RSCMU_GSM_NSig_SourRfgRxcIFLevAll (ViSession instrumentHandle_GSMNSig,
                                                     ViReal64 frameLevels[],
                                                     ViChar errorMessage[]);

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//          APPLICATION FUNCTIONS
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
ViStatus _VI_FUNC RSCMU_K2G_RevisionQuery (ViSession, ViChar[], ViChar[], ViChar[]);

ViStatus _VI_FUNC RSCMU_K2G_errorMessage (ViSession, ViStatus, ViChar[]);

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//          Functions for LabVIEW 5.x and higher
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#ifdef _OUTSIDEVEE_
ViStatus _VI_FUNC RSCMU_GSM_Sig_GetResourceName (ViSession, ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU_GSM_NSig_GetResourceName (ViSession, ViSession, ViChar[]);
#endif

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//          VXI PLUG & PLAY COMPATIBILITY FUNCTIONS
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#ifndef _REMVXIPNP

ViStatus _VI_FUNC RSCMU_GetInstrumentHandle (ViSession, ViSession*);
ViStatus _VI_FUNC RSCMU_initGSMNSig (ViSession, ViSession, ViUInt32);
ViStatus _VI_FUNC RSCMU_initGSMSig (ViSession, ViSession, ViUInt32);

ViStatus _VI_FUNC RSCMU_init (ViRsrc, ViBoolean, ViBoolean, ViPSession);

ViStatus _VI_FUNC RSCMU_reset (ViSession);
ViStatus _VI_FUNC RSCMU_self_test (ViSession, ViPInt16, ViChar[]);
ViStatus _VI_FUNC RSCMU_error_query (ViSession, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU_error_message (ViSession, ViStatus, ViChar[]);
ViStatus _VI_FUNC RSCMU_revision_query (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU_close (ViSession);

#endif

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//          END INCLUDE FILE
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#ifdef __cplusplus
    }
#endif

#endif



